(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     76168,       1482]
NotebookOptionsPosition[     74366,       1423]
NotebookOutlinePosition[     75168,       1450]
CellTagsIndexPosition[     75002,       1444]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Note: requires CRNSimulatorSSA.m to be loaded.", "Text",
 CellChangeTimes->{{3.521032815786957*^9, 3.521032822918911*^9}, {
  3.656288980522304*^9, 3.656288981145041*^9}}],

Cell["\<\
Note that the input format to SimulateRxnsysSSA is consistent with \
SimulateRxnsys in that a reaction system is created with rxn and conc \
statements. Arbitrary order (zero-order, unimolecular, bimolecular, etc) \
reactions are supported. The output of SimulateRxnsysSSA is a list of \
discrete times and states rather than continuous (interpolated) functions as \
in SimulateRxnsys, so ListPlot rather than Plot is used.\
\>", "Text",
 CellChangeTimes->{{3.6562890268016376`*^9, 3.656289196637195*^9}, {
  3.656291800845439*^9, 3.656291895060103*^9}, {3.661626344907495*^9, 
  3.66162639977738*^9}}],

Cell["See documentation for SimulateRxnsysSSA:", "Text",
 CellChangeTimes->{{3.656291888224341*^9, 3.656291897098534*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SimulateRxnsysSSA"}]], "Input",
 CellChangeTimes->{{3.6562918979955263`*^9, 3.656291908603574*^9}}],

Cell[BoxData[
 StyleBox["\<\"SimulateRxnsysSSA[rxnsys,endtime] runs Gillespie's SSA \
simulation of the reaction system rxnsys for time 0 to endtime or until no \
further reactions are possible. Set endtime to \[Infinity] to continue until \
no further reactions are possible. In rxnsys, reactions are specified by rxn \
statements (arbitrary order reactions are allowed: eg rxn[a+a+b,c+c,1], \
including zero-order reactions), and initial molecular counts are specified \
by conc statements. If no initial count is set for a species, its initial \
count is set to 0. SimulateRxnsysSSA returns {times, data} where times is a \
list of reaction firing times, and data is the corresponding list of states. \
The propensity of reaction a\[Rule]\[Ellipsis] is k*a, the propensity of \
reaction a+b\[Rule]\[Ellipsis] is k*a*b, and the propensity of reaction a+a\
\[Rule]\[Ellipsis] is k*a*(a-1), etc.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.662386244036934*^9},
 CellTags->"Info-1c107787-c714-488a-9013-003745bfd5c6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SSAToListPlot"}]], "Input",
 CellChangeTimes->{{3.6623861185194407`*^9, 3.662386127865602*^9}, 
   3.662386202016754*^9}],

Cell[BoxData[
 StyleBox["\<\"SSAToListPlot[{times,data}] takes the output of \
SimulateRxnsysSSA and converts it to a form that can be directly plotted \
using ListPlot, ListLinePlot, etc. SSAToListPlot[{times,data},maxpoints] \
limits the number of points to plot to maxpoints (useful for long runs).\"\>",
   "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.662386244156475*^9},
 CellTags->"Info-03fc39b2-6016-4f54-ba10-76b6b7f6bbd7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Approximate majority", "Subsection",
 CellChangeTimes->{{3.656281293809908*^9, 3.6562812973252897`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "=", "1000"}], ";"}]], "Input",
 CellChangeTimes->{{3.655586435415097*^9, 3.655586482502449*^9}, {
   3.655586534219007*^9, 3.655586546034733*^9}, 3.6555866241058292`*^9, {
   3.656252797388349*^9, 3.6562528024666147`*^9}, {3.6562531534477253`*^9, 
   3.656253154069437*^9}, {3.656253219052073*^9, 3.656253219599894*^9}, {
   3.65626635307651*^9, 3.656266354053401*^9}, {3.656333893630958*^9, 
   3.65633391813202*^9}, {3.6563340167314997`*^9, 3.656334024447117*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsys", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rxn", "[", 
      RowBox[{
       RowBox[{"x", "+", "y"}], ",", 
       RowBox[{"x", "+", "b"}], ",", 
       RowBox[{"1", "/", "n"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{
       RowBox[{"x", "+", "y"}], ",", 
       RowBox[{"y", "+", "b"}], ",", 
       RowBox[{"1", "/", "n"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{
       RowBox[{"x", "+", "b"}], ",", 
       RowBox[{"2", "x"}], ",", 
       RowBox[{"1", "/", "n"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{
       RowBox[{"y", "+", "b"}], ",", 
       RowBox[{"2", "y"}], ",", 
       RowBox[{"1", "/", "n"}]}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}], ",", 
       RowBox[{"n", "/", "2"}]}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6555693256563*^9, 3.655569375311858*^9}, {
  3.6555864443890877`*^9, 3.655586449438074*^9}, {3.6562661849876127`*^9, 
  3.6562661890404053`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Simulate", " ", "until", " ", "no", " ", "further", " ", "reactions", " ",
     "are", " ", "possible"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"times", ",", "data"}], "}"}], "=", 
    RowBox[{"SimulateRxnsysSSA", "[", 
     RowBox[{"rsys", ",", "\[Infinity]"}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.655569381302664*^9, 3.655569430982396*^9}, 
   3.655569599889739*^9, {3.655569637042144*^9, 3.655569637132442*^9}, {
   3.655570171755032*^9, 3.655570171935727*^9}, {3.655570206719384*^9, 
   3.655570210834999*^9}, {3.6555864935614853`*^9, 3.65558649360857*^9}, {
   3.655586532402664*^9, 3.655586532452038*^9}, 3.655599011066224*^9, {
   3.655599070351659*^9, 3.6555990711787157`*^9}, {3.656251704743993*^9, 
   3.6562517236909122`*^9}, 3.656252655029769*^9, {3.6562527354262733`*^9, 
   3.656252736252966*^9}, {3.656252782391427*^9, 3.656252783617483*^9}, {
   3.65625294811371*^9, 3.65625294992074*^9}, {3.656262364108659*^9, 
   3.6562623876853848`*^9}, {3.656262641047584*^9, 3.656262641688209*^9}, {
   3.656281322111396*^9, 3.656281322433421*^9}, {3.6562892839283752`*^9, 
   3.656289296750527*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Convert", " ", "the", " ", "trajectory", " ", "to", " ", "the", " ", 
     "form", " ", "used", " ", "by", " ", "ListLinePlot"}], ",", " ", 
    RowBox[{
    "and", " ", "decrease", " ", "the", " ", "number", " ", "of", " ", 
     "points", " ", "to", " ", "plot", " ", "to", " ", "at", " ", "most", " ",
      "500"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"trajectory", "=", 
    RowBox[{"SSAToListPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], ",", "500"}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.656253004745927*^9, 3.656253020630576*^9}, {
  3.656289232994705*^9, 3.656289255717132*^9}, {3.656333720452796*^9, 
  3.656333735269209*^9}, {3.656333857156747*^9, 3.656333877715708*^9}, {
  3.656333938163826*^9, 3.656333950312696*^9}, {3.662386016289863*^9, 
  3.662386097354401*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", "\[IndentingNewLine]", 
  RowBox[{"trajectory", ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.655570226317813*^9, 3.6555703863173933`*^9}, {
   3.65557042801285*^9, 3.655570460735579*^9}, {3.655570496269919*^9, 
   3.655570496948267*^9}, {3.655570562012814*^9, 3.655570596846856*^9}, {
   3.6555710100254917`*^9, 3.655571010313361*^9}, {3.655571538113305*^9, 
   3.655571565609786*^9}, {3.655572452590282*^9, 3.655572465702355*^9}, {
   3.6555725679037447`*^9, 3.6555725830927896`*^9}, 3.6555847968673267`*^9, {
   3.655584927511272*^9, 3.6555849393569183`*^9}, 3.655585400214162*^9, 
   3.655586230436507*^9, {3.655586825160666*^9, 3.655586829155188*^9}, 
   3.662386138758854*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.006944444444444445], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxdl3c41u37x0lWJNmk3PYuZKTxOGmiMkoDZZPtXlKEIiSlnmS0SFqU0NYj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         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.006944444444444445], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxV13k4lG3UAHCSJUmyExlkT00KaXkd2kRlKSUUpZJSthnGGIx9j94U2kg7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         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.006944444444444445], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxV1nk8VV33APArmSLJGNE1jykUUnosGg1lCJnKTGZ3Mk9FphQ9KSlFGh9K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         "]]}}}, {}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 28.84569377530897}, {0, 998.}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{0, 28.84569377530897}, {0, 998.}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"b", "x", "y"}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.006944444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.006944444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.006944444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.6555702867979383`*^9, 3.6555703877210913`*^9}, {
   3.655570432807827*^9, 3.65557046116155*^9}, 3.6555705997584887`*^9, 
   3.65557102170741*^9, 3.655571090058749*^9, 3.6555712042294807`*^9, 
   3.655571404862955*^9, 3.6555714702240047`*^9, {3.655571540694688*^9, 
   3.6555715603961267`*^9}, 3.6555716689080687`*^9, 3.655572468017811*^9, {
   3.655572574492649*^9, 3.655572586116308*^9}, 3.655584811704328*^9, {
   3.655584932181735*^9, 3.6555849403112288`*^9}, 3.655585401697906*^9, 
   3.655585436699802*^9, {3.6555862312916527`*^9, 3.65558623612256*^9}, 
   3.655586267786628*^9, {3.655586418718378*^9, 3.655586421722135*^9}, {
   3.655586458041861*^9, 3.655586502946805*^9}, {3.655586536399946*^9, 
   3.655586553343595*^9}, {3.655586607193935*^9, 3.655586634174013*^9}, 
   3.6555990144139233`*^9, {3.655599063506703*^9, 3.655599074047854*^9}, 
   3.6562515654547443`*^9, 3.656251652351939*^9, 3.656251694145276*^9, 
   3.6562526503731728`*^9, 3.656252739899416*^9, {3.656252777483959*^9, 
   3.656252820215271*^9}, 3.656252977747621*^9, {3.656253093816627*^9, 
   3.656253139778142*^9}, {3.656253177993581*^9, 3.656253223707402*^9}, 
   3.6562623057291527`*^9, {3.656262342281611*^9, 3.656262358439608*^9}, {
   3.656262441917123*^9, 3.6562624455620728`*^9}, 3.656262644073839*^9, 
   3.656266196534234*^9, 3.656266863069005*^9, {3.656281362488757*^9, 
   3.6562813756156397`*^9}, 3.6562922053234653`*^9, {3.656333881960925*^9, 
   3.656333919151292*^9}, {3.6563339521152887`*^9, 3.656334025507287*^9}, 
   3.661626494832946*^9, 3.6622088468534613`*^9, 3.662208891140036*^9, {
   3.662386140790585*^9, 3.662386146667905*^9}, 3.66238624453876*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Predator-prey", "Subsection",
 CellChangeTimes->{{3.656281293809908*^9, 3.6562813077924137`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "=", "300"}], ";"}]], "Input",
 CellChangeTimes->{{3.655586435415097*^9, 3.655586482502449*^9}, {
   3.655586534219007*^9, 3.655586546034733*^9}, 3.6555866241058292`*^9, {
   3.656252797388349*^9, 3.6562528024666147`*^9}, {3.6562531534477253`*^9, 
   3.656253154069437*^9}, {3.656253219052073*^9, 3.656253219599894*^9}, {
   3.65626635307651*^9, 3.656266354053401*^9}, {3.656333978583722*^9, 
   3.656334011311634*^9}, {3.662208895224642*^9, 3.662208944357786*^9}, 
   3.662218312392486*^9, {3.662218399526532*^9, 3.6622184009449387`*^9}, {
   3.662386170553523*^9, 3.662386175328332*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsys", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"rxn", "[", 
      RowBox[{
       RowBox[{"x1", "+", "x2"}], ",", 
       RowBox[{"2", "x2"}], ",", 
       RowBox[{"1", "/", "n"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{"x1", ",", 
       RowBox[{"2", "x1"}], ",", "1"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"rxn", "[", 
      RowBox[{"x2", ",", "1", ",", "1"}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"conc", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x1", ",", "x2"}], "}"}], ",", 
       RowBox[{"n", "/", "2"}]}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6555693256563*^9, 3.655569375311858*^9}, {
  3.6555864443890877`*^9, 3.655586449438074*^9}, {3.6562661849876127`*^9, 
  3.6562661890404053`*^9}, {3.656266293806223*^9, 3.656266347060748*^9}, {
  3.656266458628278*^9, 3.656266458678631*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"times", ",", "data"}], "}"}], "=", 
   RowBox[{"SimulateRxnsysSSA", "[", 
    RowBox[{"rsys", ",", "20"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.655569381302664*^9, 3.655569430982396*^9}, 
   3.655569599889739*^9, {3.655569637042144*^9, 3.655569637132442*^9}, {
   3.655570171755032*^9, 3.655570171935727*^9}, {3.655570206719384*^9, 
   3.655570210834999*^9}, {3.6555864935614853`*^9, 3.65558649360857*^9}, {
   3.655586532402664*^9, 3.655586532452038*^9}, 3.655599011066224*^9, {
   3.655599070351659*^9, 3.6555990711787157`*^9}, {3.656251704743993*^9, 
   3.6562517236909122`*^9}, 3.656252655029769*^9, {3.6562527354262733`*^9, 
   3.656252736252966*^9}, {3.656252782391427*^9, 3.656252783617483*^9}, {
   3.65625294811371*^9, 3.65625294992074*^9}, {3.656262364108659*^9, 
   3.6562623876853848`*^9}, {3.656262641047584*^9, 3.656262641688209*^9}, {
   3.656266370567904*^9, 3.656266391544516*^9}, {3.6562664424865522`*^9, 
   3.656266469057404*^9}, {3.65628132708134*^9, 3.656281353746784*^9}, {
   3.662208952011924*^9, 3.662208952089623*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Convert", " ", "the", " ", "trajectory", " ", "to", " ", "the", " ", 
     "form", " ", "used", " ", "by", " ", "ListLinePlot"}], ",", " ", 
    RowBox[{
    "and", " ", "decrease", " ", "the", " ", "number", " ", "of", " ", 
     "points", " ", "to", " ", "plot", " ", "to", " ", "at", " ", "most", " ",
      "500"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"trajectory", "=", 
    RowBox[{"SSAToListPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], ",", "500"}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.656253004745927*^9, 3.656253020630576*^9}, {
  3.656289232994705*^9, 3.656289255717132*^9}, {3.656333720452796*^9, 
  3.656333735269209*^9}, {3.656333857156747*^9, 3.656333877715708*^9}, {
  3.656333938163826*^9, 3.656333950312696*^9}, {3.662386016289863*^9, 
  3.662386097354401*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", "\[IndentingNewLine]", 
  RowBox[{"trajectory", ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.655570226317813*^9, 3.6555703863173933`*^9}, {
   3.65557042801285*^9, 3.655570460735579*^9}, {3.655570496269919*^9, 
   3.655570496948267*^9}, {3.655570562012814*^9, 3.655570596846856*^9}, {
   3.6555710100254917`*^9, 3.655571010313361*^9}, {3.655571538113305*^9, 
   3.655571565609786*^9}, {3.655572452590282*^9, 3.655572465702355*^9}, {
   3.6555725679037447`*^9, 3.6555725830927896`*^9}, 3.6555847968673267`*^9, {
   3.655584927511272*^9, 3.6555849393569183`*^9}, 3.655585400214162*^9, 
   3.655586230436507*^9, {3.655586825160666*^9, 3.655586829155188*^9}, {
   3.662386160961955*^9, 3.662386163210033*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.006944444444444445], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxV13c81W34B/CjoSkq2YqmoqLdk/F52kMiGREO2SR7j4PjHFkpIxo6DaWh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         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.006944444444444445], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJxV13c81W38P/CjvUQlmXW0KKqj3Z143e2hIoUIx57p2GQdHBwzZURDGtqK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         "]]}}}, {}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 19.950880585060826`}, {0, 917.}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], Method -> {}, 
     PlotRange -> {{0, 19.950880585060826`}, {0, 917.}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"x1", "x2"}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.125], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.006944444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.006944444444444445`", "]"}], 
                   ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.6555702867979383`*^9, 3.6555703877210913`*^9}, {
   3.655570432807827*^9, 3.65557046116155*^9}, 3.6555705997584887`*^9, 
   3.65557102170741*^9, 3.655571090058749*^9, 3.6555712042294807`*^9, 
   3.655571404862955*^9, 3.6555714702240047`*^9, {3.655571540694688*^9, 
   3.6555715603961267`*^9}, 3.6555716689080687`*^9, 3.655572468017811*^9, {
   3.655572574492649*^9, 3.655572586116308*^9}, 3.655584811704328*^9, {
   3.655584932181735*^9, 3.6555849403112288`*^9}, 3.655585401697906*^9, 
   3.655585436699802*^9, {3.6555862312916527`*^9, 3.65558623612256*^9}, 
   3.655586267786628*^9, {3.655586418718378*^9, 3.655586421722135*^9}, {
   3.655586458041861*^9, 3.655586502946805*^9}, {3.655586536399946*^9, 
   3.655586553343595*^9}, {3.655586607193935*^9, 3.655586634174013*^9}, 
   3.6555990144139233`*^9, {3.655599063506703*^9, 3.655599074047854*^9}, 
   3.6562515654547443`*^9, 3.656251652351939*^9, 3.656251694145276*^9, 
   3.6562526503731728`*^9, 3.656252739899416*^9, {3.656252777483959*^9, 
   3.656252820215271*^9}, 3.656252977747621*^9, {3.656253093816627*^9, 
   3.656253139778142*^9}, {3.656253177993581*^9, 3.656253223707402*^9}, 
   3.6562623057291527`*^9, {3.656262342281611*^9, 3.656262358439608*^9}, {
   3.656262441917123*^9, 3.6562624455620728`*^9}, 3.656262644073839*^9, 
   3.656266196534234*^9, {3.656266440430071*^9, 3.656266486865638*^9}, {
   3.656281362905364*^9, 3.656281376126685*^9}, 3.6562922061254587`*^9, {
   3.656333882477515*^9, 3.656333919626462*^9}, {3.6563339525446367`*^9, 
   3.656334025905734*^9}, 3.661626495544998*^9, 3.662208847208056*^9, {
   3.662208891594365*^9, 3.662208954768146*^9}, 3.662218316648004*^9, 
   3.662218409344439*^9, {3.662386166472884*^9, 3.662386177432085*^9}, 
   3.662386244926669*^9}]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{638, 736},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 10, \
2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info-1c107787-c714-488a-9013-003745bfd5c6"->{
  Cell[1631, 45, 1031, 14, 178, "Print",
   CellTags->"Info-1c107787-c714-488a-9013-003745bfd5c6"]},
 "Info-03fc39b2-6016-4f54-ba10-76b6b7f6bbd7"->{
  Cell[2852, 69, 440, 7, 78, "Print",
   CellTags->"Info-03fc39b2-6016-4f54-ba10-76b6b7f6bbd7"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info-1c107787-c714-488a-9013-003745bfd5c6", 74732, 1435},
 {"Info-03fc39b2-6016-4f54-ba10-76b6b7f6bbd7", 74881, 1438}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 177, 2, 30, "Text"],
Cell[738, 24, 612, 10, 106, "Text"],
Cell[1353, 36, 122, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[1500, 41, 128, 2, 28, "Input"],
Cell[1631, 45, 1031, 14, 178, "Print",
 CellTags->"Info-1c107787-c714-488a-9013-003745bfd5c6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2699, 64, 150, 3, 28, "Input"],
Cell[2852, 69, 440, 7, 78, "Print",
 CellTags->"Info-03fc39b2-6016-4f54-ba10-76b6b7f6bbd7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3329, 81, 110, 1, 44, "Subsection"],
Cell[3442, 84, 506, 8, 28, "Input"],
Cell[3951, 94, 1213, 33, 131, "Input"],
Cell[5167, 129, 1234, 23, 46, "Input"],
Cell[6404, 154, 940, 22, 63, "Input"],
Cell[CellGroupData[{
Cell[7369, 180, 965, 16, 80, "Input"],
Cell[8337, 198, 35194, 638, 245, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[43580, 842, 103, 1, 44, "Subsection"],
Cell[43686, 845, 628, 10, 28, "Input"],
Cell[44317, 857, 989, 24, 114, "Input"],
Cell[45309, 883, 1121, 19, 28, "Input"],
Cell[46433, 904, 940, 22, 63, "Input"],
Cell[CellGroupData[{
Cell[47398, 930, 989, 16, 80, "Input"],
Cell[48390, 948, 25948, 471, 248, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
