(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   5822411,     123040]
NotebookOptionsPosition[   5810905,     122842]
NotebookOutlinePosition[   5811242,     122857]
CellTagsIndexPosition[   5811199,     122854]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This Mathematica notebook (RecognizingAndGeneratingPatterns.nb) accompanies \
the article \[OpenCurlyDoubleQuote]Chemical Reaction Networks and Stochastic \
Local Search\[CloseCurlyDoubleQuote] (DNA 25, LNCS vol 11648, pp 1-20, 2019) \
by Erik Winfree, who is also the author of the notebook.   To use this \
notebook, first open and execute the initialization cells of \
CircuitsAndFormulas.nb, which will load David Soloveichik\[CloseCurlyQuote]s \
CRN simulator (as enhanced by me) as well as the WalkSATCRN definitions.\
\>", "Text",
 CellChangeTimes->{{3.7731345194022903`*^9, 3.7731346761403522`*^9}, {
  3.773134715066553*^9, 3.77313475194668*^9}, {3.773165491221787*^9, 
  3.7731656627009563`*^9}, {3.773165781403113*^9, 3.773165926870805*^9}, {
  3.773165958446312*^9, 3.773165987968218*^9}, {3.773166098232452*^9, 
  3.773166116149541*^9}, {3.773166153960567*^9, 3.7731661678560467`*^9}, {
  3.7733259189541407`*^9, 3.77332599232587*^9}, {3.773549221010396*^9, 
  3.7735492218740683`*^9}, {3.7735493375630903`*^9, 3.773549448093026*^9}, {
  3.77366948943023*^9, 3.773669490815489*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"07a9c1e2-ad94-4f25-ab88-8408d0d895bb"],

Cell[CellGroupData[{

Cell["Networks of Relations", "Section",
 CellChangeTimes->{{3.680209931402063*^9, 3.68020993828316*^9}, {
   3.680272869980444*^9, 3.680272870641974*^9}, {3.6802729072000227`*^9, 
   3.6802729075839663`*^9}, {3.680737689193554*^9, 3.680737699038948*^9}, 
   3.773578009290552*^9},ExpressionUUID->"4a485d40-6bec-460b-a8fe-\
c11fd994f9c1"],

Cell[TextData[{
 "Matt Cook\[CloseCurlyQuote]s 2005 PhD thesis, \
\[OpenCurlyDoubleQuote]Networks of relations\[CloseCurlyDoubleQuote], \
investigates an alternative standard form for predicates, where a Boolean \
formula is expressed as a conjunction of low-arity relations, and a relation \
on variables X,Y,Z is just a lookup-table of allowed combinations of X, Y, Z. \
 (A standard disjunction, as used in a CNF expression, is a relation that \
disallows just one combination.)  \n\nFor random relations, we parameterize \
by k, the number of variables involved, and h, the number of allowed \
combinations of those variables.  Like random k-SAT problems, we sample \
without replacement (i.e. all k variables in a relation must be distinct, and \
h distinct combinations are chosen; but it is possible that the same k \
variables will be chosen for another relation).  Note that h=7 essentially \
results in a CNF expression, since in both cases exactly one combination is \
outlawed.\n\nNetworks of relations have the standard form And[ relation1, \
relation2, relation3, ...] where relation_i = Or[combination1, combination2, \
...] and combination_i = And[literal1, literal2, ...].  I.e. it is nested \
And-Or-And, where all the combinations within a given relation have the same \
variables and list all variables. \n\nThere is a technical problem though:  \
if a relation allows exactly one combination, then ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " will simplify to remove the Or.   Thus, all singleton relations will pop \
up to top level, where each term of the combination will directly assert a \
value for a particular variable.  These are not so interesting as networks of \
relations, but our code needs to handle them properly."
}], "Text",
 CellChangeTimes->{{3.6807469496218653`*^9, 3.68074698915353*^9}, {
  3.680747027684188*^9, 3.680747147453773*^9}, {3.681499880215797*^9, 
  3.681499928215541*^9}, {3.6816067142018747`*^9, 3.6816068300929728`*^9}, {
  3.681606860983522*^9, 3.6816069014268293`*^9}, {3.6816073856050653`*^9, 
  3.6816074521878557`*^9}, {3.6816077367121553`*^9, 3.681607802913294*^9}, {
  3.681678085630711*^9, 3.681678115205966*^9}, {3.681680321171743*^9, 
  3.681680374487686*^9}, {3.773578046305632*^9, 3.77357806615973*^9}, {
  3.77357819830581*^9, 3.7735781984479933`*^9}, {3.773578231733852*^9, 
  3.773578244144314*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"ae684848-15bf-40b4-bb80-08c2ccece031"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomNetworkOfRelations", "[", 
   RowBox[{"k_", ",", "h_", ",", "Nvars_", ",", "Mrelations_"}], "]"}], ":=", 
  
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"vars", ",", "options", ",", "term", ",", "potato"}], "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"vars", "=", 
      RowBox[{"StandardVariables", "[", "Nvars", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"options", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"IntegerDigits", "[", 
         RowBox[{"#", ",", "2", ",", "k"}], "]"}], "&"}], " ", "/@", " ", 
       RowBox[{"Range", "[", 
        RowBox[{"2", "^", "k"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"term", "[", 
       RowBox[{"wires_", ",", "yn_"}], "]"}], " ", ":=", " ", 
      RowBox[{"And", " ", "@@", 
       RowBox[{"MapThread", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#1", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"0", "\[Rule]", 
               RowBox[{"Not", "[", "#2", "]"}]}], ",", 
              RowBox[{"1", "\[Rule]", "#2"}]}], "}"}]}], ")"}], "&"}], ",", 
         RowBox[{"{", 
          RowBox[{"yn", ",", "wires"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"potato", "[", "wires_", "]"}], ":=", 
      RowBox[{"Or", " ", "@@", " ", 
       RowBox[{"RandomSample", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"term", "[", 
            RowBox[{"wires", ",", "#"}], "]"}], "&"}], " ", "/@", " ", 
          "options"}], ",", "h"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"And", " ", "@@", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"potato", "[", 
         RowBox[{"RandomSample", "[", 
          RowBox[{"vars", ",", "k"}], "]"}], "]"}], ",", 
        RowBox[{"{", "Mrelations", "}"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.680721426662169*^9, 3.680721475828668*^9}, {
  3.680721565578004*^9, 3.68072168617736*^9}, {3.680721761136931*^9, 
  3.680721772217637*^9}, {3.680721941293428*^9, 3.680721943876987*^9}, {
  3.6807219753121223`*^9, 3.6807220123429003`*^9}, {3.680722185945175*^9, 
  3.68072220895612*^9}, {3.68072242263768*^9, 3.680722537059044*^9}, {
  3.680722611864402*^9, 3.680722703529517*^9}, {3.680722973267057*^9, 
  3.680723096506195*^9}, {3.6807235259840727`*^9, 3.680723558422318*^9}, {
  3.680723596860284*^9, 3.680723611883181*^9}, {3.680723844537498*^9, 
  3.680723865983735*^9}, {3.6807291657346582`*^9, 3.6807291675331507`*^9}, {
  3.681486572719243*^9, 3.681486595036066*^9}, {3.773578126741935*^9, 
  3.773578143832169*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"b07be64a-a142-4f4e-a769-58c20b03ad13"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nor", "=", 
  RowBox[{"RandomNetworkOfRelations", "[", 
   RowBox[{"3", ",", "3", ",", "20", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6807227128986597`*^9, 3.680722730547319*^9}, {
   3.680723117022106*^9, 3.680723117356007*^9}, {3.6807235410233393`*^9, 
   3.680723551110384*^9}, {3.6807239064672537`*^9, 3.680723916232854*^9}, 
   3.681446115395947*^9, {3.681446284852186*^9, 3.681446285314765*^9}, {
   3.681486603051464*^9, 3.681486610650522*^9}, {3.773582034929627*^9, 
   3.7735820658324966`*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"8d653884-393b-45fe-9fce-bb385e0d927b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x02"}], "&&", "x18", "&&", 
      RowBox[{"!", "x01"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"x02", "&&", 
      RowBox[{"!", "x18"}], "&&", 
      RowBox[{"!", "x01"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"x02", "&&", 
      RowBox[{"!", "x18"}], "&&", "x01"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x18"}], "&&", 
      RowBox[{"!", "x10"}], "&&", 
      RowBox[{"!", "x16"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x18"}], "&&", "x10", "&&", 
      RowBox[{"!", "x16"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "x18"}], "&&", "x10", "&&", "x16"}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.6886778021530457`*^9, 3.773578167558362*^9, 3.773582001111947*^9, {
   3.773582035432646*^9, 3.773582066274817*^9}},
 CellLabel->"Out[98]=",ExpressionUUID->"f1f420bf-e89d-4b57-a13a-8ba2efd8c83d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiableQ", "[", "nor", "]"}]], "Input",
 CellChangeTimes->{{3.680723336748096*^9, 3.680723341612297*^9}, {
  3.680723911705722*^9, 3.6807239121374702`*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"900e5f6f-9b54-4998-8e2b-efdf2d4ad3d6"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.68072334213134*^9, {3.680723903884577*^9, 3.680723924003417*^9}, 
   3.681440142220023*^9, 3.681486620306408*^9, 3.681874910719171*^9, 
   3.682061506575118*^9, 3.688677804582766*^9, 3.77357818216175*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"fed2eef6-25b6-4c45-901a-be33dfa2ff34"]
}, Open  ]],

Cell["\<\
It appears that SatisfiableQ[ ] is especially efficient when Boolean formulas \
are preprocessed into CNF form.\
\>", "Text",
 CellChangeTimes->{{3.680746879639876*^9, 3.680746905888817*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"51de36eb-1ea3-4699-acdf-d3b090672476"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ConjunctiveNormalForm", "[", "f_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Not", "[", 
    RowBox[{"LogicalExpand", "[", 
     RowBox[{"Not", "[", "f", "]"}], "]"}], "]"}], "//.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Not", "[", "a_Or", "]"}], "\[RuleDelayed]", 
      RowBox[{"And", "@@", 
       RowBox[{"(", 
        RowBox[{"Not", "/@", 
         RowBox[{"List", "@@", "a"}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"Not", "[", "a_And", "]"}], "\[RuleDelayed]", 
      RowBox[{"Or", "@@", 
       RowBox[{"(", 
        RowBox[{"Not", "/@", 
         RowBox[{"List", "@@", "a"}]}], ")"}]}]}]}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.680727796771617*^9, 3.680727807172724*^9}, {
  3.680727974616045*^9, 3.680727975064106*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"47fa993e-aa3d-4ae7-8c00-358f926f08b9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ConjunctiveNormalForm", "[", "nor", "]"}]], "Input",
 CellChangeTimes->{{3.680727978376876*^9, 3.680727985056321*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"31330635-9988-45f4-9628-f11378ea9095"],

Cell[BoxData[
 RowBox[{
  RowBox[{"!", "x18"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"!", "x16"}], "||", "x10"}], ")"}], "&&", "x02"}]], "Output",
 CellChangeTimes->{{3.680727985458808*^9, 3.680728041768593*^9}, 
   3.681440149621784*^9, {3.681486635017737*^9, 3.6814866370591183`*^9}, 
   3.6815995631577177`*^9, 3.681874939141963*^9, 3.773579331447082*^9, 
   3.773582005527802*^9, {3.773582043555094*^9, 3.773582070072586*^9}},
 CellLabel->"Out[99]=",ExpressionUUID->"990d5dd9-de01-465c-b122-9490ef746297"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"CompareNoRFormats", "[", 
   RowBox[{"k_", ",", "h_", ",", "Nvars_", ",", "Mrelations_"}], "]"}], ":=", 
  
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"nor", "=", 
      RowBox[{"RandomNetworkOfRelations", "[", 
       RowBox[{"k", ",", "h", ",", "Nvars", ",", "Mrelations"}], "]"}]}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"Timing", "[", 
       RowBox[{"SatisfiableQ", "[", 
        RowBox[{"nor", ",", 
         RowBox[{"StandardVariables", "[", "Nvars", "]"}]}], "]"}], "]"}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"Timing", "[", 
       RowBox[{"SatisfiableQ", "[", 
        RowBox[{
         RowBox[{"ConjunctiveNormalForm", "[", "nor", "]"}], ",", 
         RowBox[{"StandardVariables", "[", "Nvars", "]"}]}], "]"}], "]"}], 
      "]"}], ";"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6807280557605047`*^9, 3.680728207809374*^9}, {
  3.6814866503143883`*^9, 3.681486650394684*^9}, {3.681679737040452*^9, 
  3.681679774385632*^9}, {3.773579351533491*^9, 3.7735794008102617`*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"5c67d52e-6f10-498f-b591-978745ebec09"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompareNoRFormats", "[", 
  RowBox[{"3", ",", "5", ",", "50", ",", "50"}], "]"}]], "Input",
 CellChangeTimes->{{3.6807282136921062`*^9, 3.680728267711443*^9}, {
   3.6807283604214373`*^9, 3.6807283604923067`*^9}, {3.681679797012672*^9, 
   3.681679800562414*^9}, 3.773579416635757*^9, {3.773579458523588*^9, 
   3.773579459390943*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"3f0e9785-b05e-427d-86ca-d2944ce22bcb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"70.193513`", ",", "False"}], "}"}]], "Print",
 CellChangeTimes->{{3.7735794233351183`*^9, 3.7735794531254673`*^9}, 
   3.773579530709531*^9},
 CellLabel->
  "During evaluation of \
In[82]:=",ExpressionUUID->"644df2e6-d6f3-4308-b11b-392a136d8e86"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.040598`", ",", "False"}], "}"}]], "Print",
 CellChangeTimes->{{3.7735794233351183`*^9, 3.7735794531254673`*^9}, 
   3.7735795307653427`*^9},
 CellLabel->
  "During evaluation of \
In[82]:=",ExpressionUUID->"95d4c9e6-9c0a-4577-b3c7-8f1ea6143104"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Associative Memories for Images", "Section",
 CellChangeTimes->{{3.682883960591103*^9, 3.682883967305956*^9}, {
  3.7736919444568653`*^9, 
  3.773691949591926*^9}},ExpressionUUID->"97e060b4-fa6f-4252-817c-\
614ae7f5d133"],

Cell["\<\
Now we will watch the deducer \[OpenCurlyDoubleQuote]thinking\
\[CloseCurlyDoubleQuote] as an associative memory:  following an example that \
Matt Cook developed in his graduate student days.  Consider a set of binary \
images.  Each pixel is a variable. Consider groups of variables -- e.g. \
triplets of nearby pixels -- and consider them as a relation.  Or rather, \
consider the relation between them, given a collection of \
\[OpenCurlyDoubleQuote]memory images\[CloseCurlyDoubleQuote].  All the bit \
combinations that occur in the known images will be permitted by the \
relation, and none other.  Now, given values for one or a few pixels, we can \
deduce what some other pixels MUST be.   Each new pixel triggers a cascade of \
new inferences.  This ought to be the natural behavior of a SAT-solver.  

Note that if too few relations are imposed, then there will be many more \
solutions to the network of relations than just the given memory images.  So, \
to take this approach, one must have enough constraints imposed by the \
relations.  We will in fact take a completely random approach:  randomly \
select pixel triples and add the associated relation (subject to guaranteed \
coverage of each pixel).  If the given memories are not the EXACT set of \
solutions, then increase the coverage.  (If this does not ever happen, as may \
be the case if there are too many memories, then one must increase from \
triples to quadruples, etc.)  \
\>", "Text",
 CellChangeTimes->{{3.681599966088789*^9, 3.681599985720096*^9}, {
  3.6816000264351873`*^9, 3.6816000319302683`*^9}, {3.681600122118102*^9, 
  3.68160016925455*^9}, {3.681600403519821*^9, 3.68160055413632*^9}, {
  3.773581388172679*^9, 3.773581601713944*^9}, {3.773581949121195*^9, 
  3.773581959367587*^9}, {3.773582102175932*^9, 3.773582102331246*^9}, {
  3.773582375890552*^9, 3.7735824150534363`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"0c500a1b-c2f1-41b2-bb15-6e5aa100191b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ImageVar", "[", 
   RowBox[{"{", 
    RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", 
  RowBox[{"ToExpression", "[", 
   RowBox[{"\"\<pix\>\"", "<>", 
    RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\<v\>\"", "<>", 
    RowBox[{"ToString", "[", "j", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ImageCombination", "[", 
   RowBox[{"pixels_", ",", "value_"}], "]"}], ":=", 
  RowBox[{"And", "@@", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"#2", "\[Equal]", "1"}], ",", 
        RowBox[{"ImageVar", "[", "#1", "]"}], ",", 
        RowBox[{"Not", "[", 
         RowBox[{"ImageVar", "[", "#1", "]"}], "]"}]}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"pixels", ",", "value"}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ImageRelation", "[", 
   RowBox[{"pixels_", ",", "values_"}], "]"}], ":=", 
  RowBox[{"Or", "@@", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ImageCombination", "[", 
       RowBox[{"pixels", ",", "#"}], "]"}], "&"}], ",", " ", "values"}], 
    "]"}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.68021565999244*^9, 3.680215750241291*^9}, {
   3.6802158052863903`*^9, 3.6802158385740547`*^9}, {3.680396720762792*^9, 
   3.680396724069549*^9}, {3.680398097632565*^9, 3.680398152164218*^9}, {
   3.680398268166543*^9, 3.680398298490245*^9}, {3.6803984139021463`*^9, 
   3.680398421516244*^9}, {3.68039845789701*^9, 3.680398480702437*^9}, {
   3.681412963952653*^9, 3.6814129745989733`*^9}, {3.681413251959447*^9, 
   3.681413316831092*^9}, {3.6814134642722692`*^9, 3.681413490404778*^9}, {
   3.681431818398024*^9, 3.681431843083418*^9}, {3.681502613050127*^9, 
   3.68150268022546*^9}, {3.681502726228442*^9, 3.681502772041398*^9}, {
   3.681502858841318*^9, 3.681502875055496*^9}, {3.681503050125663*^9, 
   3.6815031353248663`*^9}, {3.6815035862840633`*^9, 3.681503694780457*^9}, {
   3.681503739418647*^9, 3.68150397454366*^9}, {3.6815040148583107`*^9, 
   3.681504038895832*^9}, {3.6815040697362127`*^9, 3.681504072349462*^9}, {
   3.68150412010783*^9, 3.681504144080656*^9}, {3.6815041842556763`*^9, 
   3.6815042803584547`*^9}, {3.681521057225382*^9, 3.681521088591481*^9}, {
   3.681521161943376*^9, 3.6815211858890553`*^9}, {3.681521254095139*^9, 
   3.6815212957814417`*^9}, {3.681521330564622*^9, 3.681521350994069*^9}, {
   3.681521516802969*^9, 3.681521617670149*^9}, {3.6815216976708508`*^9, 
   3.681521699637886*^9}, {3.681521796384542*^9, 3.681521837485147*^9}, {
   3.681603218784536*^9, 3.68160322540489*^9}, 3.681603343899156*^9, {
   3.681603446636636*^9, 3.681603491235497*^9}, {3.68161342331843*^9, 
   3.681613602988584*^9}, {3.7735817629916*^9, 3.7735817637786913`*^9}, 
   3.773581812771055*^9},ExpressionUUID->"01a2480c-8721-427b-8bb8-\
16ce2be3462d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomWiredImageMemory", "[", 
   RowBox[{"images_", ",", 
    RowBox[{"coverage_:", "1"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "width", ",", "height", ",", "num", ",", "vars", ",", "pixels", ",", 
      "pixelneighbors"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"width", "=", 
      RowBox[{"Length", "[", 
       RowBox[{
        RowBox[{"First", "[", "images", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", " ", 
     RowBox[{"height", "=", 
      RowBox[{"Length", "[", 
       RowBox[{"First", "[", "images", "]"}], "]"}]}], ";", 
     RowBox[{"num", "=", 
      RowBox[{"Length", "[", "images", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vars", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"ImageVar", "[", 
           RowBox[{"{", 
            RowBox[{"i", ",", "j"}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "width"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "height"}], "}"}]}], "]"}], ",", "1"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"pixels", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "width"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "height"}], "}"}]}], "]"}], ",", "1"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"pixelneighbors", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "}"}], ",", 
            RowBox[{"RandomSample", "[", 
             RowBox[{
              RowBox[{"Complement", "[", 
               RowBox[{"pixels", ",", 
                RowBox[{"{", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "j"}], "}"}], "}"}]}], "]"}], ",", "2"}], 
             "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", "width"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "height"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", "coverage", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"And", "@@", 
      RowBox[{"Join", " ", "@@", 
       RowBox[{"(", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{
            RowBox[{"Table", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"ImageRelation", "[", 
               RowBox[{
                RowBox[{"#", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "j"}], "]"}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Union", "[", 
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"images", "[", 
                    RowBox[{"[", 
                    RowBox[{"n", ",", 
                    RowBox[{"Last", "[", "#", "]"}], ",", 
                    RowBox[{"First", "[", "#", "]"}]}], "]"}], "]"}], "&"}], "/@", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
                   RowBox[{"{", 
                    RowBox[{"n", ",", "num"}], "}"}]}], "]"}], "]"}]}], "]"}],
               ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{"i", ",", "1", ",", "width"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", "1", ",", "height"}], "}"}]}], "]"}], ",", 
            "1"}], "]"}], "&"}], "\[IndentingNewLine]", "/@", " ", 
         "pixelneighbors"}], "\[IndentingNewLine]", ")"}]}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.682073257985998*^9, 3.682073300186923*^9}, {
   3.682073361268417*^9, 3.6820733769784117`*^9}, {3.6820734355422363`*^9, 
   3.682073585838285*^9}, {3.682073701690791*^9, 3.6820738238580303`*^9}, {
   3.682076018978155*^9, 3.6820760575784683`*^9}, {3.682076349747355*^9, 
   3.6820763782959414`*^9}, {3.682076417109178*^9, 3.682076547257526*^9}, {
   3.682076583706328*^9, 3.682076587785956*^9}, 3.682076691039549*^9, {
   3.682076723913808*^9, 3.6820767422159023`*^9}, {3.6820855414078083`*^9, 
   3.682085658395608*^9}, 3.682085688858823*^9, {3.6820857660611467`*^9, 
   3.682085766459145*^9}, 3.7735817954576817`*^9, {3.773582354142603*^9, 
   3.773582361738641*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"1648ca59-5466-45f4-9161-3aec6bb30216"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"iPlus", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iCross", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iTriangle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iCircle", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iDash", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"testimages", "=", 
   RowBox[{"{", 
    RowBox[{
    "iPlus", ",", "iCross", ",", "iTriangle", ",", "iCircle", ",", "iDash"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Image", "/@", "testimages"}]}], "Input",
 CellChangeTimes->{{3.681502995888752*^9, 3.6815030252025127`*^9}, {
  3.681504347906925*^9, 3.6815043481860857`*^9}, {3.681521369091845*^9, 
  3.681521495297245*^9}, {3.681521725175042*^9, 3.681521757277741*^9}, {
  3.7735825965848703`*^9, 3.773582613295074*^9}, {3.773584608605895*^9, 
  3.773584614561957*^9}},
 CellLabel->
  "In[146]:=",ExpressionUUID->"3ff80e14-b438-461d-a18d-2f302615376f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    TagBox[
     RasterBox[
      RawArray["Real32",{{0., 1., 0.}, {1., 1., 1.}, {0., 1., 0.}}], {{0, 
      3}, {3, 0}}, {0., 1.},
      ColorFunction->GrayLevel],
     BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSizeRaw->{3, 3},
    PlotRange->{{0, 3}, {0, 3}}], ",", 
   GraphicsBox[
    TagBox[
     RasterBox[
      RawArray["Real32",{{1., 0., 1.}, {0., 1., 0.}, {1., 0., 1.}}], {{0, 
      3}, {3, 0}}, {0., 1.},
      ColorFunction->GrayLevel],
     BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSizeRaw->{3, 3},
    PlotRange->{{0, 3}, {0, 3}}], ",", 
   GraphicsBox[
    TagBox[
     RasterBox[
      RawArray["Real32",{{1., 1., 1.}, {0., 1., 1.}, {0., 0., 1.}}], {{0, 
      3}, {3, 0}}, {0., 1.},
      ColorFunction->GrayLevel],
     BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSizeRaw->{3, 3},
    PlotRange->{{0, 3}, {0, 3}}], ",", 
   GraphicsBox[
    TagBox[
     RasterBox[
      RawArray["Real32",{{1., 1., 1.}, {1., 0., 1.}, {1., 1., 1.}}], {{0, 
      3}, {3, 0}}, {0., 1.},
      ColorFunction->GrayLevel],
     BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSizeRaw->{3, 3},
    PlotRange->{{0, 3}, {0, 3}}], ",", 
   GraphicsBox[
    TagBox[
     RasterBox[
      RawArray["Real32",{{0., 0., 0.}, {0., 1., 1.}, {0., 0., 0.}}], {{0, 
      3}, {3, 0}}, {0., 1.},
      ColorFunction->GrayLevel],
     BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
     Selectable->False],
    DefaultBaseStyle->"ImageGraphics",
    ImageSizeRaw->{3, 3},
    PlotRange->{{0, 3}, {0, 3}}]}], "}"}]], "Output",
 CellChangeTimes->{3.773581635529871*^9, 3.7735826144825907`*^9, 
  3.773584615163801*^9},
 CellLabel->
  "Out[152]=",ExpressionUUID->"46d558ee-7733-4434-aa19-281b5f4af3fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"inor", "=", 
  RowBox[{"RandomWiredImageMemory", "[", 
   RowBox[{"testimages", ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.773582580068782*^9, 3.7735825853667183`*^9}, {
  3.773582617410563*^9, 3.77358264458117*^9}, {3.773584617555872*^9, 
  3.773584619209407*^9}},
 CellLabel->
  "In[162]:=",ExpressionUUID->"b5302d73-a853-4e09-bd70-e656e061d147"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v1"}], "&&", 
      RowBox[{"!", "pix1v2"}], "&&", 
      RowBox[{"!", "pix1v3"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v1"}], "&&", "pix1v2", "&&", 
      RowBox[{"!", "pix1v3"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix1v1", "&&", 
      RowBox[{"!", "pix1v2"}], "&&", 
      RowBox[{"!", "pix1v3"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix1v1", "&&", 
      RowBox[{"!", "pix1v2"}], "&&", "pix1v3"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix1v1", "&&", "pix1v2", "&&", "pix1v3"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v2"}], "&&", 
      RowBox[{"!", "pix3v1"}], "&&", 
      RowBox[{"!", "pix1v1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v2"}], "&&", "pix3v1", "&&", "pix1v1"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix1v2", "&&", 
      RowBox[{"!", "pix3v1"}], "&&", 
      RowBox[{"!", "pix1v1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix1v2", "&&", "pix3v1", "&&", "pix1v1"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v3"}], "&&", "pix3v2", "&&", "pix2v2"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix1v3", "&&", 
      RowBox[{"!", "pix3v2"}], "&&", "pix2v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix1v3", "&&", "pix3v2", "&&", 
      RowBox[{"!", "pix2v2"}]}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v1"}], "&&", 
      RowBox[{"!", "pix1v2"}], "&&", 
      RowBox[{"!", "pix3v3"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v1"}], "&&", 
      RowBox[{"!", "pix1v2"}], "&&", "pix3v3"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v1", "&&", 
      RowBox[{"!", "pix1v2"}], "&&", "pix3v3"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v1", "&&", "pix1v2", "&&", 
      RowBox[{"!", "pix3v3"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v1", "&&", "pix1v2", "&&", "pix3v3"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v2"}], "&&", "pix1v3", "&&", "pix1v1"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix2v2", "&&", 
      RowBox[{"!", "pix1v3"}], "&&", 
      RowBox[{"!", "pix1v1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v2", "&&", 
      RowBox[{"!", "pix1v3"}], "&&", "pix1v1"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v2", "&&", "pix1v3", "&&", "pix1v1"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v3"}], "&&", 
      RowBox[{"!", "pix1v1"}], "&&", "pix3v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v3"}], "&&", "pix1v1", "&&", 
      RowBox[{"!", "pix3v2"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v3"}], "&&", "pix1v1", "&&", "pix3v2"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix2v3", "&&", 
      RowBox[{"!", "pix1v1"}], "&&", "pix3v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v3", "&&", "pix1v1", "&&", "pix3v2"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v1"}], "&&", 
      RowBox[{"!", "pix1v3"}], "&&", 
      RowBox[{"!", "pix3v3"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v1", "&&", 
      RowBox[{"!", "pix1v3"}], "&&", "pix3v3"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v1", "&&", "pix1v3", "&&", "pix3v3"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v2"}], "&&", "pix1v1", "&&", "pix3v3"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix3v2", "&&", 
      RowBox[{"!", "pix1v1"}], "&&", 
      RowBox[{"!", "pix3v3"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v2", "&&", "pix1v1", "&&", "pix3v3"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v3"}], "&&", 
      RowBox[{"!", "pix2v1"}], "&&", "pix3v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v3"}], "&&", "pix2v1", "&&", "pix3v2"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix3v3", "&&", 
      RowBox[{"!", "pix2v1"}], "&&", 
      RowBox[{"!", "pix3v2"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v3", "&&", "pix2v1", "&&", "pix3v2"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v1"}], "&&", 
      RowBox[{"!", "pix2v3"}], "&&", 
      RowBox[{"!", "pix1v2"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v1"}], "&&", "pix2v3", "&&", "pix1v2"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix1v1", "&&", 
      RowBox[{"!", "pix2v3"}], "&&", 
      RowBox[{"!", "pix1v2"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix1v1", "&&", "pix2v3", "&&", "pix1v2"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v2"}], "&&", 
      RowBox[{"!", "pix3v3"}], "&&", 
      RowBox[{"!", "pix3v1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v2"}], "&&", "pix3v3", "&&", "pix3v1"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix1v2", "&&", 
      RowBox[{"!", "pix3v3"}], "&&", 
      RowBox[{"!", "pix3v1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix1v2", "&&", "pix3v3", "&&", "pix3v1"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v3"}], "&&", 
      RowBox[{"!", "pix1v2"}], "&&", "pix2v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix1v3"}], "&&", "pix1v2", "&&", "pix2v2"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix1v3", "&&", 
      RowBox[{"!", "pix1v2"}], "&&", "pix2v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix1v3", "&&", "pix1v2", "&&", 
      RowBox[{"!", "pix2v2"}]}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v1"}], "&&", 
      RowBox[{"!", "pix3v3"}], "&&", "pix2v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v1"}], "&&", "pix3v3", "&&", "pix2v2"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix2v1", "&&", 
      RowBox[{"!", "pix3v3"}], "&&", "pix2v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v1", "&&", "pix3v3", "&&", 
      RowBox[{"!", "pix2v2"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v1", "&&", "pix3v3", "&&", "pix2v2"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v2"}], "&&", "pix1v3", "&&", "pix2v1"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix2v2", "&&", 
      RowBox[{"!", "pix1v3"}], "&&", 
      RowBox[{"!", "pix2v1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v2", "&&", 
      RowBox[{"!", "pix1v3"}], "&&", "pix2v1"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v2", "&&", "pix1v3", "&&", 
      RowBox[{"!", "pix2v1"}]}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v3"}], "&&", 
      RowBox[{"!", "pix2v1"}], "&&", 
      RowBox[{"!", "pix1v1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v3"}], "&&", 
      RowBox[{"!", "pix2v1"}], "&&", "pix1v1"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix2v3"}], "&&", "pix2v1", "&&", "pix1v1"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix2v3", "&&", "pix2v1", "&&", 
      RowBox[{"!", "pix1v1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix2v3", "&&", "pix2v1", "&&", "pix1v1"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v1"}], "&&", 
      RowBox[{"!", "pix2v1"}], "&&", "pix2v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v1"}], "&&", "pix2v1", "&&", "pix2v2"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix3v1", "&&", 
      RowBox[{"!", "pix2v1"}], "&&", "pix2v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v1", "&&", "pix2v1", "&&", 
      RowBox[{"!", "pix2v2"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v1", "&&", "pix2v1", "&&", "pix2v2"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v2"}], "&&", "pix2v2", "&&", "pix3v3"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix3v2", "&&", 
      RowBox[{"!", "pix2v2"}], "&&", "pix3v3"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v2", "&&", "pix2v2", "&&", 
      RowBox[{"!", "pix3v3"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v2", "&&", "pix2v2", "&&", "pix3v3"}], ")"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v3"}], "&&", 
      RowBox[{"!", "pix1v2"}], "&&", "pix3v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"!", "pix3v3"}], "&&", "pix1v2", "&&", "pix3v2"}], ")"}], "||", 
    
    RowBox[{"(", 
     RowBox[{"pix3v3", "&&", 
      RowBox[{"!", "pix1v2"}], "&&", 
      RowBox[{"!", "pix3v2"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v3", "&&", 
      RowBox[{"!", "pix1v2"}], "&&", "pix3v2"}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{"pix3v3", "&&", "pix1v2", "&&", "pix3v2"}], ")"}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.773582625004471*^9, 3.773582646304083*^9}, {
   3.773584620139758*^9, 3.773584641211755*^9}, 3.7735847418236637`*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"fad495e7-67fd-4bb1-966b-5746cdf0c269"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiableQ", "[", "inor", "]"}]], "Input",
 CellChangeTimes->{{3.773582658898219*^9, 3.7735826671503267`*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"c94a3878-3ada-4f51-a65d-e08e71cda07b"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.7735826678530893`*^9, {3.773584625712976*^9, 3.773584635651923*^9}},
 CellLabel->
  "Out[157]=",ExpressionUUID->"8d7eb4e2-993b-46b8-b946-414bd58ecc81"]
}, Open  ]],

Cell["\<\
There should be exactly 5 solutions.  If so, then they are the correct \
solutions, by construction.  However, with coverage of just 2 (as above) it \
is not uncommon to have more solutions.  So, repeat the build step until we \
get the desired result, or increase the coverage...\
\>", "Text",
 CellChangeTimes->{{3.773584657631589*^9, 3.773584729094819*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"7e2749be-e465-49e1-abc7-6e0a6ba08d6d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiabilityCount", "[", "inor", "]"}]], "Input",
 CellChangeTimes->{{3.7735826720950727`*^9, 3.773582682575241*^9}},
 CellLabel->
  "In[163]:=",ExpressionUUID->"baddc9f9-dd53-4dfd-bb73-f0f86b0b2395"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.773582683214851*^9, {3.7735846271525707`*^9, 3.773584646763101*^9}, {
   3.773584740290975*^9, 3.7735847468232107`*^9}},
 CellLabel->
  "Out[163]=",ExpressionUUID->"02e3fc16-7700-4ae8-8bd7-12ab15425e6d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"RunWalkSATCRN", "[", "inor", "]"}]}]], "Input",
 CellChangeTimes->{{3.773582768621831*^9, 3.773582788505673*^9}},
 CellLabel->
  "In[164]:=",ExpressionUUID->"47a0a090-a485-485a-980b-814461003014"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pix1v1", "\[Rule]", "True"}], ",", 
   RowBox[{"pix1v2", "\[Rule]", "True"}], ",", 
   RowBox[{"pix1v3", "\[Rule]", "True"}], ",", 
   RowBox[{"pix2v1", "\[Rule]", "True"}], ",", 
   RowBox[{"pix2v2", "\[Rule]", "False"}], ",", 
   RowBox[{"pix2v3", "\[Rule]", "True"}], ",", 
   RowBox[{"pix3v1", "\[Rule]", "True"}], ",", 
   RowBox[{"pix3v2", "\[Rule]", "True"}], ",", 
   RowBox[{"pix3v3", "\[Rule]", "True"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773582778710259*^9, 3.7735828175766706`*^9, {3.773584126910964*^9, 
   3.773584151887659*^9}, 3.773584749522704*^9},
 CellLabel->
  "Out[164]=",ExpressionUUID->"5cfb52cb-5902-4a0e-a07c-158383e40898"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"AssignmentImage", "[", "assignment_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "allpixels", ",", "onpixels", ",", "height", ",", "width", ",", 
      "image"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"allpixels", "=", 
      RowBox[{"assignment", "/.", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{
           RowBox[{"p_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"StringMatchQ", "[", 
               RowBox[{
                RowBox[{"ToString", "[", "#", "]"}], ",", "\"\<pix*\>\""}], 
               "]"}], "&"}], ")"}]}], ",", "v_"}], "]"}], "\[RuleDelayed]", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"First", "[", 
          RowBox[{"StringCases", "[", 
           RowBox[{
            RowBox[{"ToString", "[", "p", "]"}], ",", 
            RowBox[{
             RowBox[{
             "\"\<pix\>\"", "~~", "i__", "~~", "\"\<v\>\"", "~~", "j__"}], 
             " ", "\[RuleDelayed]", " ", 
             RowBox[{"(", 
              RowBox[{"ToExpression", "/@", 
               RowBox[{"{", 
                RowBox[{"j", ",", "i"}], "}"}]}], ")"}]}]}], "]"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"onpixels", "=", 
      RowBox[{
       RowBox[{"Cases", "[", 
        RowBox[{"assignment", ",", 
         RowBox[{"_", "[", 
          RowBox[{"_", ",", "True"}], "]"}]}], "]"}], "/.", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Rule", "[", 
          RowBox[{
           RowBox[{"p_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"StringMatchQ", "[", 
               RowBox[{
                RowBox[{"ToString", "[", "#", "]"}], ",", "\"\<pix*\>\""}], 
               "]"}], "&"}], ")"}]}], ",", "v_"}], "]"}], "\[RuleDelayed]", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"First", "[", 
          RowBox[{"StringCases", "[", 
           RowBox[{
            RowBox[{"ToString", "[", "p", "]"}], ",", 
            RowBox[{
             RowBox[{
             "\"\<pix\>\"", "~~", "i__", "~~", "\"\<v\>\"", "~~", "j__"}], 
             " ", "\[RuleDelayed]", " ", 
             RowBox[{"(", 
              RowBox[{"ToExpression", "/@", 
               RowBox[{"{", 
                RowBox[{"j", ",", "i"}], "}"}]}], ")"}]}]}], "]"}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"height", ",", "width"}], "}"}], "=", 
      RowBox[{"Max", " ", "/@", " ", 
       RowBox[{"Transpose", "[", "allpixels", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"image", "=", 
      RowBox[{"ReplacePart", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "height", "}"}], ",", 
          RowBox[{"{", "width", "}"}]}], "]"}], ",", 
        RowBox[{"onpixels", "\[Rule]", "1"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Framed", "[", 
      RowBox[{"Image", "[", 
       RowBox[{"image", ",", 
        RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.681521885815668*^9, 3.681521900774042*^9}, {
   3.6815219361226807`*^9, 3.681521947677137*^9}, {3.681522022724805*^9, 
   3.681522065386664*^9}, {3.681522513685163*^9, 3.681522536517891*^9}, {
   3.6815226728909407`*^9, 3.6815227670582933`*^9}, {3.681522858667428*^9, 
   3.681522860755457*^9}, {3.681522912600263*^9, 3.681522934753068*^9}, {
   3.68152300827422*^9, 3.681523084579948*^9}, {3.681523168960926*^9, 
   3.681523273897455*^9}, {3.681523390239278*^9, 3.6815234468865843`*^9}, 
   3.681524608306995*^9, {3.6815272040615664`*^9, 3.6815272378654423`*^9}, {
   3.681527338263603*^9, 3.68152736214692*^9}, {3.681527449676206*^9, 
   3.6815274878160553`*^9}, {3.681527800021933*^9, 3.681527870170924*^9}, {
   3.681527919077364*^9, 3.681527966266214*^9}, {3.6815280137285643`*^9, 
   3.6815280383865423`*^9}, {3.6815282287564707`*^9, 3.681528273292029*^9}, {
   3.681529495058014*^9, 3.681529523505414*^9}, {3.6815306009358397`*^9, 
   3.6815306069600554`*^9}, 3.681530799910944*^9, {3.681600797369205*^9, 
   3.6816008068405123`*^9}, {3.6820454985141497`*^9, 
   3.6820455097184057`*^9}, {3.682064056798408*^9, 3.682064072364852*^9}, {
   3.7735828332608747`*^9, 3.773582842136825*^9}, 3.7735828890618477`*^9, {
   3.773583468306616*^9, 3.773583628004887*^9}, {3.77358369870684*^9, 
   3.773583707414586*^9}, {3.773583753148065*^9, 3.773583786155376*^9}, {
   3.7735838534033823`*^9, 3.773583931247991*^9}, {3.773584012726293*^9, 
   3.773584025706647*^9}, {3.773584078226293*^9, 3.7735840795123873`*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"6a0c4008-e604-4e6b-9110-ad3c1ee50698"],

Cell[BoxData["True"], "Input",
 CellChangeTimes->{{3.773589783795198*^9, 
  3.77358978421137*^9}},ExpressionUUID->"f5599664-c7ab-4f58-86c2-\
080953d8b0fc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AssignmentImage", "[", "sol", "]"}]], "Input",
 CellChangeTimes->{{3.7735837279254*^9, 3.7735837327016573`*^9}, {
  3.773584029940785*^9, 3.773584083522214*^9}},
 CellLabel->
  "In[165]:=",ExpressionUUID->"86c870f9-2009-48ea-8a28-a852b5c4adc5"],

Cell[BoxData[
 FrameBox[
  GraphicsBox[
   TagBox[
    RasterBox[
     RawArray["Real32",{{1., 1., 1.}, {1., 0., 1.}, {1., 1., 1.}}], {{0, 3}, {
     3, 0}}, {0., 1.},
     ColorFunction->GrayLevel],
    BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
    
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->Tiny,
   ImageSizeRaw->{3, 3},
   PlotRange->{{0, 3}, {0, 3}}],
  StripOnInput->False]], "Output",
 CellChangeTimes->{
  3.773584038922893*^9, {3.7735840699486303`*^9, 3.773584083930265*^9}, {
   3.77358412952462*^9, 3.7735841541297503`*^9}, 3.773584752397211*^9},
 CellLabel->
  "Out[165]=",ExpressionUUID->"e968db83-9280-4b27-9179-bc264b859458"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiabilityInstances", "[", 
  RowBox[{"inor", ",", 
   RowBox[{"BooleanVariables", "[", "inor", "]"}], ",", "10"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.773584172408443*^9, 3.773584177335229*^9}, {
  3.773584217282483*^9, 3.773584222328156*^9}},
 CellLabel->
  "In[166]:=",ExpressionUUID->"edddfbfd-a65f-4daa-b341-b229a00ec883"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "True", ",", "True", ",", "True", ",", "True", ",", "False", ",", "True", 
     ",", "True", ",", "True", ",", "True"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "True", ",", "False", ",", "True", ",", "False", ",", "True", ",", 
     "False", ",", "True", ",", "False", ",", "True"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "True", ",", "False", ",", "False", ",", "True", ",", "True", ",", 
     "False", ",", "True", ",", "True", ",", "True"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "False", ",", "True", ",", "False", ",", "True", ",", "True", ",", "True",
      ",", "False", ",", "True", ",", "False"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "False", ",", "False", ",", "False", ",", "False", ",", "True", ",", 
     "False", ",", "False", ",", "True", ",", "False"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.773584177884976*^9, 3.7735842231301413`*^9, 
  3.7735847568099327`*^9},
 CellLabel->
  "Out[166]=",ExpressionUUID->"b8e8197e-9f35-474c-afbb-32515fd4a570"]
}, Open  ]],

Cell["\<\
Here\[CloseCurlyQuote]s how to visually verify that the full set of solutions \
to the network of relations is indeed the full set of given images.\
\>", "Text",
 CellChangeTimes->{{3.773584539849351*^9, 3.773584575909774*^9}, {
  3.773584768229395*^9, 3.7735847806143227`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"06c2b59a-9512-4211-98da-eec8708e0160"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SatisfiabilityImages", "[", 
   RowBox[{"expr_", ",", "num_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"AssignmentImage", "[", 
     RowBox[{"MapThread", "[", 
      RowBox[{"Rule", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"BooleanVariables", "[", "expr", "]"}], ",", "#"}], "}"}]}], 
      "]"}], "]"}], "&"}], "/@", 
   RowBox[{"SatisfiabilityInstances", "[", 
    RowBox[{"expr", ",", 
     RowBox[{"BooleanVariables", "[", "expr", "]"}], ",", "num"}], 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773584270680972*^9, 3.773584319673155*^9}, {
  3.7735993171355343`*^9, 3.773599325693767*^9}, {3.773605902254537*^9, 
  3.7736059590075607`*^9}, {3.77360608524304*^9, 3.773606086513994*^9}, {
  3.7736061507135687`*^9, 3.773606175126758*^9}, {3.7736064712775517`*^9, 
  3.773606482719328*^9}},
 CellLabel->
  "In[299]:=",ExpressionUUID->"3bbf5390-a180-45b5-8808-06dd2e704ce1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiabilityImages", "[", 
  RowBox[{"inor", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.773605975149851*^9, 3.773605981517799*^9}, {
  3.773606188245194*^9, 3.773606188623384*^9}},
 CellLabel->
  "In[300]:=",ExpressionUUID->"2a25765c-33d8-4e9c-9fa9-d57647ab9115"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 1., 1.}, {1., 0., 1.}, {1., 1., 1.}}], {{0, 
       3}, {3, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{3, 3},
     PlotRange->{{0, 3}, {0, 3}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1.}, {0., 1., 0.}, {1., 0., 1.}}], {{0, 
       3}, {3, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{3, 3},
     PlotRange->{{0, 3}, {0, 3}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 1., 1.}, {0., 1., 1.}, {0., 0., 1.}}], {{0, 
       3}, {3, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{3, 3},
     PlotRange->{{0, 3}, {0, 3}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{0., 1., 0.}, {1., 1., 1.}, {0., 1., 0.}}], {{0, 
       3}, {3, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{3, 3},
     PlotRange->{{0, 3}, {0, 3}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{0., 0., 0.}, {0., 1., 1.}, {0., 0., 0.}}], {{0, 3},
        {3, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{3, 3},
     PlotRange->{{0, 3}, {0, 3}}],
    StripOnInput->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773605982418125*^9, 3.773606107242201*^9, {3.7736061807864523`*^9, 
   3.773606189166123*^9}, 3.773606487283925*^9},
 CellLabel->
  "Out[300]=",ExpressionUUID->"3a954e1b-c6af-4874-a5f2-4d194085f417"]
}, Open  ]],

Cell["Now let\[CloseCurlyQuote]s bring the six scientists on board.", "Text",
 CellChangeTimes->{{3.773584539849351*^9, 3.773584575909774*^9}, {
  3.773584768229395*^9, 3.7735848245366077`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"88983f03-a27a-4ab4-ba5d-d19d29824552"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AlanTuring", "=", 
   RowBox[{"Import", "[", "\"\<Scientists/Alan-Turing.png\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GeorgeBoole", "=", 
   RowBox[{"ImageResize", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<Scientists/George-Boole.jpeg\>\"", "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "35"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LudwigBoltzmann", "=", 
   RowBox[{"ImageResize", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<Scientists/Ludwig-Boltzmann.jpg\>\"", "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "35"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RosalindFranklin", "=", 
   RowBox[{"ImageResize", "[", 
    RowBox[{
     RowBox[{"Import", "[", "\"\<Scientists/Rosalind-Franklin.jpg\>\"", "]"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "35"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AdaLovelace", "=", 
   RowBox[{"ImageResize", "[", 
    RowBox[{
     RowBox[{"Image", "[", 
      RowBox[{
       RowBox[{"ImageData", "[", 
        RowBox[{"Import", "[", "\"\<Scientists/Ada-Lovelace.jpg\>\"", "]"}], 
        "]"}], "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"1", ";;", "237"}], ",", 
         RowBox[{"1", ";;", "237"}]}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "35"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"WarrenMcCulloch", "=", 
   RowBox[{"ImageResize", "[", 
    RowBox[{
     RowBox[{"Image", "[", 
      RowBox[{
       RowBox[{"ImageData", "[", 
        RowBox[{
        "Import", "[", "\"\<Scientists/Warren-McCulloch.jpg\>\"", "]"}], 
        "]"}], "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"1", ";;", "150"}], ",", 
         RowBox[{"141", ";;", "290"}]}], "]"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "35"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Framed", "/@", 
  RowBox[{"{", 
   RowBox[{
   "AlanTuring", ",", "GeorgeBoole", ",", "LudwigBoltzmann", ",", 
    "RosalindFranklin", ",", "AdaLovelace", ",", "WarrenMcCulloch"}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.681533192324348*^9, 3.68153325434492*^9}, {
  3.6819845060306683`*^9, 3.6819845299004707`*^9}, {3.68198479557996*^9, 
  3.681984879359516*^9}, {3.681985306970598*^9, 3.681985416364263*^9}, {
  3.773584866670039*^9, 3.7735848669908257`*^9}, {3.773584901655446*^9, 
  3.773584982694326*^9}, {3.773585060300911*^9, 3.7735851224130487`*^9}, {
  3.7736745993969812`*^9, 
  3.773674606005034*^9}},ExpressionUUID->"ed1f1403-78f5-480a-82cc-\
b899f9ea306c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxt2Gnwl3MXBnDzPGY8LxsvDCaqKUNKSNEitCt7iVSktIrSQnsxEclW9l0U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       "], {{0, 35}, {35, 
       0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{35, 35},
     PlotRange->{{0, 35}, {0, 35}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxV11WsVlkSBWAy8zKPEx54wgbSuNO4NDTu2t24X1wad3cNLgk0DiF4gOAQ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       "], {{0, 35}, {35, 0}}, {0, 
       255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["

1:eJylkL1Lw0AYxp/Wj/pRUdDBwSGCOEgF0cVR61AUEYkt+LUkaZIKaRouKVIc
HVw7dFFx8QP/A93Ef0AQBHVy0dlBQQSR+FwjFEQn77h7f3nufd/cPYN6SbXi
APw2bqq2OS2EVlnq4UfO9Tds18zPuoFpm2JSj1GsylzEq45R9JvHgKIbCDWT
VpZXVpXEA1rRgXZ0YUQzfG96cXEef463W8iGuBmVvf7O+3V05k3fAGLy0pOG
JwLyFHlhM/AkV8l9RkHLk4/JKcELkq+lrkf8JNmO+F2yyKozfFuSrNgRpyTr
Ecu3KEZBFMkOeajolI3v+8iXJE03t8Q4UF8+VGSQhgIdZWzAQYBRRpee/V43
Xq9bQIk1BncPFQhW2CiwNkW1zK4mo0Xd5HSYwSG9/+mpb02MR39IzgEtj2H4
OgIk9oHPnTD8OAzDzyOg6R64rDXqSzXa+Uy92tCGDoDubeDsoqHpJ8A5Pe5/
8DSh1aUmrrhlAS+nQNcK0EuvO9b+ex75/X2OozsguwXMXwG7e8Aw87vXvwBc
cIGL
         "], "RGB", "XYZ"], Interleaving -> True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{35, 35},
     PlotRange->{{0, 35}, {0, 35}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxd1vWP1d0RBnDS/vL+2H+haXB3K+764m4LLM4Ciwe34E6ABA/uEiAECZ6g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       "], {{0, 35}, {35, 0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{35, 35},
     PlotRange->{{0, 35}, {0, 35}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJw91oWzFlcSBXDc3ZfF3YNbcHd3DfIIBLcQXAso3N3d3d3dIRAWd4fKf7C/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       "], {{0, 35}, {35,
        0}}, {0, 255},
       ColorFunction->RGBColor],
      BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["

1:eJylkL1Lw0AYxp9WRdFKBQUdHCIUB6kgdXH0YxBFRKKCVZckTVIhTcMlRcTR
wbWDi4qLH/gf6Cb+A4IgqJMIOjsoiCAlPtcIBWkn3+Pufnnufd/cPQN6UbXi
APw2Lqq2OSGEtrXYxY9l19+wXTM34wambYoxPUaxLHMRLztGwW8eAQpuINTp
SWUlu6q0PiOOdh73ok0zfG9iYWEODePzHrIh7oZlr8Z5daMjZ/oGEJOXHjM8
EZDHyfObgSe5TO4x8lqOfEpOC16QfCt1PeJXyXbEX5LFkjrFtyXIih1xWrIe
sXyLYuRFgeyQUwWnZPzeR74kYbrLi9z7q9OHimlMQoGOEjbgIMAwd5ee1a/L
VOvmUWSNwdXDFgQrbORZm6ZaYleTu0Xd5HCYwZDe//XUt0Yz0R8Ss0DLSxh+
DAGth0BlNwy/j8OwcgI0PQLXe7X64h7tfKNermmpIyC5A1xc1TT9DLikx31P
nia0qtTEGbcs4P0c6MwC3fS6fe2/55Hfv+c4eQCWtoG5G2D/ABhkfnL9Bwdt
gWg=
         "], "RGB", "XYZ"], Interleaving -> True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{35, 35},
     PlotRange->{{0, 35}, {0, 35}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJwtmXVUVO3bhQFBWroZGoaYYYpmznPRKQrGa3d3d3d3vXZ3YqFivHYndmFj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       "], {{0, 35}, {35, 0}}, {0., 1.},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{35, 35},
     PlotRange->{{0, 35}, {0, 35}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJw9l3c4lv/7/zWMQvYmKyN7ZnU9nyhKqIyI7ETSkhYtaWkv7b333lNRkQql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       "], {{0, 35}, {35, 0}}, {0., 1.},
       ColorFunction->RGBColor],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> True],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSizeRaw->{35, 35},
     PlotRange->{{0, 35}, {0, 35}}],
    StripOnInput->False]}], "}"}]], "Output",
 CellChangeTimes->{3.773585098176598*^9, 3.7735851290337276`*^9},
 CellLabel->
  "Out[181]=",ExpressionUUID->"4f7ca0b7-6701-4fbe-b552-1682b6566be9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"iSmallTuring", "=", 
    RowBox[{
     RowBox[{"ImageData", "[", 
      RowBox[{"ImageResize", "[", 
       RowBox[{"AlanTuring", ",", 
        RowBox[{"{", 
         RowBox[{"17", ",", "17"}], "}"}]}], "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"r_", ",", "g_", ",", "b_", ",", "i_"}], "}"}], 
      "\[RuleDelayed]", 
      RowBox[{"Boole", "[", 
       RowBox[{
        RowBox[{"r", "+", "g", "+", "b"}], ">", "1.5"}], "]"}]}]}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iSmallBoole", "=", 
   RowBox[{
    RowBox[{"ImageData", "[", 
     RowBox[{"ImageResize", "[", 
      RowBox[{"GeorgeBoole", ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "17"}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r_", ",", "g_", ",", "b_"}], "}"}], "\[RuleDelayed]", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"r", "+", "g", "+", "b"}], ">", "1.8"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iSmallBoltzmann", "=", 
   RowBox[{
    RowBox[{"ImageData", "[", 
     RowBox[{"ImageResize", "[", 
      RowBox[{"LudwigBoltzmann", ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "17"}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r_", ",", "g_", ",", "b_"}], "}"}], "\[RuleDelayed]", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"r", "+", "g", "+", "b"}], ">", "1.8"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iSmallFranklin", "=", 
   RowBox[{
    RowBox[{"ImageData", "[", 
     RowBox[{"ImageResize", "[", 
      RowBox[{"RosalindFranklin", ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "17"}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r_", ",", "g_", ",", "b_"}], "}"}], "\[RuleDelayed]", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"r", "+", "g", "+", "b"}], ">", "2.0"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iSmallLovelace", "=", 
   RowBox[{
    RowBox[{"ImageData", "[", 
     RowBox[{"ImageResize", "[", 
      RowBox[{"AdaLovelace", ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "17"}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r_", ",", "g_", ",", "b_"}], "}"}], "\[RuleDelayed]", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"r", "+", "g", "+", "b"}], ">", "1.7"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iSmallMcCulloch", "=", 
   RowBox[{
    RowBox[{"ImageData", "[", 
     RowBox[{"ImageResize", "[", 
      RowBox[{"WarrenMcCulloch", ",", 
       RowBox[{"{", 
        RowBox[{"17", ",", "17"}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r_", ",", "g_", ",", "b_"}], "}"}], "\[RuleDelayed]", 
     RowBox[{"Boole", "[", 
      RowBox[{
       RowBox[{"r", "+", "g", "+", "b"}], ">", "1.7"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Framed", "[", 
    RowBox[{"Image", "[", 
     RowBox[{"#", ",", 
      RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], "]"}], "&"}], "/@", 
  
  RowBox[{"{", 
   RowBox[{
   "iSmallTuring", ",", "iSmallBoole", ",", "iSmallBoltzmann", ",", 
    "iSmallFranklin", ",", "iSmallLovelace", ",", "iSmallMcCulloch"}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.773585015531946*^9, 3.77358504949085*^9}, {
  3.773585145830041*^9, 3.773585211128696*^9}},
 CellLabel->
  "In[196]:=",ExpressionUUID->"82dde36e-6e2a-4dbd-a008-3135d0d37213"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgYQq5+QGkrMgKmj1Axi/EILM9HNJUYfuXbSwhxqu4NUd5GSJonRT6o5
6HpIMQufWmLdQor70d1IiRmo+gCv757Z
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Small,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Small,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
SvWTag42feSYgc9caoQPvf2CrIfcMCUkRk68UmoGvjgjJW0RchMx7ifFfFL0
E2MGvQDl7gAAHl92jw==
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Small,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQikcBqaDBHoIp
1U+uOej6STUHXT2p5uBST44bqOEPUs1BlqdEPyF9pJqBTZwU/+OSI8UMctIF
KWZgNwcAyhxMCA==
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Small,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph9EB
pfphZpBiHj43EGMGLjeQYg4tzMAlT0lYkmsGKX4hRj+l6YpYswn5gVz3UWoG
peFDbJoixwxy3IXLDIg4AL/ppw4=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Small,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiiGgwZ44jA9g
U0uJOYTcRsgMYv020GYQAtjUYTOXGmYQ8guheCXXHejmorsPm3pc5pCaVolx
IyG/DEQ6JyYMiPEHLnMpMQPZLMIAALQ4Ymo=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Small,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.7735851800051317`*^9, 3.773585213135845*^9}},
 CellLabel->
  "Out[202]=",ExpressionUUID->"44d76937-7802-4626-81fa-94259027c597"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"memimages", "=", 
   RowBox[{"{", 
    RowBox[{
    "iSmallTuring", ",", "iSmallBoole", ",", "iSmallBoltzmann", ",", 
     "iSmallFranklin", ",", "iSmallLovelace", ",", "iSmallMcCulloch"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.773587777856584*^9, 3.773587782189734*^9}},
 CellLabel->
  "In[218]:=",ExpressionUUID->"7207e662-6e6d-416b-b69a-654e9b391112"],

Cell[BoxData[
 RowBox[{
  RowBox[{"memcnf", "=", 
   RowBox[{"ConjunctiveNormalForm", "[", 
    RowBox[{"RandomWiredImageMemory", "[", 
     RowBox[{"memimages", ",", "10"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.681985544074872*^9, 3.681985568961883*^9}, {
  3.7735852969356117`*^9, 3.773585309165771*^9}, {3.773585372290698*^9, 
  3.773585379933597*^9}, {3.773585692399609*^9, 3.773585692832959*^9}, {
  3.773587773097481*^9, 3.7735878046536694`*^9}, {3.773598301034754*^9, 
  3.773598302693603*^9}},
 CellLabel->
  "In[264]:=",ExpressionUUID->"6cf1fbe4-47ea-4935-9f05-9b43e5ba077a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Max", "[", 
  RowBox[{"Length", "/@", 
   RowBox[{"(", 
    RowBox[{"List", "@@", "memcnf"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773598428514043*^9, 3.77359843385541*^9}, {
  3.773598469188182*^9, 3.7735984734333878`*^9}},
 CellLabel->
  "In[267]:=",ExpressionUUID->"83be6c81-6a06-486e-9634-7cf1cc3d2856"],

Cell[BoxData["3"], "Output",
 CellChangeTimes->{3.773598434743257*^9, 3.773598474156116*^9},
 CellLabel->
  "Out[267]=",ExpressionUUID->"dde3ccc8-3dcc-4cf4-90e2-469702b90d22"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiableQ", "[", "memcnf", "]"}]], "Input",
 CellChangeTimes->{{3.773585327886876*^9, 3.773585332177846*^9}, {
  3.773587810686089*^9, 3.77358781086653*^9}},
 CellLabel->
  "In[265]:=",ExpressionUUID->"f1cef060-00cc-4028-b373-611e8f722c95"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.77358535793191*^9, 3.773585391885861*^9, 
  3.773585752055121*^9, 3.773587833099049*^9, 3.773598425391807*^9},
 CellLabel->
  "Out[265]=",ExpressionUUID->"afe01d04-8c86-4a7d-87c9-7a42bf977d69"]
}, Open  ]],

Cell["\<\
The formula is too large to get guarantees of correctness, unfortunately.  \
But we can try it, and \[OpenCurlyDoubleQuote]it \
works\[CloseCurlyDoubleQuote], in a sense.\
\>", "Text",
 CellChangeTimes->{{3.773588269872414*^9, 3.773588309375141*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"413fc386-2e9c-4e11-b644-67c4cf900a53"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiabilityCount", "[", "memcnf", "]"}]], "Input",
 CellChangeTimes->{{3.773585327886876*^9, 3.773585332177846*^9}, {
  3.7735854048477163`*^9, 3.7735854219480124`*^9}, {3.773587816104423*^9, 
  3.773587816279684*^9}, {3.773588142359633*^9, 3.77358814674214*^9}},
 CellLabel->
  "In[301]:=",ExpressionUUID->"578928a8-ad06-448f-bb44-a9efe86086a6"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.773585471161949*^9, 3.7735857667852488`*^9, 
  3.773588187774126*^9, 3.77360657468113*^9},
 CellLabel->
  "Out[301]=",ExpressionUUID->"809c5c27-f35d-4532-9eca-12aa673d5a75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatisfiabilityImages", "[", 
  RowBox[{"memcnf", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.773584270680972*^9, 3.773584319673155*^9}, {
  3.773585488653426*^9, 3.773585496922027*^9}, {3.7735857770244503`*^9, 
  3.773585778020776*^9}, {3.773587819853855*^9, 3.7735878255616417`*^9}, {
  3.77360653800173*^9, 3.773606578738756*^9}},
 CellLabel->
  "In[302]:=",ExpressionUUID->"c09d2bf0-3179-4cab-a446-ecbade163063"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.7735856888702173`*^9, 3.773586480188772*^9, 
  3.7736066169522343`*^9},
 CellLabel->
  "Out[302]=",ExpressionUUID->"21f0e612-af21-478e-ba36-aeae41ffecc3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"recall", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sol", "=", 
      RowBox[{"RunWalkSATCRN", "[", "memcnf", "]"}]}], ";", 
     RowBox[{"AssignmentImage", "[", "sol", "]"}]}], ",", " ", "20"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.773582768621831*^9, 3.773582788505673*^9}, {
   3.773586504068939*^9, 3.773586506881898*^9}, 3.773586586082066*^9, {
   3.773586995908826*^9, 3.7735870128849277`*^9}, {3.7735881983033323`*^9, 
   3.7735881996417837`*^9}, {3.773596065145587*^9, 3.773596065360888*^9}},
 CellLabel->
  "In[268]:=",ExpressionUUID->"b1e26919-9068-416b-af36-9dbac759f535"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiiGgwZ44jA9g
U0uJOYTcRsgMYv020GYQAtjUYTOXGmYQ8guheCXXHejmorsPm3pc5pCaVolx
IyG/DEQ6JyYMiPEHLnMpMQPZLMIAALQ4Ymo=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiiGgwZ44jA9g
U0uJOYTcRsgMYv020GYQAtjUYTOXGmYQ8guheCXXHejmorsPm3pc5pCaVolx
IyG/DEQ6JyYMiPEHLnMpMQPZLMIAALQ4Ymo=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgYQq5+QGkrMgKmj1Axi/EILM9HNJUYfuXbSwhxqu4NUd5GSJonRT6o5
6HpIMQufWmLdQor70d1IiRmo+gCv757Z
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgYQq5+QGkrMgKmj1Axi/EILM9HNJUYfuXbSwhxqu4NUd5GSJonRT6o5
6HpIMQufWmLdQor70d1IiRmo+gCv757Z
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph9EB
pfphZpBiHj43EGMGLjeQYg4tzMAlT0lYkmsGKX4hRj+l6YpYswn5gVz3UWoG
peFDbJoixwxy3IXLDIg4AL/ppw4=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiiGgwZ44jA9g
U0uJOYTcRsgMYv020GYQAtjUYTOXGmYQ8guheCXXHejmorsPm3pc5pCaVolx
IyG/DEQ6JyYMiPEHLnMpMQPZLMIAALQ4Ymo=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph9EB
pfphZpBiHj43EGMGLjeQYg4tzMAlT0lYkmsGKX4hRj+l6YpYswn5gVz3UWoG
peFDbJoixwxy3IXLDIg4AL/ppw4=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgYQq5+QGkrMgKmj1Axi/EILM9HNJUYfuXbSwhxqu4NUd5GSJonRT6o5
6HpIMQufWmLdQor70d1IiRmo+gCv757Z
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiiGgwZ44jA9g
U0uJOYTcRsgMYv020GYQAtjUYTOXGmYQ8guheCXXHejmorsPm3pc5pCaVolx
IyG/DEQ6JyYMiPEHLnMpMQPZLMIAALQ4Ymo=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
SvWTag6yemSaVDPwuY0a4UNOeFDiF2Q9lIQpOWYQApSYgS/OSElbhNxEjPtJ
MZ8U/cSYQS9AuTsAziR3Tg==
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiiGgwZ44jA9g
U0uJOYTcRsgMYv020GYQAtjUYTOXGmYQ8guheCXXHejmorsPm3pc5pCaVolx
IyG/DEQ6JyYMiPEHLnMpMQPZLMIAALQ4Ymo=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgYQq5+QGkrMgKmj1Axi/EILM9HNJUYfuXbSwhxqu4NUd5GSJonRT6o5
6HpIMQufWmLdQor70d1IiRmo+gCv757Z
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
SvWTag6yemSaVDPwuY0a4UNOeFDiF2Q9lIQpOWYQApSYgS/OSElbhNxEjPtJ
MZ8U/cSYQS9AuTsAziR3Tg==
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False]}], "}"}]], "Output",
 CellChangeTimes->{3.7735865328049183`*^9, 3.77358658108208*^9, 
  3.773587515588941*^9, 3.773588720831703*^9, 3.7735965868502207`*^9, 
  3.773599601167459*^9},
 CellLabel->
  "Out[268]=",ExpressionUUID->"d0adfe25-9c7a-4211-84a0-0d5fac4473ba"]
}, Open  ]],

Cell["\<\
With coverage of 5, the resulting images look good, but there are some with a \
few pixels off if you look closely.  That\[CloseCurlyQuote]s because the \
formula has more solutions than just the desired images.   All perfect images \
are of course still guaranteed as possible solutions.  (We don\
\[CloseCurlyQuote]t always get examples of all six scientists; the basins of \
attraction are not equally weighted.)\
\>", "Text",
 CellChangeTimes->{{3.7735881005627537`*^9, 3.7735881263447027`*^9}, {
  3.77358815647579*^9, 3.773588179519414*^9}, {3.773588450225716*^9, 
  3.773588468718265*^9}, {3.773588843355393*^9, 3.773588896696906*^9}, {
  3.773596730200733*^9, 3.773596745620757*^9}, {3.7736026101382313`*^9, 
  3.773602612453136*^9}, {3.773602677870414*^9, 3.773602726762092*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"70a4529b-39a7-4c8c-9809-343bb89031f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MemberQ", "[", 
    RowBox[{"memimages", ",", " ", 
     RowBox[{"Round", "[", 
      RowBox[{"ImageData", "[", 
       RowBox[{"First", "[", "#", "]"}], "]"}], "]"}]}], " ", "]"}], "&"}], "/@",
   " ", "recall"}]], "Input",
 CellChangeTimes->{{3.773587869183095*^9, 3.773587999230912*^9}, {
  3.773588224313113*^9, 3.7735882255934753`*^9}},
 CellLabel->
  "In[269]:=",ExpressionUUID->"f0b49837-be5d-4f57-a7a4-1ee06b826288"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", 
   "False", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "False", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.7735878869677553`*^9, 3.7735879313387203`*^9}, {
   3.773587974910309*^9, 3.773588000303158*^9}, 3.77358890339145*^9, 
   3.773596679876178*^9, 3.773602596963108*^9},
 CellLabel->
  "Out[269]=",ExpressionUUID->"4b50a2f9-bef6-492c-a6c8-caa111c4ec06"]
}, Open  ]],

Cell["\<\
Let us watch the SAT-solving process in action.  To illustrate inference, we \
would like to ask the network to find a solution in which certain pixels are \
ON or OFF.  This could be done either (a) by adding a trivial clause to the \
formula (e.g. memcnf && pix4v5 && !pix3v12) and converting that to a \
WalkSATCRN, or (b) by creating a single core WalkSATCRN from memcnf, and then \
adding clamping reactions (e.g. { pix4v5[0] -> pix4v5[1], pix3v12[1] -> \
pix3v12[0] } ).   Option (b) is a better analogy for their being a CRN \
\[OpenCurlyDoubleQuote]brain\[CloseCurlyDoubleQuote] that has information \
provided from the environment due to processes that force certain species \
high or low, so that\[CloseCurlyQuote]s what we do.

The code here is specialized for images, i.e. formulas and CRN species with \
pixel names as above.  ON is white, OFF is black, and bits that are trying to \
change will be shown in grey. \
\>", "Text",
 CellChangeTimes->{{3.773588328075235*^9, 3.773588370447504*^9}, 
   3.77358856613006*^9, {3.773588943648637*^9, 3.773588946951139*^9}, {
   3.773589022800261*^9, 3.7735893671134853`*^9}, {3.773589437623076*^9, 
   3.773589527375475*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"f88412fc-bed1-4e08-9200-04a50c6c9c73"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PixelIndices", "[", "name_", "]"}], ":=", 
  RowBox[{"First", "[", 
   RowBox[{"StringCases", "[", 
    RowBox[{
     RowBox[{"ToString", "[", "name", "]"}], ",", 
     RowBox[{
      RowBox[{"\"\<pix\>\"", "~~", "i__", "~~", "\"\<v\>\"", "~~", "j__"}], 
      " ", "\[RuleDelayed]", " ", 
      RowBox[{"(", 
       RowBox[{"ToExpression", "/@", 
        RowBox[{"{", 
         RowBox[{"j", ",", "i"}], "}"}]}], ")"}]}]}], "]"}], "]"}]}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.773595049063808*^9, 3.7735951031030207`*^9}},
 CellLabel->
  "In[231]:=",ExpressionUUID->"3c4411fd-8029-4b93-8a6f-96d7f0316322"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WatchImageWalkSATCRN", "[", 
   RowBox[{"expr_", ",", "clamps_", ",", 
    RowBox[{"maxpoints_:", "1000"}], ",", 
    RowBox[{"timeout_:", "Infinity"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "crn", ",", "rsys", ",", "times", ",", "data", ",", "points", ",", 
      "lessdata", ",", "species", ",", "reprules", ",", "height", ",", 
      "width", ",", "images"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"crn", "=", 
      RowBox[{"WalkSATCRN", "[", "expr", "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"rsys", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"crn", ",", 
        RowBox[{"ClampCRN", "[", "clamps", "]"}], ",", 
        RowBox[{"DualRailInitialState", "[", "crn", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"times", ",", "data"}], "}"}], "=", 
      RowBox[{"SimulateRxnsysSSA", "[", 
       RowBox[{"rsys", ",", "timeout"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"points", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "data", "]"}], ">", "maxpoints"}], ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Ceiling", "/@", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"maxpoints", "-", "1"}], "]"}], "*", 
             RowBox[{
              RowBox[{"Length", "[", "data", "]"}], "/", 
              RowBox[{"(", 
               RowBox[{"maxpoints", "-", "1"}], ")"}]}]}], ")"}]}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Range", "[", 
         RowBox[{"Length", "[", "data", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"lessdata", "=", 
      RowBox[{"data", "[", 
       RowBox[{"[", "points", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"species", "=", 
      RowBox[{"SpeciesInRxnsys", "[", "rsys", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"height", ",", "width"}], "}"}], "=", 
      RowBox[{"Max", " ", "/@", " ", 
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"PixelIndices", "[", 
           RowBox[{"Head", "[", "#", "]"}], "]"}], "&"}], "/@", "species"}], 
        "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"reprules", "=", 
      RowBox[{"species", "/.", 
       RowBox[{"{", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"p_", "[", "v_Integer", "]"}], "\[RuleDelayed]", " ", 
          RowBox[{"Rule", "[", 
           RowBox[{
            RowBox[{"PixelIndices", "[", "p", "]"}], ",", "v"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"p_", "[", 
           RowBox[{"try", ",", "_"}], "]"}], "\[RuleDelayed]", " ", 
          RowBox[{"Rule", "[", 
           RowBox[{
            RowBox[{"PixelIndices", "[", "p", "]"}], ",", "0.5"}], "]"}]}]}], 
        " ", "}"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"images", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Framed", "[", 
         RowBox[{"Image", "[", 
          RowBox[{"#", ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"height", "*", "width"}], "<", "300"}], ",", "Tiny", 
              ",", "Small"}], "]"}]}]}], "]"}], "]"}], "&"}], "/@", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ReplacePart", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", "height", "}"}], ",", 
             RowBox[{"{", "width", "}"}]}], "]"}], ",", 
           RowBox[{"reprules", "[", 
            RowBox[{"[", 
             RowBox[{"Flatten", "[", 
              RowBox[{"Position", "[", 
               RowBox[{"state", ",", "1"}], "]"}], "]"}], "]"}], "]"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"state", ",", "lessdata"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"ListAnimate", "[", 
      RowBox[{"images", ",", 
       RowBox[{"AnimationRepetitions", "\[Rule]", "1"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6803973434360723`*^9, 3.680397421797638*^9}, {
   3.6803975247123137`*^9, 3.6803975615801764`*^9}, {3.680398471315331*^9, 
   3.680398498077474*^9}, {3.680398559044063*^9, 3.68039857798982*^9}, {
   3.6803993556148853`*^9, 3.680399361294039*^9}, {3.6803996349269247`*^9, 
   3.6803996606914062`*^9}, 3.6803997017693*^9, {3.6803998127154408`*^9, 
   3.680399832954554*^9}, {3.680400011951935*^9, 3.680400022408893*^9}, {
   3.680400120742281*^9, 3.680400147115947*^9}, {3.680400196612588*^9, 
   3.680400201442669*^9}, {3.680400505028851*^9, 3.6804005354642277`*^9}, {
   3.6804006208005667`*^9, 3.6804006768463573`*^9}, {3.6836715597221317`*^9, 
   3.6836715619369373`*^9}, {3.68373743268504*^9, 3.683737434579191*^9}, {
   3.773348071110723*^9, 3.773348149948955*^9}, 3.773348260508574*^9, {
   3.7733484599229794`*^9, 3.7733484827009573`*^9}, {3.7733498168230963`*^9, 
   3.773349822510388*^9}, {3.773349861492824*^9, 3.773349966539503*^9}, {
   3.773350019973353*^9, 3.773350020507333*^9}, {3.773350052731489*^9, 
   3.773350066729409*^9}, {3.77358851320046*^9, 3.773588555141059*^9}, {
   3.7735891307340918`*^9, 3.773589132618944*^9}, {3.773589397461082*^9, 
   3.773589424900527*^9}, {3.773589902651178*^9, 3.773589917778227*^9}, {
   3.7735899659691267`*^9, 3.773589970712801*^9}, {3.773590050440625*^9, 
   3.773590179634062*^9}, {3.773590287592293*^9, 3.7735902953051567`*^9}, {
   3.773590327844152*^9, 3.773590448573854*^9}, {3.773590492253236*^9, 
   3.773590530674477*^9}, {3.7735905672981043`*^9, 3.773590571863522*^9}, {
   3.773590605238675*^9, 3.773590636398233*^9}, {3.773594935872201*^9, 
   3.773594935986368*^9}, {3.7735950006597233`*^9, 3.773595035071658*^9}, {
   3.773595264379964*^9, 3.7735953480041533`*^9}, {3.7735954428363857`*^9, 
   3.773595454460191*^9}, {3.773595485736169*^9, 3.7735955163192577`*^9}, {
   3.773595605114277*^9, 3.773595772265443*^9}, {3.773595812051676*^9, 
   3.7735958563739557`*^9}, {3.77359589968277*^9, 3.77359591509059*^9}, {
   3.7735967994842*^9, 3.773596800074991*^9}, {3.7735969556245337`*^9, 
   3.773596962144964*^9}, {3.773606678291636*^9, 3.773606709080615*^9}, {
   3.7736090830457077`*^9, 3.7736090942350883`*^9}},
 CellLabel->
  "In[320]:=",ExpressionUUID->"6a419f7c-acf9-41fe-8f90-1c116e19e80d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WatchImageWalkSATCRN", "[", 
  RowBox[{"memcnf", ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773595960289752*^9, 3.7735959747253923`*^9}, {
  3.77360674812173*^9, 3.773606750155671*^9}},
 CellLabel->
  "In[306]:=",ExpressionUUID->"43acb53e-a427-465e-b281-11a39b9e3a9f"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i27$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i27$$ = 1}, 
     "\"max\"" :> {$CellContext`i27$$ = 1000}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i27$$], 1, ""}, 1, 1000, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i27$41452383$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            TagBox[
             StyleBox[GridBox[{
                {"\<\"\"\>", 
                 AnimatorBox[Dynamic[$CellContext`i27$$], {1, 1000, 1},
                  AnimationRate->Automatic,
                  AnimationRepetitions->1,
                  AnimationRunTime->0.,
                  AnimationRunning->False,
                  AnimationTimeIndex->5.,
                  
                  AppearanceElements->{
                   "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons",
                     "DirectionButton"},
                  AutoAction->False,
                  DisplayAllSteps->True]}
               },
               AutoDelete->False,
               
               GridBoxAlignment->{
                "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "ListAnimateLabel",
              StripOnInput->False],
             {"ControlArea", Top}],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhGAaQ
2ejy6GqxqSNGHhvGpR7ZTejuRNePTQ+6fkL243M/LrdhMx+bvbjswOcWQmGE
yzxS+MS4A5s/0MUIxQW+cCHGDHzpAJsZxMQLPrNx+RndTELpClccEqMHn7+I
cS+hdEXIHEJuR9dPbBwj5AAvuHyH
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 2->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmMGe
Ac5HBnB5NDY6gMkRI48N41IPdxOaOgz9yP7AopaQGxjQ7AIDLGYw2GO6DYON
FpbofsQWxujmYvUjljDCMM8e0w9Y7cMCcNmHL/4JhgUWd2LzLzFmYPMvXjPw
xBk+O3H5D5s4MekaVxwSo4eBgDkE3UsgXREyByMs0e3BF8cMmH7CoO0BF+t7
+Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 3->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREcsEFuOwBXgABVXKCcIEl1VQioLxC5Hhwqokpdpm0hunY89
47EP13vbbSQ9dp9PG57nYQivy3bc3EJ/Ovbj5f5nUmy+pkbTPl3TPXzNvMvi
4f9xojHGEFd4x1xpfvtWHjeNyXKAf1q348YaHW6Ra6EWx5crAsdxoBasheeF
Lgt18IzzQX6un+6uxi/wzXxRgzU+zG1rXpkl17O5HtbEUMeaWXLz4DSryVNo
SRzDkf+ib5nub1iuei4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 4->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAihXKBEGCVyWk8kD8PDpUkOJez6aRXCdxbd+d
szvf2usKwH3z/rTlcez78jyth8OldId9NwS3XwOs+RgajGfQ2cS+xuuqMfP3
tK+1vef+3hthUjhN1AXhYPxs4DzB0QgXY1MaSN1AGgVcFF7WlftMdBM6Ki58
r2YS8eA7fh9KB8kXcd5sL7SM3tWSuXg8Exx1JdovMdX/X42Ir3oL2Tw8/kyP
rA7nzvoIjKNPZvz75wVgJXvl
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 5->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU8ENwjAMPPFA/TICK8AAESuUCYIEr0pI7QPxy+hQQVPncg4SkdLUdXw+
n9395d7fNgCm7v3o4+M0jvF53s7GNQ7HwzA7d98NpPDZCMg2yF6+5Xes/mUl
9vMiHItn89szESfFk/khlLH5LnHkDYHB9VlezE1pwDEKK58OF6mrwK909mwv
TujDeVR/uV5Vszw9HR28qs+cX83pj754PSxWQ/vWDCktCt1bs+jUq2ah1Y8q
9x84HFvlEdpbTb3/Yb3zApRIemE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 6->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMPPGo+HaErlAGQF2BTpBK5YWEBI+qv4xOUUsazmcUSyY4FzuX
sy+PsesrAHP9+XThdZum8L6f1uAZhuY6rOD550Bsv44WKQbF2176xx/fLDLO
JurscrgunYfDU/IjHjHL8Rx8h3hfzisSD6UB56haaXW4SF2pPmOsJ/ekpIdG
axAPscc482PNpI4HNbzeunMi7jO8nLlK5szn0RyZnolY9dfTUs1v/v7cFK76
WVqHc809BdqaOd2dWQCNZ3zb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 7->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMPPVR8WWErlAGiLoCnSCVygsJCR4Vv4zeojYhOc5QSyYxju3z
2ZfH0HYnAFP1+bT+dRtHP9/Pi/H0fXPtF2f9UyC4r8Ih2SA7/kt3rP4ogf0s
rnzDClEXWV0YOCU+whGymKP63D/nYB44duPLYlSudBpYJK+Un33MJ8/knxnu
8ccYLD/jY84OudrZQ8Ys90TMfYPL2rsotHcqp8qvuOC+zByCV+ZNYuMZiN4l
HpR31Z+1K8WOCW6tGa9v3r1KfJg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 8->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwjAURAcX4tYjeAU9QPAK9QQR7Kog1IW469G1aGvyMkkgJT+/+X9m
/hyu967fSHrsPp8uPs/jGF+X7Rzc4nA6DnNy/9vSFL5bQWssxMvdetY/v6yJ
ea6Q/8Mt01dJXwGnDCZiTbERY60/+bOG60ksWS55k51bXEy9TFdTv8BKTo18
eu/6teZv9QdP6lHo3dCq5kNitj5xM3N+c74z9R1v56Oar8irWgM4eGe9RLyI
Cw5uxvLv2KPQpTZrxwkaKrwByL97Eg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 9->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDzIXn2CX9AHFL+wvqCCnhaE3YN469N10dZmOqmFLElmSSaT
7C/38bYBsAzvzxgfp3mOz/N2Da5xOh6mFdx9DUjhYwgoMSjOueLjh2c/Mc6P
/xEx90X1H4gnBCeunR/jyriXmU/wqWty3mDV7MZ3zKtndBX1Pa6shcLrfNPv
z/5798G78DTr5dRuFWd5J8RF4nRXqVNfza3uqOGqtOvdIgQnEH/SuDzadzOz
qgPrs2ZND9bF27WaiTREeAETO3sM
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 10->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHx8+hQaCvncm4jualzju07
53R/Nc8dgP7w/TR5uHZdft/2o/PI7eXcjuBxMsDS35Cw+CB/PitiJ/y3HGZ0
HsYIn+vCxfl9yU01OTf3YSk2rlXUEf3Y2rnHHPfiX3BhrOpR8Il0rnK6pfT2
dy3od1X/rXuINVO85zg1W99zNfNAXxVXaQ7iyHU3eFc6BG8mmq98V0I3pR/n
9f0rzjLOL8FL4WpmXJexUusP5CJ5hA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 11->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKg0AMDV0Utz1Cr9AeQLyCPcEU6koo2EVxl6Or1Mqb5GVGiMzMy++9
5Pp898NJRD7N+uvTt5umND/O2+WVxvtt3MDLbiLa/kx2w7PFre/xAab4LgUf
cs/ykp6U4FjT5sbatp41xx9jxfto6R0x4J6dK1xZv7QnuNP8ZCZUb4jVoN+i
/rU4iTVjvP9+bLbYs5s52yfSJ+ZxMwvy13g7HYK9iOZL94roxvQ78oJ/FMP2
wu4I48VwNjNb12K51gvu1XjF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 12->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADFK9QTzCCXRWEdiHu5uha7EDm5WVoICWTl+bz
kvPjNYwHAEv3+wzpfZvn9Lkf18czTdfLtIKnTYHc/xWbWptxji0xFsvFx8Ix
4s05uacscFuTcxdR9Vjd/LYH+Jjc8FeYmb2yW7ME/VouOT/z7PgzIvkOON3N
/45dhLyoHSDOZ3t2dRo5lb/ig2xXV8wd1Y9qt3LIu2Le1G75Dqh/dRP8L98I
94cA5zuqblLNBIrtvxWceUM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 13->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA/HIErgAHQFxhnKBI8DUJaXwg/np0mPaQcRxYpaxrnTqJ
k93l3txWAB6bz6cpz1PXldd53R+upT3s2x7cjgbU42AYjf8VV9/Jh7E63elS
H3NWTs2pGpxjKjfXoPHUQv2cA6JP/XGfYZnGgTfTh7Sc+REx1VN7EvQ2/sy9
SP9/vUDcA2b8HR/X63rudjsbGhuxxqB/Mksu3tJ+By6Xk9PA5cY78pzcnMwr
qe9rJe+5t24mOL/h/RtQZnt8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 14->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+KtT9eilNnJZGlgm02TnZ1M
9nB99PcNgOfu++nL6zyO5X3ZzsGtDKfjMCf3/wVM3W/BLckve9Q1nFvyalpj
YsUE1bHnPN+p2NxDdp+LWxz0jPvPfLh3h2V7yfiSlorPpnrqTNbo7bg39c9m
gdxb7AZG0A3x/sxnM6v0AIImmf5TAzd9U4l2AUs4pRo4XPbIOQVeK/pTc+er
N9n5PmrdP3+Xd4A=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 15->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QB4hfqC1bQU0GoB/G2T9eiLelkZnEhDdskk8lk
d5d7d1sBeGw+n648T8NQXuf1eLmW/rDvx+D2Z0A9fg3KKC5zsYzV6R8fzhF3
xkTIiz7GY0/Gdrmt/qpuwk49TW3kE2dPPdwsjh9y/nwPh/Xk+n/0Vtyb+rtd
wHuJ3cBQvNUulHc7W+gBPaOy2sC1b8pol7AUJ6cB40YPzamledyLfX+EnbSk
GWVsrn8DXSV4uw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 16->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhR8uxK1H8Ap6gOAV6gki6KogtIviLkfXoovMy3ttA1OYn77M
fJPT/dU9dwDGw/fT5ek6DPl928/OI/eXcz8nj38DSvoZlFFe1iHWlSoWTqIa
4QfNym/uR8yxntPacr+bkWsUk7Lyj6tTutxf4Op0IOLMDdt4l9TqKTaSPzSj
Orek3WigZYOFuNOUcyDyCazUW3C7URzMW3IaPG/oyTFgXTOP3Qcxr/fC8/FZ
e0dIeo7Y2wfccnhy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 17->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNks0JAkEMhR8exKsl2IIWsNjCWsEIeloQ1oN4m9J1USTJfGEcyED+XpKX
7M638bqSdN+8v7E8jvNcnqf1olzKdNhPi3P7FakOHxFJ8GOcfFw1NveGEAO6
wzR6U1/eF/EyrH/qZzPGGOKkdnJ6cdSLsxkuCcfyTPzZXRFHTR/JHqKN8ogj
66OagrjebslOdbOdOT7UctXcAmASPt5R4DTFoJ46s9pH86T7CJzbvcS54svu
KOvP3dQv/wW4jXmz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 18->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCexBv+3Qtimwmk7SQbtPMJpNJ
jrfHMO4ALN3nNZTnZZ7L67pfnXuZzqdpDR5+BtT+a1BGcYmDxdXmn3l6wgjf
5Gx8Vx82VgW25cbYrH7UI2OUJlmujCPzUXyNrhu9cg+VMJHesp7KFejf3uNv
N8eAK1SOZE/ULNQZzczoAa+V24VgNptcSes0h+IEndfxDfrJdDIzASQ3rmHq
iN4cP96d//03S2t6sw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 19->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhR9dSLcewSvoAYpXqCeIoKtCoV2Iuxy9FkUmb96kDUyTNC/z
82VO97F/NgDm9vPp0+s6Tel9O6ybRxou52E9PP4MyN3XoIzOpQ6lLpt/xehI
I/aFT7N38VGesT/OjbW1+FGNkYbXe3XKt2IhuSouxFnxs2+leGcVT/na4g+/
lvkGvBWPqE9YE82hLsiVWVtOipUy10c7fXAeLk/1Hma4u7X6Kz3kaoniiNr4
LV3v/O8vfHJ79A==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 20->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAUHFyIW4/gFewBxCu0J0jBrgKFuhB3ObotllonM2kDLyR5k3mf
eZe2r7sDgOdp3Orwug9DeDfH6fIIsbrGyXmeDUi3r0EZ+SUOP9+CVYsx4s6c
oLhphz8xD/5xW/FlLvAYPrt+2RimFskp+gn2GQ5Xi9PQzURa4bnn6zz5LPM1
cZSebk424xR0KeUqeyXqLpnq3x4OziN7U3oQL+iPrb8wQ1kdtNwcKS0zrZf/
H12TevI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 21->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKwkAQCx7Eq0/wC/qA4hfqC1bQU0FoD8XbPl2LVXeymWkLKbtMJpPN
HK6P9r4BMOzevzaN575Pz8t2utxSdzp2U3E/A8jNB5hRnlW9Av59P676mCPu
rMme8oq64cJy18yXXuBz1Lnyu5Ax++O3yVyDtyqN6i1lhs5+FLhX5fmd4eWR
aaac4WlTdjzTm6f8RBomq2BXEbhnSQOOD5VptQ/SBelE+zDeAJmZqXu7Ex5K
jsodzQuhxHpy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 22->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAQs3ggvozACjAAYoUyQZHoqxJSeSB+GR0qEhR8dkqkay+Na7u+
7i63blgBuG/el65/nKapf57X8+baj4f9OB9ucwHp+CnkqvvF84wpz79YtRgj
9szJmj/c5rxgFPYffekFHqN6vrd65c96piVzQfyGVGshapTezoO5lGeRv8sj
kabUMHycXZi50VN+WhwySzMXV/zOEkc9m0T+ONMwD+IF8ag5hewrHpc3Y1r/
hcQEby96rHq5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 23->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUcENwjAQs3ggvozACjAAYoUyQZDgVQmpPBC/jA5VAwSfnRLpmlxyPfvs
zenaXRYAbqvXp0v3wzCkx3E5JufU77b9+LguAeT9FChRn2ffS837/lOrFteI
nHEZ86e3eW/V/oMv5zN83Jn31lnxs5xpyVkRZ8g1FiKG88eG4kw8gxfKG6NF
qx/Xc43Ds3xMj1qrTPy4J0fQfEa7gE88lKbSW3EXtGz5jG8fp3e95P/GA+X1
lD8BjZ56uQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 24->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAihXKBEGir0pI5YH4ZXSomsfFPodEcpvE9vns
y+n+HKcdgNfh9xnT+7os6XPbr4dHmi/neXUeiwF52AzFeP/XX2I4LtNdtSg/
i73FVDUr7F48Eauspz8VE/LsiIv4YfB3bq6NuSgM1wvV5bxQkw7OzLM1F1XT
4io8xw26pvpbnhDYFW8YX0MX9ZaintTsXJ6aX8DFam9rO21aOhNONG9eMl/x
C/Tfzl+yg3n0
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 25->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx7Eq0/wC/qAxS/UF6xgTwWhHsRbn67VIrtpMu3AlG1nJ5Nk
erjem3YD4LH7PJr8PPd9fl2248std6djNxb3UwJD+iWmLM/fiOp054+lItX3
+MyYamaFvYA3ED/myBnqg+dsebp7pM1pUZzZT+eLw6i0FHPLPuWJ2g/j85zI
FzVT4SpsxnCeRb0WA8TF+LnmX7Ka4DGgeNA31su759mz3UQ7NtyqehFR/4yL
8R3pDc0fejE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 26->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmAGK
kdlggE8ei5oGmBg6QJJvwMJGVgNzFzobxWwC5uHSjwvj9R8WM7CpRzcPqzoG
NPOx6McmhhGuuMIcjxkofkELb2zhQyjOcYY/A3b9uNIWvrDBFndY0wke+3DF
C7JbMdyNJzyJSUs4/YQl7DD0YQs/BuxhgB736HbjigeMsMTjNhR5fOGCJ/6w
xT+EDwBavnqx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 27->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBS79QX7CCngpCeyi95elttWI2OwldSMk2m2Qy
k8vj3b4OAIbT8mnz2PR9nu7H9fLM3e3arcHzZoCkr2Ez7X9OFCdvRP/XJ/17
6bdi6vx8Ib6k/fW8fM/C+VDGaZ8dsWpOYwxLUZPw6fFC60LxYfi29Rh2NgPl
H5wHb7cibph2dE8CvJ4uFVYYLA6fVBtPe4uRcFflmZyIA6t91DvkMsBWxB1e
qp0imnPtZgSwfa8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 28->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbnq7VCttkMm0hJUuSSTKT
w/XedhsAj93n15bneRjK67IdH7fSn479GNxPBljzM0xW+99PxUlOqMc8x1yu
OZy/b8S3Zj1eVi9nYPsJDMZNiBEOM2OzzDCr3Zd4obio6gDaX3HCtKJcIvrq
tugNJDN5DMar75dppmb1OyqtWJ8aJ9Oe6cs4UxyEuxC9JZeJrkGzqhedQ3DH
tXsDmCB+rQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 29->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkkEOgjAQRX9cGLYewSvoARqugCeoiaxITHBh2PXogBIzzPyZgE2GTGn7
//RNz/dn0x4AvKrp0+R33fd5uB3nySN310s3L56WAEr6BpaQ+Wfof06UZLVW
g+wx+8W5QvKS1npaQ+dGa0MNph7YGqiPt/YHQ6Zn7q4YaM5UV94FoP6bmUT8
YfPobUVsPO7QPs6ZqGdRrYZv0CvmI3W8+7H+MmYRA/MuAm/tt6evkD4A5wKu
Qzn+ahsBA6V9qw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 30->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsTbPl2rtaSTSdCFtGmTzWQm
2Z2vbbcCcNu8Hm25H4ehPE7r8eNS+sO+H4PbyYDafAyTWf99+F9gtaFafCjH
5RNuVX6zrAeqwb66z7gpf4PH+Q4nirGGgOcb4DudLHeuQzqr2Sy4iD7+0uQH
/b84Sivba7Zfke52topvdpfno3pljqqvDMfWifip+SrNMg3cXiTYjCfnKuZS
OQ44XeY+6B3u0dzvE/o9e+4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 31->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgjAQ3HAwXHmCX9AHEL+AL6iJnkhM4GC49emIErOdnWlsUljo7uzM
bI+35/BozGxu348hvS7TlJbrYfu4p/F8GrfDbt9muf9u27ePP6t2Dv8Rq1iQ
Q/NdXWZxX+IZYGDsNSieVf2uH+aHPuoMPQQ+zEeGlx0XigM+M82FFoPaPzxh
GtQ8fU/mle+p7hTjhBisvjYbxoNxRY2MF+IxHxQfNV+FqTwI9wLmVLtPQZfD
oX5ZzAk84C1n++O7AnUwfGw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 32->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QB4hfqC1bQU0GoB/G2T9dqlXQysxbSpiSZJDPZ
nK7dZQHgtnq9unI/DEN5HJfjz7n0u20/BteTAXX/MUwW/ffTioe8L06qxxxH
mcNLPs3FM1XyXS7nyRloB85PfVyMOYbAN/wmngKXEkfoBVFfuZ7q3E2oHZye
iiN3Wy3+He/xNngf1ddpxhhuRzWX2+8vfw19W1iKg9ldsP7IuUord0NSd9WH
NQhfq+2P3ye1PXtu
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 33->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwlAMszggrozACjAAYoUywUOip0pI5YC4dXQoVPDq2IEnpU2bz0ts
b06Xpl0AuK6ej6bcDn1f7sfl+HEu3W7bjcH1ZMCwfxsmq/3XyeL0n3vNDuWw
geoG5dNcoHr2OVfN+fEpj3fg/HCPizHGfI/ZReFVYyn7CL7CjhD7Up3ThNpB
conoZ9r6pSmpL8R73LyOs2zWDE+ntb/xS/jNegUMWBc8L2Kum1HtLHk3uMw4
qN6O2y9fD9hAfHI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 34->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPqPhCeUGQ4FQJqRwQtz4dCgXCeCbBkhs33iZj
rw/n7rQAcGkeny5dd8OQbvvl9HNM/XbTT87VrMDYvhSz5vZTSn6651o/QjGs
oLyRbURcoHy2/8H5saHj38Lxqo/0Mccwp+AicMSiuBZv53zHp+KR7x1mxsl2
abdqs5L7hdjH4XUzK2EN9SvYavypOo43V0vVCXtBHJX2KbwrE/U+24dnkJ1u
tt86d8PAfPY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 35->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8uxK1H8Ap6APEK9QQj2FVBqAtx59G1WKXz81INpJNpkkn+
TzanS9MuJF1Xr09Tboe+L/fjcricS7fbdoNzPar02L9Vo07tn37777GVWIyr
oG5ly960umT/0+fXFsRPxOOpTuarMCo5gYvAkQv1Ctg9P+C1vGzmAUM2S+U8
0G7hrOCNwKMMG9WDOpk/YFTe3xy+rKdsLs4b7RVy4HsBGCgX52H7NcfJpxb2
YSfOtur5CeYIfLc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 36->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHooXvuEfqF9gPgF+4It1JNQsIfibZ+uUpfGZBINRHc37Mxk
stfnu+1OAD7V/GnTtxmGND7Oy+aV+vutX4qXNYFc/xJrynXZZ7LWmVldhoNF
MSHOyhoKc0ffUZ1RT5KT6dY8Xm3DAedPtBiPdDCvoxmC+Fnbe96bMD0QjQXb
80HP2PWfYBgfYTkNH+Hx6qZHONqCN2D8PnAW9cDmYmoQuNj2wO56umVEnhQu
dp/1yPz740z2BHy1
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 37->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszigXXkCX4AHIL4wXlAkOE1C2g6IW58OEy10rt1FypYuc+o4
2V8f/X0DYOo+jz48z+MYXpftfLiF4XgY5uQuORBPX0fyMs7nKGL1T5Uvjepb
TMJFjrHMKz7MFYxbwVQO1HzcPaIfqRvMu8Ht951Nad2aYYkzejoeVR3DMeed
Djxjq7+oofaL7yxnxVwkH8M1m9sNtwNrOrk6krvRv8rRXMseFNbxXlhDE86z
lty30u9f5w07vnt0
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 38->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4hfqC1awp4JQD+Jtn67FKslkxnUh7TZpJplJ
dudrP6zM7LZ5PfpyP05TeZzW88eljIf9OAe3i5nV7m22mL97n7e/4/4A/k9M
cz4DLOdjvVeo42u3cpK5es06hA9yTXwAW/X29eNhWhM+mF87yIc8tRMBR/T4
iSsdcMZSf4LB9iv1BHqyOiqe9sZ0f2oHWjqx/1A3tldKg7AXgBHuJD/xsvhW
c8M4aom802wDzhNYDXwz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 39->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx6kV5/gF/QBxS/UF6ygp4LQHsTbPl2LRbKzyWphynRmk00z
s7/ch9sGwNy9X0N6nKYpPc/b5eOaxuNhXJq7NYDcfwJrcM41jr/7/AT+CoMS
l5mjDzyoOSDyCi80Nv+fsA6j6rGXG3qY22krPHKeUi3OKOKV31avylFzR53O
hzhjtU/OZ7Vf1f4EP/mM1GO0sldKo9sB5d+vWvRNem48ULPMKm/cxf/r9qE4
w/cJL7lvZ/zleQHNvnw1
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 40->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRUK9SDe9ulaLJJNZtYWUrLZTHYy
yfE29cMOwKP7/Pr8vMxzfl33y+Gex/NpXC4PqwElfQ2rWd/GrG2+t5/IpTVh
YiC1EGuB+AFP3mv2b7AKs6VWafCxtRW3X5xoAH9H9PT4kmq8x7U08Vg6S3CN
vLZqn5TOYV/geiN62hzKB5G33TfFUe1A0FtoquYbeAgN/Dy8JsFXb7kdYLPx
mlS5ZKb/+q5qpTfiN3y3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 41->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAUCy7ErUfwCnqA4hXqCUbQVaFQF+KuR9diW95kkraFV97M++Vl
crq39XMH4HX4/er0vnZd+tz2w+GRmsu5GYLH0YC++htGi3684zwXz3LiJ/pn
Ncjr+tiDe0HjYr+oFxi37O9wL92j0rgYj81TvAoOwDGxA9crvtdwFLMMximu
OGJtbNWV1RhoNzVPzHHxmRviSuFzGlB8K07d+xY4DAf8HsxJ4btZpAGnh8gJ
x/lNuYecM/f5Aib9e/Y=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 42->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADFK9QT7CC/SoI9UP88+haLEt2Mold2JLmMclM
9nC998MGwGP3/fTleZ6m8rps559bGU/HcQ7ulwu8u9/Fcq1tfZwXxZsceyg3
xYXxQWBB17Pt6kW/NfzZL/sE87geiLGj2apfaACOCQ5c/49jpknFMXtye0Ss
A+94zbuSWnAf1iOodXHCaPaEeL7oDUR6Kxy1XzdHwoM5ILMTHSpfsl2ePUoX
1k/xBlqs7gMqqn4x
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 43->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHHqQXvsEv6APKH6hvmAFPRWEehBvfXotLSU7O4m1kJJNMrPJ
bI63Z/eoALzq769L78swpM/1MB/uqT+f+jnZrAaM7WJYzfo2xnVePquxH9WG
vDAxCC5oPPsFXty3Z36Oe3jVT4GBz+31tsWFBuCcmIHxv2aMNCn6UO8IrQPv
RrhXKLFKi+zs3Le3j0wb4vc0jXJ/c0D36O0XBM71BZ51iLS3mnCetdy4IOY2
ucWfAPbHe/Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 44->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNks0NwjAMhZ84IK6MwAowAGKFMkGQ6KkSUjkgbh0dCkVynM8hkZw6/n1+
7u5y6/qVpPvmfXXpcRrH9Dyv58c1DYf9MDu3i0jT8StaxOrWZqXZb08QizVl
bIJaKmsJ9CIf/C3ze7vXfa0CA+EBH2HJagIH8j6YwecT362cTCY+2sOvB3Ht
dxz9UzVu/SwZpkrffzgybmC26m4a+I7iqD/xH+HwuFGHfM9D9qU4e2hvMnND
/6LPR38B54t9cg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 45->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHoQr32CX9AHFL9QX7CCngqFehBvPl2LRbKTSdiFlG2SnUwm
OVzn8d4BeOy/n7E8z8tSXpfd+nMr0+k4rcF+M+A9/Ayb2buNWwNZGLcnyJWY
MD4ILHhuEHf3XsTT/oVf5XMsrQGNn2H//XxsHePjHvi90rtVE8dDzRGxDnYe
2U5l2nIvFW6iv9sN5oq6B1k34tOgd5Sn6iv9Ix7MW94bdFB9u32gufMeqRlz
To3zAQArfzU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 46->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEOgkAMnHAwXH2CX9AHEL+AL1gTOZGYwMF44+mIEjO002U3KSmd7k5n
ero/264CMNafT5te12FI79th+Xmk/nLuF/C4BjA1v8AanDPOARMhzifolW+C
ahBvwc8Gkbv7As/qF3XVb7EsB3mxyTNv/+v2MA/VrAZ7fwrmKPHEcindvBvn
OXxPznPlrdUieQr24mbFVoPkjebZ8Tvqs/1qxkiH0mo1RDMrH0p08+7d3kC6
Bb/j+eIzuD6AdA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 47->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDxC/UF6ygp4LQHsRbn67FsmQnmdCFlHQnySST
Pd5f/XMHYOp+n768r+NYPrf98vMow/k0LOBhNWC+/A2rWd/i1kAmcXtEbFaz
1uBa8L0h8F1+gKfzkw4qnrGUA23dSEepKx/LY+54Bs6fLXeQpzRxfahdQutg
ed3+Ez2UFpJnw164j6oNvRfXZ3Kv9M7iIv5Mf4WBajT+Bh2yuRtdEORbPtox
Iqt1vtkAgjU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 48->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPyQ/noEr6AHKF6hnmAF+1UQ6of416NrsUh2MskupGzzmElm
c7w9hnEH4Nl9P0N5Xea5vK/79edepvNpWoOHzYCl/xk2s3cbtwayMG5PkJth
/jEYC743iHtVT35V4+YnHaJ8jqUcqHGVjqGufCyP8fEMXL9YbsZpaKK4VJ+R
DpbXvX+ih9yXjKfxLhIDvhfJG/gdPmp8tVsZhu0v25Fqn9CudRxiHzK9bA7v
hXpjnrnG+QB3UYGz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 49->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwkAQLDyIV5/gF/QB4hfiC0bQU0CIB/E2T9dgCNX7QIdJL9XVXXO4
PYfHBsBr9/sM7X2Zpva5buefextPx3EO7hcD+vlvWIzvHGeDsjDOJ8jNMFcM
jQXLDc7d1DvxrnINF0i/ty8dMxw8PjxTgb369WFs8ukZdH1nHhon4JH1MjPD
34PXV+/f5Z28r7BPoYvWnHl7/EptPHxI/EiXbAbBqdBG6JvUmh6VLk6P8F1w
DgIMgfMFmDJ9eA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 50->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbiQbj2CV9ADFK9QTxBBVwWhXYi7Hl2LMYxv3iQGJiTzeW9+
+8t9uG0AzN37GtLjNE3ped6un2saj4dxNe6yAEv/EWSx7++fBQ2fYrOnghdh
FgzGyofj+e3ihX0hX5cLfvWqX2xzOah8bE0N7KLnY7GNLqwR5N97nGruAZeL
g8ZiXjd/6k3UW56X5GnMRWLA5yJ5A73st6rzTwybX21HeJ+YW/HJWFE3WGj2
bi+sj+D3OC/3Cn94
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 51->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAiBXKBEGCVyWk9oH4dXSoCOBczjGRXDmufeez
sz3f+usKwNS9Pn26H8cxPU7r5XJJw343LD832YD58DZks/7nbg3C3Bx7nFwP
d7YYjJUP17Nf1YvcSL/lYg7FKXtQ/VhNAfY3zsdimxjzF/Xkt3ajZqK4Ks3Q
c2Beqe+P2dpZujzBXiQGyng0k3DfqHUqfYqf+2u9EcVX+I05wPCovYKNciq9
lOe9ox/OE49WgLc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 52->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDxIrz7BL+gDxC/UF6xgTwWhPYi3Pl2rW0zGzC5dyDbZJpNk
kv313nYbAGPzvtr0OA9Del62s3FL/fHQzz93WYDp9BVksfpis6Di8znLF8YW
eAoTCisfjmf9Lz7wrfVvcym+Iswol6vH9hT5KV4Fp6pHcHw0oxWcuDpUDDQP
Nm9xBwKMVXkqcwkx4N9rnJRwLU+qx2i+XLurqTAbzuf0Ag+W72iuYCEf3ouJ
sNQe/XBexe2COQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 53->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADFK9QTzCCrgpCXYi7Hl2rU8i8/BxIm8wkL8lL
9pf7cNsAeHSfz1Cep2kqr/N2Ma5lPB7G5XFXBZj7n6CK1FebBYnP96x/CNvB
8zDhYdXD8ayreMM361/m4hxWTquf2apH9pRgN7w6nMo75oDnYs4o6MHkJOIR
mheFAydW1Jdym+TxYt1a0d5ne8KzceeV7IWVn+uLdoR3QOkRh7JftHGh3x91
WPk1zhvkqYA5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 54->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXHmCX9AHEL+AL1gTPZGYwMFw26cjEU23nW0lKWmXdmaZ
6fH2HB4NgLl9v4b0ukxTWq6Hrbin8Xwat4/dHkDuP4E9ZP6tdSDooY+DV8NE
L2Zhcz2vczNPeqP/l1x6jnGyO2R2H1Kzu7i6Sh5xFvFnyev442ri6Yi6DiA9
lI9gmF0JeP7xrMBAeR7tifbG4MPiIMAwmoPz6j7JZ3JHh8JTlHPG98qeac80
Dt2jH84K6lqAuQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 55->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAUHFxItx7BK+gBileoJ4igq4LQLsRdj67FKq+TmcTAa16S15l5
n/3l3t02AMbm/enS4zQM6Xnezodr6o+Hfn7cLQZM7cewWPTjXbTqu1kcV8PE
F8tg8v8SC+udY6v5By7O1/lTq7lWesRZabF1Zc3h/i9+rqvJwdakEB97o/Rw
jOQTGFksBHchf3lG7vO8OI1Zb7jeyHFYp5sNzrE0I9ybyO04VT8iv8QWOame
xWW1/nBe3fB9Nw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 56->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKg1AMHFwUtx6hV2gPIL2CPcErtCtB0IV059FVqm1MJnk0EH3RvJnJ
5/zomlcBYCiXR5PGW9+n9/20Bs/UXi/t+rPaHJjqj2Nzed5j7cjkeMawIkzU
v3s5PHhYOL5z/PQ+bA7jZHqMLhB8R3/YV61ZfP+bn+Ble+LULGfGdLAcykcw
TC4Id1A/jWHP0b6Es9H9g8WJdEp+r0avV7qvu3ma2TzYHkC7qonNTJq7R1+c
Ga1+fzc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 57->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgkAMnHAwXnmCX9AHEL+AL1gTPZGY4MF426cjEbS0M7skhS3bdqbT
Hq6P/t4AeO4/rz69zuOY3pfd7NzScDoO82W7GJC7r2Exe159b6jEqIfVKtVE
98+r1QM5r/n2W8MPXAyWz2eYjENmfIjPuEhdPWfzX+LbXqwupF5VE9GznRnj
wWIoHqkRYkGwC/1TH/Fc2pfibITeTFM1n6CV0EHNYzNfaM5sHmwPAo7ryd9n
Fyf36FdnAhptf3o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 58->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHHoQr32CX9AHiF+oL1jBngpCPYi3fXpbXCEkM2kh3Q1NZyaT
nB6vYewAvI/rayif2zyX7/2wJc8yXc7T9rFvAdTrL9DC3v+5D+zUyEfgKUw0
LIXJtFfyvz33+IMew5XyJLiV6bE9Ce7UV++V89iftqZaHQIv2wmm2XvGPFI1
lI9ghFoQ7qR/miPes31JZyP8pnvF/EbUrnwIs2fzhdbM5kF7YDUC23PTmsC3
AGdlfr0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 59->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHHoQr32CX9AHLH6hvmAFPRWEepDe+nQtVk0nk7iQ0m2TzGQm
u/OtuzYA7tvXo6uP4zDU8bSZL5faH/b9/LNdApjKO7CEff/cOfAnJzqqV9YT
5Vf3PcX3Yx5hvcDMejCW0kjVphjAelbE2KmuzMF8Zw243ukt+mU7wZxdDvz8
Kkf5IXlH+wKaLcCL/JhED/ZJ4kbeBHrLvVJ6w3NXWoZ+WH8NtuIs/VAzEBd7
nGeMrXIc3hMsZH45
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 60->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6VBRwPePEkpu48TIe
+3B9dPcNgHH3/nR5Og9Dfl62s3HL/enYz4/7RYGSPopF7f1re0XDJxKVq5YT
6R/3k8T5PI5VLhsvajZzmFqKIxVbrQEQvqh2lVePwfwviU/i0PWn5hnthMdM
PuD+6QzmIXFH+wK27axULNngu+1R1o1mU+Gb9qqCZcWn4JK4Arh/wYXiobUH
HosVhaOkhg/VewFa9H67
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 61->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzwdKrbgmUmx5Dpu7LE9
zuZ47voFgMvq8enydT+O+XZYTs4pD7vtMF2uXwqU9FQYLULnYpworBYm0jfv
I+Fc50ss/NpYM+YQRl039mZymzUCVu27XiSvsYfASbTE4cx8bkbVM1nw/IRj
9iH7du8F7L//KRzpg8+uv9ndNPimd2UwiCtwnN1NPb/g4p/c1m6jqHdRko+R
9dIdUF19Ow==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 62->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEQCx7Eq0/wC/qA4hfWF1RwTwvCehBv83RdFG0zmdZCt7SbpJlJ
d+frMK4A3Davz5Dvx3nOj9N62VzydNhPy8/tZwKW3hPBtFRjFNYYFwzGsTZr
Iv1435G0HiIt1GuP4zTKe0UPFFfVZexH7CMvsq+N/nBWjv9HfVGNyrNb4Xvs
dII8Whoqm+oMRT8auTLH6M7IXzcboRe9m0jDeYfHhdmU9YteMF9xW9kyRr0L
I1zPK9ITojR6/A==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 63->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtPpA/TICK8AAESuUCYIEr0qVygPxy+il0EJyvkstuYlr++z4
fLgO3b0xs0f7/nTxeR7H+LrsZuMW+9Oxn537Rc1S+Kotmt9XO49BP8Z8/EIw
DrER08I/7yeB45nCsvLcqu8wslqqN6yvcIt+iK16kXMV80GuXD55H+NT7QT2
7E4yF4dD+LANDMZN8Q+4UrxiToKatX2pckPwcK5szqw+66+2Vzm/7i7yHR+r
KN4ghuUniHO74/ZuArEVfD8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 64->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwjAUszggrozACjAAYoUyQZDgVAmpHBC3jg6FRjxsv1Apze/Zcexs
TtfusgBwW71+XbkfhqE8jstpci79bttPm+u5AeP+0zC3OK7zWMP7XPPeTz6u
Y27mROVKOJ020YnfvoVxfkSc0+a43L1ETzJnTNPXiAlr7IHg+XyjofUm5Gzu
jS/Ck+TR4nDZcH51LfOymTmI60+eosfwpfdP8pXaxAebTTzPeMGaBYsvR5p7
qHH4keqEQ97dE4GXej0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 65->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAQs3igfhmBFWCAihXKBEGCVyWk8kD8OjoUWulq+0Kka5LG53N8
2V/u3W0D4NF8Pl15noahvM7baXMt/fHQT4e7OYCx/QXmiOtlHzF8zpjveTIY
x9zMiYUr4XTaRCfWcy3H+RHznDbH5e4lepI95whXHDEn/GMPpC9c32iovQmp
zbPxZaUz6wfqHK43zpvs/n97DuKq1LZ6DJ/zqNZfwUJxaW/IP/Yiq5W9KwnC
uPyRcOKPvLs3yNN6PQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 66->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFxItx7BK+gBileIJ4hgVwWhXRR3ObpWW3iZN68NpGnIzPvM
vPPjlboDgLH5flKebsOQ3/fjfHnm/nrp58fTsoHS/jeWbf/Xu8XwO2N+79ES
WM7v6oA5aanaXJ2oz7U+xVF6VDzmQOdXfbl6grvKI3VlDmnMp8W4/kS8rZmw
eNW70sVpD81jnIwf+UX9RdzQc1CsHT+dLiKe8iP0V2HhcaE3pB9rEeWq5sB4
q3qzS/FLu4GRc/cBIER6vw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 67->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHHoQrz7BL+gDil+oL1hBT4VCPYi3Pr1WKySTyXYhuxsyO5kk
e7wN3aMB8Nx/tq68LuNY3tfd4txLfz71S/CwGjC1P8Nq9v73LYbjjPnGsyWw
nD/ogDlpKW1BJ/zJcVW/00Pv1J25VF1Bj/AzLWlfLTf1WNZo+ubyk6atPxFy
C51qFjZmtTp9FY7QV0S/Vr+cOaJu5srmyXkUn+XkPirugEXEpbOh/vGss1zu
H4jZSgz0+6mtYCTXDF2ke/4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 68->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe+nRd3EKSznQLKWmaJpOZ
nu7PYdwBeB1+25Df13nOn9t+OTzydDlPy+VxNaCkv2E169v7wu5NzOWpRXJj
f9u3+ki+Rl0MW4Ozvglx1b/BAzRzq/zNuQgee1ZYJK8WT+CYzWp5c/0JR/JP
EMwRq9VG4bFYC4mxGkwbFyNzsLesBvOZDlKbDibaV9RocgUPVJvAX9R6i4ee
tu6vkNpu1l5Oijlfynt7eg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 69->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMHHooXvuEfqE+QPoF+4IV9CQIeii97dNbqUicTNaF6MbEZDKT
eze1wwXAUv0ebXo/5zl9XtfV6dNYP8Y1eNsMyM3fsJm923hWcfPtkBcdkcv9
HQ6Yt7gzNocTer6ov8ODuEbUvzTXPoPwIyyZsBy4YM4FB6yLmy/QU+4EcSq5
gNZC9XV7U6ihtHE7d6K1wiF3RehS0l1iIp95VLviagY8SG2IP9b6jAfmUOlu
j/o/N4UcW3c/XzA3eXw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 70->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAESuUCYJEX5WQygPxy+hQtSDnfE4tpUka++w7
+3h79MMOwLP7fvr8ukxTfl/38+Wex/NpnB8P6wJKWhbWZc/2vah386/yi0z4
cn5XBwgzaTx1ruIDX8Xfxv4s0kjFtnj9OYh7VEuoq62BNOHd+nCPo37KmRCa
ujjoXqi8jl8Dw2lquZAmir+shzAU3tacqJoYU82DmhWHGegge0P6ca+jXBVf
QGOzD3R8SQ0f0n2xD26fef4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 71->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+KtT9dilclktjWQdrdJpplJ
dudbe10BuG/ej7Y8jn1fnqf1eLmU7rDvxuB2cmBoPo7J+cxxdoineM1M7hwm
98AYDs+dQ30l1/Hn2q9Zjcz3RW7Id9ffX7pyP6KJvjlHZ1ybp90J03OqQz67
3VKOoX/EPqyezIU1MTpUsQTD4S3tietJMd0uuD1JmBUd7GxEv8Bn5l+Br3DW
ubO5+qHJOZbbz14APXzB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 72->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbpWt7CdZFIDKQm7MzuZ
5nC9d/0GwGP3+XT5eR7H/Lpsp+aWh9NxmA73NYGSfomabT33nFi5I0PwqTdR
uRacyefz6gVe3PXmb7FzKI88bOgXqBb6/vJV+MMeML54ehpdazvBmg0OtjY8
gJnR0x/+LzjeBDxuD8undkztiZqLNbKP3kyGM/AkfBs0TzQ375bQy+HhS7J3
pE/feAPiUHyC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 73->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT9diCslkpu3Clmy7O92Z
yen+7PodgNfh9+ji+zqO8XPbT8UjDpfzMH085gRS+Cdylue55sRKjw2D5zCR
sSrMoPHUuZo3vYp/OTuHwmC9NnGDr90uVlejD2vA80n9f2UP3rnR2Xlhetm/
RO82+QWhzQKOrNHiuTu2xJW1UTuyjopTgwm9u/Sm5E1eOw7VrODMvpeh5lNo
exqcSt8vf6N9fg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 74->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3Pl2LVZrJJG0hJcsmk5nZ
HK73pt0AeOw+v6Y+z31fX5fteLjV7nTsxsv9FMBQvoEp5vnvzIGFmvAL8P49
igdsjqLxVM796l7pN/MQY7BfobZ5ID5HXCJORh95IjWSFufpCo3uTQTXzGue
q3ZAzY68cDsncDJuRgvlkmO2a8yJMDPPQq+QcE88Ve8UzVJ7xXNcDXT/UHyN
wzE1b8l4e/w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 75->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEQCx7Eq0/wC/qAxS+sL6igpwVhPYg3n66LVdo0mRZm29I2m2Sy
O9/G6wrAffP5jOlxnOf0PK2XzSVNh/20HG5zAa/hW8hVrn97LnTu2GHwHCYy
VrnGoPHUmt+rc6W/+h88BvsVaWs0iL3j4jhV+sgTqRF0X80djU1PBNfIaxRc
ZG4CDOWFzZx5q3pss6Y4RlljToRZ+d7JidQoeKgsNb0OfKjekneq7+WwuaA7
ku9/vAE1BX1+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 76->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozACjBAxQrpBKlUXpWQygPx6+jQ0kTN5c6N5MiWnZzv
7Ev3DI+Dmb1OvyvE930c46c9zkEfh9t1mJPn1cym5m+22tZP8bYG81iz5NUh
tYjP+si+8x/z0xsvz/gzPK9e6aD6Kbha/V7qihqIvyVH4KJsj2PFYUdHujtk
fojHZotaIDelg9qTQg/wJa6aLfYEMWrn7QnlKPRimrJZK6xqrwimqkH8qalr
aL/5fAEDC323
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 77->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwlAMRIMLcesRvIIeoHiFeoIv6Kog1IW469G12paYvPl+SElIOpNJ
sjvf2uvKzO6b96ctj2Pfl+dpPQaX0h323ZjcTmY2NF+zybw/x74m5mPNJ68e
1EZ+6mPxK3jkz//U8qSf+NSMiJ+0/WB6rcZYONc4A4EtNYKW1I/oI+KoO1Fz
SbcD+6P+1Wz9btNsBQ7u3IQu2Ms/fYTn48hRuxOlMfZBt6R2rbjSXQGnqon8
Q5Nr8N6W9wLjTX56
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 78->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAUCy6kW4/gFfQAxSvUE4xgVwWhXYi7Hl2rrbxmkqGF13mP90sy
c7w9mnYHYKg+vyY9L32fXtf9FNxTdz51U/IwGzDWP8Ns0V/iWMN5rvnm3Sdq
eb/C8fcL85S/9JTyir/a5/C4fqsbiCt07yZd42zSRHIUXHiW04TnuHeiYnki
56vwWy1Y/8jDzJF3DsOL9NzCz2HiOyxxUu/FYmeLvMVdu10rvoSZsXAN7x/r
vCbbs6p5AzwsfgA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 79->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbn67FCtnJJLuQbtok08wk
h+tjuG8APHffx1Bf52mq78t2ebnV8XQcl+B+NWAuP8Nq1rffrHXj0SGMHqbz
6XA9+/+aLK74N/0gxoj0U3o1HARfpUdX10K30VhyJC5O00QTxuGZZTrKW8xP
9R9qEeif4XRnCOoFuj7ip/AcT+Sc1L5EO+XM8hazjv7l9kDop3JU/Vx8jstr
cj6oGn4/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 80->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDggrjyBL8ADKr5QXhAkOFVCag8VN54OhRZNpjNRLDmO43gb
+3B9tPdNRAy7z9Gm8dz36XnZTsotdadjNxn3M0e8mh/HzHhfdOQQvPrjiOKU
4sqaiNif74uPsnPtTsdcK3v4fhT/41XgWIVrQxIwZon+qj+sy+0ExqnBUflj
Xjd/N0+FpdwfgYPbkyxG5O8Yp7Qnri/EW+VQPale7C6V+qaZOhzkHgj81D/5
TnqGBcsvvQGxLXy9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 81->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOgkAMnHAwXn2CX9AHEL6AL1gTPZGY4MFw8+lIBMNOp11sUrbLttOd
2R6vj/ZeAXjuP582vZq+T8NlN21uqTufuunwMDvwrr+O2dfxsmdHIcc1wihh
mpiM6zleaqJzxT+7D3wM1k9pZTjCclU6btK1pnWlseRIXIymgSaM84+O5k1I
OzVz0ax4+mecgjdwMZD/5zuW+Ck8wxMxJ8XFnSXRG6L3pl5sKo9M1jv6/c5A
+RgBP8mA/g==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 82->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKAkEMCx7Eq0/wC/oA8QvrC0ZwTwvCehBvPl1X12UmTTrQYUozbdpm
d7l1/QrAffO5uvI4jWN5nteTcy3DYT9Mwe1swOv4M8xWv/9+jeE4Y75xdwSW
6ysey5uO4tbwrHAyLuoHPkjw0PXTHhF7zWadzpV5Cq4Q/0N/lMtpQvXg9uRm
DYHh/bt9qd1I/SD+cTppcoB6FHnUjCwntD7XcNy4F6slURuidqavoAPiHPZO
GKkjMbslFnK9Aa8wfvw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 83->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOgkAMnHgwXH2CX9AHEL6AL1gSPZGQwIFw8+mKoCmz0xKbFLrpbDvT
7rnp6scBwFC8P3Uaq75P0+04H+6pvV7aOXlaHXiWi2N1G3/PFsN5xnzyngks
91c8fjHM3+G+4WlwMi/6Z3yoBvNRd0ONQKY1mnU4V8GTtUHcV/oUD9arNERz
UTwgMFzX21eGVVqojtqBx2NTjzTuvjWnnq2p8CE3MadwN6AYf/Sy5uHI3HdE
GMst7/cCorl7vQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 84->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREcsEFuOwBXgABVXKCcIEqwqIZUFYsfRoVCQsV/cWnLiKP7M
TLI5XtrzQtJ19Vractv3fbkflsPhVLrdthsu16NLj+bjGt3G37N3TeRUrdKv
1jPEzny9j381yT3x/8NjZhEeqk05GjyZjrN0bdxuNEaOwKXGj/hOcch0CTu8
H+EnLTzugEuxBv+GxyrmGGbP6Ed6U36KLflXQXOvX/KuNdzWMA9yBPOxjyD3
bU8lF3u9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 85->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfEbU+HiYGCawcqZUvVOLWd
bo6X7rwAcF09P1297Yeh3g/LaXOq/W7bT4frOYCxvAJzxPy958CPGrtMP9ez
yWkxnvMPJjlX+r/4hLsUH4VNNYJ6G/xfvhb6B4+lRqHF6VN6lW7nufMaooa9
cb2VF9JbaEzGQ+VuLlY3aydvVX3KLXlXPJvGv2Sujndcbq5c0+BLWzMGbu19
D7ECfT8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 86->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhPRRvPl2LLaTJTNpASrabZGcm
Od1fzXMHoD/8Pk0drl1X37f9eHjU9nJux8vj5MCn/B2T23g+e8dKjjTRT/Vc
xMR8vY8x1yX3jP8Cj3lLYku0Chzheov6TboWg81pLDliGz/GkfWg+iP+D7tF
5sfwr2lBtQWvyXCwWM1F7ZLn5bVl+Sm2ZK/8bIJ+yVwVbms0j+SE+hJz7E7E
976ybn7+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 87->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDil+oL1hBTwWhHsTbPl2LraSzM2sXsmRJMpuZ
ZH+5d7cNgEfzubr0PA1Dep234+Oa+uOhH4O7yYDcfg2TRX9+s+FPjj0Gz2Eu
/IAxH65n/5dbiSv+i37CX7a3ilYFRxC2qV+laxt6I40lR8HF8VMcIweneQ5x
1QcIQ2lTw1ZcCm2ha2p9KN/Nxe4acydt3VwsVmWveDZKv8jB7RfvgdI1qxxX
T3m8E+V/b23Pf3w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 88->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmAGK
kdkwPjpmIKAGJ8BhHi4zUdhIZsAAun50NooebPJY7MdwD5JdGG7DIo4Pw80j
Qj9R4YpsBloYY/UjFr/g8h82/2LzA9bwZ8AUx0hbWOIPm/sJhQVG2KCZgy0O
sLkDGxtXvOBKS+j+Qg9bXPGCN6zxpSV0u/HEE670hZ4OMMIV3TykcMaq3x5T
TQMWtyAAAMw6fr0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 89->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmAGK
kdkwPjpmIKAGJ8BhHi4zUdhYALp+dDayvdjksdmP4R4kuzDchkUcH4abh0Tj
0k9UuCK7AS2M0WlkNTj9hyVMsZlHKEyRzcGqH5ddWNxPKCwwwgbNHGxxgM0d
2Ni44gVrWsPiL/TwxhUvhMIKZ1pCtxtZDDk8iAwHZIBVHTLApd8eUw3cPeg0
GAAA2Fx/wQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 90->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOgjAQnPhh/PUIXkEOYLwCnqAk8EViUj+Mfx4dUEiWYYZusu223cd0
di/Ns+4OAF6ncanT+55z+jyO06FNfXXtp8fzrMD39lfMGu3lzIqCjxWTz+Vc
2UI4nu1YV72r+hIPDEfifk+XmLhzrl2Mgs8VBsq54QXkz3cCg8rnOGW+FA7l
o2au2C9QHeLE9cPhcFxyHjdL8u/Et+tLiSs7S7GOujN/cLijSL8oKp79uF+8
/2QAwz9/Pw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 91->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz1Cr6AHEK9QT7AF+1UQ6of4t0fX0hay05nVQLrZNI/J
ZJvu0fY7AM/D99Om13Uc0/u2ny73NJxPw/TzuCiQL7Ni0Wivd1b8iLFi6rma
7GPhfLZjXxA+11/igYkx/uqMKM9MPdQ8lteIgTjmM8YU86Gs4ThRWBVfXEfm
V3pJ3BUuNtwQt2oHCoey1V7VO3FzMUa3lypG+JjI94Y/lP5/eIgi+0VR+SIu
M0ZwzAcXH4EC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 92->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx6kV5/gF/QBxS/UF6ygp4JQD+Jtn67VKrPZxHZh2u5MmGQy
3Z6u3WUF4Na8Hl26H4YhPY7r8XJO/X7Xj8XNFEBuP4Ep4vf3HjFcZ8y77o7A
Mr/TAdFXaSt0Bl5w3vBXegJXhTF5NVuO/YSGf/NYX6MG8pjfEbN4PtGn4HRY
6NmZ1+3f7TOThoJHeDO7C94hyrzaq/LIzcUa3V7m/heHiX5X/qHML/EhHqeF
/VV+yT4g3O88AZzmfUM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 93->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKg0AUC12I2x6hV9ADFK+gJxihroSCLqS7Hr3VannGxIGRmffxJZnc
2mfdXQCM+fdTp6kahvRqsvnySH1Z9HPyum7gff9trDuet3us4TzXLHm3RC3P
dzig/iuwHXDiiDP28iyJB6bGxE85AhJXfAvmY3WlfseL+3f8RMx5InJQmisu
TmfFV81TWjBujkUd1Btwj/Wam+28xtwJI3vmzCeMT3opzlEx7HN2hvCWw8L6
Kr3k+4Dq/usDGpR9vw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 94->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOgkAQazwQrz7BL+gDjF/AF6yJnEhM8GC88XRF0QydFsMmA+xOmem0
uz1f62YF4LZ+PepyP3ZdeZyqYXMp7X7XDsnNGEB/+ATGiN/ffcRwnjHvvFsC
y/0dD6i6glviicyTe/BZL3o6jDqfnRGaV/SC57G60v9RE35HzJL5pE4Qtc0s
c146/52fSgvnl/MjcSYtJ3VE7393YMKJODpfHEelk9M76ReXmUPqRvolTVye
daTZfzkQHk/wQHx+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 95->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmAEH
brBHVYNNbQO6OlwAi1pc9mN1Ex7zsLFherDJM2BTi809DPjVYBPH60cGNBop
zLCFNd5wRfYfWpig08hqMPzHgD8MiA1TZHsIpRls/sVmH6GwwBe2uOIAqx4c
bKxxiCcNoLgJixlYwxOPGvRwwhU3GOGHDAjZgSNtYZiNTx7ZLiSAK24QAADV
Pnw9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 96->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAgXn2CX8AHGL+AL1gTOZGY4MF426cjEbTOTgtNlt1l2u10
2sP13nYVgMfu/WnT8zwM6XWpp8st9cemn8D9vIB8+izMy56Xu/VhnH2+uDLh
y/k9HupNxa3giRVcnDPnDHzU/7A+0L7gQT3Z+LCeYExw4/iCj9BI6bNFU65F
xjv1qnxrWhQzRz1TfZAxwdnTxKsrmost9SmtJXehnZoHqZ/ijf+44u0It/mM
eb352Qjp5H45
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 97->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszigXXkCX4AHTHxhvKBIcJqENA6I254Og3UUY6eRsrWNk9Zx
tqdrd1kBuDWvT5fuh2FIj+N62pxTv9/1U3AzOzC2H8fs5Trv2VHBvM+VmXqu
Jp+xcT6vc46L/2HVexBj1HnID/TP8YDPWGC4nws/6glEnRLDPVV3shaqhsQG
7yjvdfpHeikuPzNHmikdZA7NCuujeNZ4OZ41fjD5tt9Gg8WCPvAcMG8EGJlP
OKfN154v1n/8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 98->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHgwXHmCX9AHGL+AL1gTPZGYwMFw4+mKsmSZToubFHa703Y6
3cPt2Tx2APrq82nS69J1abjup8M9tadjO13WswHj+WeYrdznMxs2MF+/Wk4+
Lyf7eHE875cY595gFR9Hoyg27A+WF9dhjotP6JnjFFfTKwjv+EKdCC/fT8Aj
6jf3FOVWvcg3F8xB1VRayrobb2DFiTi6cxEa/zMPU1vMydNC8S7xXm7Oqfzl
3+gJwuMNXTp9/A==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 99->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMfbiQ2XoEr6AHGLzCeIIKuhoQxoW48+g6Oi1p8l61kJLPS5q8
dHu6DpcVgFv3voZ0P0xTehzXs3FO4343zsHNIsCz/woWsXq2veAH5uNnR9RT
NYPujs/3eskR8YBl/YBjlN6Sqh/TV7bVPMVH+Mx5vgZIHctbNR80B6Gew1Ns
o4/WvJ5rvwvGRYtbtQOZA+IXO1T/p4q5HuVeCMf/7CO8TfbUmqPgxN9itWXc
vmWO5yxiXtVmfYA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 100->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDxC/UF6ygp4LQHsSbT9did4nJTOjClu5mNpmZ
ZH999PcNgKn7fvryPI9jeV228+FWhuNhmIO7ZQPv029j2fa/ni3Gxz2mxdki
WF+f8VA5GbfAE5Gn0sYwlnfKLdEWfHG86lnpaXfEz/rOewKSx2L+9EF7EPI5
PMUmPJTeljupzeYr8zbTQd+A3K+YE6XLc5R9IR6v6UeoTfrkvaD9FLPFcsu4
ubfL+snrfQDNtH2A
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 101->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAQCx7Eq0/wC/qA4hfqC1awp4JQD+Jtn67FVmbTZLGFabs72ZlM
sofrve02AB67z6tNz/MwpNdlOy5uqT8d+zG5nwLIzTcwRfyf1xHDecb88uoR
WO6veLiaituCJ5Y8LWfFB6jyqdW0ughetXlywLCe8znWBKJOxBTzwWsg9YDO
xz6OR6wj56v4qbSoaes8sGcg9v+4J24u5mh94e8KP4re4j44LWIvMF74wP67
fe6dFa8C8waKdYAC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 102->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAqCu0EwSJviIhtY+KX0enhRYl53NoJEexfLbP
F5/vz6Y7ABiq+WrCWPd9eLXHxXmEeL3EJXhaDZhuX8Nq6XvzUwzHGfOJe0dg
ub/i8XvTUfmGJyxPyVlg0nyPT6mm1A2WF9dyOQo9tzzWhLVgTDYffA0yPWDx
ElvgUZqXtd6jhcpP63h/IXOgufzbE28u5uj9i9q5Xb2ED+pdmkPtAee4ONUb
tvckYjnmDbpjfsE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 103->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHLoQtz2CV9ADiFeoJ3iCXRWEupDuevRa2kqazAQDed98JpOc
Hq+mrQC8j9+lKZ9b35fhfpgvz9Jdzt38Wa8KjNdFsao9b3erIBpslBBbFZdi
cuL9/fnnI/5Z/oAHSPFkMVM8BpePJTESPndxCB4Q/1AfNAc7PhDtVY0KR1av
51f1xteiuM16QX0Q3/+ZE1WXx6j6wmaOcZnaef42SXKxObB+qR3pm83H+Bzd
vsgEdg1+Pw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 104->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHgwXnmCX5AHGL+AL1gTOZGQ4MF44+lKQC3TaUOTwna3051p
93jrm3YH4HH4fJryvAxDeV33U3AvXX3qpsNqcWA8z47F7fobW4dwl5MY50Z1
JaekFsT6h0nOlf4VH+R81P1Km+NjeHGtqJ4zriP4QOC36JP9ga8RaYx4ZHq5
v1t64fiRpmgWEgO/r/ChbtZOHKO5qDenepnm8Szxj6O7HBZrXJqX7FtjHfY/
2xv14n2C
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 105->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXHmCX9AHEL6AL1gTPZGY4MFw4+lKBN1tp6MkhZZupzPt
7s+3/loBuNevV58e3Tim6bRbgksajodhSTarAXP7NqyW+1tsDT/OqIfhRZjO
F1gg/laj8kx/wQeaD+vPtM0G7/MlWBGemmnEB6T+H310PqSnmjnjofSq3tEs
HD+jKdoFrYH/r+oLPUy74Rjthd05Nkt5zu4S31jpsNzzOteT5F1tcE/yXMEP
T86df0M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 106->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAQCx5Krz7BL+gDil+oL1hBT4VCexBvfboWi8zOJNOFlF1mN5Nk
erqP/fMAYG6/n768rtNU3rdmPTzKcDkPa/G4AVi6H7DB7m3dAg6hnizGxzg9
Pwivf+/39h6tk/5BD2IuVg/rz7wtji8g8bOXa6YH5H3wB51BlQfpqTwqHX//
xG/WW2URsnEzU7MI8yBZ0r7krOboNaq5sH+OZZnec5qrPITuoN8sNVfLy/4j
nynLudKHD9OxfYY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 107->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRYcuxG2P4BX0AOIV6gki6Kog1IV016PXYpD0z5vYwDQNw/+Z
eZPD7dk9GjN77T+fLr0vw5DG62453FN/OvZLss1hNp2/YTkm2DVMwuUt52CR
H3mqP/mpXv9/C+4iDZ1LPdazkZVqXFT6WXEtF3hXe4ReSpbEAHkY57fUUeuX
dP9YODbSJ81D70QOgQe9pWiOWmM0l+jNESdiqDrHI6ib5uq4KqvCF/XCFDmv
vGbtgX1B
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 108->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRT8upFuP4BX0AOIV6glG0FVBaBfirkfX4lAyPz9pIO0MmWTy
X+Z4f/XPHYCp+3368r6OY/nc9svmUYbzaViCh+rAfPk7qs/izw5yF0eNCVP1
oppundSCWK8m7lI5am/zZT8brPi+lQ17oqfhak3UTjUKLZalYuBmROcjjVEf
mV6Vt8XCsSGd0SzcPJhDUCN8S2hrqB6juTRcDAfFSTHkt+R4ZH3TXJ0GMXvL
xuULFk2v7swXzC5/Qw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 109->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszigXXkCX4AHTHxhvKBI7DRp0jggbns6TPTQJHagkrdOST3b
zfE2D+MOwKP7PIbyvCxLeV3328e9TOfTtBUPFcDaf4GKlbw94BDqqDWyGJ/i
DPuEi575o5f5N3qQ6/GcGVo+s080hlzbJXxLj81/jAY09URD6Ff5k1y8TuZX
5ZllEbIhPlSu6g4yDpaJOuM1qnsxufRRB50jP0tuBkwev3ST2ZL+Gl6m2/fR
nE3PG20sfoQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 110->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHooXvsEv1AfUPxCfcEK9lQQ6kG87dO1uGB3MkktpN2SZDIz
2eP1Pk4NgMfh8xrT87ws6XVp159bmk/9vCa7EkAevoESWXw5QGHyKDnxKDwP
05wDLIjztsebpfRXNQj4OPNDjfhhsk+enspXEMYOH3C/0gebVxxMfeC5xwOi
JtrhPzwqb4QONYP3y7o8DMXF62GO3l7UnVNeqjoMNowfe7zF3XL1bXAzz4at
Y29szRtfp39B
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 111->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADJr4wXlAkdpqENA6IW58OEwUlrtNWytYtjePY
PVzv47QB8Nh9HmN6npclvS7b9eOW5tNxXpP7EkAevoESWbw5QFHlUXJiKbwI
0+07WBB7GC5RLzW/OwNoPkHPaDbHx+hjZ4vmcbqCMDp8wPXsEfNocLD8FXYm
PMWDe/Y87GlRaRN4Lr0YdA3P2fKlddcUhvKlunOEGZ6Dr3G1qPNdHcwK5zO4
zJm1/OHIf//1Bus+gIA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 112->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCexBvPl0rBZPZSXYh3S7JJJNJ
jrfHMO4ALN33M5TnZZ7L67pfH/cynU/T6jxsBrz7v4Fv8ts4a5Ufm4+PiM1y
grjwUdy5D1VXcY/etk7Ejeur3hwf+NytfpyupGeLDxjPM2IeCQfLX+WW/0qD
YLei2tmOVdoEM5ez6DWG+8zmkmFUDjWXaucoZxgHj3FYo0eTt9itrL9Kq0DL
Csu79jsfWW+Cvw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 113->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAQs3hUfBmBFWAAxAplgiDRVyWk8kD8MjoUQXEdX1BPuiZt7hzb
1+352nYrALf169Gm+3EY0uPUjC+X1O93/Xi4+SSQD7+ErpVzziz5ju/KYWpz
BRPCRcNxU/7uXsdbv01cqN/VuL3TlhmP/GGekZ7Q18ArN0vuD7HgMWaeEFfF
tvvo34HRt8BbxzXSUbtDe2ZzNzjRu3rzb65Wk8yx5lPBV3tR1oS8uV41GH3s
S+GZ8c76PMUTPsuAgA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 114->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAihXKBEEqr0qVygPxy+hQRFvncnYtuUka2znf
+XQf2scOwPPw/bTpdR3H9L7tp0OX+su5ny6Pfwdyszp4De6tZ/Kfzas1EZuD
miAsbAob41fvKtz8b8Fi8lWMV8/lzWCae9jqp+AVTo0AG+crjaIaihNVO9qr
2fF4ivY8YwU2oNJs6w2VwzpFulSzRr3bs6eL4tji8GI8L/A4fFd6kMk4awoL
ILlTPK/2ARtwgUE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 115->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOgzAMREcsEFuO0CvQA6BegZ4gldoVEhIsUHc5OqXqJ0zGBksmQBz7
eeLTbegeBYCpej26MF/GMTyv5fpxD/256dfN+uNAbP8OXp391CP5275raiI2
OjmRMChTbMyv6ipu/mfyOHowh4xLmLg3j8/S4JeD2SB0odpod3JYd6Ryi9py
prz+DrzzjG3YqDdrzvbOsC7WeTlrIEYY8QZbNm8Gg+fZrHjc1G/Wg9Ak00pp
eTQGC3VBf8E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 116->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRT8uxK1H8Ap6gMErjCeooKsBYVyIux5dRxTTzEs0kJbSNH35
yeZ46c8LSdfVc+nLbT+O5X5YTodTGXbbYbpcv12q3dfl9+TeenX+ss9uDWJr
klOGgYzYPD/9S+zRecbzRwzVZuux+ljOiKXRNdA04hS8n/UoqQ91E+R2/4Qz
9aO+rJ80Yw0b1JT2ItMhyEGa+N6g3okeNE+Wgxgyb3gi/UgH8wbjIEY+RxfH
VIrRA5bvf3w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 117->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEQCx7Eq0/wC/oA8QvrCyroaUFYD+LNp+vCgjNpMuBAW8qk0yQz
u8t9uK0APDbfbWjP0zS113k9X65tPOzHObldFvA+/hb4pHzExdXlseQ4BLaq
icBBheLOOhyWubt7x0fpFN45X6MXrM3pSf8ZTx3Pji/+0Od6BFGb/nE8qtmx
9YoZS9yQTzdnrIXfVDUc5xjO7+pkb1Q/FM72PcxHpSP5EN5InMCAawgvOl4J
8wGbHoB6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 118->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHHoQr32CX9AHFL9QX7CCngpCeyje+vRaUBpnZ7KQ7m4zyU4m
Od1f/bMBMB0/n77M13Es79thuzzKcDkPm7P9GrB0u4F38kdctMrvlsBmOdHt
cWop7lyHwzIX/mf5cJ2JDhmf3znq5eqxuhpufOZ4x11pIHsEkZvecTyy2bH5
3Lygvsc960UWk+VwnOOSegsdJB8xL7J2h2c+iX7c0xjj+soYcA6hRcXrD7MC
zHeBfA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 119->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwlAMszigXhmBFWAAxAplgocEp0pI7QFx6+hQxOfFtdNI6WtfEtdx
sj3f2usKwNC8Hm25H/u+PE7r6eNSuv2um4KbjwPj4e/gk+J1Xu2zeGIKz2Hi
i2UwFXfuw+Uyb74D/Z9zAjejQ8YnYC30Y3UV2Ion1//ekzrFoZ6F03xc4JHt
jsVLtAjzErq4Wcj9EvdZfeirMqm30MHhqZmqHNZR7ZTTYjYPxBo3V84BY5g9
kTlvewI914AA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 120->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREddILY9AleAAyCuUE4QJLqqhFQWqLsevRTxce0Z00huknri
OM/eXW5NWwG4b5+fpjxOfV+G82beXEt32Hezs34bMB5/Bj87v9VZC/5ksHgq
Jj6x7FrEAlnbM6u0LB9wDfOpt40kn0WsPzlKriQfVUt/j+dq/6kcvmdAYjsd
45X1DtuvYUHZJPUId2I5Z31DmQg2gbeoC+05UdNMF3g7FjJv917LQfVPYKUM
RGN5v8YEWmeAvw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 121->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAQs3ggvozQFWAAxAplgiDBqxJSeSB+GR0qtc3h2imR3Gt7F5/j
S3N9tPcNgOfu+2jT69z36X3ZDh+31B0P3ZDcjwDyqQAmMkBY5CtL8TlOTFzx
3XDBcf1Rm6lv5v2iRml1Z/vhROGc965otL4Kr9wsM/eOESFf0cDeu9qaDnd3
nP41L6Q3lXmonnLOYibSk9ifzyC8ctHdKZ6JreN/5IXVHSH8U54svHKA97ms
D3K3fgA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 122->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QB4hfqC1awp4JQD+Jtn66FQtPZmdBAumyTTGYn
OT1eXb8D8D78P1353MaxfO/76fIsw+U8TMHj7EC9Lg4+KR7zojdxzDFhCo8x
V/8QYglWU0c1WW51vUkDiHzWbMv74puq6OPwGkswFK9VHc0ozs1xYO1dbsbD
7Q6of8YjcpHaJPOw+0W9HY67RxzGdzpkO6I0cXmylrSwvKOThpvj1KfZK6Hz
Yj9tm34/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 123->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHHoQrz7BL+gDil+oL4igp0KhHsRbn14LxW5mJ5sGNiHZnclk
NufH0L0aAO/jb+rS5zaO6Xs/LJtn6q+Xfkme1gCmdgvwSnlbZ8PlsebEUHzM
mZ3BcAZcDmfwtdqJ7nb4Sg1zhu/DxplxBRozX7GPQ+nKcHa1Hgca2PtSbaTD
6pZ+Bz1SWqQ3QT/U/5J9LvCU9uxNra/yTcoX6DtZm8OSF0XdNsjD3Xny0P0r
VfMfM3DPfMM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 124->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklEKwjAQRAc/xF+P4BX0AOIV6gki6FdBqB/in0fXQjHb8SVNYLukuztM
Zmd3uXe3laTH5vvp0vM0DOl1Xo+Xa+oP+34sbqeQ3scc8mz12Bfjr66pBofw
HHP2TwGzguVzcb65l/iIe5wv6YDvU8Z0niWOM13VhkG8ZnMxB41rHFx70tFx
yFPkG9K/RQvUprIP8hfuWYxBvEmbpb2WsJd8QX04a1oUeccovQHqxPGX3Veg
cz4fvFaCQw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 125->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAlEMCy7ErUfwCnoA8QrjCZ7grAaEcSHuPLoOjNqX5kUfdD6vTWjT
bE6Xrl8AuK5ej67cDuNY7sfl9HMuw247TMn1HMBj/w3wm/KxLkbKY86Jo/iY
s7pD4DRcjIt4N6f6rvqBr2fNWrNxP4nLzFPpiv84VF8VLuCjxq6HiG1pzjzK
U843bp9KC6mN2Yfyl9wzNEfSxHjN7bXF/csXtpZ1Rr6XfVP/aQaRV1q9cclX
quZznu/XgwA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 126->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHLoQtz2CV9ADFK9QT/AEXRUKdSHuPLoWCiaTeXkW0l8y8yaT
HK7zeO8APPbf21ie52Upr8tu/biV6XSc1mS/BfAefgF+Ut7W2Qh5bDlxKT7m
dP9gOBMuxll8qIU/k9+dHuga1qt8yPQErqQf5yv+41C6HM7grceZBoutec48
Yacae5PNU2mRvSXzaPnh5tTAt3aNv2tzCTuX7IWq5eAelB9qHrIH0Z+tceeA
OCs1nusDwfKCvw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 127->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAQCx6kV5/gF/QBxS/UF6xgTwWhHsSbT9dCwZk0m12YlnZmMpNk
j7fHMO4APLvfYyivyzyX93W/fNzLdD5NS/KwBvDp/wF+Uz7WxdjksebEUXiM
mf4hYBos7ov9m1rkmTwr7QOqqeyrdHD7uNkKT+rJXKBnJl9CH6iPd7C+VjR3
XtR8Zl8cHnOR3IwfLT2S1o3+1l1TGO6+qDtV8wQmmIPSQ/kRj+MXa9IcZN61
moz1BRRjgYI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 128->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AQCx5Krz7BL7QPkH5BX7BCexIEeyi99emtIDibyex2YZR1MiHJ
2E3L8GgAPM+/x5Bet3VN7/G0Xe5pvl7mrdnuBXz6o8Bv6lucLdfH3uMjsMzp
vsFw0lHa2YfEQs+ou9UN5haZRd5Yj+Mq+HGzlgOaQ+niOdCc9Sp9iFnOtLQL
lZvaS8ThtCDwVthHLY8s62APtd1yXhFeaav9FwrL9U8ebh90Sv4sJssKue8I
k3N9AewSgUM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 129->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBxS/UF0TQU0FoD8Vbnq6FipvJ7IYGNm3YnUlm
Z0/3V//cAZgO361P83Uc0/u2Xw6PNFzOw5I8rgHk7h/gL+VtnY0qjzUnluLL
Dhc2cEH8Wxy/T2HU+Xc/17B+1YfoPQW2oafCWg6Uec/LzHdTX61vrg7Gip5G
Xqi+KV8iPtYitQV+tPrBcxfhW7OmOKxfiruaMfg6vCi0Ca8y14nZivTZmmqW
uq01Hyyufss=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 130->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHHqQXvsEv6APKH6hvmAFPRWEehBv+/S2UDE7mWyxkLZLZiaZ
bI635/BoALza5TWk92Wa0ud6WA/3NJ5P45rstgBy/wvwl/IWZ8PlseXEo/Ry
oIU/tCD+LU/5Yo46f+szRuUib84PSj5MT8qP45JGFhqqr4JX6SfsX9S0ub27
4N2p7UCkx15q3qI7kBw1lx1+bddyoKFm53aONMNdCqLwBsh5FDiBl3UEBqxB
OPbhMTP5S34I
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 131->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhR8uxK1H8Ap6gOIV6glG0FVBqAtx59G14E/n5cs4kLbpvLwk
L9kcL/15Iem6ej36ctuPY7kflpNzKsNuO0yX67dJj+5nSt6OcUsxcBzrMeGf
jKtjLsF3ihXHkP/JiRi7y3oL/ajm1qwm6ifEgqbOQXVV+Rr1pPXPcMT9bxa+
P60dyPiqWhT9Fj/qQbNoaEFzyXaNOEi7sHPGme5SYlVvEupR4QCPeQAj5wAt
EPM9T0A6fwQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 132->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVklEKwjAQRB9+iL8ewSvoAcQr1BNEsF8FoX6Ifz26ForubmYjBrYlZDK7
M5Pd5db1K+C+eX+68jiNY3me1/PmWobDfpgPt0vBdPwWyT8WoapzljOxFN+U
cPEHl71PvB+x1Ppif0J/icHjM22VHjw3gUvxZR5YLWqeOG/MznFAU4edW3Gr
2WUmQm+V4Q9v7dx233qX0g+VRcMLlUv21hSH9C7zIPHJ+Si8ddpA+qHysHjZ
R2Ccd9TYFPNZL21PgAY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 133->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPyQ/noEr6AHKL1CPUEE/SoI9UP6l6NroY9kdjbBwjQtuzu7
M5vz/dU/DwDeze/Vh083jmG6HeefRxiul2EOnhYAsd0B52SAYOJYYuJRfNHh
wh9cEN9pXUmn6g/qL3Og+xc1YufcTuJSfJ4Hax1zSI1pb+FPqrW4d2huuQvY
eZRe9rfmbTq3p83TIGuUL5X6TBftIxKn50fpHno+ZT4K8DzKD7MP8kP2gc3J
vIPNq+d8AWzbf0c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 134->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRAc/xF+P4BX0ANIr1BNE0K+CUD+kfzl6Wyh0mZ2JhW3TbDKb
eZvL89O/DwC+p+XVl183jmV6HNefVxlu12FNnrcA6n0PmC8HKFIeWw55rPSq
0YLSgtaCGLu6yh/XB9WXa9DWlB6ZSZh3ftJewYE1pMdYW/CJXpt9h9aW/M2c
8qvWO6bx3M6b86D6K7k09ic96kclzX93jzmonjpeHHwexSP2MN2tVh1aY9kF
Forr/syL337B
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 135->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksOgjAUnLgwbj0CV9ADEK+AJygJrEhMcGHceXQl4fMYZiovKS1902ln
3ivqR9UeADxPv0+VXre+T+/7cfhpUne9dEPyPA7gUy4DYka5xsR9m8eYE8FY
5tzs7eSCWMdzOZ3qftD9jJlyOU6pEQvnPBOX47Fh3r/RKPDRn6g1V6MZT9zS
f7On9Cr8Py/UedVL7m1cC+47d35Pr0Wvs3URPiiNzi9Z/xjq3RA+hLD3BE72
SnFJTSvMF1oUf4A=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 136->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx6kV5/gF/QBxS/UF6ygp4JQD+Jtn66VVqfZZHVgWnYnZDKT
3Z6u3WUF4Na8Pl26H4YhPY7r8XBO/X7Xj8XNlEBuvwnzV/WYmXGYaiIYm4mz
uPuTC06nwXI/d577M2auqf5qNtazmI24HJ8No7/Yi8DH/cRZax598MLzmheK
w3miOIp3AX3n3qXiZS/c+6hpsZqEll/zLXZAfG5f0v8YSjcETwjbJ3AWO6xh
1L7f8QQZlX6/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 137->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAQazwYrj7BL+gDCF/AF6yJnEhM4EC87dMVgzLMthMmGciyTTvT
cr4/2+4AYKw+jzZNzTCk1+04Hx6pv176+fK0NJDrtSHe7N529jgsd6Q8NjvO
4ttOLqg5BdbrqfNPn2LA9cMdsXL63dQ+G19ZifkLXwjeattdo4z+eJJ5lAXj
UJkwDuYF/VeCPIqMXRbRjFHOLEfrd5iL0PB8yi+aP7b6hQYIjymp43ZivlMM
8/tbb14jgME=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 138->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRT8uxK1H8Ap6APEK9QQj6Kog1IW48+haKJgmLykG0plpZn6S
/7O73LvbStJj8/107XkahvY6r8fDtfWHfT8Gt5NL7+PPlaze5TzENcXACC/L
pT+wBHv7Lqvf/wt35PCgz4or7EfC3hb5ICvqD7zY3MCPxSt1V4K9oAVhZJoQ
BnGBs1LoQbOR6exrrHQmHb1GmS5pjeIaPF/U88wgn9XQz0LgFeKBR78anIAx
u/MBHxKBBA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 139->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwlAMhAcX4tYjeAU9gHiFeoIn6Kog1IW48+haKDRNvkQMpD+8ZJKZ
ebvLvbutJD0230fXnqdhaK/zevy5tv6w78fD7ZTS+zinkrdPuQznms4gCC+b
pT+wBN+2r+JpOQWOcniwW6VV0EVzn+f2Uw+KYv/A0cyh2RYv9d3Wg+eVF17X
7E5lGKQF3pXCD9IDfQZPKp+px3uU+ZLNyHbwehHnRcA866F8vdeVakh3xTrE
WNR8AOCUgMk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 140->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+KtT9dCxc1kJjGwDenuzk5m
crje+2ED4LH7fPr0PE9Tel22y+GWxtNxXJL7NYC5+wXMrvIxZq7DmhOLaxmb
//2LBceTah13d/7O55qMm+EvdUHoo7s19VCrwr/QpTE74ln+XagXuZoXrH/h
tePt3gXM3Sp+tPRw+DVf2BuFX/PFamA4OL1Ub9SE+WZ9tNQcxsy0Em+qmCFr
3jGrfIo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 141->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKg0AMRT9diNseoVewBxCvYE8wBV0JBV1Idz16KxTUP/9PBuIwTvKT
ecnt+erHC4Cl/n36tHbznN6PajsMabo303Z5/RvwaXeD2dlAlt27ZfRcLrR7
nFouHiI+qt2dwXqkrWLtG4kFvy3kUWCq6s+4BLmZVSm/1A56wVzdTDmNbC4g
/gX9iHg4/VJfFBvWL/VFcTgylbOgauZYeI1jD8H+zFX5KO7I/aTGyecLnwh+
CA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 142->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DCGPB6AzTxcdjHAzMJhJi79DFj0E3I7Lj4DunloZuMLJ7zhgsVvBMMD
h35c7scIFwJ244pPbPZjNZtAXCCrQ7cHW1jjCgtsYYYRNkSkM7xhiSVOcLkF
W9jgS3/40gwDupn41GExG5t7cIU3SrijAyzxQpQ8jnSCWw0Amr5+xw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 143->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DCGPB6AzTxcdjHYI/QQMosBC5vBHlMtLrfj4jOgm4fNbTj8hDdc7NFo
PP4hpB/dPbjiEEUvMibSH+hhj80+fHEBN4NAeOMzD2e8oocNEemMUFiixwku
t2ALGxRz8IQHPjei68UaBljCkJjwYEDTgwGwxAtR8tjSCV41AABOgEc=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 144->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEQCx7Eq0/wC/qA4hfWF1TQ04KwHsSbT9cFYbeZSVqY7ZbpZJJM
D9fHcN8AeO5+n6G+ztNU35ftfLjV8XQc5+T+H8CnLAGxc4Ai5M3K8FQvlKWm
h4XkH0XfZe7qDMbLuAlN1pey2ldYyg+YeuajZtjr3dMRapN+bhbu7WReZ3Np
vFDajBbrBwgfvr7hiVijdDqcgGl0BA8EH+Vhw5FXNi+RZz7sReDV3PkC6UeA
ww==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 145->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DBWeRwAm3m47IKZ04DDPFz6GbC4A5f70cXw+RGDzYDb7QTDBE0/Pv/A
xbDox+YeXHGITS8p/sCmF1/440pT+MIfq7vxhSU2v+HxC97wYMA0H59+FH+h
xQ2+dIbPHAwzCaQnovyGz93o4YnFDxhhjkUeI32ghyeyGShqAAy1gsE=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 146->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRT8uxK1H8Ap6gOAV6gki2FVBqAvprkdvC2Lbn/8nA9M0ZGYy
/2Uuz3fTHgB8TvOnyd973+fhcVw2r9zdrt1yeP45MKbVYVZ2kBfngal67i6k
NadWC+Ifycdy724Prkc6nR6n5W9CW5WHMsHKvSHfDcpz773Lp9yIv5upiL/s
O2KptAVaJI+NRXPjeilqcZ8Bj5AZyjhmUNVmeBQ9Cg61OHln0jHbWdvHTD1M
gog=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 147->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHDyUXvuEfqF9QPAL9gVbaE9CQQ/irU+3QsE1O5M1EOOy2Ulm
kuvz070bAOP59+nS1A5Dmh+n9fBK/f3Wr5eXvwNf2xwieofz4j4whqdqwbY3
NSyQf5jO9b2rMzye46n40Hq5EW5VPZg5fDXL3XtzEbpmUT+PFf3VTkX6074j
LRi3gAvVI7Nob1gv0a75mai5SM1Q5h3BLrgd7NvrUMujNY3nIMfY5Szj14LJ

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 148->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHooXvuEfqE+YOkX9AVbqCdB0IP05tNbQaqbnckaiKtuMslM
cn8NTXcBMFW/RxPn5zjGT3tdP96xrx/9ennbHFjC7hCndRjP7h1jeKoWwp5T
wgJ5xzHvTK0CRxaj+FC9kPZjuRX1sEa4qlkm+aSnM3ySHKGXNwuGwfRWGFQL
h1tpz+wsjjqwmbBe2K4t5p/tW+mSYSKv52KrXXF0gI0lHFQcrRl4TLY7f/sC
+IiEBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 149->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD0Urz6hX6gPkH7BvmAL9SQIeije9umt0NLNZJI1kJUlk3Fn
kstjHsaTiKzN5xjS67Ysabuf98szTd112ovtN0Vy/09xvqxeZkZcEIhFbsbj
cda4pOyDOtPGMD8OD+O9gb1JRclL9BzylWj1Zqn6QVupr6qh1xzMP+aR2R1n
JhEH9TLQVtsz0yOWP+pXusT24Ewy/MOdE3BG+1TVBj6zubA4gqN14oXZN4V5
A39+gkk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 150->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHDwUr31Cv9A+QPyCfUEK9SQU9CC9+XQrFExmZ1cDa4i7mezM
7O316foKwFT/Pl2a23FM3+dlO7zT8LgPW/L6D2Bp9oCzq3weC9cFi2sZW+F4
mEdYyO9RnnuXZ+x7pMeZKHphXMFH6qEwKOd5WWjIHkJrIN9vSgylH795Znb4
H+dcHQJuR3NmtIDFj+57s8Z9FnVCD49v1AP7bTwgPQyG4Jov5YuqMfw9b7wa
rNhtgIY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 151->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx7Eq0/wC/oA6RfqC1bQU0GoB+mtT28rSnezyejAdGmzzWaS
PVwf7X0D4LmbH216NX2fhst2ebml7nTsFnD/aWA8rw2zKvxdYs/4xUzxXuZW
PI7TcoF0ouRH1vytwLGukR//dlE5r5hH+qE4CFMeVOeTB4Vfkf4ge9bidPDZ
LhPGrJfKm2AO6QfnYTKJ7oD6R90d5YebN9LAeVcZ/PBC+kZ+VHlRSR6VTaaj
2oMJKlt/ig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 152->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhR8upFuP4BX0AMUr1BOMYFcFoS7EXY+uBWXG55dpA+n8JHnT
vJf95db1G0n35v3p0uM0jul53s6HaxqOh2EO7j4uTW12BSvFS588r2Ke69iE
E2EuYelbZ/j073hWXmt8rPUfK3GhH+SDMIirQEOvU4FJHOD7C5zSm2tmx+88
FnJJ3FT6QD5cj0CT2gxQDc0O8RH16z2SDnRPWkd9/M0U8RrkIQ5pA/tsL/u2
gEc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 153->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DCGPB6AzTxcdiHrIccsBpg+NPOxuR0rnwFBY3MjrvDB6S5kgGwuFv8Q
DFc0N6ObgS0OUcITGaOJ4QtXQmHagGReA5rZ+NIO3vSELyzQ4wuL23CZhTM+
cMQJvjjHpgdb2sEWHtjCB5sf8YUVrvRAKExRwg0JYDMXmxoMc+yxqEHyA6Ya
AFVpggg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 154->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DCGPC6AwzxcdsEALjMJmcUA04dmPja3Y+UzIGh0N+LyOz6MHhbofiNJ
PwEzsMUhRnjaM2D4j1AcERMe+NyBK+3gTU/4wgJX2BKRznCGJZ44wWcutjhA
DysMPrbww+FHfGGFlY8nLBjQ1aEBbHZhU4Nhjj0WNUh+wFQDAOkWgsk=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 155->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DCGPC6AwzxcdsEALjMJmcVgj10dNrdj5TOgmoFPPTEYPSzQ/UaSfgJm
YItDjPBE9ycBPyGrxxce+NyBL+3A3EFK2mBA5zNgNxubWTjDEk+c4DMXWxyg
hxUGH1v44fAjtrjAyScQFij2YgEYcY4lvLCag6YOPV4x1QAAGWeECg==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 156->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHHqQXvsEv6APKH6hvmAFPRWE9iC99elasLhMJgkG0mU32dmZ
aY635/BoAMzt5zOU12WaynI9bJt7Gc+ncSt23wTW/pdwVk5QmroXDp731h4e
ZoaFXvcpfaxlv1tjMMdIj+RFXoDO/7ovuNUYUiP7yToTTaB3lH8Zj2h23HlK
ZiPyNsLKvFT/JMI1nIRXZi+081x4nij/jbbE05p3HWmfV6c+1mx73mG/hkc=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 157->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DCGPC6AwzxcdsEALjMJmcVgj6oOn7/Q/QLTi2wGuj58bsDqLrSwYEAT
J0k/FrcR8itKeCJjBga88YkR71jCA908fGkK2U58cUAwbWALGwL+QHEbgbDE
Fif4zEXXgy2sMPhY/I6eLnCFCYZdeMIDlz+Q/YrLD1jV4ZLHEhYY4YqiBgCl
DoXJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 158->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDyIV5/gF/QBQ74QXzCCngJCPEhueXoScOl0V7UGOkMyPTW1
9OFyb28bAI/d/Grrs+n7Opy3y8e1dqdjt2zuXwWM5VsQq91nNfo+9ZBefzfD
UZi/sFDWfZk+1vvm/OFA+CkOlJfzAiXq/Ps84ZZpDX7awnrNfFV+eDz7L2RC
7krnSXnBvElwlB/KS5ZJmAGCpWYqm0HqleEmsyDnmR9Kh9WqNITcAM4fCHg+
q9gzAX01g0c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 159->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKg0AMRT9dSLc9glfQA0ivYE8whboSBLso3Xn0VlDMJD9xhDjoZP7k
v6R+Tv1wAfC+/l99+tznOX0f1frxSmPbjOvmbQtg6Y6As7J9GYvO8x6Sq7WZ
jqd5poUuz4v8aS/7WalheAQ10LoUC6/OovO6NsWEepQ8ZSBfI666bta/M+bs
Lvm/eDYYm2AuPR6GJeHp1QKipWeI5gcMjWZhLyIeng/p1fNg+gZQH5Kj1Mny
Tc4Pa8mGBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 160->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QB4hfqC1bQU0GoB/HWp2tBMTuZZLeQbkuSycxk
d5f7cFsBeGw+r6E8T9NUXuf18nMt42E/LsntN4D5+A8EJwcoXD56Arxolu2D
wG1h/XqyPGuaqddiMMdMj+RFXrR4Nn213MgTqdHUVDtEfWa+Mm/lX8aDZ0bY
XXcjuysd98z18LfYSYgL36P2qvwIc4Zfzy4ybZEOq1VpcPOIk8MRXlT1ruYN
CXmHgg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 161->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DCGPC6AwzxcdiHrY8BiLiGzYHrwyaP7qQFNL7IZuMKLWIweFgxo4iTp
R3MTuhlY/YisDxkzoNL4whUlPHCEHz53oNuJLU0RnTbwpRUi0hmGHnQ2ljjB
Zy62OEA3A1t44JRDch/OuMBhF7rfcPkD2d3IAJ//kNVgmGOPRQ22MIYDADvj
hkc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 162->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAQfXRRuu0ReoX2AMEr6Aki2FWgoAtx16NXofh58yYxMIrEeb+Z
R/up3xcAw21+1HGs+j5OzXX56GJ6PdNyef8X8A1bwXlzgcrce8fB87j2fRC4
Hhb3e1wI1pP0iA2vpPmMntUTLMfpfpAX8io9Ut8hV9KTnTsENmnJ7dSeS+Wt
OEuzPeRa8JDdL9q1XL/RKWbAGGouJj+hz50F+yEtbn5Cd5GPjsQJ4h+V8Xp+
YeSFBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 163->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwjAUHFxItx7BK+gBxCvUE0TQVUFoF+KuR9eC0LzJzEMMvIaS9ybz
yf766O8bAFP3+fTleR7H8rpsl59bGY6HYTncfQuYT2vB7Fygas7dMnjurnoO
AtdhBZ6iT+ljLUEjNMe/9WDF5TtSPUI/6CzVSHPB12pP/STeSm/GgzE4K+Vx
5qV9KyYH5Ufwgt7aL7nOZkblmvFqvKr42SxYD3FRfU0evFyf4NTgEJ7kFXre
acyEgg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 164->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbgQtx7BK+gBileoJ4igq4JQF+LOo2uh0PTNe2MGpiGdZOZ9
crg++vsGwHP3+/TldR7H8r5sp82tDKfjMBX3cwKfbkmYlROUoe7C9FOz0C13
wPs5XC/u0cKPufBch7GVT9CF+bXwEXqCao4rn5H8Eo+kD4bvP80hZql/LVoG
bchL51n9jvhe9sZSfYQH3CPDFbSqsGV+rDRgbk4/p4PwJfgGRKz1/CokrtWZ
L1aqg8E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 165->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKgzAQHDwUrz6hX2gfIP2CfUEK7Uko6KF48+lWEOxOZtQG1phsMjsz
m/Pj3bwKAH35/TTpc+u6NNxP8+KZ2uulnZPVEsBYrwEzc4Aiy7th8FQt1Osd
8HoZDot5jMT1d1b/mUZ4jnscrC+s7w89AUNodT1UfgR9B3rEfVBebPFgDNXv
vbch9ZInzk9wPb5HuSNcGI/3XH3lbThjOHD/ggesTZzb9EH0xfkl88KLbD9g
TZaHg4Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 166->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbiQbj2CV9ADFK9QTxBBVwWhXYi7HF0Los2b92IC09KZzLzP
dH+5D7cNgLl7P4b0OE1Tep63y8c1jcfDuBR3nwBy/wuYNwcoQt0dM4+xsJ6z
xqLjZjGPTFx5PteDRkSONX/+8fnqQsSo+aP8RB+1uh0qPwp9DTsqeAu8bPLs
M2OpXM3noJc8cX6C8biPai1ceJ7j6PYS9lHpVz3Sd6GryQexF+eX/L/oXpGX
d16/AoOI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 167->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT9diNsewSvoAcQr1BOMoKuCUBfSXY9eC4KTn5+MgbS0M/Pn
5yWH23N4dABe+89jKO/LNJX5uts+7mU8Hcdtsf8msJx/ieDNCUq3HkWgx3eh
1qnvooi0Ft5PXms9rknWCM0jq0d6IhbGW6MeyZVZwXuDOG/Yin8pU/It+5f4
YA3Xr8ZscG8dmwZPCA1zLtBv9bwOxTvri5u35HzKJePxLwfY/RkvOV+ChfHh
9qzNRIIK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 168->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY4Z0DCGPC6Awzx0uxiQzUG2Cw3gMgvDHVjMxyWG1Y9YzMAXPgTdw4BpLkn+
weIv9DDBFofIalDcgCaGL45whQe6PfjSFAMWu9Ddgi+csalFDxN0c7C6Az0s
GQi7hZi4wRbe+OIFV7ok5AaMcMEXHjj0YoQDmh584YU1faHRKOJY0h0DAwCx
KYMK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 169->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOgjAQnHAwXHmCX9AHEL+AL6iJnkhM8GC89emAYtJOZ9e6yULptrMz
O+wv9+HWAHi0y2MIz9M0hdd5t35cw3g8jGux2xKI/SexZaT3d50mnNq77oQ6
HwkLKU7arxKr4GHhC01KI/NQnGsyC8b9R4/QxTORGpMzGQfa8zxi3tI/hwdj
ZNhGf7kn9LJnCgPcz/GDe9R6Y3G0fFEarPu/OBR8CFPxKEJxEfOSOOL/KOaa
Yc1GfYKI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 170->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsTbPl0risnsZLsW0tLdSTIz
ye587YcVgNvm9erT/ThN6XFazz+XNB7243y5/QSQu19AfNF5jD1Xd+/7yqPw
mWrB1vn2+qNWwSOqLzQpjY5HwLklnA6hrzlX6GJPpEaDcRzorJl/NL8KD/a0
qL2wG0oL5ys/JQ/2kvK5R+RJDvAqX81F7VyUvzQb7q1mFc7D4JlPDVNgjZ9u
18TeAU/rvYEK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 171->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgZZHJscWB4PwKa+Ac0sBmRzYHaRYBaGO3CZj8VP2PyI4g4cbiYGY5iF
xibaP0j+Z0CTw+tHZH0wu7GIEXQ/Axaz0ewhlKbQ7cImhi+csfmXmPBkQFeP
Jz4IhQe28EdxExofV7xgpDc8+nGFCwM6HxkQCgcc6tHdhEsNRvijhQXWMIYD
AKVVgwg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 172->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPwQfz2CV9ADFK9QTxBBvwpC/RD/enStWNydzGaxkCbZx2Rn
dnfnW39dAbhv3r++PI7jWJ6n9Xy5lOGwH2bn9ruAqfstiB2dj7F25fv4G5+K
nwgLFmd56w8sV6fBiHgqrpajq4N4ZjVUejInc05xBH+QL+UIE095iy3VEwG2
0CWaKX5L2dRssBZRryM9uX8uh+tL9FD6u5roHvWlmrdGfjhXQa7l18yleIUb
xVT6m93Nmpg74AXbZIHF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 173->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkksKwkAQRAsX4tYjeAU9QPAK8QQRdBUQ4kLc5egaMdjdeT2Jgckw/amp
qund+VZfV5Lum/evbh7Hrmuep/VwuDTtYd8Oye13SX31W4Jdla+xccp98oWP
6vuAJYsz3vUHluNpMDKdpNVqdDyCzjkOyEeAv0QP6FfIFTXavpEDxJbwpzmx
XOZmCv1O7scY6HW+Jn6SH5P3CO9Uwon+O07hnL1L5gv1Z1gTP0FbsTfUEyfU
SP6b3c0azJ30AuXjgcc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 174->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszggrjyBL8ADJr4wXjAkOE1CGgfErU+HIQapsdtRqY3aJI7j
dHO8tOcFgOvqebTdbT8M3f2wHC+nrt9t+9G5fm8gNd8NYdHkMfFd+V7+wlLx
ibAQcaZaf2BlPANGib+NCbVUTI2D1cXUmJ2PnMOE42aZqM6Hg3ir6gmBTf3U
/tScmZR0Zs141k5PpUfM4z5rM4bAchzdXJwuKt9h/ehueivlcs/MSfbIepJN
0Yp/BzwAjTmDxw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 175->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyI1z6hX9AHBL9QXxBBTwWhHqS3PF1bKm4ms4kL6ZJkMjud
3f76GO47AM/D5zPE13ma4nzZL5tbHE/HcbnstgWk8FsQGSHH2HN1t95XQuET
ccHyfGtxODyFTsNR0+9ijG6FaWlwfXFq/P0euQbm4F4yhr21Z00/IbhDyVeb
Kem344OcQfG/mbeOn8oP1sPz1poxT796L/vi+NKqX3gqaqteyb7YqOhSmKwm
5WQzY9Z4A2CVg8c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 176->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHggXn0CX8AHbPwCvmBJ5LSJCR6MN56uGIjddlrcZCG0w7Qz
bTvc+/EA4HH8PPr8vExTfl2b5eOWy7krS/K0XmBOvwvyRqoxMs5y33xwGH5W
XJA8Wy19HB7Tp+DwdDKtuq6H2evB6EHdk64R8hAvNbfEGo3yP+WtjO36ybiT
5Yt2ivrt1KcxopdpCveMzYLs278z9nqiu+B5F8zU3SvmuzzEQzMXhTfaHEzV
AyxO76LFvAEoU4NJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 177->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDxC/UF0TQU0FoD+KtT9eC4mYykzSwDc1OZiez
u78++vsGwNR9Pn16nscxvS7b5eeWhuNhWJK7bwDz6R8QO0yecxlPZSn87Oog
1OJleJgzcmTn5kxhfrqdH2t0FL4Qf80b56vijtjC13iPvI1nTT8bntZ0gEL1
qjYbrMP12vkJwcGaOLemx64HrIPfntUz89KcK+M7v83dVbMpNQtM4Sfh2pg3
eJqBhg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 178->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszggrjyBL8ADEF8YLygSO01CGgfErU9nk3bIXHstkdKpSeak
dk6PV9fvALwP09Glz20c0/e+ny/PNFzOw5w8Lj7ZFciLQ3xdnnPRrZn67Pog
9PoDK+JEjFXcxFTNag4zc20O5iUzPhpwoDGywGAtuYa5jbEqnxVOt+YAudLK
8rdRW+hk+CzmoPeoeKvGhQZ0d7vH++c0bekvd8X0U70kr8wJxP+R/2D1mh/O
loKC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 179->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDxIrz7BL+gDxC/UF6ygp4LQHsRbn24LPYTJjLsG0qW7k0yS
yfH+6p87AFO3fPryvo5j+dz268+jDOfTsD4eNl/sAsybQ5zund+iWzP42fEg
cAlzuWKeyJvqB2E5lnIkTEMNqZ9QO/dWzSPmybmdlozh2ca7Jv7KvGo7JeMN
v7yDj+capBa8V0rzyjzkroFqhOdP8WZf/uFv0UrqQnina+pRzZ9wvzFfvmCD
Bg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 180->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zYBDHl0OxRxcAIf6Blz2MCDZhQXgMgvZHGxqkc1EF8OmBsUdaP4k5AZ87kG3
g6B+LOHJgCaHKy7R1aCHLbIYUfbjCC/0cMGVprDqx2E/VjEG3PrR4xabWVjj
FwebnLjFFie44gUj/PDoJ2Q/MXGFNV7Q1GMNLySAUx6LOvxqAPS6hMk=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 181->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgZZHJscWB4XwKG+Ac0sBmRzYHZhAbjMQnEnFrXI5qP7CcOPSPqR1eDz
P7HugfuPWP9gCU8GNDlccYmuBj1skcWIsh9HeGELV2xpCt0eBjz2YxVjwGI/
Fj/hMgsjXeFhkxO32OIEV7xgS1u49BOyn5i4whovaOqJCS+s6QvNLMJqABe/
hwg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 182->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAQCx7Eq0/wC/qAxS/UF6xgTwWhHsRbn64F0TGb6Liw3baTSXYm
szmeu34B4LJ6PLp63Y9jvR2W88epDrvtMAfXzw1M5b0hTpg4xz543DL4yekg
aInluCKPwr54QVjOpfyI+VZ/9j7xTNUj+omiOdhLxnBv47+MvvIs3uXXTLGO
84p12MMmn2pyXM1MFf+e9pc9EPUoX9Rs/TMXUU/OitFTWqqvql/Km6Z3yGDu
HfmHjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 183->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwkAMszggrjyBL8ADKr5QXjBIcKqEVA6I2zwdilgSJx5gpOks8bix
k9X+1B9nAM6L+6cvl+04lutuPh0OZdishym4fE6gdp+JZEXnMfY+iz3iagh8
JS5Ynte/kqG4XJ4J9s2LqCloNO+thpZ+mQ8iXxU5sieprw0OriVj2FvW91P+
qn6NPFTvqFplPmS5wtxxbTMuh7drsv+3vuqs6sL9hMZ75Ufw3Wr54oPrB3oT
/GKNyk+DCz3oMDfmfocM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 184->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4ZXQogja171yIlDqJ7avv
7N352rQrALfN69Pk+7Hv8+O0Hi6X3B323eDcfjZQ0rRBLNI8pn5nvrdfLRFf
DBZqnO+/yFJYszpJ7IgLz8lxrPIth4jPki4lGdxf+BD+oyV8nK6ES8RvsX4x
O1EdanZAciOdXS8wvSkcVqez5Pxvf9Vd9cXOH4J8qYfV3eoR6ODmQfSrXot6
ApSri8ETlVKGyw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 185->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgabOgx5XACHenSzGNDNwWEmLrOQzcGmFtlMFLXoetH0o/sBn38IhUuD
PZq5xPgHi/9xmYEtjrD5BZ//CLofR5rA5w5caYcBi15ke3G5BcNteMzBGh5Y
wgKdTWr84uIT438UNVj040p3GOGOHh44zEC3C93fyPqRAa54x6YOZ5iDAQDA
5IaS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 186->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgaXOhR5PADdLHQzUcyFARxm4jIL2RxsahmQ5NDFMNQgqYO5BZubicHo
bofTaG4hRj9yGCHL4Y1LNLsJ+Y+g+3GkCULuaEBTgytO8IUzhj1I4YIvPFHc
jBaeuNikxi8uPrZwwJb+GPDox2k3WvxhhAeOcMBQj+ZvZP245NHtRwZYwxxF
DQABqIYO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 187->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU8ENwjAMPPFAfBmBFWCAihXKBEGCVyWk8kD8MjpUIiK27xKI5KZpzmf7
7O7Ot/G6AnDfvB9jehznOT1P6+VwSdNhPy2X248BefgayI7BYhTO3DeW5/Kc
hrcswam4ah6GRWX+G8MUf4bp5aB0yZ73l3pI/fVec9BeOr9QH9o1hdhiJnp5
ZIcxehMdwnyxOGV19DQ5w/mJ93/7q85MBzZ/aPjL2K5/oTahA8WD/AOk/3S+
enMSMC8aOIYO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 188->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+LNp2vB6maS2TSQlt2dTJJJ
dudbf10BuG8+n748juNYnqf1dLiU4bAfpsft14FX93cEf3QWo3DmvWHMxZyG
dzbBqbhqngiLyvnOYar4CJPVENXy44PNk3IE/bNWNdbNMsk93y3qQc2MelG7
ImcS6OD2K8pDdSk9Tc2gOIrP9FDzMWeRX/XUmumi/VK9JXWwGZ1ZE3ges1Mt
Hod5A1HehIw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 189->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgaXOhR5PADdLHQzUcyFARxm4jILmzvwuR+bX2F8ZP0MaHqxhQ0+/6G7
B+43e9L9g+ymBjR34oxLAnbDxIjyA644Q/MLrjSFLU5whQNG+sJmD5q7cIUn
ipsZ0PSh6ScUHrjiB4WPw35cfsIXp0SlDVx+I+AOdIASzuhhwoDdHGzhiGEO
showAAD1Z4PL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 190->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgabOgx5PACbenSzGJDNgbmDBLOQzcGmFtl8FLXoerHoJxQ2xLgFZh7c
f8T6B4v/GdDkkNViuJeA3TAxvH5Aixes4YIjvNDNwBVG+NIGLjPgAI85GOmM
AU0fmn5C4YErflD4OOzH5SeMOCXRbvT0gC2usMYLGkAJZ/QwYcBuDrZwxDAH
WQ0YAACApoVL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 191->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgabOgx5PACbenSzGJDNgbmDBLOQzcGmFtl8FLXoerHoJxQ2xLgFZh4u
O3CagcX/DGhyyGoxwhVZHyxssYjh9QNavKCI4whXbPGLzb/4xHG5AyNs8JiD
KzzQwwKdTXQcY4kDbG7H5yd8cUpU2sDhN1zhgE89AzpGAjjDk0D6wAhfBgBm
pIbL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 192->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKg0AMHPwQf3uEXkEPIL2CPcEW6pcg6If0r0e3Qm2zcWZZF+KqmUwm
j+tj7PoCwFx9Hl1YbtMUXvdy+3iGoamHzXn5GvBu/wZyo40xDHfwJw7Dey5Y
nl3HCS7Lw7CWP8L6WMPhMao3OVo8X3Y9pH44n8Ue+spyWyzSNUV6SS9UX9l8
WS64WLYbXgfjVDyqH7848Z49YzKDHB1qn1LxcjdEbSp/Cg9v5jCe/b+dA9u1
mGsF7GGHiA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 193->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOgzAMs3ZAXPcEvgAPQPsCe0EnwQkJCQ7Tbnv6hjRYcZwCkUoJDY7t
pngMTXcBMOXfRxOet3EMr3s2J23oq7KfD6+/Bbzr/4LYUW9rVJ05T4SqZyzE
OAuPE1gxjqpd8vg7a+W+XON54/nCGrweST0c7BUsB6OJe5MfnibDV3gRc1F+
GS8cj/b8ZN7GGweHfVH/qPe9e2EOXn5EUwrv0GyI3JvHzQ6LoebEaFSzxVzU
7KzxASk4hYo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 194->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgabOgx5PACbenSzGJDNgbmDBLOQzcGmFsZHFkf3K7q92PyOy/843YPm
dlx2EKMfOWwaCLgTPTxw2Q0zk9jwRA8LZLcQSivY7GJA04stbaC7HWvY4DAH
w81Y9GBjkxq/uPjE+AmfeUSlDSx8QnGKHB/ofkaOW2SAKzyxugXdDBSzAGm+
iMs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 195->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqgabOgx5PACbenSzYPaCATKbSLNQzGHAdCdML7IZ6H5Ftxeb33H5H6d7
0NyOyw5i9COHTQMeMzD8hG43Wnjg8xO6W7GFF3q44nMHRrwQoRc93DDCBo85
GPGHRQ+cjxa+RKc1LG7C5w5c6Y+QfpxpA4ff8LkbOe7R4wU9nWD4EVvaYkA1
hwGL+QgAAJpEiUc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 196->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOgzAMs/hA+90RdgV2AMQV4ASdNL6QJrGPib8dHZj2oMbuGqmtoiZ2
4uR0ubV9AeB+WK42PJpxDFNXrs41DOdqWD+P7wM869+BeFHHMSpu958wFc9Y
H96XsZ+BFeFgXyc2dTKnrAG6d9e/1YtqdxwWh01g/9U1wa20knrCYAtdnW7M
BVGf6sHNljVxeoLzKefrk77Zu7bhdTNRPSmuVL7dDdNb1m6m5kL75/SMsBxG
hDUDWrCIBA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 197->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zUBAvgELxgewqUc3iwHZHCR3EGsWsjkwMzDEsdiJjY9uF3rY4AoDQuGCbgZR
/kEH6GGFxQwU92KzG1kMS1hhDU8GVLPRw4+gO7DYhUscWzrDphY9THCFJ7bw
wEhfaGmPqLjFllZwxAk+P2GLb5LSFpa4JRSnyHGPM17Q0h/O8MQSdhhmoJgF
APe/hkM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 198->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zUBAvgELxgewqUc3iwHZHCR3EGsWsjkwM7DKEcFHtws9bHCFAaFwQTeDKP+g
AzzuxOpebHYji+EIK4zwZEA1Gz388LkDV7ww4BDHls6whRlGmOAIT2zhgTW9
IbFJjV9cfLx+wuZvPPpxpg0scUsoTvGFP1bzGLD7A24/Eo3VDBSzAPMviMM=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 199->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zUBAvgELxgewqUc3iwHZHCR3EGsWsjkwM7DZQQwf3S70sMEVBoTCBd0MovyD
DvC4E2u4YrMbWYyBAa9/MNTjsAtXeGGELa7wxuMHdLdghA2B8GSwx/QL1vRG
ICzwhQ+28MYXL7jCHp9+nGkD3W9ExCm+8MeWxnDFL9x+JBqrGShmAQCe+ImC

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 200->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zUBAvgELxgewqUc3iwHZHCR3EGsWsjkwM7DZQQwfDnCEDa4wIBQu2OwgRT8D
mhtwmcGART8uuwn5B5t6XO4kFL/4whufXnS34AwbHOHJYI/pF6zpDUmc6PhF
dxMR7mhAsxtbfJOUtnCEBz4341KPK42h+xElPNFoDHOQ1YABAGoPikM=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 201->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zYBHHhfGB3DqwWYPA6o7iDUL2RwwwOFuZDOw+RXFThxhQygscIULNjtI0Q9z
EwOaHN5wJWA3If9gU4/LnYTiF194ExWW6PGHFia4zGGwx/QLShhiSTdExy8O
N+FzRwOa3djim6S0hS2tEHAzLvUM6BgJ4AxPNBrDHGQ1YAAAJrqMRQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 202->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqqYBhxiKPB6AUw82dzCguoNYszDcgct/DKh2oruBAY8Z+MKHmHDBZgcp
+pH1NuAxgwGLflx2E/IPNvVY0w8hdxAIb6LCEj3+cIQLLndgjVs0/cTELYYf
sLiJkL4GHPYRE6fY/I8tPAi5HwVgiScGNDU40xcajWEOshowAABtp4vF
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 203->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GC4gwHJPHQzCbihwR5TLQaNw/9Y7UQSQ1dDbPighwMyjS9s
sOlHdh8+MzDciy1MCfgHW7xi8yeucMUZtjjCm1A4oPsFa9jgMIfBHtMvyO7G
Fi6E3EHITYT0NeCwj5g4xfA/Fj6hOMUWfujxxICmBqv/kcIea1pDVwMGAKcR
jMM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 204->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GC4gwHJPCxm4nNDA7J6HHbh8j82O/GpIeQODPcwoNpPsn+Q
/EXIDAYs+jH8R6R/0MOD2HDFGbZ4zCYYFmj24AoXXO5ASU9Y0guyOCF3EHIT
IX0NOOwjJk4x/I8jPAi5H5t6BnSMBHCmLzQawxxkNWAAACL7jUk=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 205->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GC4gwHJPGxmEukOrOJY5NDdgGwntjBisCfsBhTz0cIBmcYX
Ntj0w/xPyAwGLPox/IfmJ2LiFVs6QI83gmFLRJwQG7e4wgWXO1DSE7oZaOFC
yB143USEPlzxhytOcaYNtDhA9x/e8MChHjmukAHO9IVG4zMDAgDT743H
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 206->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GC4gwHJPGxmEukOrOJY/IHuBhQ7sYQNNjPwugctHJBpXO7E
pR/mJmLNYEBTg+I/ND8RE69Y3YcWbwTDFld4ExOW6PqRwwSHG7DGH7L/0cKV
pLjFYi82M9DTEXrYYotvotMWrrRCwN3Y1GOEE5oarPGKFnYwdejxggoAXGaM
Qw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 207->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GCIMSCZh81MIt2BVRyLnQzY1KDZhU0NPjeg+wc5HJBpfGGD
TT/MTYTMwHAvtjAl0j8MaPbgCj9i3YEzvIkJS3QzkcMEhxvwuQM9rol1B66w
acBhBr6ww6YWlz+wpg1caYWAu/GpR0kbSABreKKFHdyv2MIYDgD0RY8E
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 208->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHBZ8BmLiF32GO3kwEJ43MDip141OBzA65wwWYHMX5B
9z/cLBxmYLgXm91E+gfdrbjCj1h3YBUjEA64wh4lTHC4AcWNuPyPFK7EugXd
DSh8LGpwhR0uPxFtN460RihO8anHCBt0P2JxA7o69HhBBQBXv42G
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 209->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPlGSBqsAGcerC5gwHBx2YePjc0IOnBKUfAXyh24lFDyB3YwgXFX3jc
idUtDFjMwhEm6OGKrIYBTR+2MMFwP5p6rOmHSHdgFSMiXrG5FVe44HIHAxZ3
IPPR3Ud0/DKg8bGowZnWcPiJpLSFIzzwhSM+9Rhhg6YGw73Y0gkDdjkIAABc
Ro8G
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 210->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHBZ8BiLj43NCDpwetOPP5CsROfGgLuQLcP2V/EuBNn
uCKbhSNMGLDox+Y/YvyCHvbYwgI53vDFL7awJzZesbkVV7jgcgeuuEXWT2y8
4gxfLGbgCztsaokODwZUMzDCA084YlOP7iYGPGqwuQHZ7ejxgmoWANA2jog=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 211->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GC4gwHVLcSahe4OvPJ4/IVsJz41hNwBV4vmdnS/kaIfFjZw
s3CECQMW/bj8hx4e+OIVX1gQdAda3OIKa4Jxiyts8IQnVj1Y3IXuPlLiF4WP
RQ3OtEbAPIJ2o8UBSnjgCUdsaQvdTQxYzMQanmjq0MMZEwAAbQGPyQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 212->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbn66lui7DTLYG0jabTTKZ
6e58664rAPfN+9Hlx3EY8vO0noJL7g/7fkpuPw6M6ecwb5fn8xIHNibtUHMw
fxdf2Kvu4+6BZrq9eFaLoxAPYUdq4wx5reocJxD1bj/FieKM8SvdWvp+8Udc
N3EobkwfpVddw7gY3z/6ujj6byByS/kod0Utnztd2BQm7sn7MP+lD3RuthfK
RIvJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 213->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jUseF8YHcOrBZg8DhA3HRJqFbA4uddjksPkX3S7kMGDAoofYcEE3gyj/oAMk
fbjChAGLflz+I+QfdLeixxlyvBGKX5j78YU1QXfgEMNnDrbwwBan6O4jNq1h
C19s9mNNa+hqiAwPbHGHAgjow5a2sLkJnzzcDGzqGLDLQQAAaAyNRQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 214->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jUseF8YHcOrBZg8DhA3HyICAGxqQ9BArh82/6O5GDgMGLHqIDRd0M/CFDc5w
RdKHK3wZsOjH5T9C/kF3K870QcgdSHGLL6yJdQe2sMRlDgMW+7DFKbr7yHYT
A277saU19HAkJjyw2YUCCOjDlrYwwgNLmCGnF+QwwwhXdDYKAADgaozD
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 215->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmNkQMANDUh6iJVDNxPZTmxhhIwJuQU9XDDMwBM2
OMMVPaywmMGART82/xHjF3S34kwfhNyBFLf4wppYd6CbSSjesfkdW3wQm8YI
hS8u+7GlNRQ1RIYHVruRARHuRwfo4YzCRuZjC3/0cEU2EwMAAFtkjAY=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 216->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmNkQMANyG7BZR+6OehmItuJLYyQMbFuQTYP3V+k
6EcOmwY8ZjBg0Y/Nf8T4Bdm9eNMHIXfgCHtiw6EBzR3oZqLLkRQeONyHzx0o
5uExHz394PIPoTjFlzawphV8cYUjbaHHNwMOMxnQ3I8t/FD0YAAAvUyMRw==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 217->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GC4gwFqFjYzCbihAckMXO5mwGEvNn9gCyMGLGYQcguyeej+
IkU/ctg04DGDAYt+rPFEhF/Q3YpLPa7wQg93DDEiwwFZPTYz0eUIhQfWOGVg
ICpeMczDE964wgPdP4TiFF/awOY3QnFKVNpCU4Me/8hhhh5+KGZiAACajIzD

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 218->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wI49TBgcQcD1CwcZuJzAz5zUdyJx1/IdhJrBiG3IJuH7i+i9COb
gx5WWMxgwGI/1ngiwi/EqifoDhxhT1K8Yolb9LSCSx9GfGAzg4GBqHjFMA9P
eOPyO7p/CMUpvrSFzW+E4hRFPRZ9cD4SwNBvj6oPI1yxmAEBADp+jcM=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 219->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKg0AMRT9diNseoVfQA0ivYE8wgl0Jgi5Kdz16K1Wcpv/HDETRTN78
n8ylG9v7CcBcfh5telynKT1vxfLRp6GuhiV5XgN4NXtAvG2o/3leLVkDogMr
SzA9DR73R6fjKz8zyjjSkvOsr1B9zmkMizBAzqdzCnixWtnekA7Re1XraWFM
j8P6Qe8bEJrrH8/pt/Ju/cCpP7pbzJs7U5j9TPPGIXkY/ax/EIzvegPNVo8E

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 220->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GC4gwFqFg4ziXEXITux2YvNH/jCiFB4ILsF2Tx0fxGlH9kc
JP8REybY/ILNPcTEK87wxhHm6OGMLexx6cXnFgy3ETAHW3hgTW8MDETFK4Z5
eMIbW/rBF2644hRf2sLmN7xxyoCmHpubYeZgkWdAcz+28GPAYQYEAAA2mo/F

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 221->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xiSPL4wL49GC4gwFqFg4ziXEXXjsZsNuLzR/4wohQeKDYh2Qeur9IDlMk
/xETJtj8gs09xLgBZ3jjEUdXg1WMQDiguwXDbQTMwRseaOFKjFsw/IBuHg71
GOJY7CPWDQT9QkAfetrE6g577PLI/sFQh08ODgDPbY7J
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 222->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmIEA
jUsdOgaJ4wLY1KObBTefAWoWDjNxmYViLj47GbDbi80fuNzJgEUfXvuQzEP3
F1692MKUCDMYsNiPy3/ofiEUHtj8jSs8iAk3mPlEhSWaWrjbCJiDNzzQ9BMV
J0SYh81+DHEs9iG7h9i0hZHWCOhnQFePbg6yO3DI41RHwAwIAACVko0G
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 223->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmIEA
ja4OF8YHcOrB5g4GCBuOiTQL3S143YnHX8h24lVDhDvQwwVZLzH+weZ/bGGD
N1yx+AWbWcS4AVc6wGUGejhjUwczn6iwRFOL4Q8c5uANDzT9xLiFGPOwqScm
HSH7idi0hSs8CLkfHaDEEwMDalphwO4fDHX45OAAAJBYjcc=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 224->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmIEA
ja4OF8YHcOrB5g4GCBuOkQEBNyC7Ba878fgL2c4GJHegyBMRHtjCBcOfeNyJ
7hbkMEAPG7zhiqYGrg+HXzDCA4f7iQkPYsKNmHBAdzuG27DIEQoPrOmNSLfg
DV8GBqxhhDNsiRDDm7Zw+A2fGehpECMckcMFCWDzD4Y6fHJwAACTw4wG
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 225->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmNkQMANyG7B6048/kK2E5c7GbDoIyZcUPQT4ScM
/+MIG7zhistuIv2Czf1Y3UlE/KKrw+cHfOGBHpcMWOQIhQfW9EaEW5D9gDWt
IJmNbj+GODa1WMQIxg0WPr54xVCPRR96mKD4EYt7MdyCTQ4OAAqmisU=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 226->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmNkQMANyG7B6048/kK2E1sYMWDRQ2y4oJhBhJ8w
/I8jbPCGKxa/YJhDrBtwhRcOM9DDGV0dPj/gcwtG2GKRIxQeWNMbEW5B9gPW
tIJkNrb0g5E2iBDDm7aQzUcPDzx+QFGPHiZY0hiKH7G5AZsZDDjsYQAAm4KL
hA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 227->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmNkQMANDUj68LoTj7+Q7UQ3k4EI8/GFC4pZBMIG
3S3IYYBCYzGDAYv9GHYT6R90e7CGFw4z0MMZXR2x4YCuHkM/FjlC4YE1vSGx
iUlf2OxFNhvdfgxxbGqxiOFNWzj8hs8fDOjq0cMEPa2gxRGKOgbs6pDDBRMA
AEXliwI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 228->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmMizUI2B59bYebj8heynehmMhBhPr5wQTGLWP+g
AyLMYMCiH8NuIv2Dbg82tbjMQA9ndHWkhAOyeoywwSJHTHhgpDckNrHpC5d5
2OzHEMemFosYobSBMzzw+AFX2kKPK2SAzT9w+9DUIccHJgAAA/2MRQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 229->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmMizUI2B59bYebj8heyvRhiRIYFrnBBN58o/6AD
IsxgwKIfw24s/sIZnmhmEAovXPGLbhcp4dCAxR4Mv+AwB1d4YKQ3BvxhQYp5
2NRjDTs0NxPrBpx2o8UtPvcjhz+yvSjhigRw6seljgFHGmYAAK9OjgQ=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 230->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmMizUI2h5Cd2OxFl4e5A0UMhxnEhguG+cT4Bx0Q
YQYDFv3Y/IbuL3zhiWwGrvAiFL/IYYpuNjHhiW4Phl9whCc2O1HCB4f7iHUP
NvOw2Y817NDcjCtO8aUNjLRCIF4Z7DHdjxy/KOGKJo9NfwMudchyKGoAL4aN
BA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 231->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHChmMizUI2B2YGTnfi8ReKnchiRIQRoXBBMYtY/6AD
IsxgwKIfw24s/sIbngyYZqObSSh+sYU9seHQgMUeDL/gMAebnejpgVC6IRQ/
uNIXsv240ho+8wjajSutEAhH9PBHCQfkcEECOPUTUocBAOe9jQY=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 232->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHCRqGJMAvZHJherP5Ek8OmDg6QxYgII0LhgmIWsf5B
BmhuwWUGuv+w2o3FX3jDkwHTbHQzCaUZbGFPbDggm4EtrnG5gWB4oOknJm4Z
0NyD4iYs/sGVbrC5mZTwwAhPZECE+xnQ9GBNI2jyGPpxmIOiDgMAAAhojUU=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 233->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwHCRqHxmIXuLmS9WP2JJodTP5I6XGYRg9HdzoBmByn6
GezRMBFhAlOHy24GNPXYzEK3H0MeyQ5C7sAqRkQ4IIcHNjNxuQHDHeh+R9NP
KDzwmYce3hhpD0fYYotvUtIWRlohIk4x4hY5TLCkFXQ/YqjFpw4DAAA27YzF

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 234->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPl8QCcerC5gwG/efjcADMHDHDYhcv/GPqRzMBlFjEY3e0MaHaQop/B
Hg3jMAPZ3TB1uOxmQFJPrPtxhTmh+EWPF1LCAdk92MzE5QYMd6CHJQ42oTSG
bh6+sMCXjjDUkhAeGHaj+Y2Q+5HDHyUcsKQVdD9ihD8OdRh2gAEAJcyMiA==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 235->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jUseF8YHcOrBYQ4+8wiZwQDTi8M+XP7H0I9kBjLNgEUPseGCYgaBsMEZrsju
IRAmyHbhshvdPxjhgSfs8YUrulnY4oWkcEBLH+hm4nIDhjsYMPVgYxPjFmxx
gE0/ejrCF27oYUQwbeDxG8GwRE9f9lgwEsCpH486DDvAAAA0E4uG
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 236->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jUseFwYDGI0GcOrBYU4DDnPwmYVsJswtuOTwuQHFD1jCgAGLHoLhguR2BjQ7
SNGPHMYNeMzAcC8euwn5hxi3YgtX9LDFFi/4zMblJmS1KGGCww0Y7sCiBz1c
iUlj6Oah8PHEB8H0iEU/3rSBx2+E3I/ifwbMNI5NHqt+POrQ5SAAAK9hjYg=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 237->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jY5xicPlGSBqsAGcenCYg888fG6AmQnTi0sOnxuQ7cQXRoTCAyVckMxjwGEH
MfrhYYImhytcke3C5T9CfsFmBjHhih62DFjswhcOONMhAyobOUxwuZHBHr8e
OJ+I+MBlHgofT3wQCjds+gmmDRx+I+R+dIAeTwz2mPIY6YsBvzp0OQgAAN+E
jwY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 238->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfErU+HCRhRZmeplE1tE8d2
ujvfuusKwH3z/nT1cRyG+jytx82l9od9P15uvwG08g+Ivw91Pt3jk8OWrBE4
EV7EwXNh/ZR+n2PzrDc20lwMHkSPTL31pAUYKHM9St+SFhCMjK+UhzpLzrW5
3EnLAg5c/a/G77M8GF709kDqlG9qpuHbYFoS/P3yc0KZ33s91jvmBesDvAAQ
jZDH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 239->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqwWEOPvOIdQsu+3D5H10NsjrksGHAoodguCCZx4DDDmL0I4dJ
Ax4zMNzLgNt/hPxDjFuxhSt62OJ0C1Jckxq3KGFCIN6x6cEwg4j4wGUeCh9P
fGCLW0JiBNMGjvAg5H50gBInaHGP4kd0N+BSx4DdHgYGAMOkkMs=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 240->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqoYYDAYwGg3g1IPDHGR3EGsWNjOIkUN3A7Kd2MKIlPBBdz82f5GiHyWM
8ZjBgMUMXP4j5B9i3IpuB053YHMLkn+IDU8M/XjcgOEO9LhFC1dsaYJk83Co
xxDHEq6EwhqfWhS/4PEHA7p6JHOwhSmGPehuwKUOixwEAABA+4+I
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 241->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqoYYDAYwGg3g1IPDHGR3EGsWNjNIlUPxCwOmOxmQMFHuQHM/Nn8R6xY4
QA4jHGYwYHEDNjcRE9/ExiNR7sDmFiLjBFv8MaBjHOYwoOlHMQNbuBIRr3jN
w6EeQxxLuBIKa3xqUQAefzBgU4/kd3gawRH/GP7HpY4Buz0MDACQ95JL
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 242->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqwWEOTI4Us1D8gM9OAmY02GPahRw2DEh8guag+QHFDCL804Cm
HzmMsbkTW7gi60N3E7J7iLGfkD/xugOLOmLiC1/8MaBjHObg8jt6+CCHCTHp
DGtaYcDUz4CLxhKuhMIan1oUv+DxB7r9yPrQ/YEMcIUnrnSCTQ4CABhmkYw=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 243->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqwWEOTA6beXjdgGYGsXZi9QsDFnORMFFhYo/pdnR/EesWOEAO
IxxmMGDTj8NuQv4hxq3IbsLpDnzqGEgIUwY0fQz4zcaIPwY8ZjBgupvktILF
Lwy4aCzhSiisCdqNFB744gtb2sKIU3vs8ujhiW4WelxhAgCeU5MK
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 244->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqwWEOTI4Bi7l43YBmBrF2YlODbAZy2DAQaQa2cMHmL5LDFc2f2Mxg
wKYfh92E/EOMW9HDC6s78KljID5M0eMFxW843MiArp4BzW4GVP3kxC8uPrr9
+PTii1Ni4gXFLwT04kpbKHGFpgZX+kI3Cz1eMQEAmyCSyQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 245->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAYu5eN2AZgYhO3H5lwHNDOSwYcChh5hwweYvksMVOYxw
mIEeruh+weYefOGFz60MWOzA6Q4s6uDmkxCe2PTicgNG/KH5BVu4Eh23eMzD
ZT8KjU0tkWGB1y8EzEC3H109AzJGArjiFT0c0f2CCQBc2JKG
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 246->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfFLNwmYHPTnzmINuFHDYMRJqBLVxQzMDhH3SzMQCy/4gw
A5tfsLmHUFjA7MaQw2IHTndg8589drMJxS26XlxuwHAHWphhC1ei4xaXebjc
ji09odlJTFjgCjcUQGRYovgfG0YC2PyDoQ6LXzABABNhj8M=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 247->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfFLPQ3YLLL8T4D90u5LBhINIMbOGCbgYx/sEAyP7DESbo
4YruF2zuwRdHyHbjtIcYd2Cxi+hwwGIP3G0EzEF3J4oZWMKV6LjFYx5Wt2NL
T+hqccQpTrvRwgZXXOEKSxT/Y8N4zMSqDt0v6GaAAQCSkpFF
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 248->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfFLPQ3YLLL8T4D90u5LBhINYMLOGCbgYxYYMRDljMJhSu
6H5BcQ8Dfv+gqycU5njdgSXsCIUDrvSBErYEzEFxB3rcIptBhDtwxQ0u89HV
Y0tP+NIewXjBkdawmY0tLDHCEB2jqcHpBix2osihAAB6cpCE
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 249->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGAEhiOPVgcwcDgs+AxVxi3YLLL8T4D90u5LBhINIMbOGCbgYxYYM1XHG4
E1e4ovsFxT0M+P1DTDw22GOXx3AHLjEi4hXZvRhhS8AcBntMPVjNIMIdxJqH
NS5xpCd8aY9gvOBKK1jMxpu2sLiLAU0NVjegq8MRv6gAANxXkkM=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 250->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGAEhiOPVgcwcDgs+AxVxi3UKMnYT8gi2MGIg0A1u4oJtBjDuxhisOd+IK
V3S/oLiHAb9/8MUjij3EuAOXGBHxiuxejLAlYA66O7HxkfUTil8M/VjCF2tc
4ghbfGkPm50o8YIrreDxByH1yHGFrgbDDejqcMQvKgAAlcSRwQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 251->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGAEhiOPVgcwcDgs+AxVxi3UKsHDb/ottFSRihu50BGRMRNljDFYc7cYUr
ul9Q3MOA3z/44hHFHmLcQSDO8YYjFrXoYYLLHHR3YpiBpp9Q/OI1D08aQzcX
q1oC8YERL7jSCh5/EFKPHFfIAKsb0NVhk8cAAHErk0E=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 252->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAYu5+MxoQDMDlzuJ9Qsuu0gJI3S3MyBjIsIGA2CRwxuu
aGoY0MRgZhIVrwTsIRS/DFjEiI4TLGoxwgWHOXjDAylMkeOIGLfgDF8i0w02
NxOKD3xq8cUVwbSFI66QATZzMNRhk8cAALLzlIQ=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 253->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAYu5xLqFHDl0v+ByLylhhO52MMBjB7bwQAFY5PCGK5oa
dLthZhLrfnz24JNHjlN0PlFxgsUejHDBYQ7e8EAKU2LcQVT4Ekg3yDS6nYTi
A59ajPAgJW3hiCtC8Y+hjpA8GAAAXMKVRQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 254->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAYu5xLqFHDl0v+ByL6EwYsBiFrK/8NmBLTxQABFmYLMf
WQ7FPQz4/YOuHp89uMKaAQ2jmE1snGCxByNccJiDHG8Y4UGEfpLDl8h0g81O
QvGBTy2KX7DYhzdtYXMbmhqcacMeuzkMOMxhYAAAhWiURQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 255->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoG6cMF8OmBsxnQaBxmEusOnPLEmIHFLph78IURNnF0tzPgsQNrvDCghQMR
ZqCHK7IaBjQxmJnExCsx8YdTHi0MiU1z6Gqw+Q05rRAyAyM8kM3AEx8khS8B
P6CHLUZ6IcIN2NQyIIlhcwfWtMWAwxy08MIVv8hhR6w5DAwAsq6Uvw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 256->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqQdOPQsMwkWYhm4lNHQOaPcT4BcNcMsII3e0MeOzA5V6UcCDCDPRw
RVbDgCYGM5NQeBJUR8Ad6GFIaprDphY9THCFJ97wQDYDT3wQm1bQ/YjPn9js
xBWnOO3GFlc43IE1bWGJW2T9yABn2sChDpc5DAwAiT+WAg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 257->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAYu5BN1hj10duvmkmsGAbAYR+rGFCzZ/ETIDDJDNQQ4j
HGZgsx/db+jmEwoLbOrQ7SEYpgTinJgwRfELcpjgMQdveGAJV1Iw1vDF5XYc
YYLPPIJ2o4cvcngQk7awxC2KOUgAZ9rAoY4B3V1wAAAAJpQC
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 258->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoG6cMF8OnBcAcDknlYzCTWHbjsIsZ/6GYwYMGE9MPZaG5H9xchM8AA2Rzk
MMJhBjb7MeIJzXxi4hVfWBKKG2xhhx7nxIQpijuQwwSPOXjDA0u4EusWnOGL
rp4BUx8+tYTSFza1GGkEi9nodqLrwZZGkAHOtIFDHbI7UAEAoSeSgA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 259->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoG6cMF8OnBcAcDknlYzCTWHbjsIsZ/6HYxIOEGNDZBf6G5Hd1fRLkF2Ry0
sMLnV5x+YUAzg8h4xReWhPyCLwyJjVd0tehhgsscvOFBhH6SwxdLHOILW3xp
j5i0gR5P6GGNLR5Qwg9ND3IaQQY40wYOdehxjQAA4liSQQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 260->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoG6cMF8OnBcAcDknlYzCTWHbjsIsoMNLsYkHADGpugv9DcDgZY7MAbpsjm
oPkFn19x+oUBzQwcerG5H1daISbd4ApDYuMVXS16mOAyB294EKGf5PDFEob4
4hcjvIlwA7pabGkEmznY0g+2NAA3B0v8E6sOPa4RAABCy5KC
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 261->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TQpmgGEcAJ8+DHcw4DeTKPfgs5MIM9DtYkDCDWhsgv5CczsYYLEDZ7iiqUdx
Bw4zsNmPzcwGNDa+sEA3A1f8EUwjWMKQqDjBohY9THCZg00PRvgS6Q6C4Ysl
PHG6C4scrjjFGTfo8YrsHzzxgB636HGJHi7Y/IXsBmSA7m8McxgAV2aRxQ==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 262->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TQpmgGEcAJ8+DHcw4DeTKPdgUYduPiH9yOoYkHADGpugv9DcDgZY7MAZrmjq
UdyBwwxs9mMzswGNjS8sUPTgiT9i0glZcYJFLXqY4DIHmx6M8CXSHQTDF0uc
4HQXFjlccYozbtDjFdk/BOIAW9ziChdsbkJRh8UcdDsRAABOepKE
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 263->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TQpmgGEcAJ8+DHcw4DeTKPdgUYduPiH9yOoYcGBi3YJsHhhgsQNnuKKpR7Yb
lxkMWOzHZmYDGhuvG5D1EIhLQumErDjBohY9THCZgys8UMKXSHcQG77oaQBf
2OJLewTTFrZ4whOn2NIPunoGdIwWZtjSEi570c2AAACiXpMC
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 264->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoG6cMF8OnBcAcDknlYzCTKLVjUoZtPSD+yOgYcmFi3IJsHBljsIDpM0fyC
z684/cKAZgaRbiDkVkLxix5uyHFMTPpCjz/0MMFlDrbwQPc/se4gNnzR0wC+
sMWX9gimLVxpBV98YtODI67QzcRQx0CkOShmAQAZDZIC
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 265->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoG6cMF8OnBcAcDknlYzCTKLVjUkeI/dLsYcGBi3YJsHhhgsYPoMEULK0J+
hZmBYaY9qnvwugFHmOKKS7zm4DCbGP3ocYseJrjciGInFj3E+hGfeejhS0zY
YEtHxKQLFLW40gqJ7scaLwTMRAk/HO7Gag4DAHa4lH4=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 266->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAYu5eN2AZgY+fxLjF2x6kTGp4QLnY7EDl38wAJo/8fkV
2QwMM+1R3YPX/TjClJRwxRVu6O4hJW7Rw4SQG3HpIaSfGPNwhTe+sMEaHjji
FF/cYE0rJLofJV0hYzxmooQfHndjmMMAALOrlIA=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 267->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqweYOBgQfm3l43YBmBj5/EvQLA6ZaBjRMdLgguR0eTjjciWEf
OkDzJz6/YlPDgOSGBjQ2TjfgcSux4Yor3NDdg80PuOIWPUwIuRFb3JISH6SE
Lz6/4FWLI07xpS2saYUI96PowRFX+MxEjjt87sYwhwEAv36UgA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 268->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqoYYDAYwGg3g1IPNHTBz7LGbR6xbiLETr18YMNUyoGGiwwXJ7Sj+I+Af
rOGJJWzwhiuaGgYkNzSgsXG6AY9bkc0h6Bcs4YbLbGzq0O3BFh4E0xkDqjtI
iQ9SwpeYNIdVLRFxik0tenrAFtYYYYmcvnDEFQrA4X70NIXLnwgAAOFclL0=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 269->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqweYOmDn22M0j1i3E2InXLwzYwwYZ4zUD3SwGLP4j4B+s4Ykl
bPCGK5oaBiQ3NKCxCcYrAX8S9AuWOCcmHHDZgxEmOMzBCA9c6Y0IdxAVvkSm
OWx2EhOn2NSipBUc7sAISzQ92OIKBeBwP6H0gWEOAwCT2JJ+
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 270->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqweYOmDn2SObZEzYL3S3E2InLv8h2MSC7zR5TjJA96OGA4j8C
/sEanuhhg8UM9HBFVoOuD2YmUfFKwJ8E/YLNbUToxWUPtjDBqxeLP0iJD5zh
gx6+RKQxbHGDLz6wiiHHI5bwIBSW6GGILa5QAA7340ofOM1hAAAsUpQ7
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 271->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqweYOmDn2SObZEzYL3S3kyKH7pQHJHehhRCicUPyD5HZ0vxEy
AwOghw0WM9DDFVkNuj5kv+J0Ax51yP4k6BdsbiM2TrDYgy1cCKYzBux8Yt2B
K37R/YTLfmzx24DFPfj8gO5/rPFKhNtRwhBHXKGHMTb3o9DEmMMAACg+lPo=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 272->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqweYOmDn2SObZEzYL3S3kyKH7BVsYMdgzEBVGKP5Bcju63wiZ
gQHQwwaLGShuR1ODrg/dr3jjlYA/CfoFS5wTEw647EEJHzzxghEeuNIbEe7A
Gj7obsJjP7b4xWcePjNQ4hELn1BYIpuBEiZY0hjO+EdLH1jjF90cBgCW0JT8

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 273->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqweYOmDn2SObZEzYL3S24/EKMGTA7KQkjFP8woLoJ2W+EzMAA
6GGDxQwUt6OpQdeH7lecYYlDHQOaOrx+wRLnxIQDLrUo4YMnXtDDA2t6wxKW
RMUztvDFYz8+vbjEcJmBEo9Y+PjCEj1MGbCJo6U/rHHCgN0MDHtQAAAggZS9

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 274->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqweYOmDn2SObZEzYL3S24/EKM/+CAzDBiQFaLFg7ofiNoDjpA
DxssZqCEK5oadH3I/sQblljCA12emDDBFecE4wRLmKGkDzzxgtW96OkNR1gS
m1awxT2hNIfNTmLiFJtajHglEJboYYqSrrCkMVxuQgk/LPGLzRwGBgAUsJM9

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 275->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoGAxiNBnDqweYOBgQfm3nEugWXX4gxAw7IDCMGZLVobmdAxgTcgjU8sYQ1
rnDFpgZdDNmfeMMSS3igyxOKXwZcYgTcgK4WWzyhm43THQyoYoTCkti0gi3u
sdmPTy8uMVxmoMQjCX5ASR9Y4hYD43ETSvjh8DuyGRAAAHcgkoA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 276->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jS5PCIMBjEYDOPVgcwcDgo9hHgluweV2fO5B8QsDkhsIhBE2fzGgm4XuLyLc
gs3/yPpwhS8DFv0YYYoWbwTDkoEBq/+R5YkJE/Q4R3cPQf0MqHZjCxdC4YER
13jCEp952OIA3Y/40gs2O0lyB3rcEqkXJTywxC0DuhwOc5H1IscDrnhDAABF
QJI/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 277->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jS5PCIMBjEYDOPVgcwcDgo9hHgluweV2YsxBto8BiznEuIMB3Sx0fyG5E58Z
GADZfzjCFyVc0dTAzSQyPFDswmE+Mo0vftHDkgGLe/CGBZo9GPGEIzyR3Y2u
BjlMCcUHvrSC7k5i0gs2O0lxB7JabH7AaS+B8GdAxzjchKwXW/xiqIMDAEH0
lH4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 278->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jS5PCOMDOPVgcwcDgs+Abi4JbsHrTmL9QkGYMKCbhcNfhMzAAFjMxhuuaGrg
ZhIZHnB3YwkPBjR5gn7BEufo7iGonwHTb9jksMYFFjVw/UTEB760gu5OYtIL
zrgh0h3IarHpxWkvjvDHECfgJnS92PyO7jYIAADrKJQ/
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 279->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAd1cEtyC152E9KOpQ3cnMe5A9g9yODAgYzzuRHEHWhig
m00oXJHVYPiNAVM9trDEFh4MaPIE/YIjLImNE3R7MMIFhxvQ3YuNj2wOMWkM
3Q340hcuPrawJ8UNyHZj8wMuc1D8jxwGWOKKAc0ejDhlwFSPUx0cAAAW9ZJ8

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 280->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAd1cEtyCzQ64Ownpx2MGAxYz8fkNPRwYkDGesEF2B3oY
oJtNKFzR/YIcBoTCA+5uLOHBgEMer3+w8ImNEwx3oIcLDjeguxcbH1dYEpPW
MNyEJz4w9BIhRozdKGmFkL04wh9DHM1crPHJgN0MrOrgAAD2HpU9
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 281->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAYu5xLoF2QwMdxLpF1zuJCaMGNDMwvCXPaoduMzAAFjM
JhSu6H5BNodQeMDdjSU8GHDI4/UPFj4xYYqePlDClkB4MmCxDz094ApLYtIa
hpvwxAe2+MVnHrF2o/sBX5hihAcDqnr0eMHlJhS9SHGBNX5RAADTupN+
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 282->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqwWEOTI4Bi7nEugXZDAx3EukXbO5kwGEuLr+hux3dX4TMwABYzMYX
rjAzsJpJRHjA3Y0lPBhwyOP1D46wJCU8MdIcFn/iDA8G7Hxi4oOotIIlPHH5
DZubSXEHslp0P+ALU5T4Qw4DXBiHm1D0IsUFrvhFAAAILJMA
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 283->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqwWEOTI4Bi7nEugXZDAx3EukXbO5kwGEuLr+hux3dX4TMwABYzMYX
rjAzsJlJTHgg24XLfbjksaUxXGFJdHhiS3MEwhNDDxY+MfFBVFrBEp64/IYe
N/jilJDdGPFKwF6U8GdgwIgLBnR5IuIfI2yxmAEBAAvqlAA=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 284->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqwWEOTI4Bi7l43YBmBi53EusXUtyNzy3I5qH7i6RwRdKPz50MaGxk
Neh2w8wlJ0yRzSYUXuhuxyeO1x3YwoZAeGLowcInNj5wuQGX+fjSC3rcEJP2
cKnFiFcC9qKEPwMDRlwwoMsTEf8YYYvFDAgAAO/Zlj8=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 285->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBgSfAYu5eN2AxQxs7iTWL8S4G58adPdjEydoBjJA0o/Pnejh
iqwG3W6YucSGKTb3EQpXBjSMLe0RClMGNBolzREITxR7GDDNwPALEfGLK61g
8wsu85Ddj8s8kuxGjld89mJLY1jiiQFZHk/841KDzQwIAACKNZV+
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 286->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB/DpwXAHA4LPgMVcYt2Cyy/EmIHLLlLCiAHNLAx/EeEWDP8j6SXGnQ1Y
7GFA0wczlxh/4HIfoXBlQMPYwpNQmGILe4xwweEGFHsYMM3AFk7EYvQ4wOYX
XH5Ddj8u80iyGzle8dmLHi/IYYgNY3Enip040hFWM8AAAOj5lnw=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 287->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB/DpwXAHA4LPgMVcYt2Cyy/EmIHLLnLCCN3tDMiYgFsw/I+klxh3NmCx
hwFNH8xcfG7AF27I5hD0Cxa3NWARx+sObGFLIDyx6cGWVohJG4TSCja/4PIb
svtxmUeS3cjxis9e9DhhwCKGLo8jncDDH4u7sZoBBgAvbph+
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 288->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBiTzsJhLrFvIkUP3Cy73khJG6G5ngGEi/YMCkPQT405satDt
hplLKLxwuZWQPIq9uOKciDDFFvZwvyCxCaYz9PBgQDWL2HjFG7547Mcat0Sk
PaLsRo5XfPaixwkDFjF0eRzpBDn+0d2N1QwwAAAEHpmA
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 289->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBiTzsJhLrFtw+YUYM+AAh3uJCSMGdLOQ3ITsL5LDFYvZeMMV
TQ263Qxo6nGGJQ57CMmjqMUjRihMsYU93C9obiHoDuTwIEI/PjdhDV889mOL
W0JihNIGNj6+MEUOS1zpgQGLPDZ/Icc/hl+wmQEGAAvTlYA=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 290->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEL
zWCPqoYYjA/g1IPNHQxI5mExl1i3oJuPLkeMX3C5l5jwYUAzC9lNDHjsIBiu
RJjBgEU/shw29xAMSxz2EJLH8DO6fiLTHHr6QEkjaG4hKTwYCOsnJa1gMweX
37DFH644JcpuIuMVa7yg+wGLPLp56PGPzd8YZoABAFgPlIQ=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 291->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBiTzsJhLrFtw+YUYM3DZRUoYMaCZhewmBjx2EAxXIsxgwKIf
WQ6bewiGJQ63oscbLjVwe7GJExGm2OyBhwcSTTCdoYcHcpgSER+E0go2c3D5
DVv84YpTouwmMl4Z7FHVYPUDFnl085D9issM9DQHAQDPx5YE
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 292->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jU0NPowP4NSDzR0MCD4DFnPxugHNDFzuJNYv+OwhFCYMaGbh8hchMzAAEWag
hCuSPnQzifELXB0OtxIV5sj24kh7xIQnA5o9GOFCwI3Y4hYlHAjEBzFpBZs5
uPyGLf5wxSlRdqPFK6G0iZHG7HFgJHmMOGFgwB43WOIXAQBeuJUC
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 293->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jU0NPowP4NSDzR0MCD4DzFx7wmZhMwOXO4n1C07ziQgTBjSzsPqLBLfAARFm
MGDRjyyHzT2EwguXW4kKc2S3ECGOywwGNHuQ/YIuhzPe0MODAVWOUHwQSivY
zMHlN2zxhytOibIbLV4JxQe2MEQJayLSGXLYY4QDNjvAAADcN5ZD
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 294->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
jU0NLswAwzgAPn0Y7mDAYqY9pln43InXTjxyKP7BYhcyTUyYwOxDdjsDMibG
LegAS3jjDVcs4YbNPYTCC5dbiQpzZLfgSTfEhic2v+ALT/R4QzGDAc0sAvGB
K35wpR30+MBwD7paIsICp91o8UooLLGFIUo4EZHOkMMem7/RzYAAALDflL8=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 295->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoG6cMF8OnBcAcDknkwM+0Jm4ViLj47iTCDAU0dtjAiFE7I/kF2OwMyJsYt
6AA9bLCYwYBFPzYzifELXB0Ot6LHG0G/4AkjYsMTa5ojxo1Y7EIJBzT3EZvW
sLkJV3xgcw8+80iyGy1eCYUlzjDBksawuQk5zLCpwWUOAwMArt6YQQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 296->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
NyDRpGKwGTgAPj3obDBAdhcDA4rZRLmFAbsd6HJ4/YLDndjk8ZmBHg4o/iTG
LegAi9l4wxWLGhT3MOD3C7J78crjCS9s6YzUsMDmDoxwIcKN6HYhxwty+OLz
C66wRDYHV3xgcw8+80iyGzleiQhLnGGCJY1hcxNKmOEzAz2uGAB7+JUA
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 297->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSoG6cMF8OnBcAcD1CwcZhLlFgbsdhDrP2T7cZlBtDlobkf3FzF+QQFEmMGA
RT82M5HDm1Ac4XIrsekGPUwx4pxAWGBzBzZAyI3o6lDiBUtYEPQXFvMwwpuA
e/CZR67dxMQpNn8zoGM8YYusF5e/sZnDwAAACoeVwQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 298->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBggbjok0C8MtFPgP2X5cZhBtDprb0f1GUrhi0Y/NDAYs+rGZ
iR5W+OIIl1vxhSu6GLpdhPxByB0o4YLHDJR4Y8A0A0WOyHjFFb5Yw5tA+sAV
N0SnDWzxSqz70fyNkcaw2INNLy5/Y5gBBgA/F5O/
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 299->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBggbjok0C8MtOOwixgx0/bjMwmsGlnCBiSP7jaRwxaIfmxkM
WPRjMxNXWJESbvjSDUa44QhXYuIWmztQwgWPGchuRFeHEi8EwoKY8MUa3njM
wRc3RKcNbPFKrPvR/I2RxrDYg00vLn9jmAEGAEHXlcE=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 300->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB3DqweYOBggbjok0C8MtuPxHhBnI+rGFCSlhhO52ZPcQ7RZkgB5WWMxg
wKIfm5nY/IrLLFxuxZZucJnHgEMdMXGLzR0oYYLHDPQwRzcDRY6YOMUTvljD
G194MOA3j6i0gS1eiXU/NjegYwZMNeh68fkbxQwwAAB3tZdB
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 301->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEH
TSrGB/DpwXAHA4QNx0SaheEWHP4hxn9wQIEZ2MIFPZyJ8Q8GQA8rLGYwYNGP
zUz0sMJqP5a4wpd+8PoF3W0E/IFNL7I6lDDBYwa+8ECOF0JhQax5GOGNz094
4obotIEtXomJUyz+ZsCG0ezBcAMBf6OYAQYAuEaXgg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 302->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
NyDRpGJ8AKceLGwwQKeJMAubGdj8Q4z/4HbjcCcDkeaghwu6fmz+wXAvOkD3
JwEzkPVhE0OXwxemeOWJCQt8cU5C3GKLC1zhiSs8GtDMIyYssPkZm3no7sBl
JrqbsZlHVNrCFq/Eut8eUw96mKLbg+EGbOGAI5wgAABoIpK/
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 303->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmAEN
NyDRpGJ8AKceLGwwQKeJMAumF9kMbP4hxn9wu9HdhiW8SAkXDDOw+AfDvegA
PawImIGsD5sYuhy+MMUXh0SFK644J0I/sp9RzEMKE0JubMCijhj9xIQvLj6+
sMFmJ644xZu2sMUrMWGJJQxRxJHNxJFO4HrR5DHMQwEAClyS/g==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 304->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
NyDRpGJ8AKceLGyYejDAZi4BNyDrxeYfYvyH7m5ks9DDi5RwwTADS9ighwk2
/zPgcCdW92JRg2IWoTBFC1t8duENByzhhh6uhMIR3R3I7scVnhhhih63ROgn
2Tz08MYXJjjihqS0hS1eiYlTtDDEFlcoAJcbCJmBbg4DAKA2koA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 305->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj1YHMHA5J5WMwl5AZkGpu/iPEnul3IYYSMSQ0XDDOw+Ac9TDAAWlgR
NAOLGhT3MOD3C3q84JQnFA5Ywg09XMmJW+QwIeRGrHFLhH6SzUMPb3xhgidu
iE5bWPj4whQ9ztDTALJ+FIDLDTjiFiV+UQAATO6WPw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 306->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DAHbh4Wc/G6Ac0MYu3E5RdsYcRArBlYwgXdDGL8gwGwmI3Pj9jU
oLiHAb9/kNXh9Schf2CxCz1cCcUJujvQw4SQG7HGLRH6STaPAVUdLr9hsxNX
nOIKE3T3o/AJuB9fvGCYyYDdPLh9SPaixymGOQwAsueUgg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 307->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DAHbh4Wc/G6wR5VL7F2YlMDdweWMCLWDPRwQTYP2Q5C7kABWMzG
50dsapDDB19YoccHXn8S8gcWuxjQ5AmlL3R3IJuJLzzxhQcx+kk2Dz28iUhn
+PTjCxMU9yOHEwF7CcULihwDphqM8ENyB7r9GOYwAADBtpX+
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 308->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DLHHgkTaRaKX0i0E5d/cIURMWYguwXZ7eh+I2QGBsBiNj4/YlMD
MwedTU6YEhMmKHGJQy+hMIWHH1q8oKQXAm7EFh7o+olNH9jCEmd4EwgXDPMI
pAt0tdjSFL4wRQ93lPSAHq7IAI//kd2BYo49FnMYAKLGlrs=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 309->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DLHHgkTaRaKX0i0E5d/cOkhxgxktyC7Hd1vhMzAAFjMxudHbGpg
5qCzyQlTZH8R5RccaY+gfgZMdyCbiS888YUHSrwQCAtc7iIY3rjCFJscjjjF
aTey/9H9QyhOsfgbPV2gADxxiuwOFLPtsZjDAAAR6Jd8
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 310->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DLHHgmjA3xuQDKDFDtx+QeXHmLMQHYLcjig+4uQGdj8j242Pj9i
U4McjgTDlAGVxilPRHig24Wc9gjqx+IOBjT7cboRT3ig6yc2fWALS5zhTSBM
sMU30XYjxyWSe/DGKVq4Y4sXuDlIAF+cotvLgI5RAAACUZe/
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 311->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DLHHgkTaRaKX0i0E5d/cIURMWYguwXZ7ej+IjlcsZiN024camDm
oLPxhQMutxIbJgxY7EJxJ5HxgRIvaGFCjBvRwwMlXoiID6zxgyW+iElz6HaS
ki6Q7cbwH54wxVCPLUzQzcHhJmT3Y3ULFjsgAABDaZb+
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 312->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DLHHgkzINF4zELxCxZ1pPoT2Qx0PcSYAdOPHg4o/iLgH6zhiuZP
Qn7FpgbFPQz4/YNiFz55Qv7AYgaKO0kIT6z+wBHvhMKDGP3ExA8uPr6wwdBL
QrpAjhMM/+EJUwz1+NyBlv5wxSlOt2DxFwQAAGWNlsE=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 313->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DLHHgkzINF4zELxCxZ1pPoT2Qx0PcSYAdOPHg4o/iLgH6zhisVs
fH7FpgbFPUTGEcxuUsIcXR26GSjuJCE80dMKsvl4/YAcnujmEuEHfPGDi48v
vRCKG6LsxuI/QmGKHu4YfsCW7nCFLQMet+A0DwBRwZeE
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 314->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
xobxySGrwQVIMRemngHZTHvCZqH4BYs6YvyJzR3Y9BAVHgwIGtntKP4iwj8Y
AIvZ+PyKTQ2Ke4iMI5jd6P4nNlwZ0MzAcCcJ4YniDzTzCaUz5HDESG8E4gOX
u3C5iVB6wdBLZLpAtwsjvgmEKXq443MHMiDkBgy34DQPAFQKloA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 315->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
xobxySGrwQVIMRemngHZTHvCZhHyC9xcAmYg+wWXO4kKDyT7kN2O4i8GwuGO
AbCYjS8csKlBcQ+RcYQrPIhJPyhuweVOEsITxR844gxXfKGHO0q84AkHfO7C
5SZ0txPUi0MMr93Y4ptAmKKHO1Z3YEl7eN2AHq5oaQcVAADDWpSE
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 316->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
xobxySGrwQVIMRemngHZTHvCZhHyC9xcAmYg+wWXO4kKDzR3Y/UXEf7BAMj+
xGEGA7o70OMc2T1EuAM93Biw2EUoTJDjEptegvqxxB+yeehxRmx4oMQLEeGA
NZ5xuAlb2OHVi0OMYBrDEsbEhAeudMSA5hZ0eVzxghEfOMxhYAAAuW6WhA==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 317->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
xobxySGrwQVIMRemngHZTHvCZhHyC7K5hPzSgGQvNj1EhwdamGATJzlMkf2J
wwxk92FTg+IeItyBHH4Y5uMLc2x+wRZGRIQpsntxxREuf+ALD5R4ISIcsKYT
dDdhCW+i9OIQw2s3WhwgixEKDwY0czDihIGBYFpFjhds7kbWjwAALOuWwQ==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 318->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JheD9OMC+PRgiDEgmYfFTEJuIMZcovzDgNudxJgBtw/N7ej+IjlMkf2JwwwG
NHdgxDmye4hwB77wIDb9wP2CLoZFnFB4YvUHmhyx4UGMfkLuwuUmbGGHoRdH
fBOT1mD6GdD1ExkeDFjcwWDPgBEv2PyELV6wuRubOQwMAEI5mEM=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 319->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JheD9OMC+PRgiDEgmQcz056wWdj8woDNXAJmoKvHMIfIsEK2D9ntKP7C4hYM
u9ABsv+IMQOLGhT3EBGuhMKDmPSDHJfoYYkuTig8sfoDT9ziCw9i9BNyFzHh
jS9MsMU3Nrfjshs9PTBgMRtbeKCHPwZGA4TiBZu7sZnDwAAAC/iVRQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 320->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
RmcTi0F6cAF8ejDEGJDMg5lpT9gsbH5hQGYzoNIE/cOA253EhA+yvchuR/EX
FregxwMGwGEGrvjDZg+KPiLCFV94EJt+kN2NIcZAOEyxxR+yPgY0OZxhiuZf
YvQTcheGm9DDG08aQY4/bOkCX7ggpweUtEZkeKCHP1ZxJEAoXtDjowGHOQwM
AJh9k8E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 321->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JheD9OMC+PRgiDEgmQcz056wWeh6kPko5hIwA5c7CLkbl9/QwwHFX8T4Bx3g
MIMBh/uw2YOijwh34As3bOkHa7wixSW2+CIUpujx2ICmj8GesBux+ZcY/YTC
BcNN6OFNIH7xpQt84YKcHjDilcg4Y8BiDq60hy9dwAGOcEUFAG4plQI=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 322->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmAGK
G5BocjE+gE8PLjGY28AA2Xx8bkDSg+E/Btx24nMbshnI9hCtHy0cGLCI4fUP
OkAPG2xhiCVesMUVLnli4wrZLkJhghyXGPFFpH50dyCbx2BP2I3Y/IsensSk
DVxhiTO8CYQJuv/Q3YfXbhx6iQkPlHSELo4F4EsXcIDNDgwAACGOk4Y=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 323->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DAHJscAM9eesFnoejD8x4BKE+MfXO4kJqyQ7UN2OwMWMbz+QQdE
hAkDFv3Y4gqdTWx4kJN+kN2NEV9E6seIFwY0Mwi4EZt/idFPKFww3IQe3gTC
BN1/6O7DazcOvdjMRvYvit8ZcIihAXzpAg7wpEEEAABWoZOG
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 324->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DAHJgcH9oTNgutBMwPDXAJmoKvH5k5iwgrZPhSAJkaMXzD0o8nh
CldcapDFiAlXfOFGbPqBuwWbH4nUjxEvWMKDUDpD9y8x+kkyD1t4EwgTdP+h
uw9fnDDg0IsepihpAlsaI5TuGLC7B+4GBgQbVxpEAACm3pEG
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 325->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DAHJgcH9oTNguuxx64Obi4BM9DVY3MnMWGFbB8KQBMjxi8Y+tHk
cIUrLjXIYsSEK75wYyAg34DuFmx+JCJMsdmD4g8i3IgSH9jcQEQ44DIPFx9f
ekG2kwGXeQTihAGHXnxhii19MOASRwLY3APXiyVcMcIcDgAPk5JJ
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 326->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DAHJgcH9oTNguuxx66OAc18guYw4HYnIT6KP9ABmhjJ4YrmF7x+
xaEGWYwUd+AKb2LCFe4WbPFFRPrDZg+KP/C4AcVOBlR3IIcpMeGAyzxcfFzp
A6daIuMD3e3khAdKWsQljgSw+QWuFz1csbgLAQDZjZJL
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 327->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DAHJkeKWXA9aGZg+JOAGQ1oZmBzJzFhBXcDOkATIzlc0fyJzQzk
OMWmBlmMFHfgCyei4oYBM06QMSH96Pag+AOPG1DsZEB1B0qYEhEOWM3DEbaE
0guhuCEqbaCFDSnhgZ4WUcSxpD28bsBlBhZzGBgAKhSRjA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 328->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
JhfjAzj14DAHn3l43QDDDJjmM6CZT9AcBtzuJCaswACbP9DESA5XNH9iMwM5
TrGpQRYjxR34womouGHAESdEhCm2+EPxBx43oNjJgOoOYvQTYx4uPr70Qihu
iE4bBPxGTPpA0YdNDpdZDGhq0c3AYg4DAwDj+ZFP
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 329->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEN
N5CJwfpxAHx6MMQY8JtH0A322NUxoJlPjDm43ElMOMH9gQ7QxEgOUzS/4PUr
DjXIYsS4A1e4IYc10X7B5U4i4gTdHhR/4HEDip0MmGYQ0k+Mv3CZjy+9EIob
YuIEOUyR+cSEB0b6QosPdIAvTnGagcUcBgYA0IqSSw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 330->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEN
N5CJwfpxAHx6MMQY0NxFpFnoenDZRciMBjxmINtB0AwGBI0C0MRIDlM0v+D1
Kw412NxCrH9whQU+M1Diksy0h80eZLcTijNccUuMflLSCtbwxhOmuOKGKLvR
1KLEKxHhgZG+sMUXEsCZPtHsxohbDAAA97aRyQ==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 331->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEN
N5CJwfpxAHx6MMQY8JtHyA3IZhArh8svpLgbpz/QAZoYyWGK5hd8fsWlBptb
iPUPOeEKT18MWNxGZNrDZg+y2/HFGQO6W9DMICbO8YULLjcRSi/44oYSu5HD
m2B4MGAxB0faw5U+0e1GiS8s5jAwAAC1SJUM
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 332->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAYoZ
0HADmRisHwfApwdDjAG/eYTcgGwGsXK4/EKKu3H6Ax2giRFjDoZ+NDl87sPm
F2xuIcodJIY51vSBK+2REbfIbsdnBgO6fWhmEBPnhOIHXzjhSi9Y1RIZHzjt
JiE80NMXRrwwYJfHlrawmdGAwxwGBgCNUZZJ
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 333->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMGe
AQ6QxUnFyOagA3x6MMQY8JtHyA3IZhArh9UsHOoYcLgbpz/QAZoYMeZg6EeT
wxeuDPaYapD1keQOEsMca/rAEpbY3EiMPcT6gwHdPjQzcIUTsekEw0144oNQ
mBIbHzjtxuI3vOmDAYs+5PjCIo8tbWEzowGHOQwMAAVYl4w=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 334->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGG
0cRJxTAzsAGcerDIwcRwmUfIDQTNJdKfWM1AwsSEB8wcFIAmRow7MPSjyeGy
GzkcsZmJzwys/sBhPjHhyoBmBnraIyduifUHAxb7cKU3YtIGrrBEDyds8YGh
F0d6ISZ9YbUbi9+wpgks6Qub2djksaUtbGbgNgsAKMSTjg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 335->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGG
0cTR1eCSg6vBA0gxF6aeAYeZeN2AZgaGHwn4E0U9FnXI5hBjBtZwQRPDFRZ4
9aPJ4QtXbGqQxQiFK4pdJIQ5rjBlQBfDYzYhe5DjCZ8/GLDYhyu9EYpXQuGL
zS+4/IasllCc4gxPdLuJ8A+2NIQtXNEBvjjFCFe8ZgEAWmaQyw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 336->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N+DA+OTgavAAYsxlQDIH7i4SzMJmBrofscnhMgebOmLCCptbUACaGF434NKP
ZjbecMWiBlmMGHeghxu+eCMUprj0EgpTXO4gxh/odqKYwYBdnBi3YLMXa3jj
Sxs40gsxbsBnNz7/YHM/tnBFB/jiFCNc8ZoFAIQ4kcs=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 337->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
I4s1kIjxAZx6sLBh6hlwmInXDWhmoPiRAbscLnOwqcMWVsS4BQWgieF1Az79
9rjNQAlXLGqQxYhxB75wIySPHqa44pxQmGKzhwHdDEJuxBK38HAgMm1gmM2A
aR5GeONLGzjSCzHpi5DdRIUHAxZ92NIdFrNQ0iKWuMFtFgAKgpGM
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 338->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
I4s1kIjxAZx6sLBh6hlwmEmKGSh+ZMAuh8tduOxCDytCfsMAaGJ43YBPvz1u
M1DCBIsaZDFC7sAXHvjCHJcZuOKLUJhiswdZHz5/oNuJbgY2NrEY3V6s4Y0v
beBIL0TbTcAtBMODAbudWAGeOMUIV3Q1KAAAFYaTDA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 339->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYA3cXEWYxYGFj9SMDdjl8/sHlZmLCCtktKABNDJ9+rGFgj0YT
ChMsapDFCLkDPfzw+ZMYMzDchkWcWHuI9Qd6GkExg4g4J5ROcLkJmx0YaQNH
eiHabgJuIRgeDNjthAM0Nq44xbAbXQ0KAAAWsZRN
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 340->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYA3cXCWYhm4fVjwzY5fD5B5cdxIQVsltQAJrfyNLPgN8MZPdh
U4MsRmy44gsPYsIV2d0YaQ9NnFh7iPUHhp1oZhCKc0LpBJebsNmPEbc44psa
dqOwCaQPjLhBEsMmjx6nGHajxy8KAACHDpPN
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 341->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYA3cXDNgTNgubGSh+ZEByJyH9eNQRG1YMSG5BAWh+I0s/gTBB
dh82NchixIQrcvjhCgtyzCA1TtDtIdYfDHjcgYtNLEa3F2t444tbAuZRYjcK
G5v96OkLlziaPHpYYkuLDMgYAwAAhi2Sjg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 342->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEN
N5CJwfpxAHx6MMQYsJhnT9gsbGZgNZeBsD8ZcJlBQjih2IcM0PxGKGyw6icQ
Jgxo7kBXgyxGTLgSCg9cYU7IDFLjBN0eYv2BLzxwsYnF2MzD8CeBtIHPPIJ2
44pXdL8RCA90tVgBjjjFlhYZkDEGAADZVJKQ
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 343->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CAwWbgAPj0YIgxYDHPnrBZ2MzAai4DYb8y4FBHSlgxINmLAtDEyNaPFiYM
WPQ2oKnBJkaMO2B24ZLDFebYwpSSOEG3h1h/4NKDTY6Y9IUrLAn5E6u/0eKP
UHzgCn9s5uEMDzS34vIDBsARp+hpESXdYDULAEjekRA=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 344->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CAwWbgAPj0YIgxYDHPnrBZ6O7AaS4JZqCHCylhxYBkLwpAEyNLP5ocvnDF
pgZZjJhwxRWm6O4k1QyU8CAhPEn1By492OQIxSvWdMKAKYbLfmxxi0uMoP1o
4YZuHsE4Q09fuMTR5DH8jysccJoFAHwzkU8=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 345->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N2DBuMSxqcMKCOjBEGPAYh4Sm1h34DSXgBkMyHbjkiMyPGD2oYcHMiBLP5oc
eliisLHYg6KPiHDFFabo7iTVDPTwwKufAdMeYv2BLzxwsYnB2NyO1Z9Y0hDe
MCHSHbDwwxoexMQZevrCJY4mj+F/e0w1DMgYAwAAzJCQTQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 346->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N2DBuMSxqcMKCOjBEGPAYh4Sm1h3YBXHIUeKOnxhhc1v2MIDGRA0B5t+NDn0
sGTAoh+bmbjkiQ1TdH+SagZ6eBAbnqT6A1944GITg7G5HVd4Y0s/2NISMWGB
Hn7YwpioOMOSFhmwiMMBLv/bY6rBlk4RAAABmZJL
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 347->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N2DBuMSxqcMF8OnBEGPANK/BnrBZ6O7AKo5DjpA6BizyxLgD2d1wgCZG0Bxs
+tHksLkRX3iQGq74wg3ZLaSagR4exIYnqf5gQLeTAbubYO4hFCfofsLlJmz2
o/gFmxwRYYHLvfj8htN+Bkw70cXhAJf/7THVMCBjDAAAN6KRyw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 348->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYA3cXkn5CZqH4B4s6BjTz8epHU8eALkdkeGANFzQxksMVzS/4
/IpLDanhiitM0f1Jqhno4UFIP7o9KP7A50ZcfsdmHhFxiysscYY3Hr/gixui
7CbSb1jtx5EW0cXhAEecotDIcjjNAgB33ZJP
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 349->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYA3cXkn5CZqH4B4s6BjTz8foDTR0DDpqQOVjDBU2M5HBF8ws+
v+JSg80t5IQpuj+JDROsYUREvKKbgex2vG7EER4Y8UyEO3DFD97wxuUXHGFC
TFhicy+p4YErLaKLwwGOdIFCE7ADAgDNupQO
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 350->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N+DBBOXxAFLMhKlnQDbTHkHjcwOyPqzuwyGHTx1y2KDTxJqDAtDEiDIHXT+a
HLqbGLDox+o2HPJY0wcDDvPR4o2QX7DFPynpD8UdaP7H5QYUe/DoQQ9fYjB6
+GFzB7p56O7BZx4xaYyc8ECPf2x+wADYzGFAU48nzBEAANMyj4o=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 351->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGs6nHYiayeAWauPX6zMMzFog7ZHIL6sbiD1LBCdzccoImRHK7I7sFh
BgMW/Q3o+pDDl5gwwRIe6GYSE67Y3ElMmGKzB9ld+OKWAU09Lj3o4UsMRg8/
bO7A6290tUTEB7p7ccU1vvBAj38MP+BIe9jSBYpaPGGOAAAF6ZEG
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 352->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYg+I2BiQaj1noerC6D4ccNjehu4PUsILpxwBoYiSHK5obsfoV
i35sYYHPDHxhim4+enjhNANXWBMRpljjBcnt+OIWxR48eoiJD1zxgy/94fQ3
rrgh0h3I8UhqeDAgqcHqBxxpD5cb0NVgC3MEAAARiJRJ
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 353->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYg+I2BlSaoDtwqEU2h5B+ZHcwoIkRG1Zw/egATYzkcEV3DxYz
GLDoxxYW+MzAFqa4zEePN5xm4AprIsIUPV7Q3Y4vblHswaOHmPjAFT+4wgo9
vND9giFHRHxgi0dSw4MBSQ2GPmzpDptbkdyArgZbmCMAAIw0kkk=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 354->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYg+I2BlSaoDtw+AfZHKL0M2C6E24GkeGBNVzQxEgOV3T3YDGD
AYt+bGbiMwMjTHCoQTaHVDMY0DAh/RjpgwGTj1cvut+xmEcoPnDFDyF/4vIL
hhwW84i2G4/fcIY7AxZ9yOIE0hm6Gmx+xQQA/DmTCg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 355->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYg+I2BiTziXEHDv/A9ONzD4p+Bkx3ws0g0h1YwwVNjORwxWI2
elgyYNGPzUxc8ljDBIcaZHNINQM5rAmFKYM9pj3o+nC6EVt44jCPUHzgih9C
/sSXNgiZR7TdyPFKIDxQwh49TLClOyxmIccduhkYalAAALOAk0s=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 356->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmAEN
N1CA8QGcenCYg+I+BlSaoDtw+AfZHKLMYMB0J9wMIt2BNVzQxEgOVyxmY/M/
un5sZuKSJxQe2OKLHDOQ/UMoTBnsMe2B6ceWdrDqRQ5PLGYQEx+44gdbmKDb
jytt4DMPX7hgqEWOV1LDgwGHOJ40gmwHuhnoalABAMRGk4o=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 357->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYg+I2BlSakBm4/AM3hxi/YHEHOWZgDRc0MZLDFYvZOO3GoQab
W4gJD3zxRawZuOKKUJgy2GPag+wPfG5gQLcPTQ8h/cTEDzb7CPGxhgmaefjC
BUMtEh+b2chhgJ4+4OkBmzgWP6KnC/S4wFCDAgAf5JFH
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 358->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYg+I2BlSaKLdgMRtmLj73oNuL7k50mpAZWMMFTYzkcMViNk67
cajB5hai3IHF/8SGK3qYoqc9QmHKYI9pD7I/8LmBAd0+ND2E9BMTP9jsI8RH
dwu+OCXGbmQ+tvBGDgP09IEev9gAvjhFNwNreoMDAHiJlMc=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 359->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcenCYg+I2BlSaKLdgMRtmLjFmoNuHiyZkBtZwQRMjOVyxmI0vXLGp
QRYjxR24zEeXxxemuMKZUJgyYHMHUpjgcwMDDjuxmUdM+sIVltjsw8fHGiZE
xgc2tSjxSkR4YEuLDFjEcbkJ2Q70uMDmTgQAABlEl8c=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 360->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMGe
AQLsUcVJxfgATj04zMHmNkJmYfgJzQ4GNHGC+hkw3YlOEzIDa7igi5EarljM
xheu2NQgixETrrjCAzm+cMljixMMvxERpgz2WOxBC0Nc/mBAdwcDpvvx6Scm
ftDFcNmPLW0QMg+v3TjMQ/cnVvvR0hdyPKHLIYcztrDEpaYBmzkMAF5AlQg=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 361->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMGe
AQLsUcVJxfgATj1Y2DD1DGhuI2QWhp/QzUUTJ6QX2S5SzUD3DwpAEyM5XLGY
jTdcsahBFiPGHbjCAyW+cMjjcheK34iMFwx7GDD5xKQzXHqIiQ9c8YMuhtff
RMYN0WkDi9/Q/UkofaDoQ9KPAnCkCwYsbsHqTjgAAJ4QlIg=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 362->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMGe
AQLsUcVJxfgATj1Y2DD1DGhuI2QWQXPRzMemFt1ebGYwYNGDzw0YAE2M5HBF
DiMcZjBg0Y/NTOT4J+QXnOGB5BZiwgSb24gJU2zxh+43XG5ATw+49BDjB1zx
gy5GKI0REzfExAks/EiJV2xhiB6/6OkU2R4MN2BxCzY/IQAAAkuTyw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 363->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAYpB
bHQxcjA+gFMPFjZMPQOa2wiZRdBcLHLY+NjChJAZuNyA7G44QBMjOVyRwwiH
GdjiF5uZ+MzAFh7YwhTZHKLCA0c4EwpT9PSBze243MCA7gYGHP4iIj6wphMs
4YsvjSH7BUOOiPhAt5sBi15s8Y7NfcgAPZ4wAC43YHELNj8hAAAiPJGI
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 364->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMGe
AQLsUcVJxfgATj1Y2Mjqkd1GyCwMt6Cbi8VOfO5CdweyucSagTVc0MRIDlck
t+EyAz1c0dUg6yPGHTjDA80tBM3A5jYs4oTCE5s/8LmBAd0+Bhz+IiI+sIUL
tvDFFR/Y0gauuCHWbmzmYYt3bO5DBhhxwoApj9UNWNyC1Z1wAAB64pKK
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 365->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMGe
AQLsUcVJxfgATj1Y2Mjqkd1GyCwMt6Cbi8VOfO5CdweyucSagREuyH4i0j8Y
AMltuMxAD1d0Ncj6iHEHehphQDMLPd5wmoHNbVjECYUnVn/gcQOyu/HpISY+
sIYLUthgS2O4+OhuwRYf+MIF3W4Mv5EQhuj6sAFc/oebgyt+MQAACEmRCA==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 366->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMGe
AQLsUcVJxfgATj1Y2Mjqkd2Gyyxs7kb2D7q5xPiTAYs7kM0l1gyMcEH2E4Gw
wRmuyH4hIkzQ/YKujxh34AqPBjS3EGMGNrcRE6ZY0weyP/C4gQHdPhx6iIkP
rH5CD18scYg3beCIG2xmYU0bRIYHAxYzkQFcH7Z0hyVssKVF9PhFtwMCAMO5
kM0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 367->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMGe
AQLsUcVJxfgATj1Y2DD1DGhuI2QWhlvwmEtQvz2qXQxo5jIQYQ6KHgY0vUSE
Dc5wRfYLDjMYsOjHaiaR4YorPBrQ3EKKGehpj5TwRNHLgNt8DL1o6jD8RUR8
YHU/lvDFFR9Y0wae+MIXLsgAXS+u8MaVPpD1YU13WMIGJf6w+QWnWQCdHY+O

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 368->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
o4s3kIDxAZx6sLBh6uHuYkCicZiF4XYGJPOwmEvQL/aodjGgmYstvHC5CQUg
+4lA2DRgUYscFshm4w1XLGrQzSLWHbjMb7An3Qz0tEdKeOKKZ1xuYEC3Dz0u
sJhNDMYVftj8iTdt4IgbbHqxxiMDKh9feGOEBzLAl+6whA1KWGLzC06zAKN3
jEs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 369->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcerCwYerh7mJAovGYheEWLGLoduJzF7JdDGjmEhNeKHoY0PQSETYN
WNSihAWOMEF3G1Y16GYR6Q6s8caAShNrBsnhicUemH5c5uNKZ3Cz0M0g4Aec
aQ2Lv3DZjzVt4IgbbHqxxiMDpluICQ+M9IWWhtABzvSJyy84zGFgAABT646M

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 370->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QF8epDdgSwGdxcDEo3HLAy3oPkJ2VxizcDmNmLDCkUPA6peYsKmAYta
5LBANhuX3bjUoJtFrDtwmY8eXsSYgR6ehMIUPX2g+w2b+Vjdi57GGDD9QgrG
Fb647MeaNvCYhy9ckAE54YGRvnCYjc2PKPpx+QVXGmYAANblkQ4=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 371->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
I4s1kIjxAXx60O2EiTEgm2lP2CwMt6D7iQHTTkJmYHMburnoYYlVDwOqXmLC
BiUMsIUFnjBB9ze6GlLDFaYOl/nEhCu6GSjhyYA7THGlD3S/YTOfUHhg+IuA
H3CmNSz+wmU/ofSEbh6+cEEG5IQHtrSILY1i8yO+9Ikij9UsAMYKjpA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 372->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QFku9D1oMvBxBiQzbTHNIugW9Dsg5tLohm43IZVDxY2CkAObyL9g+5/
BixieN2BRQ2p4QpTh8t8YsIV3QwMvxEKB2xpBsnt2MzHFS+49BATH9j8hM1f
uOzHSBsE4gtfuCADcsKDAc0MbOkT3Q6s/kdLUyjyWM0CAKAijo4=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 373->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N+DBBOXxAGLMZEAyB+4uJP2EzMJwC7r5DAgzCepHU4fNbcSYgRIuyGFNRNjg
DFc0v2AzA8PfDDjMJDJccYYHcpiQaAZK2mMgHKbocYDuN3xxi57OcOkhJj6w
+Qlb+OKyH1fawBVf+MIFGZATHuhpEVcaxeZHFP24/ILTLACh+Y6O
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 374->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcerCwkdUj68dlFjZ3w/Wgu88euxnYzERxBx5zCfkNA6CJkRyuaH4h
FCbY1BATrkSFB454I8YMlLTHQDhMCaYPPG5Ady8uPcTEB674wZcmcfGR4xSX
efjCBRmQHR7IAD1O0ACuOGXA5RecZgEAFASQDg==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 375->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcerCwkdXDgT1us7C5G6aOAd199tjNwBoeDLjdRkxYIetBAWhiJIcr
ml8IhQk2NchixLgDZ3jYo5pDihnoYU0oTPGlD1zmY3WvPW49xMQHrvjBlyZx
8ZHjFJ95xKQNssMDGaDHCQMmG1ecYvULNjvAAABgqI+O
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 376->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmAEN
N1CA8QGcerCwUdwHA/aEzUJ3C4b5SObg1WuPqY4B3Qxi3IArXNDESA5XNL9g
MwPD3wzYzcQljzVMsIWHPao5xIQrhjuITH/Y7EHxBx43oLsXXQ+2tEcsxhq+
eOIDa9ogYB7BtEGF8ECPCxQxLO7EFv8YfsFmBxgAAHsbjo4=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 377->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAEJ
N1CA8QGcerCwYerh7mJAovGYheIfBgYMPyGbQ1A/mjoMtxATHrjCBU2M5HAl
Ikww/M2Aw0wiwxVbeKCLExuuON1BRDhgpA8GTD7euEB3M1JYEuMHnGkNPXzx
xAfWtEEgvohJG+h6iQ4PZIAWRnAxLO5EDz+sfsFmBxgAAFj6iw4=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 378->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjE+ABOPWj6UWgYZkCi8ZiF4RYs5jPYEzYD2V5sYsSGFwOyvcgATYzkcCUi
TDD8zYDDTCLDFVe4IYuTYwa6vwiFA0b6YMDk440LHHoY7InzAy4/YfgLT3xg
SxvYwoQo+xlQ1VMSHrBwYEAXR2Pji390Nej+RAAAz5ONEg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 379->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjE+ABOPWj6UWh7VP2EzEJ3CzbzGeyJMwNdHQOye4gMLwZ7VHfDAZoYyeGK
5hdsZmD4mwG7mcSGK65wQxbHsIMIM9D9RdAN6PGC7A88ccuA5gZ0PchxRUz6
QvcTNn8RCgti4oaUtIERHySGBywcGLCJI8nji390Nej+RAAAr3eOUw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 380->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjEOAE+PWj6kWkUM5HYxLoFm/kM9oTNgIUHijuQxIgNLwZ7ND9g8Qsx/sGl
H1mOULiiq0EWI8YduMIN3S2kmoESFkSEJ0a8IPsDjxsYsNiHwrcnzg9444eA
P9H9QUzckJI2MOKDxPCA+YEBmzgONyGHH3o4oMcZKgAA3viN0Q==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 381->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjE+ABOPWj6kWm42xiQaDxmobsFm/kM9oTNYLDHVMeA7hZi3IArXNDESA5X
tLDCZgYDFndjMxOfGRhhgkMNsjmkmoESFkSEJ0a8IIcJPjdisQ89XRDjB3zx
Q8if6P7AFfbExAe2tIFuN0ZYYbMflxnY0h0WN8HV4YhH3GYBAGjujhA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 382->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjE+ABOPWj6kWm42xiQaDxmobsFm/kM9oTNYLDHVMeA7hZi3IArXNDESA5X
tLAiFL7Y/Iysjxh34As3ZHNINQMlLEgIT4ywIeRGLPahpwti/IA3fgj4Ez1O
MOIBixgpaQObedjMQbEfmxlYxHG5Ca4ORzyi+wkBALlmjtE=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 383->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjE+ABOPVjYyOoZYObaEzYL3S1Y3YdDDlt4YLgDDRN0A65wQRMjOVyR3EZM
+GJTAzMHnU3IHHzixIYrtnAm1g0Y6QM5TPC4gcEe1b0YZuBJN0THD56wQvcb
etrAZh5JdjNg6sUbZ1jCAyVMsKU7XGYxMBCMR0wAAH8KkU0=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 384->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjE+ABOPVjYyOoZYOYi0QTdYY/dTpgYPvcghwe6OxqQ3UKkO7CGC5oYufqR
5QiFBboaZDFC4YotPLCFNbHhis1cQm7AmT6Q/YHHDQz2qGowzMBiNrEY3f3Y
3IHuN/S4xWceUXYzYJqHN86whAc2P2AAXOmLgLsxAQAQuI+O
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 385->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sHCRlbPADMXiSbGHGx2YjMfn1no7mhAdgsx4YErXNDEyNWPLIfP
DGxqkMWIMgNXeKC5hVB4oIcbSlgQCFf0OMDwBx43oLsXxS9o5hGKVwyz0dyO
zR3Y/I0r7AnFBza12OISV3gwoGNkgEscSR5r/NmTqIYBAK/ejow=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 386->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sHCRlbPADMXicantwGLGfjMx+cmdHc0ILuFmPDAFS7I/iIibLDq
Z0CVw2cGNjXIYkSZgSM8GtDcQig8sMUTergQFR7Y/IHHDQz2qGpQ/IKDTSxG
dzvW8CYQt7jihii7ccQltvBgQHMvA5oZOMVxuAnFPLRwQE87qGYCAC81js0=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 387->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sHCRlbPADMXiSbWLbjswuceXGYg62UgMsxQ9CADNDFy9SPL4TMD
mxpkMUJmIJuDNd4YUGm8ZuBLMySEJ1Z/4HEDunvRzcCXbohJJwxo7sMIbwJx
iytuiLIbR1xiCw8GJPeipw9kf2CI43ATsnnIZqDHOSYAANUkkhA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 388->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY9LjBDGB3DqwcJGVs8AMxeJJtYtuOzC5x50e7H6kcjwQbYPBaCJka3fnrAZ
DTjUIIvh8iu28GBAdxuSXqLMQI9zZD+REJ7o8UHIH9jsxGoGAT/gDF/0+MJj
P7a4xRdf+MIFGRATr9jiEQUgxxMWgC9dIJuBEecYAADonZAM
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 389->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uBpmDC+DTA2czoNLIZsLEiXUrNjsZ8MgRbQYDqlmEwgPubmSAJkaufmQ5
Qv5AV4MshmwewbhFdxuOeMNpBpY4h/uJhPAk1R/Y7EThk5g2MMISDx9bekGP
W3zxhS9ckAGx4YEc1uhpETmOsAF86QLZDIw4xwAAVyOTjA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 390->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uBpmDC+DTA2czoNLIZjbYEzarAYtZ2OwixQz0sIGJERNm6O6GAzQxQmGD
Sz+xYYJNDbIYsnkE4xbdbTjiDacZ6HFOQphiiz9i/cGA7gZ0M0hMG+juJ5hu
CMQtvvjCFy5wQEJ4IIc1elpEjiNsAF+6QHcLenijAgCSz5JL
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 391->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uBpmDC+DTA2czoNIoZtoTNqsBi1nY7KLUDAYks4jRjwKwhBMx5mCYgWY2
MfpxiSGbRzBu0cMSR7zhNAOLXuRwIaQfI30Q6Q8GdDegm0Fi2sAISzx8ZPux
+QVf3GDTiyttEBseOOMAKR4w4gaLO9HTBVa/YLMDDADZIZMK
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 392->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgnw6UHTj0zD5JHF0d2Ozy247CLGDAY8ZjAgmUWMG9DDggFNjFDYYAtP
uNlE+AebPchiRJkB04PuNiRxoszAo5dQmGKLP2L9wYDuBnQzSEgbyOah68fG
R1ePLW4JxRehuIWHARHhgR6PKACbOB43YcQhelhgswMMAPjjkgo=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 393->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6kHTj0zD5JHF8ZmF7hZcYsSYwYDLDCRMrBswAJoYobDBpZ/YMMGm
BlkMl18x/MyA5Ca0cCJkBrawQ9dLKEyRw4NUfzCguwPdDCxsYtyCTQ82M3Dx
CcUNMWkMJQyICA/0eEQBuMRxuAkjDtHDAqdZAH8gkE8=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 394->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6kHTj0zD5JHF8ZmF7has7sMhh81deM0gwQ0YAE2MUNigqyc1TLD5
BVkfoTBhQHYDDrfhCnOs5mAzF8lsguHBQLo/GNDdgW4GFjYxbsGmB5sZuPjY
4o9YN6CnLWLDAz0eUQC2eEGzA1vaYsDlF5xmAQBxmpDN
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 395->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCcnD1eECRJoNcxey+xjQxNHdjs8tWN2HQ45kM4gJNzR3I4cHMiAUNrj0
Exsm2PyMrI+YMIG7Gd1tOOINpxnoeokMC/TwINUfDOjuQDMDX5wTNI8BPx9d
Pba4xRU3BN2BFnbEhAd6PKIAHPGCy03I6QLZDIw4xwAAeqiQzw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 396->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjEOAE+Pej6oTSK2xhQzSfWLbjEiDEDV5jAzSAizBiQ9KCHBzIgVz96mOBy
D3qYYtNHKEzgbkZ3GwnhyoCEUfhEhAV6eJDqDwZ0d6CZgS/dEDSPAT8fW9yg
xy3W+CbGHWhhR0x4oMcjCsAljiN+kNMFVjNwmgUArZ+PzQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 397->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uBpmDFRDQA2czoNLIZjYgmU2sOzDEGXDLYTUDj7nEhBkDsr1o4YEMCJqD
Qz96mOByEzZ70PURcge6GgYs4kSZga4XPd0QGZ6k+oMB3R1oZmBjExO32PRg
8wcuPr64ITYskNUSEx4o6tHTFy5xLO5EUYfNLdjiFw4AlR2RSw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 398->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgnw6UHTj0zD5JHF0d2Ozy1Y3YdDDpu70N2N4hYS3IAtPJAByeFKYphg
U4MsRkyYoKshFG/EhCkDMkbyG6G0guIOIv2B7l50M/ClG6LMw8PHZi6DPW43
ExWn6GmDhPBAUY+evnCJ43ATA5J5WM3AaRYAhHGSjg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 399->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgnw6UHTj0zD5JHF0d2Ozy24xEgxA8V9yGaQoB9beCADksOVxDDBpgZZ
DNk8fPGEHi+khisDuj5kjOQ3QmkFxR1E+gNXPGIzj6i0QSidEEiPDFjcguw/
YsISJW2QEB4o6tHTFy5xHG5iQDIP3QyUOMYAACxkks0=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 400->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjE+ABOPWj6kWm425DEiXUnNjuxmY/XDCx8uBnE+AdXuKCJkRyu6GFCwAxs
apDFkM3DFxbo8UJquKKnM3g4IPuRiPhAcQcDJp+YeMHld2LiA5v/McwnkB4Z
sKhFTy/E2I8ebsTEK4p6NDNwiuOIH3xxyICMMQAA83iSyQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 401->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
GyjE+ABOPWj6kWm425DEiXUnNjuxmY/XDCx8uBnE+AdXuKCJkRyu6GFCwAxs
apDFkM3DFxbo8UJquGJLZxjhQUR8oLiDAZNPTDrD5Xdi4gNr+BLhT6x+wSZH
TJyipw0S4hVFPZoZWMUZUNVgSxe44pABp1kAaKWUDA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 402->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGK
G3BgfHIo6vAAYsxmQDIHxW0MSOaT4BZcYvjcgy9MGJDcQIw7kP2DAtDEyNWP
LEdMvGCIYQljvOGBLUxxxBvRYYoWHsSGJy6/4TID3a/w8MNiHlHpC0dY4vMn
1rSIQ46UsECJSzx+wxf3GOZgS3do/kRRh8UtWN0JBwByeJLL
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 403->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCcnD1eEBxJjNgGQOshiMT8gsdLdgmItFDp+70P2N4hZi3IArXNDESA5X
EsMEmxqYOej+whseWNQghxNRZuDzG4FwxZo+GDD5ePViiUdi9OMyDz0s8fkT
p3uwxQ2RYYkcduh6ccYZlrjHMAdbukPzJ4o6LG7B6k44AAAh45LJ
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 404->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCcnD1eEBxJjNgGQOshiMT8gsdLdgmItFDp+70P3NgMUsYsxAAVjESA5X
EsMEmxqYOUSbgSfciA1X9DDFFTaE0gpK3DJg8vHqRdOD7i9i4gM9/tHdjivt
4PILsltIig/k8MNhHjZzMNzKgMUcbOkOSR4jDrG4Bas74QAAXxCRiA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 405->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sHCRlbPgMQHAxLcgmEuFjl87kLXh80sYsxAAVjESA5X9DAhYAay
ehQz8cgTYwZGOBFjhj2mvehhQyitoMQtAyYfr140Pej+IiY+MNIEAwNGGkH3
By4+uluwmUds2sJmHsE4wxIHWMXRwhk9XaCoJ+BOCAAAWfqSxQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 406->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6kFjM9ijqkfmEzIL3S3odjBgkcPnLri9WNxLTJgh2wcHSGYT6x8M
QGKYoIcpXB8eeWLMQI4zYsIVWS26O5DDhpjwRA8bQv5A9yuGGSSkDYw0wcCA
NR3jUo8tbeASw5XWcKUjjPAgEA/oZuAUR3MTerpAUU/AnRAAAF0kkoY=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 407->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6kFjM9ijqkfmo5uFz93Y1GEzH5+74PaimUFsmDHYo7obDJDMJhQ2
OMMVT5gQ8guKmXjkiTEDW/wQGybo+pHDhpjwRA8bQv5A9yuGGVjMJhYj60dP
L9j8jZKe0NyPLU6xhQm2tIU1PHDFJbbwR7MTG8AV/+jxiM+dEAAASdmSxw==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 408->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6kFjM9hjqofx0c3C525sdjLgkcOmFptd6DQhMzDCBclsQmGDM1zx
hAle/ehiOPxKTHhgEyfKDBz6kcOGmPBE9xshf2D4Hd0MEtIG1vAlwp/Y5NHd
j9V9RKYtrOFBIB7Q0yJOcTQ3YcQfFrfgcicEAAAIXpNJ
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 409->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCcnD1eEBxJrNYI+pHsYnZBY2PdjsIscMdL3EhAmyHjhA8iOx/sEAJIQJ
A5oaFDfhCXNc5uATJ8oMPO7DJk8o/tD9hssN6H7FMIPEtIERP0T4E1/awCVG
StoiNjyQ3YeeFnGK43ATXB0WtyDbhQkAQs+TSw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 410->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCckjq8MFSDEbw30MCBqfWSjuwGMX0WYwYJoJdwuR4YHsbjDAEk4EzUEH
JIQJA5oaDDdh8Ssx4YErfkiNFwY0txAbnuhhQ9CNOOIRbgYJaQNr/BDhT5zu
YUDTy4ApRkzaIjZeGbDYjy0OsAF86QKbOgZsdoABAF2xk4g=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 411->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OGYhQA1eHA+DTg87GcB8DgsZnFro7cNlFjBno6hiQzCUlPJDdjayXmLDB
GaZYzCZGP4ab0PxFbpgSG67Ywg3FfySEJ3IcIfsNlxsY0NyAYQaJaQM9nTCg
2YXNnzjdg64fLU6xhQu2tEVseDBgsx+LndgAzvSFJa2hhzcqAAD1GJJF
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 412->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmAGN
Rse4xLGpwwXw6cFwB7r7GBA0PrPQ3YHLLqL9w4BmJswNSHxi9KMALOFEcpii
hRWh8MWmBpt78JqBJTyQ5bDFGy5zcPqPiHjFiBckv+HzB7p70c3AxiYWo7sd
qz/Rwx/d/1jiBl0trrBACQMiwoMBHaObgSvd4TKLAVMPtrSDCgDBkZBH
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 413->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uBpmDC+DTg87GcB8DgsZnFro7MMQZMO3Eaw4DmpkwNyDxidGPArCEE8lh
ihZWhMIXmxps7iElTLH5nSgz8PmPiHjFiBckv+HzBwMW+7DGMwE/4IpnBjS7
sIU3PvdgixtiwwIlDIgIDwZ0jG4GrnSHyywGTD0YdmEAAORtkwo=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 414->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sFhDjY+IbOQzcSmjgGPnbj8g2ImzA1IfGL0YwA0MWL8gqEfLcyJ
iRescYUnvPCFKTHxhtUMfP4jEKYofsbGxuMGdDXoZhDrB0LpBJc7sKnBKUdE
nGLEIwOmXlzhgZJ+0NMXkjw2gDN9YnFLA16zAI5sk8s=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 415->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sFhDjY+IbOQzcSmjgGPnYTMYECyn1hz0N2NrJ+YsMEZrsh+IcIM
bGrQzSJohj1CPXpYIruFoBm4zGXALo81/hjQ/EEg3jHcy4CmD808QvGBK57x
+hOLGpxyRMQptnhE14sSNzjchxIeyOkBW7rD4ibkdIFNHW6zAO6wk0k=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 416->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sFhDjY+IbOQzcSmjgGPncSYAQdEmoPubmT9xIQNznBF8wshM7DZ
g80tpIQHehgQ5Q4sYYbiBgJhihye2PyGzw3o7oTZh808QvGBy13ofsKrhpB+
It2BzS/YwgPDPdjCAykOMMRxuAkl7rCow20WAMbOk80=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 417->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAYqR
2ZRgfACnHixsdPUwPiGzkM3Bpg5uDjF+weEO5LAjZA66u5H1ExM2OMMVLawI
mYFNDTa3kBIe6GGAK8wxzMAhhu4vQuGJzW/43IDuTnQzsLGJwQxY7IX5BZvb
0d2DVY6I+MCZJikIDxRzsKU7LGahxB2aGRjxiwIAjqeTTQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 418->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sHCxnAfA6r5xLoFlxgx/mXA4Q4wIDLcGND1IeknJmxwhisWs4nR
j8sv2PxKKDzQw4BoM3CIMeCQxxWe2PyGzw3o7kQ3A1+6IcZP6GGDEd4E3EMo
vgimDSqEB4o52NIdFrPg6rC4BT18UAEAtNyVCA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 419->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgdw6sHCxnAfA5L5RLobm524zCdkBgMMM6C6gVC4obibAVU/MWGDM1zR
/ELIDGxqkM1hsCfCDDQ16GFAtBk4xBhwyBOKP2S/4XMDujvRzcCXbgjGD5aw
wQhvAu4hFF8E0wYVwgPFHGzpDotZcHVY3IIeZ6gAAKPNlUc=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 420->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY9LjBDGB3DqwcLGcB8DkvlEuhHZDAYC5uNyF7oZMPuJDRu4enSAJkYobLDq
t0c1h5h4wRpXWPxKbHhgxB8ZZmDDxIQHehhjMx+rXizhgYtNyC+4whebO9D9
hS/ciIlTbPGIrpfU8MAWlugAV5wyYHELShxjAACh4ZKI
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 421->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgnw6cHCxnAf1AwYINYtGObiMB+bmxiwmEGK/cj2YAsPZEAobLDqJ8FN
2NRgmEVMmOAJU2LCFVu8oGNCbsAwA8lv+PyB7F708MDFJsYt2MIXmzvQ/YYv
3IiJU2zxSGl4oJiDLd1hMQuuDotbUOIYAwAAGl6UCg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 422->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8OBpmBDxBrRoM9pnowQKKJMosBi7kk+BfdPmT/ER0mDEjuRwZoYsSEB4Z+
NDlC7sAapmhuISdMccnjC1MUPhomNX0gux3dfKx6CeghJhzQ/Y8eftjcge43
dP2E4otQ3GJLD6SGB8wcBmziaPag+5UBi1sa8JoFAL2pk4o=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 423->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrq5yOYT6xYMc0nwLwMWM0ixH5u74QBNjJjwwNCPJkdMvGCN
KxL8hS1McckTYwY8XJEwqekDPUxwuQE57pH9ixHPRPgB3f/o4Yc1vAnoJxRf
hOIWW3rAFR4o6Qc9fSHHBzaAzSwGTPUY8YsBABdWlE0=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 424->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrq5yOYT6xZizcflFmR1MD4pYYXubjhAEyM5XEkME2xqkMVI
cQe+NEPQHdjiFg2Tmj5Q/IHHDQxobsClh5hwwOYnXG7CFV7IfFic4tNPMG2Q
EB7IYY2eFlHiAxvA5X809RjxiwEAL0CVDg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 425->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrq5yOYT6xZizcflFmR1DGj2ExNm6O6GAzQxksMVzS+EzMCm
BsUvxJgBU4cnzRBrBoYYEiY1faDHCS43MKC5AZceYuKDUPgihxO6/dj46OqJ
iQ+MtEGF8ECPX2wAX7pANwMlfjEAAKbVlgw=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 426->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrq5yOYT6xZizcflFmR1DGj24wozBixuwABoYkSFqz2afrQw
JyZecIkRZQaW8CAmzPGZARdD8iOp6QM9TnC5gQHNDbj0EBMfhMIXOX5whRe2
dIIvvgjZjS09kBoeMHMYsImjmYstTtHdghG/KAAA8hCWSw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 427->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrIYjE+SWVjUYTOfWDMYkOxnwBNmDFj0YwA0MZLDFc0vhMzA
pgZZjCgzsIQHMWGOYQYOMULhSlT6wOMGBjT1KGbgYBOLMcxD8g+u8MKWTvDF
F76wQLYLJV5JDA/0OMAGMNyOHP5obsHqTjgAABsilcs=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 428->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0g/DDGhiDKjmE+sWbObjksPqFizuAAM8YcaAxQ0YAE0Mnxvw6Sc2
TLCpQRYjygws4UFMmGOLX5xphsg4RXEHsj/wuIHBHlUNuhnE+oGk8MWRLnCl
E4wwIRCW2NRSEh4o5mBLd1jMwpYWsfkbEwAAwK6UEA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 429->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0g/DDGhiDEg0AbMYkNxCihxWtzCguQvZLUSEG1w/OkATIzlcsZhN
jH5cYsSGK7IabH4nygx8fiMiTtDtQfEHHjcwoLkB3Qxi/UBS+GKxHxsfV9wQ
Cg9saskKD7Q4YMAmjsWPKPqxuQUtzlDNBABm5JMM
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 430->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0g/D6O5jQIgTbRYWdQx45LC6hQG72xiQ+ATDA1u4oImRHK5ofiFk
Bs4wZSDfDGx+J8oMHPEN8xch/ej2oPgDjxsYsNiJ1V9ExAfO+EELK3S/4gsH
fOaRZDc54cGAag5GvCABXOkCWzximIViJgDbvpII
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 431->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDoa59iSahUUdLvNxuQVZHQOSGAMSnxg3YAA0MZLDFc0vhMzA
pgZZjCgzsIQHMWGOYQYWPrK/SE0fKP7A4wYUexkwzSDWD3jjBy2s0P2KLRyw
pSNi4gNFLZa0Rmx4oKdFBiQ3YQO40gW2eMRpBxgAANpdk8s=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 432->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrq5yOYT6xZizSfGDAYYZkBiE6kfA6CJkRyuJIYJNjXIYkSZ
gSU8iAlzDDOwmInsL1LTB4o/8LgBxV4GTDOI9QPe+MERVtjCC69aIuIDRS2O
9EBMeGCLAwZs4jjcxIDmBoxwwGkWABOIlI4=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 433->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrq5yOYT6xZizSfGDAYYZkA1C59f0N0NB2hiJIerPRpNwAxs
apDFiDIDS3gQE+YYZuDzGxnpA8UfeNzAgMVOrPFMRHzgjB8cYYUtvPCqJSI+
UNRiSWvEhgd6WoTFEYo4HjdhS4soZmOzAwwAeYKVTQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 434->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrq5yOYT6xZs5jPgkCNkBgMSJjbMkO1DAWhiJIerPRpNwAxs
apDFiDIDS3gQE+bYwgPdTGSa1PSB4g88bmBAt5MBu7uJiQ+c8YMjrLCFF161
RMQHilq0sCE3PLD5AR3gShco6rHENyYAAFd8lYo=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 435->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDrq5yOYT6xZs5jPgkCNkBgMWTIx/YPahADQxYsIDQz+aHDHx
gkuMKDOwhAeheCNkBobfyEgfKP7A4wYGNDegm4Ev3eAzD8UP+PxJwD2E4gtv
3CKZQUl4YPMDOsAVpyjqkeWwxTMYAABtvZQM
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 436->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDoa59iSahUUdgz3CHFLNYMCCidWPAdDESA5XtLAiZAY2Nchi
RJmBFA/ExhsuM3D6jYz0ge52XG5gQHMDLj3ExAfW8EVLE+h+QZdDdw+h+CJo
N5a4xGY2vvBAjgMMcRxuYkBzA4YZ2OIZDADS5pXL
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 437->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDoa59iSaxYDFXCRMjFtg9qLrJdoMBhzhgiZGTHhg6EdzJ0F/
YAtTBkw2seGBIUfAHbjcihIeZKQP5DDBlnawpgEGLGYQ0I/LPHT92OQx1BOI
P2LiA1v4YcQrDv9gsx85HBmwieNwEwOaGzDCFqdZAMHRkUk=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 438->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uxgeI0o9kDoa59iSaxYDFXBzm43ILuhnomBT/oAA0MbL0o8kR8gfWMGUg
zgxs4YEhR0S4YlOD7B9CYYot/pDDBF/cMqC5AcMMEtIGsnm4wg/dLwxobHT3
4Iobgu5gQFWPwiYxPNDjAhvAmb6wuAU9baACANmjkss=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 439->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypixlg
GAcg1owGe1T1cDPtSTSLAYu5eORw+QfZPAZ7VEyKf1AAmhhZ+tHkCIUFuhpk
MaLMsMetBlu4EhOm2MKV5PSBFCb43ICcBtD9S4x+XObhDF986rG4h1B84Y1b
JDNQ4pXE8ECPC2wAV7pAV4/sT+xmAQBfe5MI
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 440->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYMsBgZINLFuwTAXixxR7kF2AxImxT8oAE2MLP32qOYQEy8YYnjksbkF
lxpiwxVbuKH7h+T0gRQm+NyAEZfoZpCZNkgJP3zuQQ9not3BgGoGcngQFWfo
6QtL2kIGuNIFunrk+MZuFgCuz5PH
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 441->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNrFswzLVHmEOMW2DqkO1GxqT4BwWgiZGlH02OmHjBFqZEm4En
3HDFG1YzsJiJ7idS0ge62wm5EZceYv1AjHmE1KP4BYudxJiH7naYevTwxBam
DFjsx6YPGyDkBmR1KOZhAABCJZRJ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 442->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNrFswzLVHmEOOGeiYFP+gADQxsvSjyRETLxhmEmkGoXDDFW+4
zEHhY/ETKekD3e24zGDAYid6+iLGD9jsQfYDLjdg+BvNPbjii6A7GFDNQA9P
XG7BFh7o4YgNYDWLAVM9ituwmgUAQKuTRw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 443->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNrFswzLVHmEOOGeiYFP9gACRxkvWj+4mAf7DZgxyWRJmBQw1K
mBBjBha3Exum2NIHut9wmYFhJ7oZONIeIbegxA+R6rG5h1B84Y1bJDOQ9RKK
M/TwwJYm0AGudIGuHsVtWM0CAETDlEU=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 444->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhrj2JZjFgMdceYQ45ZqBjUvyDAYjwD079SG4jxj/Y7IGZQ7QZONSg
hAkxZqDHBwOmOCnpA91vuMzAsJMB0w3Y0h5BtyDHD5FpCUM/EfGFN26R0wNy
GiEQZxjux5Im0AGudIGuHsVtWM0CAPatkkc=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 445->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhrj2JZjFgMdceYQ45ZqCbQ4p/yAkbnPqR3EZMmGBTgyxGTJjgUsOA
jIkxA1t8EBmm2NIHsf5AsROLHlxpj6BbkOOHyLSETT+++MLnJpi9cP8guQVX
mGLEAQOqPqziaG5CTxfo6lHchtUsABy2kMs=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 446->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqBwMkmiizsNjJgEYT6x6437CwifUPCkATI1c/shyhsMAapgxI
/iFkBlr4o4cF0Wbg0ktEmGJLH+h+w+UGFDux6MGV9ojxC3K84I0DPO7BF1/4
3IQMGtDcgitMMeKAAVUfVnEcfkROFxhuwRZGcAAA7/yRhg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 447->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqBwN7Es3Coo4BjUYXx6Ue7jci9ODyDwpAEyNXP7IcMfGCLUxx
yeOMW2zipJiBFg/I5hIKU2zpA93/uNyA7lcMMwjox+cX5Hgh5HZc7sEVN4Tc
hAwa0NyCK0wx4oABVR9WcbQww5YuMNyCLYzgAAD1VJOE
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 448->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqBwMkmiizGLCYi0YT7R4sdhNjBrJ/UACaGNH2o+lHNpuYeMEW
prjkMfTjCVNs8njNwZZmiAhTbOkD3f+43IAtLLGGBQE/YPMLcrwQcjuu8MMV
N4TchAwa0NyCK0wZ0DEDdn3YAK60ha4eZxjBAQCsg5KC
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 449->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNrFswzMVhPiH3NGCxmxh3INuHAtDECOpHNwPJD8SEL7J6bP7B
Jk8oXlD0khCuyOpR/EZEmGJ1BwMmn9iwxBoWRPgBZ9wQmZZwhR/OtIYvbpAA
enjgClMGdIwMcImjhRnW+EMLB/S0gQoAwAyVww==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 450->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLtx8EtyCYS4O8wm5B5vdxLgDxd3IAE2MYHigm2GPaQ4hf2ALU7j7
CIQJtnBDcRsJ4YqsHsVvRIQpVncwYPKJDUusaYUIP+CMGyLTEjb9GHGDJR3h
SmMocUlEvDJgw0h+wBBDswNb2sIWDuhpAxUAAFz/lYY=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 451->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhKNT28DFjMYCJhPyD0NWOzG5Q5sbsAAaGLEhAeGfjQ5Qv7AGqYM
xJmBLdyQw5SUcEVWj+w2dHGi3cGAyScqLnHoIcYP2MKWkPvR5RjQ9GPEDZFp
DRlgxCsO/zBgwzCASwwtzLD6H90t2MyCAwBAg5XF
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 452->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLrL5xLoFw1wc5hNyD9xuHHKE3IAB0MSICQ8M/WhyxMQLLjFS3IEt
TEkJV2T1cD4DpjjR7mDA5BMVlzj0EOMHDP8QEwe4/ILFTlh4EJPW4GGHJS6x
mY0RZ2h+YMAmhgRw+t8eUx1+swAUH5cI
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 453->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLrL5xLoFw1wc5hNyD9xuHHLE+AcFoImRpR9Njph4wSVGijvIkUdX
ix6O6JgUd6C7nZAbcekhNW2guJ+YOMDlFyx2YriPiLjFlR6wuYsBi/0Y5mBL
d7jMYkBTjy1uMQAAGaCYRw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 454->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwY0
mhQM0oMLkGQOA3Y+KWYhq0P3E1lmMKCGCTHhg2wfCkATI8YdGPrRwpsY/bjE
CJlBKNxICVcGJPXIfAYi9GOzB93thNyISw+paQPF/QxoZhCwH8UvWOzEcB8x
aQNbvOLwDwMW+7H5ARvA6X8c4cCA0ywA8EGWiA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 455->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACksxhwM6HAxLNYEB2Hxbz8fkF2TwGe0wzCZmB4m4k9xMTNgT12xM2owGH
GmQxUtxBjjxKmKKFHbIYMf7AiFsGTD4+N+LSQ6wfcKUTFPMI2I+RJhmwm8eA
xzx0v2CkFSxhjR7mGPYx4BFH8yOGG3C4mwGnWQAMupRJ
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 456->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
Us3BxgcDewgm1YwGe4ReYtyDrI4ByW5keWLMwBouaGIkh6s9Gk3ADGxqkP1D
yAxkdbjCFJc81vDHIUaMP9DtQXc7LjMY7PHrIdYPxIQvtrSBLsaARKPrRY5n
QmkNQy0SHz2sscYZevrCJY7mR2xpCasZOM0CAJ/wlQg=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 457->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgcoY
HyBKP5I56ObCzUdSR8gt2MxnwCGHVS0DKhvZfmLcgeJuBjQzSAgbnPrtiTMD
mxqYflzyxMQLshwueazhjyWciYkX5PDE5TdcZjCg24duBpF+ICZ8saULdDF0
92CEBwOqGrx2I4cNshieOMMWHij6sKU7XGHLwIDT3QzoboIDAJwJkYo=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 458->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLtx8JHWE3NKAphamlxj3MKCZAQf2ZLgBHaCJkRyu9mg0ATOwqYHp
xyVPTLxghC+x4YolnImJF+TwxOU3XGYwoNuHbgYJfiAUvtjSBroYunuwxjce
87ClDXS9uMKUAYv9GPqwpTtcYcuAqR7DHgw1ANb5ks0=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 459->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLtx8JHW49KPoQXcfFvNxmYVsBhzgsR9beGANFzQxksMVi9nE6McQ
wyOPERY4wg1bmBM0B0s4ExMvyH7G5TdcZjCg24duBpF+wJVOUMwjkDYJhRsx
5qG7HVt6wBdn2MIDbhY2cSR5fG5AsR8tXFEBAI1skk8=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 460->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYOVzwARYyDSLQ1oauH6iXAPA5oZyP4gxn4MdyMDNDFiwgNDP5ocMfGC
S4wYd+AKN/TwJRim6HpIiBdk9+LyGy4zGNDtQzeDSD9g9TcRaQKfenxxQyi9
4UsP+OIMW3ggm4UhjiSPYRYDmnos8Y0JAHMekoo=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 461->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLrL5xLoF2Uy4fizm43ILsjpS7MblbjhAEyMmPDD0k+AubGqQxYhx
B65wQw9fgmGKI5yJiRdk9+LyGy4zGNDtQzeDSD/g8je6v/CpJxRuGO4jFLc4
0gO+OMMWHij6sKU7XGYxoKlHTzdYzQIAORSWDA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 462->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLrL5xLoF2Uy4fizm43ILsjpS7MblbjhAEyMmPDD0k+AubGqQxYhx
B6FwIyZckd2NESfE6GdApbG5HcOfWGh8egi5Ad1cZD8Qqx6bfmzxjUsv1vDD
Epf4whRbeGCEHRaAK95RzEFPN1jNAgAsiZbN
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 463->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLtx8EtyCbCayfmLcg66OFLuxuhsZoImRHK72SJgIM7CpQRYjZAay
XcSGFz5zMNxBrH4GVBqb2zH8iUYT0kNMfBAyj5B6bPrxxRe+dAcPPyxxiS9M
kcMFGaDHJzrAFe8o6tHTDVazALsCl4w=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 464->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqh/HBgFi3YLETbg4JfkHWS6zdWN2NDNDEiDEHRS9aWBEyA90v
6PoImcGAxQz0sMBmBy5zMNyBnHZITB/obsflBgZ0O3HoISY+cMUPIb/jcw+2
MMGlFz0scKUHfHHCYI+qBpsfsAFcaQvFHPR0g9UsAN/LmsU=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 465->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMKSLQH3X0wPswsYszD5ke4OWS4gxR/YHU3WnggA2LMwdCLJkdMvKD7Dd19
ePWjhwceO/D6A4cYur9Iihc0Pj69hPQQEx+44oeYNIXLPfjCCW/cIIUfRrwS
ER640iK6OC4/IscbHKCnG6xmAQBXkpjH
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 466->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDSLEHXT2MDwZEugebnXBziHQLshkwu0kKN2R3MyDMYEATIylc7bGbQ4x+
9DBGdx/esMARpoTCHMMdWMKYAY1NSvpAdzsuNzCguwOHHmLiA2f8EOF2XO7B
iBsiwxUefljiEl+cMdijqsEIEyxy2MxiQHMDstsZ8JjDwAAAJweXSQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 467->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDSLEHXT2MDwZEugfDDDRziHELsjqY3SSFG7K7GRBmMKCJEQpnrABNjli/
YNNHyAwGNDOIjTes/sDiLgZ7VExK+sAIQwJuxPA7FvNIiWOU+MFhH4b9WPjY
woQYN8HDjwHTLcj24HIPvrSILofNHQxobkB2OwMecxgYALJrlEc=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 468->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
xweI0o/DPhgfDMh0M0wvA4n+QddPTrihACQ3EBs2WAGaHKFwxRoeDMSZQSjc
cMUbVn9gcReDPSomJX2gu52QGwnpISY+cMUPLvsw7MfiHmxhQoyb4OGHFpfo
cYbLPbjSIgMWOWzuYEBzA7LbGfCYw8AAAB3dlgo=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 469->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDSLEHXT2MT5JZWMxggNpBjhnI+okONzR3o7uBWP/gC1NizEBRj0MMnxn4
wo0BzUyC7kBWjyVe8IUvNnvQ3YXLDQzo7sChh5j4wBe+2OzDsB+Le9D9g0se
Z5hiSQ/44pUBGTOg6kOPc2zyuNyA7HZcdkAAAOvMlMs=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 470->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDSLEH3T6YfpLMYsA0GwywyOH1Dxqb2LDA5m5kM0gJG3xhSowZ2PxMihkM
OMwgFOa4wpMBzV1Em4/FHnR9uMxgQHcHA2n6iYkfXPZh2I/FPej+wSWPM0yx
xCW+MGVAxgyo+tDjHJs8NvfCAQE7IAAA1TCVig==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 471->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qmOAqMUGSLEH3T6YfpLMYsA0G+4+Ev2DziY2TNDdjWw/clgRDA9sAE2OULhi
hAeSPkJmMOAwg1CY40wfWNyBbj628GXAYg+623G5AZud2MKGkB8ImUeUemS/
4IobIsMVPezw+Q1rnKKlL/Q0gw5wpS0U9QTsgAAArx6VSQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 472->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
BwMYjQaI0o/DPhifJLPQzUBzH6lmwPSiu5UY/SiABLcghweuMCUmTLDZQ4oZ
DDjMIDWdIPsf3R3I4UNK+kB3Oy43YLMTW9gQ8gMh84hSj+wXXHFDZLjCwxRL
XOKLMwZkzICqrwGLOC4/IscbMhufHRAAAD4qlE8=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 473->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
BwMYjQaI0o/DPhifJLPQzUBzH6lmoNvNgORebH5A9w8ckOAWrPrRwpSYMEG2
G5t/CJmB7GZK0gmy/zHchsWNxKQPdLfjcgNOv2Mxj5S0SnQcENCPLZyIcRM8
TLHEJb44Y0DGSGGPHD/YAL60hczGaQccAAD4N5NP
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 474->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
BwMYjQaI0o/DPhifJLOwmIHsPlLNgOlFdisDkfpRAEwvEW5BDg+swJ6wGbjC
DVmMULgSYw/R7kALN+RwIKgfV7yg8fHpxfA7FvNISavEpkv0tIKuH1s4EeMm
9DCFAwJxwmCPqgZFD550hyttoZuD0w44AAB915PN
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 475->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMFSLQH3X0wM2CAWLdgdRsWOWLcAddLIEwYsLgBPSwYsJhHyB0M6OYwINQQ
9A+WcEMxg0C4MhBhDzZ5dL/B/EFu3OKMFzQ+MfGCK/wIuYGQecSox5lOcIQT
3nCHhR+aWwjFGYM9qhoMfVjSGzazUPQhsfHaAQYAT5uSSw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 476->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDSLEHXT0Y2JNoFi4zsMgRYwayfmLDBKYfBSC5gZB/kMMDV5gS4x9s9qCY
QYQ7iLWHoDtwiCGHD1HhgcNvuNzAgG4njvAj5AdC5hGjHpt+XP4j5CZ4+KGn
FQJxxmDPgDUtMiDLYwG40ha6erx2gAEAyR6Szw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 477->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDSLEHXT0Y2JNoFgOquSiYHDMYEPqRzSRGPwpAcgMh/yCHB64wJSZMsKkh
xQxiw40od+AQQw4fosIDh99wuYEBjY1LDyE/YDWPmDggoB+X/wi5CR5+6GmF
QJwx2DNgTYs4xXH4EUUfmjoMs1DUAACBFpJN
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 478->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmMEe
wcaFkdUTUocLEKUfh31gYE+iWehmIGMyzIC7gYxwQwFIbiDkH+TwwBWmxIQJ
NjWkmEEo3HDFG1Z34BBjwCGPMzxw+I2QGxuQ7MLmLkJ+wGoeMXFAQD8u/xFK
ayjhhx6vxMQZrvSJI93hSlsMaGyscYsCAK+bkk0=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 479->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDSLEHXT0Y2JNoFroZyJgMM+BuICFMYPpRAJIbiPUPvjAlxgxsfibFDGLD
jRh59HDDCBMi0wcKm4GwGxjQ2HC/YzGPmLSBKywJuR2Xe3D5j1Bag4cflrjE
F2fIdqIAtPhGBzjTJhoba9yiAAB2VpTL
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 480->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYi0STYhayH+CYRPc0oNkNM4cU/8ABkhuIDRt8YUqMGdjUkGIG
seFGlDtw+Y2I+GXAYg66u3C5gQGNDfc7kfpJDV989mO4hwFVDD0c8IYJLOyw
xSsR4YGeFuFxjS1uiIk/LHGDYQcYAABXNpTL
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 481->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGMTJ9UsZD+AARY5YsyA6YWbRaJ/4ADZLUT6B1+YEmMGNjWkmIHs
ZlLCHKs7cIgx4JDHlg5R4gLN7aSEJ3q6IFY/MeGLy+3Y+MhuweonIsIUm158
ccZgj6oGDnCJo8ljpE17TDXIYYsJABfLlJA=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 482->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGMTJ9UsZD+AARY5XH5GVgfTC5cjIqzQ3Q23H02MULjjC1NiwgSb
GlLMQHYzMf7F6w4seuDiDAx40xoDFnvQ3U7IDbj0YDObWExUHBCTTtDTBg69
+MIUJTzx+AfZbHT7MMSRAC6/43I3hhwcAACk6pKQ
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 483->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
xwdIsQddPbI4IbMYcLiZAaafRP+g+A3ZLAL2Y3M33H40MWL8gitMiQ0TZPej
6yPFDGL8izd9YNGDHC+4whVX3KK7nZAbMPyOHrdE6Mfmb2LCD6tfsLAx/ERM
mKLFJbJZeMMSix4McSSAKyzR1aOHLSYAAF0tkNE=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 484->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGMTJ2QWgz0OM2D6kWhi3dOARQ8DEeGC7m5SwwbZL7j0ERsm2MKU
UjPQ0wZBM2Dhjy3NEBGm2OIW3e3E+gPudyzmEZVWcYQlMepR/IKFTYqf4GGH
FpfIZuENSxxxgCKOBLDaz4CpHsVsdBoMABjQkNE=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 485->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGMTJ9UsZD/AMQNxfmJAM48Bhxwx/kEBaGKE7McXpsSECYM9phpq
mIEtjAimD2zhiiSOL1wZsNiD7nZi/QH3OxbziEpfWOKH2LSEyxxs7iPkJnjY
ocUlgz0DzjhDCUs0Pchuwgaw2s+AqR7FbKxmAQCJyJNP
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 486->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGMTJ9UsZD8wILuTRDPQ9ZCiHwXA3EJE2KC4F0eYEhMmDPaYaqhh
BrZwJZg+0MIOPVyISYcY8YLGJ8YfcL9jMY+Y9IUtfohRSyhc0d1HyE3wsEOL
S3g6I+R2LGkRX7rDaj+SG7CFLbocBAAAtMOUkA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 487->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGMTJ9UsZD8wILuTRDPQ9RClH1u4wNxCRNhg1Y+mD4WNxxxsYUpK
uMLdjE0cR5hjNQPNnejhQmx4YvMH0W5ACzNS9OOLH2L8Tihu0N1HKK3Bw44B
VS+2sMbqdixmYMQNEsBqPxa7sZqNAgD3UJPL
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 488->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGMTJ9UsZD+gmEOiGeh6iNKPLVyQ3ELIP1j1o+kjJkywqSHZDCxh
ChfHEeZY3YEWdujhQmx44vIbsf6A+x2LecSkL2zxQ4xaQuGK7j5CaQ0edmhx
yYDFbKxuRzMDQxwN4EpbDGhsrGajAAD3J5RP
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 489->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzkc3h0QzYHoYkMwjqB9buCC5hZB/sOpH00dMmCD7HT2uiDGD
AYsZDDjcSTB9oOtFCxtiwxObP4hyA7rf0dIDIf344gebHL7wQg5bXHFDKK3B
wxQtLrHFGdY4xWIGejghA6z2I+lH9g+62agAAFrWk00=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 490->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzkc3h0QzYHqQMSn+gQMktxDyD4M9Fv1o+ogJE2S/o8cVuWYw
4HAnwfSBLVyRwoaQG7DGCxqfGH/A/Y6WHgjpx+kv9PDF4XascnjiBpt6fGGK
HJbY4h0jLHHFC450h8vvDGhsbGajAgC0B5PR
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 491->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzkc3h5B+NDNgepAxKf6BA2QzCPiHwR6LfrQwJcYMbGpIMQNr
eOBwJ8H0gS1ckcKGkBvQ7UHXS6w/MMwgUj9W/6O7AUv6wBZe6OkEW9xgU48v
TJHdgh7WWMMSzQwMcTSA1X4GNPVY0gwmAAC/UJFR
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 492->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzkc3h5B+NDNgepAxKf6BAySz0e0gNVyJCRMGHGpIMQNreNhj
sgmagcXPyO7DZia6G9DtwdBHpD9wmUFMfGD4H8392NIHLr9hSwMY7iMhTFHi
FY9/GNDsR6Yx4gUJ4Eyb2MIBmxwcAAC/IZGQ
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 493->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPZj4DIf1oZsDdgIRJ8Q8cIJmNbgc2N+AMVzQ5Qv7AGqYM
xJmBNTxwuJNg+sBiDnK4YDMfnz3obifkBlx6iPUDVv+jxwkB9fjCFav7SAhT
lHjF4x8GNPuRabg4lrSHKywZ0Ni40hgCAAAeR5MO
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 494->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPZj4DiWag6yFKP65wQRMjWT8DphwuN+EKNxR9RIQrcvjh
cyfB9IEersj+IyE8sfmDGDcQ0kOMfvSwxogTAupxpktc7iMhTFHilZg4QzMD
RRxL2sMVltjiEcUtGAAA4t2UkA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 495->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPZj4DiWag202UfmzhguQWQv7Bqh/JHHR3YXMTrnBD0UdE
uCKHH7FhjjV9IPsLPSxICE+c8ULADYT0oLAJhQd6/GCRI2QWtnDFcB8pYYoe
r4TC0h63epS4QXMTuluxxSOG2SgAAKESlU0=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 496->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwJYwY0
mqB6PIBY/cg0NnFSzUL2C4o5JJqBbjdR+rGFC5JbCPkHq350dyDxsbmJAYca
FDEiwhU5/IgNc6zpA82dKGFBQnjijBci/YFLDyH9KOagxw8WtxJKL9jCFcN9
xIQplrjEF68MWOxH9gO2dIrNLGS/o4cDNnchAABFzZTP
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 497->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYa0+eWch+QDafGD8hm4FuNyn6UQCSWwj5h8Eei34kc9DdhctN
2NSgiBERrsjhR2yYY3UHmjsZcIgTCg+c8UKkP3DpIaQfxRwcbsAWF7jMRQ9X
rO4jJkzR4hKbOVjDEl0vFncgA1xpiwGNjdVsFAAApNiT0Q==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 498->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPbg4+vWj2NmCxG59+rOYwIMxjQBMjST+SOejuwuUmbGpQ
xIgIV5ibSQlzrO5AcycDDnFC4YHNb0S5AYtfSNGPYQ6O8EP3C7qfcYUrNvPw
hQsyQOEjhSvesESynwGLODrAaT8aGyNuMQAA+qeSTQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 499->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPbg6aHCEz0O3GpQeXf+AA2S0E/MNgj0U/kjnY3IXLHKxh
ykCcGQxYzMDmf4LuQPI/1nghEK4MWOxBDgui3IDNLzjYRJmDI/zQ/YErvWEL
Vww/EQpTLHGJzRy87kcLfwY0s7H5Eat9SHaimI0BAAQ3kcs=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 500->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPbg6JZqDbTYp+FIDsFiL9gxXgcBdW/bjClIE4MxiwmIHN
/wTdgeR/rPFCKByIiRcSwhNXPBOVvtDdjx6+ONRjY+MKD2LSGjJA4WMxB2uc
Ygl/FHE0gNN+NDZG3GIAAPp4lAw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 501->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFoM9DjPQzCHFPQ1odjMg2UOsf+AA2S1Ehg1WgOYvQmGCrAfD
P0SGK0p4EJDH6Q80vQzImAg3YMQLlngiKixw6CEmPtD9jy38sIUPTvfgCCdC
elHSBq54JWAvctrAwFgAPvsx3GKPRQ4OAEANlMk=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 502->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzofpxyJHjBnIdjNAMSn+gQNktxDpH6wAi7tw6rdH1YPhHxLM
QObjk8fpDzS9DMiYCDfgixds8Y4zLHDoISY+0P2PLfywhQ8x4YocToT0oqQN
XPGKz160tMGALocF4LMfwy32WOTgAADe0pWM
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 503->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
uBoC+pFpbOLEuh3DDJh+LHJY9SOpR7ebgYA/cLkbbj+aGFnhisVdhPTjEiPK
DLRwQ/c/MeGK7H/kcET2CyE3oKtDdztR/sBiBrH6caYT9PDF4XZC4YocToT0
oqQNLHx88Yoc9sjxgiGOBvDZj+EWeyxycAAA0fCTTQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 504->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
uBoC+pFpbOLEuh3DDJh+LHJY9aOpg+tFwsS6AQUgu4VI/2AFaOYQox+XGFFm
oIcHAXmcZiDpxeAToR9dHbZ4IiduSdFPTPjicjshtyCnNUJ6UdIGFvPwuQs5
7GH64TRa2kIG+OzH5RbsZgEAi46Vig==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 505->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
uBoC+pFpbOIMBMxA14NsLy7zsepHU4dsN6luQAFIZqOHDUnhiiZHjH5cYkSZ
gR4e6HIEwhXuZyS9DOjiRLgBPf6wxRM5cUuKfmLCF5fbCbkFOa0R0ouSNrCY
h89dDMiYgQEjbTOgmY1uDzb7cbkFRQ4OAKwnlEk=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 506->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEwYAEs+B8POZj1Y+mDmYvMibFP8huZ0ATIytc0eSI0Y9LjCgz0MMD
XY5AuML9jKQXJRyIiBdk9+LyG1HhicUMUvTjjB8sYYMrvPCFK7JZuMzDZzdy
eOLyDwMyxhL+2OIG3V3o9hPjFgQAAEJ+kg4=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 507->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYc
bLx68ABi9SPT2MTBgASzkP2Ay3xc/kdWB7MXhokOD/RwsccUIytc0eSI0Y8c
lyhixJiBHh7ocgTCFe5n5HjA4g5i0iSKO5DCgpK4JUU/zvjBEja4wgtfuGL4
iUS7kcMZl38YkDFavGAzG5dZ2NTA4xOLWxAAAFjqkg4=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 508->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYc
bLx68ACi7GFApbGJE+N2rGbgMR+Xu5DVgYE9AhMdHujhgmQ2uh0khSuaHDH6
kcMbRYwYM9DDA12OgF9w+RndHcSkSWz6scmREre40g0ht2BzA0H1BMIV3Sy8
5sLCFIt5+OKVARljixc0f+EyC5sauP322OUgAAD0LZJN
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 509->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYc
bLx6GCBqsQFi9SPT2MRJNQvZD3BzSPAPht+QMLFhiAKQ3MKAZgfecEUHaHL4
/IVNDYoYEeGK7lZs6YOgGVj8jO4OYsMTI2yIdAM2/+JiE+MWbG4gpJ5QuKKb
hddcWJhiMQ9fvDIgY2zxgiPd4Uyb9pjq0M1GBQAP9JSM
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 510->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgUhM
rFp8gFj9yDQ2cVLNQvYDLvNx+RlZHSzMGJDkiQ03FIBkNiH/YNWPZA6xYYKs
Bps+osxADw8c7iToDizmEBsv2OzBFh7E+APdDFzphpBbsLmBkHpC4YpuFl5z
0cIUPTxx+YcBGeOJF3SAK22hq0f3CyYAAMVbk08=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 511->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzsdjPjFmgAHUnAYkGq9+bOGC5BZC/sGqH8kcYsMEWQ02fUSZ
gR4eONxJ0B1Y9BIbL9jswRauxPgDOTzQzcPmR2LCF596XHLYwhXdLLzmMqCa
gR6eeO1Fsw/FDBzpDp/f0dXhkoMAAKtlk44=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 512->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzsdjPlb9aOrAACregEQTMgMjXJDMJtY/+MKTGDOwqUEWI8oM
9PBAFscR5ljdgRZ2pMQLNnuwhSux4YktrWDzI9HxQ6Q+XP5H5qOrIRimDJjm
oZuDNSxxmUEg3WENfzR1uOQgAAAmkpUO
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 513->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYC
8lj14AHE6kemsYkTMovBHocZeMwn5B643cjmE6MfW7gguYXYsMEVnsjmEHIH
tjAlNVxRwgNZHEeYY/UHWtiREi/Y7MEWrsSGJ1Z/EaEfn3kk68URHuhiBMMU
i3/wuYkBi30o4Ygn3WFNm/aY6nDJQQAACHmWDA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 514->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFoM9DjPwmI/LHGR1cDeg2UOsW+AASziRE67octjsxeUXdH3E
his2NShhQsgMLGGIEi8khCdG2BDrBnS/YzGPUHzgih9S9aGHH3o44YpPrGGK
xT/43IQSBwxoNFo4oYcZNr+jqGfALwcBACRtlks=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 515->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItF4zbDHYQYeOVzmIKuDu4GU8MAWLkhmExs2+MKTGDOwqUEWI8oM
HOHGgGYmQXcghwuaueTELXK4Eh23DKh2optHbPySEgd4w5WAefjCBR6mWPyD
HC44wxLNDAxxNIAzbdpjqsMlBwEAfDeYSw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 516->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFoM9DjPwyOEyB1kdzA0odpDgHzhAMpvYsMEK0OSI0Y9LjNhw
xaaGAc1Mgu7Aogc5PPGFKbb4wxYexIYnrngmpJ+Y8CVaLxY/o5uHLUxQ4h8t
TaLEK6GwRDYDySwGJHcgA5xpE0dcoLgFBQAAgACWyw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 517->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFoM9DjPwyBFyD4Z+NJoYt8ABzCwSwgYrQJMjRj82NxFtBo5w
Y0Czh6A7sOghJzwxwoZYN2DxLy42sZjYeMTpHgLmYQsXlHhE5iP5AZ+b0NUz
ILkFzscCcKZNHHGB2ywAsjeXyQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 518->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpwPxdjkiDGDAQ0TpR9buMDMICFssAI0OZLDA0kfMWYwYDED
2Y/EhCuy/9HF0M0iFJ7Y/EGUG9D9jsU8YuIWV1iSrBfZX7j8RChtoZmBEq+E
whLNDBQ+FoDL7+j6sMqhAAANKZiI
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 519->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzofpxyJHjBlwvVBMqn/gANktRPoHK0CTIzk8kPQRYwaucGPA
YwdWf6DrQeITClcGLPagu51Yf8D9jsU8YuIWV1iSg5HdQqyfUNTi0IucTnDq
RzMDhY8F4EybaPqwyqEAABtAl80=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 520->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4gxINClmYbjNnjwzkPXi0o8ujuwfOEB3CxFhgxWgyeF1B64w
ZcBtBq64RbeDwR7Tv3j9ga4HOZyISF9Y44WBBDdg8wsJ+rH5n5jwIyZcccUp
NrNR1GJxD7IcUe7HZiYDJhtrnCKrQbcf3Sw4AADFb5ZH
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 521->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4gxINClmobgNCRPlF2xuIFI/un/gAEs4EWMOBkCTQ3c7tnjB
ZiYuM3DFLS47sIU5Vn+ghytyOBEIWwYs9qC7nSh/YDGDWP1Y0xOR8YjVL2j+
J9VPGOkBPd0RaT8Duv1oZuPyI4YadPvRzYIDAN83lcc=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 522->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxEk1C8VtSG4k1QwwQDKDVP/AAZo7iHELVoAmR0y8YDOTXDOw
hQFBM5D8j81cQuHKgMUedLcT5Q8sZhCrH90cYsMPp1+w+J8UP2GkB/R0R6T9
8HBB5mMB+OxHprHKoQAAMcGXCg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 523->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj8EA
RqMBYvUj09jEYXYQaxacb4/QR4x+dDPgfiPBDAx3M6CaQ2zYYAVociSHB5I+
YsxgQDMDm//xmQH3L5peXOK4zMAaLwzEuQGnX8jRj+YeYvRh9QtyOiHDT+hh
h2IeUjohZD+Gf3CkO5xpE00fhtkYAAAG95eI
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 524->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzofiBiQar340M8CAVDPQ3A0HaGLkhCu6HMnhgaSPGDMwwoMI
O7D6Ay0MGbCI43MDuj3YwoPcuCVJP5p7MMKXCH9gcwupfsIIU/R4JRSWSOYz
oJuJBeBMm2j6kM3GbhYAGvuXSw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 525->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYC
8lj14AHE6kemsYmTahayfxiQ2MT4H9kMMEA2g5gwRHM3HKCJkROu6HIkhweS
PmLMwAgPIuzA6g+0eEA2l1C8YAt7mJnEugFf3JKkH0dY4gsfbHLobsFmHj43
wcMUS1yihw3WsMQS/uhmIQOcaRObW9DEUAEAJemYDA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 526->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFoM9DjOQ5YhxC5oZcDdgkSPGPygATYyscEWTI9Yt6GZiMwNb
+GCEBxF2YPUHWjwgm0soXrDFLYbbiQkLHHFLrH50tyLrxxc+WPXiihsC4cqA
phZbXGJzF4Z+tPDHZhYywBWWDMjq8cnBAQCSfZYK
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 527->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpwPxQ1INF79aGbA3YDDfEL+QQFoYmSFK5ocyeGBpI8cM7CF
ISEzMMIQLZwJxQu2sEd3O1H+wBG3xOrH5S9S9eEKV3TzsLmJAc1u9LjEZg5W
/Wjhj9UsJIArLBnQ7MYwGwMAAN3mmYo=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 528->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItGkmAXn2yP0EuMeBjR1cDeQYgaSf1AAmhg54Youh9cfuMKUgTgz
sIUptnggZAZGGKK7g4g4wXAHlvAgN26J1Y8rfjDcScAfuNyM7B5cbmJAU4se
lwxYzMGqHy1eGNDNRgM40yYaG8NsDAAAhvOWjA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 529->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjzEA
khhR+pHMwTCXVLPQzcBjPi63IKuDuwGLHCE34AsXYs1BB+hypPgF2T/EmoEe
bgxoNDHhihyGyO7CZhax6QNbeJATt6ToxxU/+MIGmz9w2YkcJoTcBA9TBrS0
gsUcrGGJI14IpTt0vzOgsTHMxgAAhx6YSQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 530->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhrj2JZqGbgcd8XG5BVgd3AxY5Qm7AAGh+Iidc0eVI8Quyf4g1Az3c
GAjI4/QHcjxgCVe85mNzB5bwIGQGXj1EhAOu+MFwJ574IDZuCLkJJocel9jC
FJc+dPUYZiEBXH5nQGNjmI0BAFrJlkk=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 531->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNlhl45HCZg6wO7gYscvjCA2u4oPmJnHBFlyPFL+j6iI0jFHsJ
yOP0B5pe9HDFaz42dyD7gxg3ENBDTDjgih8Md+JxA75wg4UJMW5C9gdKWsES
prj0wdWj6cMGcIYnmt045eAAAFCilck=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 532->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNlhl45HCZg6wO7gYSzcAaLmh+Iidc0eWI0Y9LjNg4QrGXgDxO
dyCHC5oYsplYzcfmDmR/EOMGLP7FxSY1ftHTGjY/EApX5HAixk3IfkdJKwTs
Rw8z9HghlO4wwtMeUx0uOQgAAOrhl0k=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 533->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNrFvQzUY2hxi3IKuD68VhPiH/oABS3YInPIkJX2xqkMWIjSMU
e4kIc6zuQA4XNDFCcYst7FH8QYwbCOghJhxwxS+KHUSagc1ODD4RerGmNTx6
0f3PQMgsND9ipE17THUY8YsCAOpPl0s=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 534->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
nHrQ9CPT2MSJdTuGGTD9WOSwuQldHUwvNncT8hsGIMEtuMIVXY4Y/bjEiDID
LQyw+R+fGch+ZcBiJgMOM3GFJ1Z/EBu3ePQQEx+44hc9/RBrBra4wWYPrrhF
thMFEKuPgQEjfjDMQvMjRtpEY2ONXxQAAK5jlUs=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 535->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItGkmAXno5mDV689qjpsdhPjJwYktSgATYyccEWXI0Y/tjAl2gx0
PUSEOTb9KOGCHsYkhCc2vxEdtwzY3UBsvGKNXyzph5A+XHZi8AnELda0RoI+
uHq0uMAGcKUtBjQ2htkY5gEANteWiA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 536->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItGkmAXnk2AOAxYz0PUQ4ydkc1AAmhg54YouR4x+bGFKtBnEhBse
MxiwhCsDOpuE8MTmNwYCbsDmD3Q9xMQHrvjF5leizMESN9jswacXI60RcAd6
mGGLC2wAX9rCFbbYzQMABACYCA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 537->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEGYgxB5sZSPoJmcNgj+kOdD3E+AnZHBSAJkZOuKL4CYtfMfyNJUxR
wpWAO4gKNyLMQIlPLJgU/ShhgyPecYYnjrRCjH5c8YsSVkSagc1OfPGJSy9G
WsMTXwxo+pDVY8QLGsAalmjhjx622M0CAIh5lYg=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 538->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAZsZMP1IND796O6A68Uih64PmzkoAM0tZIUrmhyhsMAWpqSE
KzFuJVYeTmPBhNyANV4YcLsRm5ko4YfFPELxgSt+CNlLMFxwuAGfWdj0wvyH
yy8MaPrQ1aPECRrAmTbRzMIwG8MsACMSlkk=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 539->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAZsZMP1IND796O6A68Uih64PmzkoAM0tZIUrmhyhsMAWpqSE
KzFuJVYeTmPBhNyANV4YiHcjclxiczcx+nHFD6n6MMIFhxvwxi8WvTD/4dLH
gKYPXT1KnKABnGnTHlMdutmoAADxWZbN
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 540->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYa0+8WQzYzEA3hwj/IpsB14snTNDFkM1BAWhi5IQruhwx+rG5
iWgzsIQprvgjNn4Z0NlEpkNc/ifGjdj8S6p+rOYRSAt40wmWuCE2XHHFKz6/
YIQ7A34xZIAzbdpjqsNnDgMDAN8DlM8=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 541->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYa0+8WQzYzEA3hwj/IpsB10tCmCCbgwLQxMgJV3Q5YvTjEiPK
DCxhiiv+iI1fBnQ2CeGJ1R/EuAGLf0nRjzN8cbiVWP24/IcrXNHVYqQ1HO7C
5WcMGp2NFmYYaRNNP3KcYjOHgQEA0ISVDg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 542->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYa0+8WQzYzEA3h5B+NDPgeu2xuxGnGdjCBU2MrHBFkyNGPy4x
oswgxs9EysNptLgglM6whT2KP4iNFwZMM4jVjzN8SdWDLVxwhCM2N6GrRU8P
6GGLMy7sMdVjmIEEcKZNNP1ws9HCHAEA4RySzw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 543->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPbg4+vUjqMdyAw3ycZmALFzQxssIVTY4Y/bjE0P2K0z8M
qHx0NjHuQKHRwhVfnOCyB58/sJmHLR1h00/ILYTCl6AeLOFCLB9fmMMBgTDF
FwcoYmgAZ9pE09OAzTwUAACkOJMM
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 544->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzJxwy4
xPEAosxlQKVRzLUnzyxkN6OYQ8B/DGhmwPXiMB+XGRjhguwWIv2DFaDJEaMf
lxi6X3H6hwGVj84mxh0oNDqbyHSHES9k+APdDAw3Ehm3xMYBTr9gsRNbXBET
Fij+I8IP2NSjpCssaQ9X2mJA04McTtjMYWAAAN/UlEk=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 545->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPZj4DPr1YzIC7AYf52MxAsY8B1QxkP5EVrmhyxOjHJUaM
O9DVMNhjsolxBwqNziYUDtjiBS0+ifUHihlY2ITSB4r/iYkDYtIJDj9gMxun
WrS0hc9eDPVo5iKHFS4/wgGaHuRwYkC2Bw4AZGGViA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 546->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPx3wMvWjqUdyAw3ysZiDZBwdIcsT6BytAkyNGPy4xdL8S
8g+MjxxWRIUJWvjDwwHNHHxuQLcHWzwR4w9cepDdRoxbiI0DotIJDj9gMxun
WuQwRUonBN2PJS4xzMLmDgbsarHGLwoAAPDTlkk=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 547->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPx3wMvVjMgLkBFx+bGcj2wQGSHDH+QVeLbA6y2cTECy4x
ZLcS4x/kMMIVXsTGL6luwBovWMwjJjyx6UF2DzFuITYOiEonOPyAzWycapHS
JozGG5bI6pExshlIAFfaQteDyy0IAADmMJYM
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 548->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFrrbsMlh6MViBswNuMwn5B84sEf1CzFuwQqw+ItQvOAMDyLD
BCU8CIQXsfFLqhuwxgsW84gJT2x6kN1DjFuIjQOiwgWHH7C5BWtYIPsPicYb
lljiBcMMJIAvbcEBelhjNQ8A+0qYTQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 549->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNrFvQzUY2h5A70O1Dt5sYP8HUoABkswmEDTa1yOYgm01MvOAS
Qw4TXOGLHm4M9pjqiXEHujoGHOYTmz7Q/UaMGfj0EAoHdLcQGwdEhQsuPpFh
geI/JBpvWGKJFwZkjGwWFj/CARobl1sQAABwmJbH
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 550->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLrL5xLoF3WwwwCKHyy3I6mB6cZmPzw0oANktSGI43YArXNHCnJh4
wSVGTJjgUkNKmCCHB4YfiXQDhn4GTD4x/sClh5B+XP4mVh/ecMHFJzIsUNIa
UrjiDUss8YIeJ9jCDKt9SOwGHPoRAABWRZhJ
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 551->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLrL5xJiDYQZMPxY5QmYg60V3E6HwwAgXZPOI9Q82gCZHjH5cYsSE
CVFqiJRHVseAjIlwA4Z+Bkw+Mf7ApYeY+EB2CynpkmC44HADAx77ccUrcrgS
shNrvDAwYKRTbH5EsQ+JjRLWWMxhYAAAodqZjA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 552->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqh/GJNYsBmxkw/Uj2EOUXNDYu87GageZuDPMI+Ac5PHCFJzFh
gk0Nshgx/sGnBle84QsPFHNJcANW/WT4A5ceQvrR3UJKuiQYLrj4JIQ5HCCF
KyE7kdVjiKEBfOkCXR0+cxgYAEOylwg=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 553->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxJwwxE
qsEFSLEDXT2MT6xZDMh68IgR5Rc0NrpZeM1AczeGeQT8gxweuMKTmDDBpgZZ
jBj/4FODK97whQeKO0hwA4Z+tHgl1h+49BDST2z4kqofm/+Q0xuxYQ4H9ghM
yE5k9djiChng8juDPaY6XHIQAABrI5bL
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 554->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqh/GJNYsBWQ+SGbjMx+sXbPqJNQPN3TAzGJDNx2MOit04wpOY
MMGmBlmMGP/gU0NsuCKHB4YYWhgTDA8c7iLWH7j8Tkg/seFLqn584YgtTHCq
hQGkdEbITmT12OIKGeDyO4M9pjpcchAAAIjnmEs=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 555->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqBwN7Es1iQDMTj/l4/YLmBnTziXIDMsASTsSYgys8sZnBgEM/
LjEGe0x5XOFBSrzhCw9s8USMGzD04zCPmPBE10+MGwiZRw5Gth+bH9DjE69a
GLBnQEnz+OyEq8cWL0hy2PyIYh8DqjpcchAAADOrmcs=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 556->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgkF5cgFj9DfaY6mF8ZLMIuRNdHQOaOUT7Bck8BizmE+UGZIBmNrHmYAC0
8MYXh1jVoIUlIXcQpYYIeXRzSHUDuj24zCMmPMnVj888cjCyW7C5AT0+sall
QHMLPH0QYSd6vKCwkeRgbKxpE5mNrhdNDgIARReXig==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 557->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwY0
mhQM0oMLEKu/wR5TPYyPbBYh92GYgcd8vH5B0sOAx3x8bkABWMKJGHMwAJo5
xOjHJcZgT4QZxKghxh1o6tDdgC9escUFcrySEi+4/E6MfmLCl1T96P7D5m98
YcGA5hZ4+iDCTvR4QWGjA1xp0x5TDYZbUAAAhDuWyQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 558->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAQtm
QKNJwTgBsfqRzMEwF8l8Yt2CbjYu87G5gwHJ3gY0NjFmIKtBDwsGNDGywhXN
HGL04xIjygxiwo0Yd6CpYyDFfCxxgWEekf6A+x1LPBOTvgiFLzH+wOVmDD4R
YcGA5hZ4+iCUNrHECwobHeBKm/aYajDcggIAYvmVCg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 559->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAQvG
JU4MxgeI1Y9Mo5hrT55ZyP5iwCGHKxyQwwk9zIgyA8k/cIBsNpH+wQrQzCHo
D2xhyoDJxmkGmp+xpRNCfkG2D0OMGP3Y3I4lnoiKVzL144sfUvXhCjcMPqGw
wBI28DjDFwbobCxxgQ5wpk00Nla3oAAAHJeTjg==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 560->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAQvG
Jo5LLYY6PIBY/cg0irn25JmF7AcGHHK4wgE5nNDDjCgzkPwDB8hmE+kfrABN
jhi9yHGJIkaEOxjsUdUw2GOyCZrBgKkO2V3EuAHD7Vjiiah4xeIGYuMVVxiT
rA+HnRh8QmGBJWzg6QxXGKCHBxYxbGkPZ/pCY2N1CwoAAOhklE0=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 561->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAQvG
JU4MxgeI1Y9Mo5hrT55ZyP5iwCGHKxyQ1aGHGVFmIPkHDpDMJtY/WAGaHF5/
ILsFiz5i3IEeHsSEOTHxi+wuYsICl9tJiltk/QTimVT3kKQPjcYVjtjcgxKP
WOKVAYc+bHZjmIEWV8gAZ9rEERfIZqMCAN7yl8s=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 562->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpwPxdjksOpHUwdzAy4+If+gADQxcsIVQw6fP5DdgqYPnU1s
eBAT5sTEL7K7CIUnup+x+Z9Yf6DYix6eRLoDm3vIweh6Mfg4/IHsXvR4JeQP
BiQawwy0uEIGONMmjrhANhtFDQMA0XWYDA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 563->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhrj2JZqGbgcd8bO5gQFMHc0MDkhwDkW4gBMgJV3Q5UvyC4R8i3IHN
DOQ4IxSuyPrR3Y8eP8SGBza3E+sPFHvRw5NIdxAbB8ToxxU36GGMLgZTix6X
hPzBgERjmIEWV8gAZ9q0x1SHIodhFgAk85bN
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 564->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GRAAmU2kfTB16OqRxUkxiwHdbfbYzcfqD3s0/UjmMRBhBjZ3kxs22AC6HEG/
YAlTBiLNwOdn9DAiRj+6+9Hjh5S4xRYexKZRbP5CNpugO9Djh0h9uNIJLjdg
M5cBTS02t+ALUwYkGsMMZDE0gDUu0NXik4MDAG0nlog=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 565->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxEk1C91t2OSw+gNNHRhgMYtY/6AANDFizMEVnoTMwOYXDP8Q
4Q4GdD1EhDkx8QsXw2EmzvDA4Xai/cGAysdmNkF3oMcPkfoIhRu6WVjDGk0t
NrfgC1PkeISrZ8AuhgzwpQv0cMBnDgMDAF66loo=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 566->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzsdjPoZeNPVwu7GYRax/UACaGFnhiiaH1y9Y1CCLEeMOuDlI
fEJhTkz8oviDlHSGw/9E+4MBlY/NbILuQI8fIvURCjd0s7CGNZpabG5hwKEX
RT+yGQzYxZABvnSBHg4o7sAAALf5lU0=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 567->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmMEe
waYUowA0PrH6kWls4qSYhew3BjzmY9WPpg7ZPHQ5YvyDNWxIMAcdoMsR8ge2
MCUlXJHdjCvdEDQDS/ijhCkp6QxPPBHlDwY0Po50Q7R7yNCHKy2hm4U1rNHU
MmBxC74wRQ8/ZHegiyEDfOkCPRxQ3IIBAMoZlYo=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 568->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTGLAZmPx3ys+tHUIZuHLkeMf1CAPSpNTriiyxHyB7YwJSVckd1M
yL/Exi+DPVqYkpLOcPifaH+ghyGOdEPILJT4wSJHrH9w+Q+XWQxoerG5BZ9f
UMIdST02MWSAM21iCQescnAAAOjYlY4=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 569->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTGLAZmPx3ys+tHUIZvHYI9qNjH+QQH2mDTJ4YomR8gf2MKUlHAl
xq0EzcAS/gxEmo0rbtHdTrQ/cOghyR3o8YNFjtR0hs0N2MxCthuXWxjwuIMB
zX50dyCLIQOcaRNLOCDrwQQABByVzQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 570->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxEkxiwHqJmS3YTOfkHuQzUM3i1j/oAA0MaL8gsUMYsIElz3I
YsS4A+5mIsOL2PhlINJsYtxOSryguAGNTbQ70MMYixwxZmCNGwJmIduNyy34
/MKAZj+6O1DiBQngTF9YwgGrHBwAAKL0lRA=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 571->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTGLAZmPx3ys+tHUIZuHLoeuD52NAdDEyApXNDli9GITJzZc4W4m
Iv5IiV8GIs3GFbco/iA2btH8i84mxh0wd5OaLgmlM2xuQHcPut1Y45uAXxjQ
7GdAswfFDCSAM32hsXHKwQEA1WiVTw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 572->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEpjEyfVLKxuI8EvyOYx4JAjxj8oAE2MGHOwmUFMmOCyB1mMGHfA
3YwnTRA0gwFTHQMWswmlQ1z+JyVeUNyAxiYmfWC4hwh7iUln2NyA7h4GNLux
xjcBvzCg2c+AxVwGZPNw+BHDPixxg80cBgYA7z6UTw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 573->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxEk1C6vbSPALsnkMyHL2hM1Bdzey/cg0MX7BZgYxYYIrDpDF
iAlXZDcTG+bExC8DkWbD1GLEBbI/SAxPDHcR6Q6s7kEPXyLNwBZu6G7AZhYD
Pr0MhP3CgEQjq8cmhgJwpS97TDXY3IIAAIMNlM0=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 574->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj3EC
EvQj0yjmIplPillwPrL7COlFUo/uBhR5EvyDHh7INFnhiibXgMM9yACbODob
b5gQCDuCZmDxMwORZmMzB9ld6GxiwhMjnkh0By7zcMUFvnBF1oPuBqzxiiPM
4YCAX9DDD1s4MiCbh2QuXvuQ4wabHBwAAIAuks0=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 575->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWVrcR4w80M5D1MdgTaQ6Sf1AAmp+I8Qs2M5DliNGL
TZwYM4j1M0EzsPiZgUizcbrdHjubWP0NZOgnZB7MLKL0otmPntZwmYWsFm9a
wWMveryihwMDEeahxAWaGmQ+JgAARgiTkA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 576->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyP7D5CepHUo+hFN4sIc7CGC5qfyApXNDlk+3D5G1uYopuB
N0wI+JmgGVj8zECk2djCA5v/SQlPjHRHpH5C5uGKC3zhipFeCJiFrBZvWiGU
NnHFC5IYPvOQxdHVYJWDAwDuzpLP
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 577->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPZg5B/WjqcLmJkBlYw4VUt2ADaHLI9mH1Nzb3M2CyCYUH
Pj8TNIMBUx0DkWYT43ZiwhNbeJCin5B70OOelHSGEqcEzEJWizetEEqbuOKF
ATWscJmHLI6uBiVuMAAAf3CVkA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 578->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhrj2JZqGbgYyJMANdHQobyU3E+gcFoPmJrHBFkyPkD1xhSowZ+PzM
gGYmMXGCHq4o4UFsOiMinogND7i7iIwPXPFDkh4s7keJDxxhjC1t4U0rpNiP
K17wmIcsjq4GqxwcAADQB5WM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 579->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmMEe
waYU4wNE6UcyB8Nce/xmofsDwwxkTIR70NWhhxkDFjuxhQfWcEHzE1nhiiZH
yB+4wpRoM7CEAXq4E/ILNj/DxYgMUwy344knYsMDxQ1ExAeu+MGXHrG5A939
yPFByCycatEBoThFth9LOBIyD1kcXQ1WOTgAACfYk0s=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 580->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhrj2JZqGbgYyJMANdHQobya3EuAEDoPmJnHBFlyPkD1xhSrQZWMKA
UJhj9QeWcEWJG2LTGZZ4IiY8sYUHihuIiA9c8YNuDyn6kfUg+w9nWOMIcwxA
KE6R7ccSv4TMQxZHV4NVDg4AKS+WCg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 581->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhLhJNrFvQzYZjItyDbh8284h1AwZA8xM54YouR9AfOMKUGDOQzcHn
f4JmYPEzXAwJExUeWNxOatxidQMR+nHFD6npAyOdYEl3OMMaR5hjAHxhgOZn
bPGLHGfYzEMWR1eDVQ4OAJDjlwg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 582->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqBwMkmiiz0M1AxkS4B90+bOYR6wYMgCZGjDm4wpOQGQw41CCL
EeMO9HBjQKOxhRFWf6CbAxNDwkSFBzZ/kBi3WN1AhH6c8UNi+sBIJ1jSHS6z
cKZLJLegm4NVP7L9DFjchGwWFvOwAvS0h1UdANSmlkk=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 583->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GVABEp9Y/Q32mOpRzCLWLehm2JNnBj43EesGDIAmRpQ7GLDrIWQGrjhAFiPG
HQz2qGoY7DHZBM1gwGIOTAwJkxovcH8Q4wZsfmHALk4shgMsYUKsfnS3ETIL
X7pEDmdc7mBAopHtxxBDA8SkTRRz0NIgAgAA9eyWiA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 584->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GVABEp9Y/Q32mOpRzCLWLehm2JPhHiT7YHpwuRGfGzAAmhhR7mDAroeQGbj8
jCxGjDsY7FHVMNhjsgmawYCpDh4eSJio8MThf2L9gU0Puh+JSaso8YNDnthw
RUmjBMzCFebI+tHNwaofzX4MMTRAMG2im4MW5ggAAGWTlck=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 585->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqBwMkmiizGNDMRHMfKWZgNQ+LGehug+tBB2hixLgDmxnIcsTE
CTYziTED2RxsfsUXJrjCAyNukTAx6QOX/4n1By49xMQHhv/R4oRUDA8XZPfh
SVf4whzZLfjcxIBEI9uPIYYGCKZNdHNwqWMAAGIuloo=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 586->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqBwMkmiizYHqQ3YbkRmLNQGfjciM+/RgATYwov2AxA1mOGL3Y
xIkxAzlu0eOKlDBBtg9bPDGgmYsvfTDgcheR/sClh5j4wPA/kfFIVDpD8x+6
XYTCHA4I+AU9/HCFIzogmDbRzUYLcwQAAAEQl4o=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 587->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItFEu8UeoZ4BzRxS3IPiNjTzifUPCkATIytc0eRw6sWhBlmMGHeg
hxuDPSaboBkMmOrg4YGE8bkBPewx3EWkP3DpISY+cMUPqfqw2o/FDdjCBFeY
I6cPQukCJTywiGFLewTTJro56HbAAQAkd5eK
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 588->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYC
8lj14AHE6kemsYkTcheDPapaBiRxuBiJ7kFxAxY5YvyDAtDEyApXZD/hMQPF
LixmorNxmoEeHjjCnNT4RfELgXSHHrcNWPSQEp744pmgGXjMIxWjhyu6WdjC
BFeYo6QPYuIUOV7QxFDSDg4/YgBkt6GbhwIA94SVCg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 589->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYC
8lj14AHE6kemsYmTbBaSf8h1Dz43EesfFECiW7ACND/hi0dkPehmEhOuyHZh
Sx8M9qj+JSV+UfxCIN0xoOlBZ5MSL+huQHcPQTPwmEcqRg9XdLOwuQdXmKOk
DwJxim4fSjygpQ1cfsQA6Gajp0E4AADB/JZN
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 590->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTYLl9tIMAOfm4j1D7rdxIQNTrfDzCAiTFDswhJXxIQrNnsYcLiT
YPrAEq5wv6CZizc8sPiDlHjBpQc9nAi5hdR0iSts8aUtbO5BD3MGNPOQaax2
YrEfJR7Q0gYuP8IBljhENw8VAAAvUJPN
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 591->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTYLh9tIMQODjcWNhPyDAtDE8JqBK1zR5IjRjy2uiAlXbGYwYFNH
yC9IfscQQ8L43IGsB5vbCbmBkB5kswnFCy7zSMHY0hIGn0BYYIQNUjjj0suA
Zj96HKCnDVx+xLAPOW7QzEMFADmtk5A=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 592->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTYLh9tIMQODjcWNhPyDAtDE8JqBK1zR5IjRjy2uiAlXYuzBFm/E
xC9cDCmu8LkD7l4s/iDGDej6sbmHkDuQ3UJquiQm3DD42OzEEn4oaQ1PWDCg
YwbsYijm4fAjun0ocYNuBwoAANKolc8=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 593->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTbLHkGT6x4MNhY3EvIPCiDBLehqkfUgyxGjH1tcERuuxKohNX7R
/UIoLOBqcbiLkBlwPUTEMzFuQYlfLHKE9GKzE4OPzU4s4YfuFlx+YUDGyOrR
0gyKeTjiHytAC2cGrOoAP7OV0Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 594->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgcoY
LyBSPzKNTRxdjqBZ9gga5g5SzGCwx3QTA5K5xPoHPSyQATnhii6HUy+S37GZ
SWy4EquG1PhlIMV8LOGPLTwImYEef3B3kZI20NMVmp8IxQm+cMPg47OfAZMP
BnjcgC38UMTQ4goZEJM2UcxGCyMEAAAQipWO
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 595->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgcoY
HyBWPzKNYq498WYxIJuFJsaAxXxC7sFgI5lLrH9QAJoYOeGKLkcoLLCGKQNl
ZuALL2LjlwGLe/C5Az38sYUHwbSBFn9wd5GQNvCFDSFz0NMOtrjBpx493LCF
Iz43YAs/BjSzUNIGnvjBCnCYjQoA0bKVEA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 596->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAVkPmhgDFvMJuQeDjWQuur343A0HJLoFX3gSChOYW7GFKbHh
ykCEGmzxRkz8MmBxDz53wNWihw2xbsASf3B3kZI2cIQlLnOwpRdc4YbsH1x6
0f2LLTxw+YWBCPXIcYUv/lEAjrjBUAcGAElllg4=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 597->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgfIBY/cg0NnFizGJA1oMmRo4Z6G5iIDKc0N0NB/aoNKG4wBeehPzDgEMN
shi5ZuDyL970gSUsiY1bBjRzUMKGWDdgiT94OBChH90t2NxObPrAFW7wcMJi
F7awwBav+PzCgKYfXT0KG0kOm3koAEfcYKgDAwCLyJRP
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 598->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgfIBY/cg0NnFizGJA1oMmRo4Z6G5ClyPGPyjAHpUmJ1zR5fD6A0eYEhuu
DESowRZvWP2BJSyJjVsGNHNQwoZYN6DpR4knIuMD2S3o7sEmT2w6wWUeNrNw
+Rc5PHD5hQFNP7p65LhAlsNmHgrAEzeYAACaC5UQ
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 599->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAVkPDreRYga6m9Dl0PWhszGAPRImxi14wpOQf3DZg6yPmDAh
Vg1BM7CEJdHmo5mDEjbEugFNP0r6IjI+MOIZzTx0eWLiF1s44TMLl3+RwwOX
XxjQ9MPVI4cPA6pbcMUPVoAlrDEBAOe/lY4=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 600->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE+sOGBsuhmQWKWaguwldjhj/oAA09xBjDq7wxBYmDGhs
bPYg6yMmXDHsxeNfvGZgCUui3YDmJ5SwIdYNaPpR4onI+MBwC4E4IDadoIcT
3rDGpxcpnHHpRY975HBB9g+KWVjCBitADxus6gB7NJRL
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 601->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmMEe
waYU4wPE6kemsYmTbBaSPxlgZhCjH80d6GFGjDvQ3Q0HaO4hJ1zR5dDdjuJW
HGFKSrhi2IvHv6TEL0r8ENKP7Bb0sCHWDVjSAEqcEBEfWM3DEwfEphN09+AN
a3x6Yf7B4RdkORT1WPyDDohJm+hxyoBVHQDDXpUO
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 602->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmMEe
wcYnRgzGB4jVj0yjmGtPnlnIfmJAMotUM9DDjBh3IPsHBaD5iZxwRZfDFX8M
ONyLrI+YcCVWDanxCxcjRj9aekAJG2LdgCUNwOOCyPjAah6eOCAqfvHxCYQF
1rSCxy8MaPpR/I/FDFx+xJU2GZDtQdOPAACZc5SO
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 603->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxxYwY8
cnj14QHE6kemUcy1J88sZD8xIJlFUD+aGShsLOYT8g8KQPMTOeGKLkfIH1jD
FNl9RLqBlDDHagZyuGCJG2LSJbJ7kcOUKDdg8S/cXUTGB1HhS6p+LO7BZxa6
f7GFBy6/MOBSj+YfFDYWP6LHKUZc4JIHAwAL/pNN
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 604->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxxYwY8
cnj14QHE6kemUcy1J88sZD+RYgYDmhkobCzm4wwP9HCxxxQjJ1zR5Qj5A2uY
MqC6kxg3kBLmhOKXAR0T0m+P6V7kcCXKDVj8ix4vRKUvLOHLgEWeKLMY0Mwk
wix0/2ILD0LpApt6dP+gA6zpwh67GqxmwgEALjeSzw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 605->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxxYwY8
cnj14QHE6kemUcy1J88sZD+RYgYDmhkobCLDCN3dcD6aGDnhii5HyB9Yw5SB
ODNIUUNK/DKgY0L60cIVJWywyOEND2zxRIQbMNyCxQ3I8qSmM2x+wGYWsn8x
woaBAas/cYYlmnoMMSRAUtrEZiYcAAAuTZGQ
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 606->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxxYwYo
xqcGqz48gFj9yDQ2cVLNQnEbBWbA3UBC+KC7G+4GNDFywrUBzRy8cYlFDYo5
RLiDWDWkxC9yWBJlPlpcosQrFjlkPRjhgSVtEOMHDLcgxw8eewnFD0ZYEzAL
3b0o/mdgwOpPnGGJph5DDAkQmzbR/YIJACnLkdE=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 607->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULxW0UmIFhHon+gQN7VHcQ4xZ84UnIDFx+RhYjxh3EqiE1ftHD
A69+tLhECRti3YCmH5t5RKUNQuFLhBk40xa6+wiEBUbYMGD3J86wRFOPIYYE
SEmbDdjMhAMAfPSWkg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 608->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFjazyTEDwzwS/QMH9qh+IcYt+MKTkBm4wg1ZjBh3EKuGnPgl
2ny09IASNkh+JSo8cfCJ0Y8e/1jDlwgzcKYtdPcRCAuMsIGFBwNud+BTj0+M
lLTZgM1MOAAA8v2YUQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 609->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxJwwzE
qMEDiLKDAbtdYGCP3yxserDJE+seBjQzcJlHlH+QAZLZyGKkhiu6HCF/YLgf
SYyYMMGlhgFNDbHhQYwbcdmFHGYo/iDGDWj6sZlHVFrFoZ+U9IEzbWEJH3xh
gRE2UPcw4HEHVvUM2MXwxQ82gCGPVR0Arl+XTQ==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 610->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvWDaWzm2pNnFpyPRBNjBro6ZLcxIJlHlH/QAZoYWeGKJkfIHxjhgSRGjDuI
VUNseBDjRmx+QdeP4g888Y5hF5b0RYwfsJmLbh42e4kKFxxuwJbe0NWipwcG
HPqw6UdWjyGGBohJmxjyWNUBAPjWls0=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 611->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj3EC
EvSDaWzm2pNnFpyPRw6rfjT3oLCxuBGvf7CEBzIgJ1zR5Qj5AyM8kMKSGHcQ
q4bY8CDGjdj8gq4fWR8DMW7Ako7QzSMqfREIG2LSB0a44HADtvSGEnfofJgY
A253YFWPJYzQATFpE1vYYgIAyq+YSw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 612->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvWDaWzm2pNnFpyPRw6rfjR16G5DdyMuM7CGC5oYOeGKLkfIHxjhwYDpPlLM
wOZ/XPGHIY9mDgOSHXj1Y4k/ZHehxxlev+BID8TEB7b0hBG+RJiBLdywug+L
eehhiZHWsJiDEQ7o6rGEEQqNJWywAhzuRAUAM76Vyw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 613->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvWDaWzm2pNnFsw8ZDPRzceqH90MNLcRawbWcEETIytc0eQI+QNdDaVmYPM/
Ib/AwxCLOcjhjStsGbDYg+wu9DjD6xdcaYWI+EB3I9bwJcIMbGkLq/uwmIce
FhhpDYs5GOGArh6XGUiAlLSJnM4wzQIA7lKVig==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 614->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvWDaWzm2pNnFsw8BixsksxAcxsxZsD1oAM0MbLCFU0Op14capDFyDEDm/8J
+QXZPqx2EAoHHPGCHDcE3YDFLnTziEobOMISX/gQDBdk8wiYhR4W6OmBAYs5
WMMBTT1KfGNJe6SkTWS/YJoFAB6vl4o=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 615->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvWDaWzm2hNvFoM9qjoGJDMZsJhPjHvQ7SXGDLh+dIAmRla4oskRCgsM9yOJ
EeMOdDXY/E+MGbjUIfsJn1/Q9aP4gxg3IKcnHOYRlTbwhA0p5mBTix4WWMMa
SxpFSSsEwhTmf2zqUdhogJS02YDHHAYGAM4qlg4=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 616->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpgNxehsvPrRzcBhHrH+QQFoYmSFK5ocIX9gDVMG4szApgab
/4kxA5c6ZD/h8wtGXKC7i5AbCOghJj7Q/Y8rfIkxB5ta9LDAGtboYYqeVgiE
KQNaWCCrR2GjAVLSZgMecxgYADoflpA=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 617->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItGkmAVm2yP0MWAxn6B78JhHrH9QAJoYTv34whVNDp8ZyGqw6SNk
BilqSI1fFPcQCk9sccuAySdkBj49hPRji39sYUOMObjUoocFtnBBDwuMtILH
DQzIGE09MWLY0gUuNRhycAAACs2Uzw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 618->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPRJNjBgobyTxi/YMC0MVw6ccXrmhyON2A5mds+ogJV3Q1
2NxMjBm4whJfOGALD5zuIuQGdL/jiWdi3IIr/Ig1B5ta9LDAGtboYYqeVgi4
AZd69PhAobHEESE1GHJwAAAs45XN
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 619->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpwPxdjkiDEDhY3DfHz+QQHoYrjsxxeuaHI4/YDLvUj6iAlX
dDX4/Ety/CLFMV79OOIFnU9sOsUWl0TpR/M/tvAjxhxcatHDAmtYo6nFSCsE
whSfehQ2OsARltjUMKBjFAAATSqUTw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 620->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpwPxdjksOpHUwd3GxY5YvyDAtDF8LgBZ7iiyeH1B64wZSDO
DBQ3oLkNX5gTHb/2qGbj8wu6fnS3E3IDht9xxDPBtIHDPHS3EoOxxg0Bs9DD
AiOtEAhTfOpR2OgAV7pAAtjiFdMsABoElE8=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 621->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jE4WwizYLzkfQQ4x4GNHXo9hJlBpq74QBNDJ8bcIYrmhxef+AIU2zh
Sihu0d2GL8yJjl+Y+UTECbp+DHcRcAO2dESyfgJhQ0z6xBdu6GGBNazxpEuY
fkLpApt65LSJLe3hCktsahjQMQoAAJSbl88=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 622->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpwPxdjkiDEDm5tI8Q8KQPMTTv34whVNDps+ZH9jDVMG3Gbg
iltsdhAbJsj2YYsbbGbiCg+c7iIyXuBuQYoLovUTCBtc4UNMOmtAcw/OsEYP
U/S0QmraQkuTyHGFDHCFJTY1DOgYBQAADVqYTQ==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 623->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTYpZKG7DIUeMGdjcRIp/UACaGKFwxxeexJjBgOwWLPqI
CVcMe4kIc2LilwENE5MOcfmfgRg3YAkPWJyQkjZQzMMSfoT8gi/ckN2DM6zR
wxQ9rRDwCy712MIDlx8Jpk208EYFAJFTl0s=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 624->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWittwyBFjBtxtJJiB7B8UgCZGjDm4wpOQGTB/Yw1T
BuLMIEUNWfGLFj/4/IItXrDFE7oeXOEBjwsS0waKeVjChpBf8IUbsntwmYXL
vXBAwC8MONSj+webGN60ic0ObOoYAEvlmks=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 625->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxEk1C9ltuOSIMQPuBizmEeMfFIAmRow52MwgJkwYkOIFm5nE
hiuxasiJX2R3Ekpf2OIFWzwRk0ZRzCAxbeAzj9j0gcvNyO7BZRYu9yKnD3Rz
cOlHVo81beCJfwyAzQ5s6hgAdXScSw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 626->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzscjR4wZcDcgYVL8gwLQxMgKVzQ5nHphGEuYkhKu6PYSE+bE
xi/cfELhgCNe0PnEhie+eCYFYws/YtIHLjvRwwKbWdjCAj2eCKULXOoZ0OXx
pBEMgMPdmAAAz66dyw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 627->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLrL5xLoFxUwscsSaQcg8gm5AB/aoNDnhii6HL0yR1SCHMQORZqC4
AT2uSAhX5PDAiHMiwhZb+sBwFwnhiRw+pKQNdPdhCz8MNUSmM/S4waUXl3+R
w4NQusClngFdHk8aQZZDV8OARw0DAwDyUJoI
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 628->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNuLrL5xLoFxUw85uNyC7I6bOYR7QZ0YI9KkxWuaHKE/IEtTIk1A5sa
bP4nxgx0dQxY3ENK+sAWHsSGJ754JgVjDV8cbscXLtjiBu5GIsICPTwIpQsM
9WhpBtkt2PyInr5IUcPAAABk9ZrJ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 629->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYNhrj1xZjHYI9SimIlmHjFuQTYDn3n4wgNruKD5iaxwRZMj5A+sYcpA
nBnY1GDzPzFmoKtjQMOkpg9s4UFu3BKrn6jwxeF2fOGC4id0O4gIC/TwIJQu
MNRjCx8ks7CZhw1g2IFVHQB3zJfJ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 630->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNplj0qjc18rPrR1OEzjxj/wAGS2eh2kBSuaHKE/IE1TBmIMwOb
Gmz+J8YMdHUMaJhQnGDoR3cXCeGJL56JSR94wxeHerzhguw+9DgkIixQ0goO
vzBg0Q9Xj+YnZLdg8yNG2kRzJ0rcYgAAt1uYCA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 631->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxxYwY8
cnj14QHE6kemUcy1J9MsLH4ixgwGNHX4zCPGP3CAZDa6HSSFK5ocIX9gDVMG
4swgRQ2p8cuAholJl+jxgi2eiPULrngmJn3gCxti0gfOtMWAZj6RYYEtrRAT
ljD7GJDk4GLINBbzsAGscYsBAA2hmMs=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 632->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNplj0qjc18rPqR7MXqJhL9AwdoZhNyCwO6fiRzkM0mRj+2uCLG
DFLUkBq/DGiYUFhg6GfA5BMbt+hsYvWjpyus4UuEGbjsRI5fXGZhCwuMtMaA
2x3o6Qc5/BmQ3IAOcKULbGoYsNkDBwCucZjL
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 633->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTZJZWPxAjBkMSPY2oLGJDRNk/8ABmtmE3IIzTO1RzSZG
P0aYMhBnBilqSI1fBiRMbDrE0M9AvBsa0OwjRz+29IQRvkSYgctO5PhF8TeB
sEBJawT8gp5+sIUJtrSHK12gAGzhjAEAPWmZRw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 634->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTZJZWPwAM48Yv+DSQ0yYIPsHDpDDCYtfiQ5Te1SzidGP
EaYMxJlBihpS45cBCRObDjH0MxDvBkJ6iNGPK2yQ0xo+/6DLYY0bAmkNW1ig
uwXdHKz67VHVo4cPOsDpd2SAJW4xAQC8j5iI
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 635->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNplj0qjWweXv1o7mDAYgYp/oEDJLPR7cDnDgyAFubE6EcJD2Qx
Es1AD09iwwTZPnRzCMUHuttxxhMx4YlHDyH9uPyFHCeE/IMuh24nMWZhCwt0
t6CbgzUc7FHV40obuNIIVoDF3ZgAANxzmAo=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 636->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNplj0qjWweXv1o7kBXT4w7kP0DB0hmo9uBzx0YAC3MidGPLa7I
NQNb+BH0CwN2dQw4zMPmDnT96HFJVHii6UM3j5j0hS0sGewx3UqsfgzzCJiF
ze3obkE3B2s42KOqR47vBjQ5bGGDDWCLV0wAAMFqmYg=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 637->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2SWPSqNbB4xfmnAoh+bGwn5Bw6Qw4kIc3CGqT2q2eh6
sOnHCFMG3GZg8wu+8CAmTJDtw/AjkekLXT9KWBAbL8jhj8U8YtIXtrBBD3dS
9GOYR8AsbGGB7hZ0c7CFObL/4TSaGDLAGZZY1KDbgQoA+JmZRw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 638->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMKiNXPgEojiyObTYpZ2PxAjJsY0MxAV0+MO5D9gxwW6OFESZhiM4MBh36M
MGXAbQY2v+ALD2LCBNk+DD+SkA5R3IHsD2LjBTlNYTGPmPSFLWzQw50U/bjS
Hc6wRrYbh1vQ5bCFOUpYYAlHdIDT78gAlx0oAAC64JdJ
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 639->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKgDAMCx7Eq0/wC/oA8Qv6ggl6EoR5EG8+XQWRbmSzG3Ti1iVp2mpc
+zkDsBX31pu9s9YcQ/78TGZp6uW5LN8AzlYfSMijS/se7leeS+wULFaDRhM8
DETuNPVILyA0xHCc3ICnzBOmlXqKMAarxeFVeK7pL0T8zRwIj69d1RfpP8HT
zFfMmxQcNgOxfjIvfN6vtoAG6TnLB8H3fQ7xST2U51sX/suVxw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 640->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTYxbMczAYh4xfsEVBsT4CdktcIAcTgTMQVGLDtDMJipO
0MOAgTgzGnCYgSv+SIlfBiRMKM1hi1t0txMbL+hxQYp+YsKGWHOwpQEMPpFh
ge4WXG5ADnMU9WjiKOahhTOGfcgAnz1wAADEzJXJ
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 641->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTYxbMczAYh6x7sHlJmLDDQUghxMBc1DU4ghPQmGCK9yQ
xUgxg8Ee1W+khAmyfRh+JCLNYYtbbOFBbDpFZxOrH5u/sIUvUXqJSFvEhgVK
WsPjBuQwR1GPJ21g8yM2eZhZOO2BAwBzL5dL
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 642->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTYpZ2PwAM48UM7C5idhwQwFYwglveOII0wY0s4mJE4ww
ZSDdDHzhRihMkO0jJ40xYLEHW3gQE69wtxCIZ2LTGnLYoJtJyK/Y4oZQ2GAL
C3S34IovBmSMrB5P2kAPZwz7sNiJ1R44AADEcZgM
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 643->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE3IDVjOwmEese3C5iZjwgNvHgLAXPZzwhieOMG1AM5uo
OEEPAwbizGjAYQa+8CIlftHjh5S4xRYexMQr3C0E4pkYjOEGAv5Bl0O3E4NP
ZFhgpDUcfmFAxkjxii5GjHkowB5Bo4cDJgAA2ACZDA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 644->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWituQ3UikX3CaR4Q7GJDUwgGWcCInTBvQzCZGP0aY
MhBnBoofSAhzYuOXnPDE5X+izEH2O4F4JjatoZhBwBz0MMSmlwGPelxhgZHW
cLiBAR0zYKEZiDMPBaC5HcMOFAAAdmiXDg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 645->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWsttQ3EikX9D14zIfqxpk9zMg7EV2AyH/4AxTNLOJ
0Y/NTcSYQYoacuKXGL3obkdPG0S7ATk8scUzEe4gFDaE4pVQWsLwE5FhgZHW
cLiBARkjhwUDA2Z6IWAeVoBmD3Z1APE8ls0=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 646->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPRMPMw6sfzQwGPHL4zMAIFzQ34DMHq360MCAUJujhhm4m
MWaQooac+CVGL7rbUfxHqjlo4YEenkSlLzxhQ2y84lILBjjU4wsL9PjG5QYG
ZMyAsA9bekAHuMIS3Sz0uMEEAHp0mEs=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 647->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWstuQ3UisX9D1k2oG3P3IAE2MZP3I7iLCDGQ16GYS
YwYpasiJX2L0orsdPW2QFC/I8YDFPKLSF56wIeQOBizuwXAfHvW4wgJXWsOa
JtDSBoM9Jo3NPLxhiRSmyPZgdRcDALfWlww=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 648->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWstuQ3UisX9D1w+WIDQ9sYYIuRoRfsJmBLEdMnGAz
kxgzCKlBdgtZ8UtCnKDrR/EHUlohKjyxxTMR7sBIDzjClxi9WMMDzQ/Y/IMr
zDEAvnSJLSzQ7EcHBNMmstuwpEEEAAAe4ZWM
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 649->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPRBNjBro6BnQ5YtyAK1zQxMgKVzQ5Qv7AGqYMxJlBSA2y
W8iKXxLiBF0/ij+INQc5HrCYR1T6IhA2hOIEn1rk+MWmHl+YYwB86QJbWKDZ
jw5ISZtY7YEDAC3klw4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 650->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPRBNjBro6BizypPgHBaCJkRWuaHJ49eIKUwZUNcS4AVdY
YQtzot1CQpyg24PiD2LNwRKGuNINIbfgChu8cYIjnaCHE760hu529PSA7kd8
+uHxgsV+dEBK2kSPX1QAAIWjmI4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 651->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPRw6rfjR1DFjkSfEPCkATIytc0eTw+gNXmDKQYAaaGgZ7
TDYxZuCKG2LjBF0/ij+INQfdLzjYxLgFV/gRCgt8apHjF1daQw8L9PRAVJwi
q8diBjHmYQX47IEDAKycl88=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 652->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE+sOdDF0e0gxgwFdnhgzkPyDAtD8RIw52MxAlsPrD1xh
ykCCGWhqGOwx2YT8gmwfKfGFzx4Uf5AYntjikhj9hMwjxRyccUNiWKCnB6Li
FFk9FjFizMMG8NoDBwBs85gO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 653->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItEEzcFmBhZ7SDED3V6izEDyDwpA8xM54YouR8gfuMKUXDOwxQMh
vyCHB6H4wuUOdP3I7iI1PLG5mxj9hMwjxRxsbkaOG5xhjR6muNIKEWEJU8eA
5B7kuMKVhgilTbzuYgAAzYeaTQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 654->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYC
8lj14AHE6kemUcxFoolxO4YZWOwhxgwGdLeRYgaSf1AAmp/ICVcUN+IxA5ca
dL+Raga2eCDkF+TwIBRfxOpH8QcpcYvD3cToxxU/pIQFPr8j+wklzWETw6aX
gYFgfkGPe1iYoMc1illY/IQNYAtrTAAA4WCYSw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 655->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYC
8lj14AHE6kemUcxFoolxO4YZWOwhxgwGHHqIMgPJPygATYwod+AIT0JmMOBQ
Q6kZ2OKBUNwghwcuOVL1I7sLW7zj9A+esCCkH5u7MMKXWL040hYDFrOwimHT
iwzw2IsSt0jhghKmDJhieO3D4nYGrOoAPiiZSw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 656->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFoM9Qi26OLo9BM1hwGMekWZgDRc0MaLcgSM8CZmBoh9LmBJj
BjY1DDjUkBO/6GLYzEYPT3T/obOJSSNY7SZCP6GwwecHXPGDYR42fxMIC1xp
DW9YItnHgMxnQHULrjSCDWALa0wAAN5/mIo=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 657->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYa0+cWQz2CLW4/ECMe5DNwGoeCWGIAdD8RIw7cIUnoTBB0Y8l
TIkxA5sabGmCGDPQ1TFg0YsrveFSix4eRMUtDncTqx9f2ODzA750hi1uUPyN
JyzQ4xJbnOMKS5g6BiT3IMcVPvOwAixhjQkAHx+Wyw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 658->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYa0+8WQzYzEDyB6lmYDWPhDDEAGhiJOlHs5uQGbjCDWYWMWZg
U4MtTRBjBro6Bjzm4UqH6PrRw4OouMUTFmTpRw9fYtMGjrTFgMUsrGLY9CIB
YsISZh8DknuQ4woF4EgXuNSgm4kAAI3PmIo=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 659->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYa0+8WQzYzEDGZJiBzU3EhhsKQDKbaP/gCU9CZuAKN5hbiDGD
FDWkxi8DGk1seBIbTzjDBE9YENKP7l7kuMUmT2w6w+UGbGbhVIsjneDTD3M7
AzY3oQMc6QKXGgYk81ABANBqmck=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 660->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYc
bEJ6cAGi9DOg0sjiyGYT6w4MMXvs5hNjBjY3ERuGKABLOBETLtjCk5gwwWUP
ut8IuYNYNaTGL7JfyEkfsDDFFe844xZL+iI2XtHdCwc45In2F660RiBt4Usr
RKdNZDFs8jjMwwqwhDUmAACb8JoK
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 661->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYs
bAZCevAAQvbB9CPTKOYi0aSYhewHOCbS/8jq4G7DYT6+MEQBSGYTGzb4wpOQ
GbjsIcUMUtSQGr/Epi18+pHNICU8cYUFUekLWxjjkCfaXzjcgM0snGpxpBOC
aRNHOMLlsPgRV9rEUINVHQDslpoK
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 662->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxJxwyE
5PEAosxnQKVRzEWiSTEL2e1wTIR70NXB3YbDfHzhhQKQzCY2bPCFJyEzcNlD
ihnY1GCLB2xmMKCbgW43EiYnfSDrxRa3uNwJNwtHPBMbtyhhTMBegv7C4Qas
fsCjF1ec402bOMIROc7Q/Yg1bWJxLwM2dQwAQZ6XyQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 663->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojizMg0QTdgM0MNDcS6xcMN9hjdyO+cEMByOFErDl4wpNQ+KLb
jR7WxJiBTQ22eCDKDHS7kTChNAfTh6GfAZONyxzkNIorngnFB7q5WMOXCDOw
uR+bG7CGBXqY4EgrxKZN9LhADmv0MMObNgmEOQIAAMkelgg=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 664->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojizMg0cS6A5cfSHVPAxa7iTGDAVkvA8IMZL8QZQ6e8CQUvuh2
4/QbAXdg2EsgvHCagW43EiYnfSC7i5jwZCCgh5j4wJae0PUR4x9cdhJjFgOa
WqxpDY9f0NWjxwVyWKOHGd60icW9DNjUMQAAli2aSQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 665->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojizMg0aSYhc0PpLoHg02CGXD3wwByOBFpDr7wJBS+KHGCx2+E
3IFhLxFhjtUMHOFKTLzC1eKIC2LCEzk8sOlBDyd85uALP2LMwBVuGHGFx370
8EMHhNyPERboYUrAPKwAXxqEAwBITpqK
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 666->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTYxbMczAYg+x7sFgk2IGephgESPGHbjCk5AZ6Hajhykx
ZmBTgy1NEGMGrnAlJo1hi1sGNDMIugHNL+h60MOJ2HSCbi8x8YpLLUZcEREW
6HFJKE6xxT162iTGPKyAqDQMABsbmY4=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 667->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYc
bLx68ABi9SPTKObaE2cWgz0OM7DYQ6x7cLmJGDMwwsUe1S9ExQWO8CQmTNDt
Rg/TBiLMwKYGW5ogxgxc4UpMGsMWt9jCg5AZ+PSghxMp8UtJ+sAwD4u/8YUF
elwSilMM9fYMGGmTGPOwAgLhDgEAEpKYzw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 668->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFoM9phkMSBib+YTcg8tNZIULzC0khA2u8CQmTHDZA3NLAxFm
kKIGV3zgil/kMCEYDjjiBV88YTMDWxiSGq/o/sIWvqSkD1xxg24XrrBAj0tC
8YWh3p4BI22ixA8O87ACbGGOoRYAL5uZDg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 669->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpiNhLGZj1U/uhlY3ERWuCCZTax/MPQzYMoR8geuMCXGDFLU
kBq/cDEy0we6uwi6AU0PoXgmJX4pSR+44gZX2DCg6UWPS0LxhaHeHg0zoLoF
l3lYAbYwx1ALAFZsm4w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 670->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNvFgOaGQxQjG4PsWagm0esGVjDBck8ov2Drp8BU46QP3CFKTFm
kKKG1PhlQMLExAmGfgZMPrHhiU0PMfqJCRtSzMEXN8j+xhcW6HFJTLpAUY8c
F0h64XI4zMMKsKVBDLUA+zybyw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 671->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItEEzUEzg8EeoQ9djhgzsOkhJQxRgD0aJsYt2ACaHCF/4ApTYswg
RQ2p8YscFsTECYZ+Bkw+seGJTQ8p8YovbEgxB1/cIPsbX1igxyUcEBGWMHXY
0iVcDod5WAG2NIihFgA0ipqI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 672->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4gxINClmIbsN2Y1E+wWHHmxm4HIbCrBHw8S4BRtAk8PrDzxh
SowZpKghNX6Rw4KYOMHQj+QuUsMTm7uJ0U9M2JBiDr64wZWu0MMCPS4JhQVW
9cjiaG5BVofN7+gAVxpEAAAXyZvF
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 673->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWstuQ3Ui0X3CZh8UMBhx8FIBmNlFuwQbQ5PDqxROm
xJhBihpS45cBCRMTJxj6GTD5xKZRbHqIiQ9iwoYUc/DFDbZ0hS0sMNIaATfg
Us+ATR5NHcG0ie4ftHCHAADbbJrJ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 674->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWittwyOH1Cy7ziDQD7n4GhHnIZhNlDjaAJodXL54w
JcYMUtSQGr8MaDSx4YnLXQTdQEAPUfGB5l5sYUOMObjUIscNrrBBDwuMtEbA
DchxgcLGJo9mLsG0ie4mtHCHAAAZ7JpL
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 675->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpwPxdjkiDEDm5sI6scWLjC3IPmJkBkY+hkwzcarH0+YEmMG
KWoImoEermg0seGJy12khCcx8UzILSjxi2YHMebgSlsMOOzCFRYYaY2AG+D6
0NSjpxcMgCNdoAP0uGXAUAsASgyYyw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 676->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPxTxSzMDmJoL6sYWLPSabpHBFcz+hMGGwx24PKWaQoobU
+GVAo4kNT1zuIiU8iYlnQm7BFTbEmoMrbTHgsAtXWGCkNSzm4IoLdPUobHRA
StpET4coAACWLJsK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 677->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYC
8lj14AHE6kemsYmTahY2/4ABEf5HNgOXm4gJQxRgj8kmxh3YwhNZDq9+HO5H
dx8xcYsvnRAMUwZUGj2MSAlPXHFJlDkMmGaQop+YsCEUFvj8juEnIvRipDUs
5uDSj6weJV1hSXu4/I7NTnQ/oAIAwqabCA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 678->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzkd3JyH9aGbgchPJ4WKPySbGHbjCk1CYMOBQgxwGxIQrhr04
7CI1frGJkaofPW6JjQ9i4pmU+CUlLJDV4IsbQmGN7A+UtIbFHFz6kdWjuwEd
4E2feOzENAsA4HWcig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 679->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgcoY
HyBWPzKNTZxUs+B8PHJY9aOpw2ceSeGCZDa6HfjcgQHQzCbGbgxxIs3Apgbm
D1LCBFv8IocHOekD2R/ExC1yeBITz9j0EwobYtMHAw47MfxEhF70uCQUpoTU
I4uhhxmu9IVXHbpaBgAp65rJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 680->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAQvG
JU4MxgeI1Y9MYxMnxiwGbGZgMY8UM/CZR1K4IJlNjH/Q1SKbQ0yY4LKHJDOw
qIH5g5QwgfufAVMPsXGCrhbZH8SYg+4XQvGMyw3YwpjU9IHL7xh+IkIvelyi
+wuffmT1sHjFEMPiR/T0xYDmdmSaAV0tAwAo3JeI
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 681->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgkF5cgCj9DKg0NnFizGLAZgaS38gxA+4GMsIJBSC5hRj/4AxTNLOJsRtD
nEgzsKlBDk9i0w7c/wyYeoiNE3S1GO5C9yee8MQXzwTdgCdsyEkf6P5jIGAW
eligxyUDFnNw6UdXj8JGA/jSF7qdyDSmWQC5qZYI
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 682->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgkF5cgCj9DKg0NnFizGLAZgaS38gxA+4GMsIJBSC5hRj/4AxTNLOJsRtD
nEgzsKlBDk/0MMJrBnq4khgn6Gox3EWMOUh6cMUzITfgCxty0ge6/wjpRw8L
9LhE9xc+/cjqUdImlrSHL32h28uAZBemWQARrJgK
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 683->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNvFgM2M7DYQ4oZ+MwjKVyQzCbGP+hqkc1BNpsYu7GFKTFmkKKG
oBno4UpinKCrRXcXUeYg6SEUz6TELyXpA91/hPSjhwV6XKL7C59+dPUM9qhi
yGkQX/rCZg7cPAy1ADSQmss=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 684->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPxTy8+tHMwGceSeFij4SJ8A8Dun4kcxqIMANXHJBiBilq
CJqBHq5YwhpfWKDbg+4uosxB0kMongm5BVfYEJs+kO1HpgnpRw8LBjTzkNMZ
If3o8YJiBhrAl76wmYMexwgAAJ6tmQo=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 685->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFpyPRw6rfjR1+MwjOVyQzCfkFgZs+hkQ9hMyA1cckGIGKWpI
jV/ksCAmTrDqxxNPhPxCjn5s6Qlb+JKSPtBpQukLPSzQ4xIerkToxxovMDPQ
AL70hawHI4ww1AIAlXSbjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 686->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNplj0qjc18rPrR1GG4iRg34AoXND+RFa5ocoT8gawHOUyJMYOQ
GmRzSI1fBixhTUx4EhtPxPiFVP3Y0hO6PmLNwRYu6HFFTFhgpDWksCUqbWJL
E1jSHlFpE81NGOkQDAAr25mM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 687->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2SWPSqNzXx8fiHGPHxmwN2PDND8RIxfsJmBLEdUnGAJ
U2LMwKaGwR67P0mNX2xixIQnoXjC5k6cfsGjn5BbcIUfseaghwFy2iAlLDDS
mj0CE5U2saUJLGmPYNrE5ib0dAgGAKiRl8s=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 688->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNplj0qjc7GqR/NDHzm4TMDa7ig+YmscEWTI0YvtjAlxgxsarD5
nxgz0NVhEyMmPElxF0G/4GAT4xZc4UesOehhgJw2SAkLjLRGwBxc6mFyKGYg
AYJpE90cZIwCACoOl80=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 689->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxJxwyE
5PEAosxnQKVRzLUn0yx7TJqQP+DqGAibR6xbUACan0jWz4DkDgJhgisOSDED
xRws/kc2h9T4JVYvTv0M2M0jxi/o5hLrDkLmkZM+kOMEOZzxpU+s6ZKBOHOw
qseSPtABwbSJ5ibk9IIKAIO2mMs=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 690->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2uM3iwGXWfaYNLpaXOYh24XLPHz6cYYLmp/IClc0OWL0YgtTYsxA
MQeb/9DCiGCcMBDWizNOcMQLSXGLJQyxmUcsRjaLHHPg4YLHPFzpC6teBgaU
NEZMWKCHH4oZDKjq8KZNNDchpxdUAABm2ZiI
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 691->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItEkmWWPSqOzcepHcwc28/CZgyyPAdD8RFa4oskRoxdbmBJjBoo5
OPyKLd6IiV9i9SKHKXq8EBsnuPyCbh4x6QtXWJJjDjxc8JiHL8yxpjVizUGK
ewZkzICFxuFPbAA9PlDMBQMAdXWYBg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 692->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItFEu8UeoR5ZH6lmoLiNBDOQ9aIAND+RFa5ocsToxec3Qu7ApwY9
jEiJX2L14lKL4g8SzEH3P7obicXoZpFjDjxcsPiJqLSFLa0Raw5SvDIgY1yA
mLSJzTwMtQAExZfJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 693->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTGLwR6CG5BodDYxZmB1EzH6cYULmhhZ4YomR4xefH4j5A58anCF
ETHxS6xeXGpR/EGsOVjCEN2NxGIGNDeQYw48XLD4iai0hS2t4TGHwR7T/ehm
4QJEpU0GNPOxmgkAfFOYjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 694->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAaYWym5AotHZxJqB4SYizcAaLmhiZIUrmhwxejHEiTSDkBpk
c0iNX1zhS6w9yP4gxg0NWOzDxSYGM2BxA6nmwMMFh58Ipi1saQ2POQz2mO5H
NwsF4Il/XAAjfjHUAgBcvZgK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 695->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAVmPPSqNzibGjAYC5uEzA2u4oImRFa5ocsToxRAn0gxS1JAa
v8jhQUp4osQTCW7Alj7Q3UNIPzaz0NMDKeagpyls5uFNW9jSGh5z0MMLOV5g
ZuECRKVNLPGDaSYANtKYyw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 696->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAVmPPSqNzXxCZjQQMA+fGVjDxR6VJjdciQkTXHEAs5/YcEV2
O6H4IyV+cYUDNnsYsNjDQGHc4opnUjC2cCHWHGT3o8QpKWkLW1rDYw56eKHb
y4BsDhogJW0i+w/TTAA3W5dN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 697->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTbLHpXGZj5W/Wjq8JmHzwys4YImRm64EhMmDDjUwNxBrhnY/E+M
GejqkMMDW9jhCk8UcymIW1zxTApGDktsZuLyB7r7UeKUlLSFLa0Raw5SvCKb
hQuQkjZR3ImhFgD5oZbN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 698->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFgO6WUgY3R5C5iCrQzavAc08YtyCAtDEyA1XZDlC/sAVpsSY
gU0Ngz12fxITnujhih7WxMYtuj/IiVuMeCYiXokJG0JhgaIWW3ohJW1hS2vE
moPkdqzmoAGS0iYyxgAAfJ2VTQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 699->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNpFhJGl8OrH00dAw6arHBBEyM3XJHlCPkDV5gSYwY2NQz2mGxi
zEBXhxwexMQJLv3Exi08PTBg10OMO4gJG0Jxgk0tSnyQEBYM6HxSwhTJ7djS
BDogKW2ihTcqAABP4pbP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 700->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4oTkwPJ4AD59yPqRaRRz7ck0Cwmjy+HVj6aOAQdNrFtQAJoYMe7AFaaEzMBl
D4rfiHEHmhoGe0w2UWZgCVd0MULpD8PtJMQttnSEi01q/KL7iSi9SHYi+4+Q
fnS1DGhuITpM0dQjxwc2gC99oatjQMYYAACXjJTP
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 701->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgfIBY/cg0irn2ZJqFxV/EmMGAZC+6OQxEmoEzXNDE8LoBV7iimU2M3djC
hxgzsKlhsMdkE2UGNrtJiBMMt5MYt9jSES42UW7BETYMRJiBrB/df4T0o6tF
Tw8MxJqDRT3ONIclbPCpQwkjDLUAIV2Tjg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 702->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFgO6WWji2MzHZQ7MXnQ9DESagTNc0MTwugFdP1o4EGUGFjXo
fiMYrmhqGOwx2USZgR6WDMTpxWUPsj+IcgM2v+Bgkxq/6PFGlF7kMMDhJ0Jh
wYDORwpnguZgUY+R5pAATv1Y1DHYo/oRFQAAhHWUkA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 703->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNplj0qjc18rPqR7EU3j4FIM4gJF3zmINuFSx9RZmBRg+43Qv5B
V8Ngj8kmygw0dcj+ICZO0NUyoLuFkBuw+YUBu9mkxi8uNxHjHnT/EdKPrhY9
LolNo9jUE0pzWPXjUYfdPACLO5VR
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 704->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNplj0qjc18rPrR1GFzEzXChZA5DPj0ExEmuNSg+42gO9DUMNhj
sokxA5vdpMQJVreTEC/YwgPZDGLcQUzYMBCrFzkMcPiJUFgwoPMZGDDSL7Z4
w6ceWQwZ4PI7TnPQwhwBAGoXl5A=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 705->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwJYwYi
1KCoxwOI1Y9Mo5iLRBPjZgwzsJhHyBxkM7C5iRrhQow5OAGSHCF/oPsZmU+M
O9DVMNhjsokxA10dNjFS4habv/DqxeYXBuxmkxq/KGFOrF4sYYDuJ0JhwYDO
Z2AgPr/gUI8ihgTwpk00/yCHBSYAABIDlU8=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 706->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
bGIwPkCsfmQaxVx74sxisMdhBhZ7CJmDrA6bm8gOFzQxssOViDBBsQtLmDYQ
YQY2NdjSCVFmYAlXdDFS4habv4iJV1xmEOMOYsKGgZAeLOmMAYt7iAkLBnQ+
UpgSNAeLehQ2GsCbNvGEBSYAALLWk88=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 707->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwJYwYi
1KCoxwOI1Y9Mo5hrT55Z2PxCjhnY3ER2uKCJkRWu9sSFCYpdWMK0gQgzsKlh
sMdkE2MGtnBlIEIvLnuw+YuQGRh+YcBuNqnxi2IHsX5BDhccfiImLNDjkugw
xaKewR5VDBkQlTaxhAUmAADyupdP
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 708->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwJYwYi
1KCoxwOI1Y9Mo5hrT55Z2PxCjhn4zCM5XNDEyA1XZDl8cQi3D0uYEmMGNjUM
9phsYszAFa5EhQOOeCElbtHTEXrYEOMOnPGDFubE+AXFXzj8RExYoMclA5Ic
If1w9USmOWLTJlZ74AAAdU2YzQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 709->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj3EC
EvQj0yjmIplPillwPh45rPrR1GEzjxR/oYcHMsDnBnzhiiyH1x9IYYgepsSY
gU0NAw534vIDrvhFDg9i4gSXfmLjFj0dEYpnkuIXR9rB6xc0NjY/ERMWGGmF
gBuwqscSRshmYY1fHABXmCMAALcIlow=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 710->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGCcgQT8yjWIukvmkmIXNf8SYwYBDDwMW80gOFzQxfG7AF67IcoT8gR4P
yHxiwhVdDTb/E2MGujoGIvXiUosrnvCGB3L4oZtHhDuICRti3IHufpT4IDEs
MNIKsWGKrB6bOBrAqR+LOgZkjAEAMgqYig==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 711->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj3EC
EvQj0yjmIplPillwPhbz8OpHMwPuNhzm4zIDa7igiZGsH0kfMWZgU4McBsSE
K7oaBhzuJDV+yQ1PFP/hiXdC4YErnknB2MKGGHegux8lPkgMC4y0Qqw5yOqx
iaMBnPqR7WRA9RsDVvMAwVSXDA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 712->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjWKuPXlmofuPAck8vPqRMIrbcJiPywxC4YLPHEL6keXw+gOL
GuQwIMcMBhzuJDV+SQlPbHHLgO4WQm5A8wsDunkkuAMlLNHdRKQ5yGpR4oOE
tIU1rRBrDrJ6ZHNwpDuc+rGoQzYTEwAAAviVDg==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 713->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjU2cVLPQ/ceARQ6rfrQwweUmQmYQChcwIFM/MWHCgEMNsr3k
mMGAw52kxi/MHcSEJ7awRw8/gm5A8wu63aS4A8UNDJh2kOoflPggIW3hTCv2
RJiDppbBHtUP6ACnfizq8JsFAClqlpA=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 714->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGps4MWYxYDMDjxxOM9DcwIBmDjFmILsbDtDFSNWPFA6E
wgRXHCDbS9AMHGrQw4JQuCK7GSNcCejFZg56PBFjDrpf0PUQox89/tHDhhT/
IKtFiQ8S0hbOtEJEOkVXS0yawxWe2MIWQw0cAADOeJQM
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 715->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGps4MWYxYDMDjxxOM7C5gYTwYkDSiwLQxUjVjxQOhMIE
Vxwg20vQDAJqkM0hNX6Rw4PodIZFP0lxixx+WMwjKk5xmEesOehhixHfJKQt
nGmFiHTKYI9dLS6AL32hq2NAxhgAAKzalY4=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 716->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxIkxiwGbGVjMI9Y9KG7AYh4+dyC7Gw7QxIhxB64wJWQGAw41
MHdQYgY2f5Iav8jhQUoaw+oPIs1BCT8c8UwwTnGYR3Iaw5a2GBgIpi/0MMea
1ohIp7jU4gKkpE24/7CqAwAiT5fP
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 717->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxBlIcAe6GLp5xLoHxQ04zMflDri7kQGaGDHuwGYGshwxcYJh
JoVmIIcHMeEKD0MGTHcQGye49OOKd3zhiU0Pse5AT0/YwpdU/6DEBwlpC19a
ITpt4fATcvxgcxcugJ4+MAEAp46ZDg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 718->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxBmIdQu6GXjkiDED7gYkfxITHnB3IwM0MWLcgdUMe8Jm4FKD
HJbEuAOfGmRzSI1f5PAgOp1h0Y/sV2LDE5seYt2Bnp6Q3UGKOehpC91PpIQF
ultICQsGewZMP2FJe0SlTeTwREuDCAAAfFKazQ==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 719->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMKiNXPgEojizPYk2cWuh8YsMjh8i+yOrjbiDQD3Rz08EAGxPgFqxn2hM3A
pQY5LIlxBz412MKL2PhFDg9SwhOrP9DiiZjwQLebWHcgm48cJ6SYg8vN6GYR
E6bY3EKUX5DVE0pzWMwjpA49nSIAAD0Elk0=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 720->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMFSNCPTKOYa0+eWeh+YMAiR4wZcLeRYAYDkl708EAGZIUrmhw+N2BTQ4oZ
hNQgm0Nq/CKHB9HpEYt+YuMWW3jgYpPiHmR3kGoOPFyw+ImUsECPJ2LcgOx2
dPdjA0SlTeTwRAtzBAAAz0uajg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 721->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMFSNCPTKOYi2Q+KWah+4EBixwxZsDdRqIZWMMFTYzccEWWwxd32NyLHC/E
uAOfGmRzSI1fcsMTqz+IcQMWv+Bikxq/+NIfITehhwUDCXZjTStEugFFPZFp
jti0iZ42UAEA+aGbTQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 722->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj3EC
EvQj0yjmIplP0Bxks+xRaWzmEzKjAc08dDmSwwVNjNxwRZbD6w88YUq0GTjU
kBKuyG7GFrekhCdWfxAbtwyYZpCSNgiZR6o5KO5H8xOxYYEel6SGBQOS/ejx
ggxISZsYfkIBADIfmU0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 723->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNvFgOyWfaoNDbz8ZnBgO42EszAGS5oYuSGK7IcXn/gcD+DPXFm
4FNDSrgiuxlb3JISnuj60eOdFL/gYpMav7jcSExaQ48rBhLsxohXEsIUXT16
+kAHpKRNrO6CAwD9A5lP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 724->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4oQwAwzjAESZwYBKYxMnxiwGbGZgMY8UM+BuINEMZHfDAZoYMeGCK0wJmYEc
Lxhm2hNnBj41MPOJCRNkv+MTIzadYPiD2HhhwDSDlLRBTNiQ5B8sccVAgt24
3EJKWKDbiyKGBEhJmxh+QgEATiWZjg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 725->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgkF5cgCj9DKg0NnFSzcLmL3LMgLuBBDOQ1aIANDFi3IErTAmZwYBDDcwd
xIYrstsxzCcyTJD9jk+MUDrEph/Zr8SGJ754JgVjDV9i9aKlLXh8kWA3LrcQ
Yw5yvGKkCXQaS9jgArjSIAIAAJVXmY4=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 726->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgkF5cgCj9DKg0NnFSzcLmL2LMYEBTx4BOE2kGsrsxAAFzCOknJkwY0NSg
mGlPnBkobsBmPpFhguxmgnFOZNzCwxFLnBETHrjcQwrGFn7YwolQOkOPG3xh
gMu9KHGNJb7wxStGmkCnsYQNLoArzBEAAN4Sl80=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 727->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzscjh1U/mjoGdJqEMMQJiHULnjAlFCYMONTA7Cc2XJHdTG64
IruZYJwTGbfwcMQSZ8SGBy42yfGLbAexepHDAIufiLEbm1vQ45iQ27GmCSxp
j5S0iS3MEQAA7W6Zzw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 728->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzscjh1U/mjq4G0gwg2C4EOsWPGFKKEwYcKiB2U9suBKrBpv9
+OKXlHDAZg9cPylxy4BpBilpg6B5JJiDrBYlPsgIC3S3EGMOLvXI8YIrDRFK
m9jSIAIAALd4nBA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 729->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzkeiiTEDpo4Bl3lEmkEoXIgyBxtAkyPoDyzuJ9YMUtSQGr/Y
xEiJW5g/cMUTMX5BDwti3YHTPBLMQVbLgMU9pIQFuluIMQddPd40h8VPhNTB
4gYTAACXyJsS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 730->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxIkxiwGbGXjk8LmHAQsbmxtxuQPZ3XCAJkaUO7CYQUyYMOBQ
Q6kZDEj+IzZMYPIo5mARIzadkB0v6H5BCwti3YHLPFLMQU6PyDR62BITFuhu
wWUOA5rduOIFG8CZNu2xq2Owx5SDAADkpZmQ
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 731->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE+sOdDF0e4hxDwOymSSawYBsDjJA8xNR7sBiBrIc3rBA
DltsfiMiXNHVoIcHMWECdwMDfjFi0wm6P4hyA5pfGNDMIMUduMKGpDRmj2k3
up+IDQt0t+ByA3p4wezDCFcsAGfatMdUx4BkHyYAAOHcmgw=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 732->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE+sOdDF0e4h1D7p+YsxgQNKDAdDEiHEHVjNwhAkDFnfg
CtMGHGbgcgM2/xEdJgxYwhWLGEnxguwPYuMF3S9oYUGsO3CFDUlpDDmdYHEP
Pn3Y7EF2Cy43MGBRjx52yGLIAF94oqtDjxdUAABTx5nL
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 733->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE3IDVjPQ3EisexjQ9KO7lVi3oAA0MaLcgcUMZDm8cYLm
Fwy/EROuaGpg5pISJjB5FHOQwoPodIZFP7Fxiy0doYcFse7AFTZEhQWWcGTA
4h5SwgLdLbjcgJEOkOIAPU2gA6x+x6Iew48YAABzypiM
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 734->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmk2IWstuQ3UisGQxo+nGZjys84OYgAzQxotyBxQxkOaLi
BJffiHAHuhoGMsIE2e/4xEiJW2R3EGMOtnSEHhbEugNX2BAVFjjcj+4eYsMC
W1ziMocBjY1NPQrAk0bQ5VHsR8YYAADGWJgK
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 735->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE3IDVjPQ3EiKe5D14+ITcgsKQBMjxh3YzECWIypOsIQp
MWZgU8OALUyIMQM9XLGIkRov6P4iNo1iNY8Ed+AKG2Ldge5+lPggMSywxSUx
fkEOe2xpAjl+sJmHC2D4DQMAAIl5moo=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 736->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE3IDVjPQ3EiKe5D14+ITcgsKQBMjxh3YzECWIyZOsIUp
MWZgU4PN/0SZgR6uWMRIihcGVLfgMgddDboZxPqBmLAhKiyQ4wdbeiExLLDF
JTF+QVePbg46ICptMmDxJwYAAFtem00=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 737->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgcoY
ZCYuQJR+BlQamzipZiG7DdmNpJrBgIMmGB7YwgRNjBh3YDODmDBhwKGGFDOw
qcHmf2LMwBaupMQJhn4s/iI2jRJjHrHuIdUd6P5HSVtIcUNsWGCLS2LcgK4e
3Rx0QFTaRA8LrOoAibScjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 738->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgcoY
HyBWPzKNTZxUs+B8JJoYvzPA7MOiv4EUM7CFC5oYUe7AZgYRYYJLDYrfiHEH
mhps/icUJsjxiBFGJKYzbP7AFu9E+QUtLIh1By7ziE0fyP5HSVsMJOhnwKIX
SzgT43aYvQzIbDSASz/p6gCgZpsI
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 739->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jESTULzEbCDUg0Xv1YzMBGEzQDW7igiZEVrmhyhPyBLUyJNQObGmz+
JxQm2OIXPW5IjlsGVL2khCeusCA2XnGZR2z6wJm2GIjXD1OLLS5JDQs4jWwu
GsClH5s6ZH9hAgCGopsI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 740->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLYxIkxiwHNDAYoRjePIjOIDA9kd8OBPSpNTLhgM4OYMGHAoYYU
M7CpweZ/QmGCLX4ZkDDR6YwBzV2kxi26X9DCgig34DGP2PSBkU5w+ImoMMXi
FlLDAtksmBvQAS792NQh+wsTAADpapzH
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 741->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGps4MWYxoJnBgOQ/dDm8ZhDgE2MGsrvhAE2MmHDBZgYx
YcKAQw0pZmBTQ056wRa/DEhuJNUcfGmFJL+ghQVRbsBjHqnhw4BOMxCvH2u8
MhBvDrp6lDSDTmMJG1wA3V+YAACbiJzH
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 742->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
uBoC+pFpbOLEuJ0Bmxl45HCagYOPLofPDKzhguQOotyCDaDJEaMXQ5xIM7Cp
Icb/xMQvcliQag6+tEKSX9DCgig34DGP1PBhQKcZiNePNV6xhDMxYQGnkdyA
QmMxDxdA9x8mAABmDZ2I
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 743->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAZsZeORwmkGAT4wZWMMFyR1EuQVPmBIyA1ccwNxBbLiiq8EW
FoTCBNnN6O4gJhzQzcFgExu3yOGHJSyIcgOW+MUW98SahZFeyAgLDL8RExbI
8YImxoBkHq40ggughxMmAACV2JtJ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 744->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jEiTGLAZsZeORwmoGDjy6Hzwys4YJkBlFuwROmhMIEVxzA3EFsuCK7
Hdlv2PxLSvwihwcp6Qwrm8TwRNbDgMU8YtMH1vAlwz8o5lGiF0s44/UHuhl4
0hy6u3AB9HDABABZLZpJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 745->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj3EC
EvQj0yjmIplP0BxsZmCxhxQzGJDMYEAzD58ZWMMFyQyi3IIDIMsR8geuMCXG
DGxqsPmfUJhgi1+4GInhiS0uSQ1PlLAlIW1gjV8SwoLBHrub8ZlHMExx+I0Y
P2CYQSDNEZs24WZhVQcA6HOaiA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 746->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj3EC
YvUjmYNhLpL5xJiDYQYeOWLMYEAyowGNTYx/0MODgRS34ADIctjsRdeLLUxx
mYHLDfj8TyhMkN2MT4yU9IEcL6SGJ0r44Eh7xGBk/cSEBXo6grsFj3mE7MYW
lySHBVqYYgNEpU10/2FVBwAle5nH
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 747->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gSj+SOejmIptPjDkYZuCRw2kGnvAhJryQ/YMCkMwnyi14wpRQmOCK
A5g7iA1XotQQ4Q/0+MUmRkr6QI4nUsMTJXxIiFes5pEQFujpCj0MsJlHyG5s
cUlsmMLVo4lhA0SlTbS4wW4eANjMmsc=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 748->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gSj+SOejmIptPyAwGbGZgMY+gOQzY9RMbXsj+QQH2qDS54UpMmKDb
iyJuT5wZpIQ9ITPQwx+bGCnpA5u/iA1PlPAhQT9W80gICwY0NnoYYDOPWLuR
/UNyWCBjHICotGlPjHkAt1iZDA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 749->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phgxcijq8ACi9COZg24usvnEmINhBh45YsxADwNiwwRruNij0uSGKzFhgm4v
irg9cWYQrYYIf6DHLzYxUtIHNn8RG54o4UOCfqzmkRAWGGoZsNPk2I3sH5LD
Ai2MsQGi0qY9qnkMWNUBAExnmow=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 750->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phgxcijq8ACi9COZg24usvnEugWXH4gxgwFNHXoYEBsmWMPFHpUmO1xxhAm6
X5HVo4ijqSHGDcTEH6E4QQlXLGKkpA+MeCEhPFHChwT9xIQNKeaguAUtboiy
G4/fiE5b2NIElrRHVNpEihs4xgAAmN+aTQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 751->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQMa
TQ7GB4jSj2QOurnI5hPrFmxmY5Mjxgz0cCElnDCAPSpNbrgSEybo9qKI2xNn
BtFqiPEHergyoNKkpg90faSEJ8xMfOaREr+kugNXGKDHFb5wxhqvpIQpUtqA
02hxhQyISptI7kQxDwUAAHVbm00=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 752->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQMa
TQ4GAxiNDIjVj2QOPnNJMQvGZkAzj5BeBjR16H4g1h1w96OFBzpNkn4kPYTC
BCU+sIQpMWbgU4MezsSmD/RwJDU8sfmDWHOQ/YLNPYT8QUzYkGIGsluw+omI
MMXqNyL8gpw24LQ9FjFc8Y8NoKc/rOoA3leZhg==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 753->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQMa
TQ5mgGEsgFj9DfaY6sHAnjyzkN3VgMN8fP7ApYdYd8DdjwzQ/USqfiQ9hMIE
VxyQYgbRaojxB45wJTU8sfqDSHOQ/YLNPYT8QUzYkGIGsluwuQGfWRhqkf1G
hF+wqUdOl+iAqLTJgOp2bOYwMAAAF7KZig==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 754->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phgxcujqwBgLIFZ/gz2mejCwJ88sbHxizGBAU4fhJiLDBO5+ZIAmRrJ+JH2E
zMBQjxamxJhBtBpi/IEjXIkJB2xxgeIPIsxBT0fY3ENK3KKEMbIdRIYTsv3Y
4oYou3HEEzHmoKtHCSMsaY+UtIkcFpgAAOnvmMs=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 755->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGAxgNBogSj+SOejmNtgTbxYDFv8wYDGPoBkMuPWQEl4YAE2MZP1I+giZ
gcsemDuIDVei1JCQPvCJERMeWP1BbNwihx8e88iJX2LCggGNjewWUt2ANV4Z
iDcHXT2ym9DTKbawxQVQ/IdVHQDW9ppN
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 756->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGps4qWZh8x8xZjCgqQMDMsMLA6CJkawfyS2EzMCmB90/
xLiDKDXE+ANHuBITDtjijwHJXmLNQfYLur/Qw4nU+CUmLNDTEdwtZLgBq14G
4s1BThtwGi1esPkPb9pECwds5jAwAADXEpgO
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 757->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYc
bEJ6cAGi9DOg0tjESTULq3+I9D+yOjAgMUwYkPUiAzQxYvyC1QwiwgSbHnT/
EOMOotQQ4w8s4UpsnGCLPwY0e4lxI7Jf0P1FijswwpjE9IGezrDFDbFhgS0u
iTEHJW0woLoJOaxwxT8ugB4/mAAAQviYTQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 758->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuzxYwYC
8lj14AHE6kemsYkT63YMM7CYR4oZYEBi+DAg60UGaGLkhisxYYJiF7qb7Ek3
g5I0g+xmQnFOjDlwt5Eat3jCjxR3YMQPifrQ0xm2uCE2LLDFJSlhwYBkLwob
DZCSNpHjBxMAADErmY4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 759->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2hNnFoM9Qi26OLo9BM1hwHQDNvMoCRei3IJHHyEz0MONAclMdPOJ
cQOhMCM1frGJEZtOsMYLCeGJzV+kuAMjfkjUh57OkOOGWLNgahnQ3EJqWDCg
2YsihgSISpvIfkNLgwgAAIuimk8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 760->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTdAN2MxAcyOxfkF3A7pbiQk3QoDccEU2mxi96G5qsCfO
DKLVkBG/2MSITSfo8UJ03KKFB4oZJLgD3TxC/scZP9jSCyl2Y0lrxJqD7Hb0
cMCW7gimSzT/4DKHgQEAmcmXjA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 761->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTYpZ6H5gwCKHzy/obsDFxxduhAC54YpsNjF6cYUPMe4g
Sg0Z8YtNjJS4RY4HouMWOfxwuIcUDAck6oPbjyW9kGQ3lrSGHjbEuB09TLAB
YtIlenxgVwcA8wuZDg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 762->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhmMEe
wcaFkdXjVQdViw0QpZ8Bu31gYE+8WQzYzMAjR8gMBiQ3oMgTYQbc/XgAMeGC
FeAIEwx3YlPDgGk+MW7Al24IhgcDDrtJSGO49JOSVpH9gm43Ke7AiB8S9WFL
Z6S6AR5+2PxGwE3IaQPdHchiyICotIluPlZ1AAS2lc8=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 763->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
Z4CqxQZIsQddPalmMWAzA48cMWaAAbo8EWZgcz8cEOsWAvrxmYEr3DD8RsAd
RKkhI35JCQecbkcLa2LDE1c8E+sOQmFMlF57VLeQ6gZsepHDGV+cIKcfdHcg
i+HzH1aAbj5WdQDBDJdR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 764->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
Z4CqxQZIsQddPUVmIbsNyY3E+gXFDSSGCYM9dvcz2KPSxPgFV5gSChMGHGqQ
/UNMuGI1A4d/SYlfUsIBW9iTFS/I4YfFPGLiFFf8EusHbOmMgUg3YA1TbH5D
Cxt8aQPdHchi+PyHFSCbj24PHAAA0AeWzw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 765->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
xwdIsQddPRjYk2mWPYJmsMduPlb9aOpgbiA1TLCGC5qfyA1XZDlC/sAWpujm
E+MGdLPx8YmJX1LCAafbSYwXfOFHMBwIxA+xfsCWzkhJnxhhistvRNiNLQ6Q
xfD5DxeAm49uDxwAALjMmNE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 766->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJx8Sq
Z4CqxQZIsQddPRjYk2kWsttI8A8DmjqYG0gNE7hePIBc/chyxMQJrjglxh1Y
zcBiF6nxCwtXUsMTW7wQaw6+8CPFHdjih2S92NIqGWHBgOYWbGkWPZ4YkNMH
jjSBLIfNXbgAivlY1QEA7CGYUQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 767->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMFiNLPgEojiyObTZJZyG4j0j8wtch2wd1gj92N+MwlBAiFOz59xJiBTQ2G
3wiEK1FqyIhfeLgSMBuv29H8SshNKOGHxTxi3YEtfknWa4/qFnQ/ERsW6GkF
nzkMWOzHFg5wgCsNYUubaG5iwKWOAQDkaZbN
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 768->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTKOYa0+mWUh+YLDHbj4hM5D14zMDVzgRAoTCHZ8+YsxAUY/Nb0SE
K1FqyIhfMCAhTnDpxyaHy034wo8Ud2CLX5L1IocLDj8RtBuf3wjEExzgSBPI
ctjCFgMg+wMZYwAAUzWXTw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 769->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYi
xbDqxQOI1Y9Mo5hrT7xZDNjMQPIHqe5B1k+qGYTChSj/4NFHyAz0cEN2P4M9
cWYQrYYYf6CHKwNxenHGCwOqXlLCEyVsyYhXbPFDsl4sYYDuJ2LCFKffCMQT
sv+R3YEL4EpbKOYgy+M0DwAbmZbP
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 770->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYi
xbDqxQOI1Y9Mo5hrT5xZDPYItdjEsZmP0xwGLObiMJ/ccIH5jSz9OMKEAYs/
4OrRwrQBhxk43YAnfRDjDxQaDZMSnuhpA5scvnhFdgt6WBDrDmzxQ7JetPDA
5ieCdmNxC3L44oovdP9jjRc0gCssUcyxJ2wOAwMAVXOSSw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 771->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYi
xXDpxQWI0s+ASiOLI5tNrDswxEjwD7oZDOiYSD/B3Y8PkKufiDBBV8OAbCaa
+US5gYJ0AncDjnAlJTzR0wY2OaLCA91fBPQTih+S9SKHCw4/EbQbi1vwxQc2
9ejuQBbD5z8MgG4OWpgjAADtsJVL
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 772->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYi
xXDpxQWI0s+ASiOLI5tNrDswxNDMI8UMBnRMpJ/g9uEDZOpHliMmTrCFKTFm
YFNDTjpBdjO2cCUlPLH5A1vaIRQeDGhmENKPN35I1IeezlDigxS7ccQTrnDF
ph7ZHcjmogNcYQlXjyt+MQAAoACWyQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 773->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyxYwYc
4sRgkF5cgCj9DKg0sjiy2aSYheI2NPOI8Qu6fgYscsS4BQWgiZGsH0kfITNw
uRfFb0S4A10NtvAjGKYMWOxGixtS4xY9Lgn6A80vGPFMRHzgjB8S9aHbjxxX
xJqFzf8wMVxm4FSPJVzRATHpEsUctDBHAADVMZiK
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 774->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwwk
qMMKiDQL5i5098HMgAGi3IJuBpLd6G7C5xd0/QxY5IhxC3p4kOIfXKCBCDOQ
ww5X+BDjDnQ12OKUYJgyYLEbLW5IjVv0uCToDzS/YMQzEfGBM35I1IduP0q6
IMVuHG7BFa441SOZhSKGBIhJl9jiBxMAAFGvloo=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 775->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj3EC
ZDUE9CPTKOYimU+sWxrQ7GXAIYdVP5o6BnRMpBlYwwXJDKLMwQEaiDADOexw
hQ8x7kBXgy1O8cUtrvhFDlNS0hm6/3DFO654hbsFzQxi4gNn/JCoDz2dMWBx
D1F243ALrnDFqR4tHLABYtIlsjoUs1EAANe5lgw=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 776->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
uBoC+pFpFHPtMc0i5BYUPpLdxJjBgKYO7gYscvjMwBouSGbgMwenfgJmIIcx
ctjhCh+YGmLiFqsdRMQtLrcg+4WUdIbL7YTiBT3MGNDMIKQfZxgTEYaE0hlK
fJMQFgzoepH9RmS8YgsH5LBCj3+c6RJNHdwtGAAA2y+VDA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 777->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipavABQmbD9CPTKObak2kWktvhmAgz0NXB3IBNjlB4YQAkM/CZg1M/KWYg
hR228EH3G6G4xZYWGLCIERu/yPFCTLwScjuheEEPMwY0Mwjpx+p/BlQzSMHI
fkeJbxLCggFdLwOm2YTiFTkcMMSQAFa9WAB62GICAD3Xk8s=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 778->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGlkc2WxSzEJxGxIm2i9obkCWIzpc0AFaWOFzA1b9pJiB
FHa4wgfZb4T8gOE2NDap8UtKnBDjdkLxgh5m2OKZKDdgMY8UP+Ayi9j4wIhf
LPFETLiipCdkGp2NFv8NWOTQ1WE1Ew4Au+GUyQ==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 779->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjWIuEk2KWcj+Q8YE9aOZgWw3uhxZ4YIkjs8NePUTYwaSXbjC
h5hwRbcHJSyITEMw/djsJjU8cbmdkDnoYYaeroh1B3paIBSGeOUY0MwkIj4w
wg9LPBHjF2S3o9B4xLCFJboebPGLCgAUi5TL
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 780->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjctcUsxC9h8cE2EGujqYXmxyZIULkjg+N+ANV2LMQFKHTbyB
CDOwqUEJCyLTEEw/ijk43Eds3CL7A1u844pXuFuwhAVRbsBhHjkY2S3Y/ESy
XizhTDBtosUFPjFsYYkOsMUvKgAAE0eUkA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 781->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjWKuPXlmofuPAYscVv1o6hjQzaA0XIjwDwM+/QyocnjtxhOm
xJiBTQ22sCAUJshuJuQ+YuMW2R/Y4h1XvMLdYo+dTbRbkOOHgvSBEd+U6CUh
TLGpRxdDDzOsfkcD2OIcFQAA8uKWDg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 782->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjWKuPXlmofuPAYscVv1o6pDtJtYMvOFChH8Y8OlnwHQXTrtx
hCk2vxHyA9bwJDINIbu5AU0/qeGJ7j9c8Y4rXuFuscfOJgXDAZYwIcU/KPFN
it3Y0gqRfsGmHl0MPcywhSU6wBbnqAAAgkiWEA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 783->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjWKuPXlmYfMfOWYg281AghlYwwXJDHzmMODSj+wWQmYghR0x
fiPkB3T3MSC7k4z4xSZGcryQELfo4Y4eNqS4g1DYkOoflPgmxW5saY1Iv2BT
jy6GHmbYwhIdYItfVAAAcaWZkA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 784->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjWKuPXlmYfMfMWYwoKlDthtdjuRwQTIDnzkMuPQju4WQGUhh
h02cGDMIqWFAo0mJX2xipMQtsj+IMQc93LHFM7HuwBc2hMICa7jg8BNBu7Gl
NSL9gk09Mh8d4ApLXOpQzEQBAKmnmVE=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 785->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjdVcYszBZgYWe0gxA9kf2MzHZQbWcEEyA585OPWTYgYDA/bw
QApLYtyBTw0DGk1K/GITIzadoPuDGHPQ/YItnol1B7a0gS29EesflPggIyxQ
0gqRfkFXj0GjAxxhiQ6wxS8qAABp45cQ
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 786->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGlkcDvDYjdUsLPLE+JUBzR3I/iDWTwz2WNwP9QMDEebg
1I9sDhFmoPsFPYyJ8Q+6GmzhSShckcOPUJwTYw7cXTjkCKVRXPFMrDtwuYHY
NIYRBnjMIyYsUNIKkeZgU49CowFcYYlLHdwsDLUACSuXTQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 787->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGlmcXLOw+Y8cM8AAC5tQeGBzPwNaWBHjDqyACDOQ7cIa
1kS6A10Ngz0Wf5IRv9jEyI0XYsxB9y962JDiDlxuICYs0N2DkV7ICAuUtEKk
XzDSEr70hm4XHrXoYYMJABcomE8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 788->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxSz0P3AgEWOGDPAAM09xIYbBkByBz5zcOonwS3IdmENayL9
g0sNA5pZpMYvNjFiwgNbvBBjDrp/0cOGGHdgDRscbiXGT+jhh808QmGKHk/Y
4hyb29DVI4cPNoArLHGpw20mAHg/llE=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 789->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxSzkP0Ax2SYAQZI+rGZjyvcMIA9Kk1WuKLJ4Ys7rO5lwC+P
yw14442M+MUmRk684It3fOGBHgekuAOXG4gJC3T3YKQXEsMCW3rAGV/Y0hZa
msQFcIUlLnUMONUBAHOSldE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 790->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxSzkP0Ax2SYAQZo7iE23DCAPSpNVrgS6RYGHGrgYU2kf/Cp
QTaL1PjFJkZuvBBjDrp/0eOAFHfgCxtCYYEv/ND9RNBuLGkNnzno4QU3A5nG
AXCFJYo56GqwmgkAG/GXEA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 791->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGlmcXLNQ3EaiX5HNAAM09xATHtjcz2CPShPjDmxmEOsW
bGow/EaGGRjxRkb8YhMjN16IMQc5jWLzFynuwBu+JOrHSC+k2I0lreEzBz28
4GYg0zgArrBEAcjyONMwANcsmJA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 792->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGCcgQT8yjctcUsxC9h8DEptUM5D9wYDFfJLCxR6VpiRciQkTbGow/EaG
GRjxRkb8YhMjN16IMQc9zND9RYo78IYvsXqxhB+6n4gKUyxuwWUOenjB1KHQ
OACusEQByPI41QEA9MCYEA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 793->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjctcUsxC9h8DDjlizAADJHOINQNruKCJkR2uSHLE6MfrNzLM
wIg3MuIXmxg58YIr3jH0ovkFPS5JcQfe8CVWL5bwQ/cTUWGKnlbwmIMeXujq
8QFcYYliDro8VjMBxBKWkg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 794->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4sSaxWCPwww8coTcA3cDFrOINQcFoImRrB/ZLcSECZoerH4j
0gy8YU5G/CKHBynhiTNeCPkDzS/oekhxB97wJVavPapb0P1ElN3oepHCFJs5
hNSj0GgAV1iiAHR5rOoA+pSVjg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 795->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxi3YpiBhklxD9wNWNhkhQuaGFnhiiaHLzywqcHwG6FwxaOG
AY0mJX5RwoPSeMES74TCA10PMfGBM35I1IduPzJNalhgSw+4zGHAoh45DlBo
NIArLLGpw28WAA+XlNE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 796->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxSzkP2AjEk1Awxg+hmINwNruKCJkRWuaHLE6McQo9AM9PRB
KExg+rGGKwlhik0/PI7R/YnFrch+QddDTHzgjB8S9aHbj0yTEhawdIkeT/j8
gq4eOQ7wAVxhiWIOujxWMwGw25UQ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 797->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsOB8Nk2oGGMD0MxBvBtZwQRPDqQ9fuKLJEWM/hhiFZmC4k4z4
RQkPCuIFHseE/IHmF2zhSWy84g1fAm5Adw8lYcGAZCayf3CZw4CuH009PoAr
LBmwuQXdbygAAKkUk5A=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 798->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsOB8Nk2oGGMD0MxBvBtZwQRMjK1zR5IjRjyFGoRnIYYtMExu/
yGFJTDjgixdk8/DqRfMLur9IcQcxYYMvvNDdjE4TbTdyHKD7jZD9DEhmINM4
AK6wRDEHh99QAQCFQZZR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 799->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsOB+KG5BoUswAA5g5DMSZwYCsFxmgiZEbrshyxOjHEMMjT4wZ
GPFGYvwihyUx4YAvXnDFO7Y4wRd+pLiDmLDBly6Q3YOeXkiyG0taw2cOengh
xwEhgCss0c3B8BsGAAC+GJaU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 800->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsOB+JJsUMBjQ2A5o4Xv24wgVNjNxwRZYjRj9ev5FhBka8kRG/
yOFKSjrD5g9s8Y4tTrCFHwOR+kkNG3zpAj09kuMG9PBD9xtB+5H8jwJwpDtc
YYmuD8N9GAAAEXyWUw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 801->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSahew2ZDcSawYDGpsBTZxQeGBzP3o4EeUObABJjhj9eP1G
hhkY8UZG/CKHK9HpDIt+YuMWPcyQwxJbuiE6naC5g5h0gSv8kM0iNo1ii0uc
8YXD7SjAHosYA6Y5GABL/GBPwwDmRZVR
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 802->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBArFvQzUBzI9F+QXYDFnFi3YIPkK0fSY4Y/RhieOSJMQM9
PAmFCVwdA6Y7iAkHbHGL4g8i4gY9zLDFM1FuwBY/WOSITWcoaZQIP2CEHzbz
cPgFl9sxABYxgukSS/xgVwsA64GTEg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 803->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBArFsY0NyFhU2MGQxobAZ70tyB4X4SwoYBn3608CYmTvD6
DY8Z+NTAzEd2LynxC/cLCWGKTT+6W4gND+TwxJb2CMUNVjNISBso4YLFT0TZ
bc+ANQyI8Quy2zEAFjGserEArPGLAgDKzpKS
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 804->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBArFsY0NyF5kaSzUCymxR3YLifhLBhIKQfSY4Y+zHE8MgT
YwaheCNGHbI/SAlPrP4gxg1ofkEOS2L8gB432MKGlLSBEi5Epi90u1H0khAf
6P7HAFjEiE3X2OIcFQAAZtuV1Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 805->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcEtcDY6JsI96OqQ/UGKOwiFC1FuwaOPkBkMONQg+4EYd+BTg+wW
UuMX5g5iwgFr3ML0Exm36OEBB1jMxmsGnrAhJW2ghAuWuCEqbaDrJRAf2NzO
YI9Go7PR/EgoXaOENVa1ALe7klc=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 806->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcEtcDY6JsI96OqQ/UGKO7CGC5L5RLkFT5gSMgOXn5H9QIw78KlB
dgup8QsPDyLCAWvcIvuDGDdgi0sG7GYTClNcYUNK2sAWLsh+IlovCekUm9sZ
7NFodDaaH/GlS/TwxGYOAwMASsmUVQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 807->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsMBsLJqgf3Qwku8GAknBBEyM3XNHdhdMfuMIUi98IuYGUeMNq
Bq64ISFMUfSj6SPoBmxxyUC8fmRziAkbUtIZSnyQGBbY4pLBHrs52NyOniZx
iRGTLtHDE6vZDADUJZSU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 808->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsMBsLJqgf3Qwku8GASDOwhguaGNnhiuYufP7AGqZY/EbIDaTE
GzHqUPxBQjrD5g9i3IA1LhlI048ct8SGH1HhgsNPJOuFhak9YXNQ1KOzsaQ9
otIlWnhiM4eBAQAY/5TV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 809->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsOB8ZE2EGujowwMImK1zQxMgOVyQ5YvRjiNlTZgaheCNGHYo/
SAhPbP4gxg3ofkEOS2L1NyDZRyhssKnHGS5kpC+sepHjlti0hY2NJe0RlS4Z
0NRgVQsAWkaUVQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 810->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSaheI2JDcS6xcUN6CZQ3S4EADk6keWI0Y/hhhanJFqBqF4
I0Yd3B0MxIcpVv1kxi26v4jRDzMD2Sxi9eENFzQ/kRoWKGmFyHSKoh4dYBEj
Jl2ihydWsxkAmQiVFA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 811->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBArFvQzUDGJLoH7gYsbELhgeF+BsxwIsYduMKUGDOwqYG7
gwIzCMUbMepQwoOMuEX2BzFuQE6nKGFLqn4iw4YU/5CavrCpRfYPujvxpk0i
0im6H/EB5HDGajYDAKvdlFM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 812->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcEtKHw8csSYgWw3Ke7AGi5oYuSGK7IcMfoxxEjwD7oZ2MKTKHfg
CFdSwhSrfhLiFlv4oevH5xYGNHli4oAY/5CTvrDqJSJMcapHZ6MBYtIlsptw
mwcAPWCUVQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 813->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcEtKHw8csSYAbObwZ40d2ANFzQxcsMVWY4Y/RhiWNjEmoEtPIlx
B7ZwJdYNhOKF2LjFFn6k6Mfmf2L1ERMu5IQFAxa34HMTunoGXGw0QDBd4oof
DAAAaUKXVQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 814->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsOB+PHDFmgAEWNlnhgiZGdrgiyRGjnxi/kWIGoXgjRh2KP0gI
Twz9RMYtepghhyVJaYPIsCHFPyhuIlUvFrfgcxO6egZsbCxpj2C6xBe/KAAA
d66XVQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 815->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxSzkP0Ax0SYga4ODLCwyQoXNDGywxVJjhj9uMKHXDMIxRsx
6pDjhJR0hi1eiHIDml/Q/UVMfMDMISX8iElnKG4iIyzQ3YLPTQxo6hmwsbGk
PaLSJVp4YjOHgQEAVbWWFg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 816->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjctcUswiVQ45PBhw8MGAknBBEyM3XJHliNGPKwzINYNQvBGj
DhaupIQphttJiFvksMfmL6LdQGTYEJXOGFDNJDcs0N2Cz00MaOrR0yQuMWLS
JbJ/cJrNAAAMXZhT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 817->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjctcUswiVQ45PBiw8OGYSHdgDRc0MXxuwBeuyHLE2I8hhkee
GDMIxRsx6lDCg4TwxOYPotyA5hd0fxHSjy19YA1fYv2CHC44/ERsWKC7BZc5
6OGFEgfIfCxpD5tdKPrR/IPVbDAAAJPXlZI=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 818->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjdVcEtyCzY8MOORwqcXQi+QessMFTQyfG/CFawORbsGmBjks
yTWDULwRow4lTMmIW3R9BN2A5hd0fxHSjy19YA1fYv2CHC44/ERsWKC7hRhz
4MAejWbAIoclrHHpR4lbrGkYAMiUlRA=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 819->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcEtGGIwTIR7YGox9CK5h+xwQRPD5wZ84dpApFuwqUEOS3LNIBRv
xKhDCVMy4hZdH0E3oPkF3V+E9BMdviTqx4hvSvQyEG8OHNij0TgAVr041DEg
YwwAAF+/llM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 820->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcEtGGIwTKx7sOlFcg/Z4YImRsh+fGFKjFuwqUEOS3LMYECTwxXm
hOKXnDBF0c+AMIMoN6DZheEvYt1AKHyJTRvI4YIlbogNCwZs5uEwB5vbGezR
aBwAV1hiU4ffTABuwZRT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 821->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcEtWMXxyOEzA6aPAck9ZIcLmhi54dpApFuwqUEOS3LMYECTwxfm
+NQxIIctkWGKop8B1T0E3YCWBjD8RawbCIUvsWkDhx+I1o9NLwN+c7C5ncEe
jcYBsLkdlzps4YwAAB08ldU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 822->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsUuXwqQMDe+LdwYArXNDEyA3XBiLdgk0NzB3kmsGAJkdMuGJT
xwDDRIYFhn4s/iIUJwxobkEPC6LcgC1+cMgT6x+U+KBELwN+cxiwqEf2Az6A
YQ4edQxIbsAEAKv2lNc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 823->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMxaoXh1n47CHWPSjusMfvDlLDhRhz8OkjxgwGPH4h2gw0NQxocsSE
KzZ15IQpun5S4hbdLjggNW3gCEtyMNwtZJiHVS8DYXPQ1SOHAwM2cSzxQ0gd
A5IbMAEAOV2WVw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 824->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsUuVwqWNAxiS4g1C4EGMOPn3EmAF3M7qZ9iSYgaYG3SxiwhWb
Opg7SAlTbPpJiVts4cdAgn5s/idWH95wweEngn5B18uA3xwGNDYKwCaGBLCm
KxzqkNMdJgAAUfmVlg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 825->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxI3M2Axnxh1DMiYBHcQChei3IJHHzFmYPMzGNiTYAaaGgY0
OWzxRkz8kuIPdD3o/sDGJ+QXBjQ9RLsBT9iQipHdgtVPBOzG0MuA3Rx8aYNY
QKxe9LDFBAD+cZSW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 826->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxg34ZJnwGI+MeoYsGBiw40QIDdckeWI0Y8hhkeeGDMIxRsx
6mDuIDYscOnHxSfkF4x4JtYN2OIHLa0QmzaR3YLVT6T6nwG7HC63kAKI1Ysr
fhEAAAQYkpY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 827->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxI3M2Axn5B74PqQMCluIATIDVdkOXxuwKYGDOyJM4OQGmRz
SI1fmDuIDQuc+ol1A5pdDEhmEKMfb/ygpRVS9GOkFyzhi8//2OIJXQ6becjh
QQzAFZa41MHcgAkA0lCTVQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 828->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosPOLEmIGuDsYnVj+yG3ACYt2CJ0wJhQkDDjUofiMiXPGpQXYL
qfGLHA5EhysW/djkiAkPBjQziHUD1vhBtoNYvfaobsHqJxL9jxzO2NyBTT2x
AFdY4lIHcwMmAABc4pMY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 829->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwJYwYi
1KCoxwOI1Y9M4zKXUrcTYwYDmjoGZEyiG3ACYt1CQD8+M3CpgetHYhPjBlLi
DasZ6OFKpD9wxR+62wm6Ac0u5LAkNm0QChtCYYkrnaGkFyzpCJ//0dMaNnOw
mUcqwBWWuNTB3YcBAO6hkdc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 830->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosPOLEmMGAZgYyn9TwwwD2qDTZ4Yokh9cfWNTA9RNhRgMBNbji
DasZaOrQw4OYOMWmH90thOIV2c3IZhATH9jcg+ImUtIGsltw+AlXeKPHI7pb
cMYXMWkLB8CVtnCpg7sPAwAAkEmTlA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 831->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj8EA
RqMBYvUj0yjmkmoWmXLIahhw8GH+JClckAFaWJGsH90cPGbgUgPXT4QZDQTU
4Io3YtShhwcp6QRbXBB0A5KfsfmLmPggFDYkpQ1ktxCZvrCGHxa34IwvLOqJ
BbjSFi51cPdhAACbZpWS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 832->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJdYteMSIMYMBTR0ynxR3YA0Xe1SaJP322NnE6McQQ/IXOWYQijdi
1KGHBynpBFtcEHQDmn+Rw5IY/djSF3rYkJQ2sIQLobBA9z+ynchuwRlfWNTj
BVjCCdnt2ADW+EUBAAqglRA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 833->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItFEmYVHjBgzGNDUIfNJcQfWcEHzE0n67bGzidGPNUztGYhyB7oZ
DGhy2OKNmPhFFiM6btH0Y3MLoXhFsRebe0hIX/jChqh0hhYuhMKCkP/hcYsj
LDD0owNc4gzY3Y5LHQOS+zABAMRElRA=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 834->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItFEmYVHjBgzGNDUIfNJcQehcCEmbFCAPao+YszApgau3x5hJilm
oIcNtngjFL8MaGJExy0DmrtwyOGLV1zhh+w2YtMHtrAh2i9Y7CQUFtj8j+4W
BjzmYOhHB3jSLDa3Y9OLIo/VPADiLJPP
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 835->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjmItFEmYVDjAGHHCEzkPURq5+YcCEmbFCAPao+YszApgau3x5hJilm
MGAziwgzMOxG9gcJ4YmeNrDJ4YpTfOGH7DaC5uAJG1LSCEa4EAgLDLuxuIUB
jzkY4YcO8KRZXGGJrhclbWE1DwBqzpRP
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 836->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwJYwYi
1KCrxwWI0s+ASiOLwwEJbqHUXwxobAYS9WN1PwNmOJGk3x5VHzFmYFMDNwsp
3kgxAyU8cMQbofhlQBMjOl4YMP2Bbh6+OMUXfoTiGMUuIsKGFP+gmEfID1ji
ESWt4DEHw63oAJc4AxZ3YNPLgGoXdrMAlEeUSw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 837->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBArDtwiGMzH5852MzEZzYu+9D9QErY4AtTYszApgbuDqR4
I8UMBjQ5YsIVXR0DsjsYsIchPnMa0PQR5Q80v8ABepwRSBMo6QFL2BDrF/Tw
QPcTTj9giUd0t+AyB8OtJABcYYkcjtjCAhMAAAUokg4=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 838->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBArDtwiGMzH5852MwkxR0Y7mdACici3YIVoMlhczO6fgwx
tHgjxg2kxBsx6tDDg5R0QpY/0PyCLTxxhSNKnGKJX0Lpj2C4YPEfTj+ghx8W
t+AKUwy3kgBwhSVyOGILC0wAALk2k44=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 839->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxJxwxE
yOMCRJnPgEoji5NsFi73YTGfkHuQ9cLdQ4IbMACaGDHuwGYGshwx+jHE0OKN
VDMIxRsx6pDjhJgwxdCPpo+gG9D8gi08caUfbGkJW9gwEKEfa7iQ4Ad0/2Nz
C64wxXArCQBXWOJSh+4uBAAA0LqU0Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 840->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxJxwxE
yOMCRJnPgEoji8MBkW7DZicDHjl87oH7Ddk9JIQXBkATI8Yd2MxAliOoH48Y
zD3EuIGUeCNGHQOS/cSEKYZ+BgaMuCE2jWLzF7rb8JqDI3wZsOjFaxYDqhpi
/IDP/yh+I0Y/MsCV3tDCCT0scaljwKkOAB4qlI4=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 841->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4oTMYsBhFjY1pLoH7jdk95ASLugATYxk/Uj2E2MGNvdi+I0Y
M3CFPY54w+UObOFKbJxguJ2BASNuiE2j2PxFrDvwpQdsaQNXekH2O9HhiCdu
MfxGjH5kgCu9oYUTeljiUseAUx0A+JyWkA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 842->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSahe4+XHK4/ILCR3YPKeGCDtDE8LkBq34kfcSECTb3oviN
WDNwqEF2CzHuwBauxMQJTrcTiHdcaRQlbElIG1jTAxY/YYtLbGz08IPTBNIF
Lv8jhzM2M7CqR9eHA+AKS1zqcKdhAHUHk9M=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 843->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSahe4+ZJoYv6Dwkd1DSrigAzQxfG7Aqp8BU44Uv6CHD1Fm
4FCDbDZRZuAIV2LcgNPtBOIdVxpFCVsi9eNMD1j8RLQ5yG4hIn2h+xeDT8Ac
rOrR9eEAuMISlzrcaRgACOqTkg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 844->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSahcudRPsFmY/sHiLNwOZ+9HAiWT+SPmLCBGYfRpjak2AG
DjXIZhNlBpo6YsMCV9wi+wOfGxjscbsZPSyIcgMyRnM7A5p9xMYNipuISFe4
/I8cztjMwaoeXR8OgM3t+NThTsMAX5+SUw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 845->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSahcudxJrBgKSHAYs4ofDA5n5i/UNIP7IcMfGC029EuANd
DQMWswm6A4s6YsMCV9wi+4MYN6D7Fw5I0I+cHnCFDdFpDDlciExf6P7F4DOg
ug9nusKWtnCJY4kfYtRhhDMcAAAtDJIU
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 846->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSYxYDLjcT6B8kMZH24zMZrDjaAxa+k6EeWIyZecPqNGDPQ
1DBgMZsYM9DVIYcDKfGCK56JDQv08GMgUj96OkI3j+Q0hhwuRKYvdP9ipE0C
YYoedygAlziaH3HqRw8LBlzqACNZkZI=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 847->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGlmcHLOw+YkBi/k4/YIULihsHGbjdQs2QMAtDAT0I8sR
G7bYwocYM3CpQfYDMWagq0MOB2LDFJt+XP7El0ZRwpZI/ehxgy1sGNDkifUP
sekLw25saQWPOcj2YQB86ZUB0x341CG7ARMAAJzNkZQ=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 848->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSYxYDHjUT7B43NgMdsvG7BA/DZj08/shyxYYstfIgxA5ca
5PAkxgx0dTB3kBKmKPrtUfURdAOaX+CASP3ocYMrbEhNHxjxTYrd2NIKHnOQ
7cMAuMRx+BGfOmQ3YAIAPhmS0w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 849->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4uSahcuNxJrBgKwP2Y+khAsuQKRb8IUpsWGCNUztiTcDlxpk
PxBjBro69PAgNW7RzSToBjS/oNtNTFgSEzbofsHnN7hbsMQNLj+gxyN6XCKn
V3z2YQBc4jj8iE8dA7L7MAAAUtmTVQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 850->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsFDEYJsIMmDoGdL1o4hSFC7FuwROmxIYJ1jDFwibkBlzhhCvM
CcUvcjgQG6a49BPlBjS/IMcFMfqJDRui/YLsdiLjgwHdbnS9SGLYzEG2DwPg
S69Y/IhPHXK8YgIAAMmR1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 851->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcEtGGIwTIR7YOoY0PTiMpuscCHWLXjClNjwxRqm9sSbgUsNsh+I
MQNdHXI4EBuuWPUTGTfodiHHBTlxiytsiE6nWMIF2T3k+B9dDJud6GGBF+Dx
Iy6AIo9VHQCK25MW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 852->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTOMylxSzsPmFGDPQ1TEghQPRbsAVLvaoNNnhiiRHanjA9DcQaQYu
Nch+IMYMdHWk+gOnfiLjBt0u5LAkJW4JhQ0DsXqRwwVL3OBLV7j8j24eznSJ
L23hALjCEpc6uPswAABrc5PV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 853->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsDHE8cvjUMUAxPrOxmYE1XNDEyA5XJDlS/AI3E818YtxASrwR
ow7dP6TGLTwciIwb9DBDt5uY+CAmbIj2C3K4YIkbfOkKl//RzcMZD0SkTXSA
KyxxqcNtJgCjY5QW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 854->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjdVcEtyCVRyPHD51DGiYKDfgChc0MbLDFUmOFL/AzUQznxg3
kBJvxKhD9w+pcQsPBwLxjh4WyG5BN48YNxAKG2L9ghIuyO4jIl3h8j+yGDZz
cIY/TB8egCss0fU3oPkFEwAA3s6TUw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 855->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjdVcEtyCVRyPHD51DMiYSP8QDBdi3YJLL5IcKX6Bm0lCmOCy
B1kvMWag0HjiFl88o8QLUlgQ5QY0v6D7i5j4ICZs8LkfZ/hhiRtcevD5Hy6G
wy8Y+hkw9eECuMISm70M9qhiqAAAGD2TEg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 856->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcUsDHE8cvjMYEDGJIYfIUCWfiS3EDIDm5sx/EbIDBz2IOslxgwU
Gt1vJIQnirvsEXqJDQtkt6CbR0rc4gsbovSihQeyn/Dpwed/uBgON2HoZ8DU
hwvgCktc6tDDGQEAKLeV1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 857->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4iSbRYQ9xPgFQwzmHlLCBRcg1i249CLJ4fM3Vr8w4JfH5QZ8
ZhNjBgqN7jcSwhPFXUj+JugGNL9ghB8R8UFs2BClFy08kP2EK04Z0O1G18vA
gDdOMfQzYOrDBXCFJboZGO7DAAAq1pVR
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 858->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBArDuIsIcYv6CLwd1DSrjgAsS6hYB+QmZg9QuSH4hxBy57
kPUSYwYKTUbcotsDDwdS4hbJL+j+IiVeCYUNUXrRwgNb+kJ3EwO63djSCp6w
QDcbPQ4wAJq5OPUiAYz4wQAAz0uWTw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 859->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJcYce+zqGOyxm4/TDHR3IImjm4/PXTgBsW4hoJ+QGVj9guQHYtyB
yx5kvcSYgUKTEbfo9jAgYaLjFskv6P4iRj+xYUOUXrTwQI8bbGmLAd1ubGkF
j1+wqkfTh0sMm9uxAYz4wQAA4+6VEA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 860->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGlkcDkhwCy4xYsxgwKIOJkaKOzDcj+QPYsMGX5iSYgaG
mfbEm4GuBjksccUbofjFSC8khCdGnODwJyG/YPiLCP2EwoYkvWjhgR43yOLY
+BhqkcISV5hiVU8kwOZ2XOqQ4wYTAAA0WZUQ
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 861->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhAQmj
88nBIDNwAaL0M6DSyOJwQIJbcIkRYwYDEsYQI8EdGO7HBsjUjyxHTLxgmGlP
ghloahjQ5LDFG6H4RQlPEsIU3R3I8URUWKC5BT0siI1X5LAlVR+2uEGJDzQ1
6HrQ4xFbXOIKUwz9uAAWeVx+x6YOOW4wAQCvh5KO
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 862->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBAgltwiRHjHgZs7kD2IynhQgCQqx9ZjmS/IPmBKDPQ1DCg
yRETrtjUoaQZEsIT3R/kxi263cTox2YWqfqwugVL3KCHNdZ4QdfLgN0cXHFH
CsDld2zqGJAxBgAAQ/eVEg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 863->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBAgltwiRHjHrhf0MWwiBPjL3Q/EBM2DLj0I+kjJnxh9mFz
E9FmoKlhQJMjJlyxqUMJCxLCE8VdJMQtchw2YLGbkH6MuCEy/IiJGxQ3YbEL
Z7xgSyt40il63GEAAmkOa9xhUYfsBkwAAGqFklM=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 864->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJdYteMRIcQ8Dmn5kTHa4oIkR8gO+MCUmfGH2YXMT0WagqWFAkyMm
XNHVMSC5DT2siTEHOY5IiVsGNLcg202MfmS34wo/ov2CLVzQwgKfWdj8DxfD
EabocYcBCKQ5dLfjUofsBkwAABV8klM=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 865->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNoFh4xUt0D04uOyQ0XdDFywxVZjhj9uMTIMYMBTY6YcEVXBw9L
BtLCFMUdaHoJugHJTpSwJTVtEApfItJjAxa3IPuJ6LSF5n+4GA5zMMIPHRBI
c+hux6UOJW4xAACAe5MU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 866->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFooYHjlsapHVMSBjBoRZ5IQLuhi54YosR4x+XGLkmMGARCOb
Q0r8oocnsWGK4g40vQTdgMPvpKQNZP9jNYOAXxiwuAc9fEgJC3T/w8VwmIPu
XxSAFkbogJh0CfcHsvswAABFoI/X
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 867->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNnFoY4Hjl86hiQMdQ95IYLuhi54YosR4x+XGLkmMGARCObQ0r8
IscpA5KZpMQtul6CbsDhd2L1o/sfqxkE/MKAxT3o4UNKWOByCy5z0P2LAvCk
N/SwIUYdbjMBGn6QWQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 868->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE+sWfG4k1i8ofGQ/khIuWMKClLDBF6bEmIFNDaVmMCDR
yOaQEr/o4UlsmKK4A00vQTfg8Dux+rGlL2xhQ7Rf0MID2U9Y7cIWL7jiFYc7
sKknFhCTLlHCgoEBR7kAAMZ+kpQ=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 869->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4iSbRcCNRPsFmY9FnBg3YAA0MWLCBVeYEmMGNjWUmoESLkjm
kBK/GOmF2HTGgMdMQm7A4mZkuwnpx5a+sIUN0X5BCw+4eTjswhov+OKVSLcT
C4hJlyhhwcCAo1wAAC63kRg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 870->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBAglvwuZFY9zDYY8Ekhh8GQBMjWT+SPmLMwKaGUjMYkGhk
c0iJX2zphZR0ghJHxLoBi5thZhCjH1v6whY26OmPmPSI7AYGIvRiVYvkH3Q5
fG7H0IcDYHM7PnW4zQQATdORFg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 871->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBAgluw8RmwmI/PPSj6SNSP1f0MmGK43IxLPzZziLEflxg5
ZmALT2LMQKGRwhhGkxq3cP32RLoBi5uR7SakH6cbGDDtwJceUdQyoKpBDwt8
4YLN/4TCFJvbsQIcaZcYvRjuwwAAn5ORUw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 872->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4qSahc1tyG4kxT1wfSTqx+d+UvyDL0yJMQObGkrNwBaexJiB
QqP7jcS4hLsL2T2E3IDD78Tqx+kGtLAhxS/I4YHsJ2x2YY0XdL0MCHOx6UVx
Kz6AI+0SoxfDfRgAADOXklc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 873->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4qSahc1tyG4kxT1wfch+JMVuLO4nxT/4wpQYM7C5lywz0MID
PTyJMQOFRvcbiXGJbhZRbsDhd2z68bkH3Q3o9pLiF2x+YCDSLJhaBjS34Eun
2NxOLCAmXaKEIbJbUAAA/Q+Slg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 874->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjctcariTKHVobDgm0Q0YAE2M3HBFliNGPy4xcsxgQKKRzSEl
ftHDgdg0iOIOdDMJuQGH3xmwmU1s2sAWvsT6BS08sPkBrzugbmdAcwsDkhwx
bicWEJMukf2D4hYUAAAjNZJZ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 875->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjdVcKrmTKHVINAomUj+ucEEXIzdckeWI0Y8hhkeeGDPgYYMj
3gjFLwOSO5DdQ0r8Iesnyg1ofkGPT2LiAzltoMQPWnohSi9aeGBzA16zGFDt
Q3YLrjDF6nYiATHpEtk/KG5BAQBfn5LV
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 876->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjdVcKrmTKHVINAom0R3YwgJmBjFuwRemxIQvNjXUMAMeNjji
jVD8MiCZS0qYItuDHo6EzEG2E9395KQNlPhBSy/EmoPiFix+QDcLw27ktIrk
FlxhgdXtRAJcYYlLHYpbUAAA55uRVQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 877->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMpYY7SVXHgIwZIDS54dKAZAYxbsEXpsSECTY11DADHi5I5pASvwxI
5pISpsj2oIcjQTcQ8Dsh/cjmYMQPFjlS/IMrfeEzD+5/LG7B5ResbicS4ApL
XOqQ3YIKAD3FlBg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 878->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMpYY7iVKHxkbGpOjH5n4wINIt+MKUmDDBpoYaZsDDBUe8EYpfBiRz
YeFBavzBw5HIuEW2E5u/COnHmjZIdD/OcMHhBnzmYvM/XAyHmzDCjwSAKyxx
qUN2HyoAAGvTldU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 879->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMpciNMPOIVYuNTax/8Lgf5gZizMIJkOSw2YuuH5cYMeGKSw2yH4gx
A4VG9xsJ6QzFXSTEDXqYofuLkH5sYUyq+3GGC4luwKUXHiY43IQRfrgAjrSL
LSzR1WNzHyoAAFB0lZQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 880->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPTXHLchcYmxT3oGJv7iPEPeliQEjY4AZIcMfoxxPDIE2MGengSYwYK
TWbcItsDDwci4wY9zND9RUx8YKQpEt2PM1xIdAMu/8PFcLgJI/xwARxpF1tY
4lKH7D5UAABDupTT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 881->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMQmdjMx+fGQw42KT6BwWgiZEdrkhyxOjHJUauGfBwQTKHkBko
NMxcJJrYdIbiLjxpB5d70f1OrH6s6YuI8CMqXEh0Ay7/EwpTjPDDBbDI4wpL
XOqQ3YcKAPu3lNM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 882->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPTXGLdgoONzXxizYBjMvyD7gdSwgYnQJIjRj+GGB55dH+gq2FAkyMm
XNHVMSC5A9k9xIQHtnghNm6R/YIclqSkDULhS6p+bDTRdmNLa3jMwQh/EgCu
dIFLHbL7UAEABFaU0w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 883->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPTXGLdQsCdxOhHVseABZPiH/SwICZscOnHZg4x8YIhhkeekBkMSDSy
WwiZgUIjuQPZPcSkM2zxQpQb0PwCBySkDfT0RUz4kRQuJJgFDz/0tILHHJTw
IxHgCktc6pDdhwoA7l+U0w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 884->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMwuVOYvQjq2PAgknxD7r7ifEPLv3YzCEmXnCJkWMGA5ocMeGK
rg4Wxsg0sekMxV2kuAGH33GlPWLSFzHhR2y4kBMWyOkR3W9EhR8ugCPtEqMX
m/tQAQAb4JPX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 885->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosIuwhyj9I5qFjcsMF2Wxi3IIvTIkJE2xqKDWDAU2OmHBFVwfz
PzJNVPxhiSMGeyLdgGQvStiSmDZQzCMi/AjpR08TxKYvbP4nFB8o8YgP4Ei7
ePViMx8tnCAAALzKlNM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 886->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosIuwh1j3IZiJjYt2Azf2k+AcnQJIjRj8uMXLMQPY/sj9JiV+4
+5FoouIP3V0kuAHZXpSwJTFtoJtFqj6sbkHzE1H6sfgfJXzxxAPetIUDEJUu
0c1HCycIAAAgrJVT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 887->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosPGLEmMGAzR1I4tjMx2cfuvuJ8Q8u/djMISZecImRYwYDDneS
Er8MSOYSG6YYdkP1kRu36HYTox/Fz0SGH1FuweEngvGCL17xxAO+tIULYHM7
CsBmPla1AHuSlBQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 888->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4shmE+sWXGLEmMGApo4B3R0kuAFbWCCbRap+ZPuJCRNsajDc
QqIZDDjcSUr8YqQXEtIZRtrAEmfExC228CTFDaSmS2xhhxwe6H4iaBaaWmT/
4ApTlHjEBXDIYQtHfOqQ3YcKAG2cklE=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 889->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj0yjm2pNoFg4xBizm49KPrI4B3R0UhAu6nwj5AV+YEhMm2NRQwwxC8UZI
HXKckhKmDOjuoiBu0f1FjH6UuCExXWK4Hy080P1EVNrCllbwpFN0/5ICsIUj
PnVwv2EAAMDikpY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 890->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosHGIMWMzHpR9ZHYyPTBPrDmzuRzaLkB/whSkxYYJNDTXMIBRv
hNRhhA0JYYriLrSwIjadYvMXMfqxuoFIfRh60cKDFDfg8j+h+ED3LykAWzji
Uwd3HwYAALu1k9k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 891->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosPOLEmIGuDsYnVj8h9xNjFgMO/XCAJEeM/bjEyDWDULwRUofs
fgY8cYYvbtH1EnIDLr8T6wecbiBSH4ZetPAgxQ24/I/uJ1zxgDdtwczFYx4+
gOE+DAAAVqaT2Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 892->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJdYtRNhDSD+yOhgfXZyccGkg0iwGHPqRw4GY8MWmBsMtZJiBHk7E
mIFCI/uNQJzhij90vQTdgMPvxPoBW/oiJvxw6kULD1LcgMv/6H7CpQdn2kKO
EzzmYZNHV4fLHAYGAJNCk9c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 893->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phgxcijq8ABi9SPTWM0l1i14xIlxDwMSRufj0o/TTixhQUzYMODQDwsHBnvC
ZuDyMza3EBO3uMIJW7wRil9k9yObQ0x4oLiLFDeghQd6GBLSj+EWIsOPmLgh
xQ/4/A8XY8AepsjieAGOtIueJrABlLDBqhYA8ROQEg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 894->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjdVcYt2CR5wY96CrY0DGRPoHV7igi5EVrkhuIWQGNjXY3EKK
GQxINLI5pMQvsvsZkMwkNp3A3YXsHkJuQHczlrDAl36wpS9iwo+YdEaKH/D5
Hy7GgN0fyOJYgT0ajQQIpkvksMRjDgMDAJigkZQ=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 895->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJdYteMSJcQ+6OgZkTGL4YQsLUsIGK0ByCyEzsKnB5hZSzGBAopHN
ISV+kd3PgGQmsekE7i5k9xByA7rfsYQFqemLqPAjJlyQ3UOC3VjTCh6/YIQf
OrBHo5EArrDEZi962kAFAJcslFM=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 896->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosPOKkugeuj0T9+NxPin+wAiS3EDIDmxpsbiHFDAYkGu4eIsxA
oZH14okzvPHCgKqXoBvQ/Y4lLEhNX8hxQpR6XOGC5idi7SaU1giGHy5AwDxs
8ujpADlcUQEA5XeT1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 897->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosPOKkugeuj4B+nHaiAzQxssIVyS2EzMDmZmR9RJmBpoYB2Wws
4YXTDOR4xoJJjhcGEt2Aw+/IfFLTF3Kc4EoLxKRHZD/gCwt0uzH0IoUzNnMw
wo8Biz50NlIYYQtLXOpwmcPAAAAn7pGS
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 898->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4iSbRYQ9xLoH7jckP5IULugATYxk/QwI/xFjBjY3I+sjygwc
amBhQky4IvsdI0wJxBnOeGFgIClukMMePWxJShsEwgbdL7j8hh4eyH4i1m4M
vWjhjC8t4ATIYYXHj7gAtjhHBQDmTpQQ
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 899->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4iSbRYQ9xLoH7jckP5IULugATYxk/QwI/xFjBjY1yGLkmoEc
LsSEK7LfsYUpvjjDGS8MmOYQTKNoaQ09PElNX1jDl8j0iB4eyH4i1m4MvUiA
WLdjBQTMwyaPrg6XOQwMAJUwlBI=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 900->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosPOKkugeuDwmT4gYMgCZGVriiyRGjH5cYuWaghydRZiCrR9KP
7CeS4gVNH0E34PA7A5H6saUvrOFLRnpEiVMSwwJXWiPW7VgBAfOwyaOrw2UO
AwMAtNqT1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 901->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosPOKkugeuDwmT4gYMgCZGbrgiyxGjH5cYuWaghydRZiCrR9IP
kyM5XtD0EXQDut/RzCAqPuwx7STGXkLpESW9EGkWNv+jhzPB8CMB4ApLbOqQ
wxYTAADOFJKW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 902->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4iSbhct9WMwn5B4UvTjMxucGbO4nxT/4wpQYM7CpoYYZyHGO
Ld6wmoGsHjnNkBKuDJhmoruFmDSKLR4I6ceWvogKPwLuwUgvpNiNLa3g8QtG
+GEDOORwhSU2dQzIGAMAAD31kxQ=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 903->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxlg
GAsgSj8DKo0sTrJZeMSwyWH1CwMaHw0T6wZs7gcDLH4lRj+GOQTCBJsaapiB
Hk5EmYGsHt1vBOIPPZ0gm4ktzvDFK7rfifUDNvehux9f2sMbfujhRKzdONyC
yy8Y4YcN4JDDFZbY1KGnDVQAAGYRkJQ=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 904->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxlg
GAsgSj8DKo0sTrJZWNgM9tjNx+kXBjQ+sv9IcAM29xPjH1z6sZlDKFxxhSkl
ZqCHEzFmoNDofiM2nTGguQuHHL54Rfc7sX7Amr6ICT8i0hlKfOPRgxEvWNyC
nn7xhh82gEMOV1hiU8eA7BcMAACCGJHX
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 905->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxlg
GAsgSj8DKo0sTrJZWNgM9tjNx+kXBjQ+sv9IcAM298PMIMotOACyHDH6cYmR
YwZymCKbQ0r8YksrpKQT5HDEJkeMX7CFJ8npi5jwIyKdoaQXItyAko5wpRV8
8YAnbeEEWNyODaDIY1UHAP2KkFk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 906->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxlg
GAsgSj8DKo0sTrJZWNgM9tjNx+kXBjQ+sv9IcAM295PiH5wASY4Y/bjEyDED
OUyRzSElfrGlFVLSCXK8YJPDF6/ofifWD1jTFzHhR0y4IJtHhBuQ1eJKa9jM
QQk/EgGusMSmjgHZfRgAAGq/kNk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 907->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjctcoszCwmaAYSLMYMBiBrJ+UsILm/tJ8Q9OgCRHjH5cYuSY
gRKmSOaQEr/I7ic2LNDtgYUDNjmc8YrF78T6gdjwxZcecYYLAT9gMwPmfwY0
t+BLpxjhhw7wpDlcYYlNHbIbMAEAQT6Q2Q==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 908->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjdVcYt2CRKOziXEPujoGNP2khBe2sCAmbBhw6IfZz2BP2IwG
HGqQ/UCOGShhiuQnUuIX2f3EuAHdHHR/EOUGNL+g2020GwiELz71OMOFjPSF
NV4Z8JuDEX7oAJc4ul0E1CG7ARMAAP3nkFc=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 909->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGAxgNBogVj8yjWIuDBDrFjxsYsxgQHMH3F/2pLkDw/0MmGKk6kcOC2LM
wKYG2Q/kmoEeTsSYgULjCBti0wm6P4hyA5pf0O0m2g1EhA0p6QPZTHQ/ERsW
WNMKMeGHRQ8ugCsssaljQPILJgAAXyCTGA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 910->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGAxgNBogVj8yjWIuDBDrFjx+I8YMBjR3wP1lT5o7MNzPgClGqn7ksCDG
DGxqsLmFVDMIxRshddjSCinpBDnNYZPDF68MyPrR+MTGK0b8oKUvXGkEIz0i
hwee9IVVDIv/YWI444tQ2sKT5rCGJQ51yH7BBAAhVJJV
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 911->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj8EA
RqMBYvUj0yjmwgCxbsHBxsbHpR/ZHXB/2ZPmDgz3M2CKkaofOSyIMQObe7G5
hRg3kBJvhNRhSyukpBNsfiPoBhx+x+YHotMaDreToh/uNhLTFzb/w8Rwxheh
tIUnzeEKS1zqkMMVFQAAwaKVFg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 912->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj8EA
RqMBYvUj0yjmwgCxbsHBxsbHpR/ZHXB/2ZPmDgz3M2CKkaofOSyIMQObe7G5
hRg34AtrYsxAV4ctbIhNJ9j8RtAN6H7HEhbExiuhsCE2jaC4hYj0he5fDD4y
ICb8SAC4whKXOpgbMAEAO12UVw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 913->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj8EA
RqMBYvUj0yjmkmoWDjY2Pi79yHbB/YVEkxQuaO5nwGIHsfrh7kCSI0Y/LjFy
zUAPT2LMQFeH7idS0glymsMmhy9eUeIBLSxITl9EhB9R4YKWzohOW2hxQChM
cYY/MQBHWOJUw4BLHQAntZSU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 914->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj8EA
RqMBovQjmYNhLgwQ6xYcbGx8XPqxuQPZnySFC1pYMOCwgxj9yGFBTPhiU4Pi
FjLNQPYHtnjDZga6OnT/EBue6GkOmxy+eEWJB7SwIDl9obmfkD8w0iOyW0hM
X9j8TyhMcYY/LoArDeHSj8V9mAAAdwmVEg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 915->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj8EA
RqMBovQjmYNhLplmobOx8XHpx+oOJJqkcEFzPwMOO4jRDwdIcmT5hQGTTcgN
pMQbvvSBHgakhCmyPQz2qPqIDQsUN6CFBbHpC9nfyO5HdxOxcYNiHilpC1ta
wWMOSvgRA3DEPwMu/VjswgQABYyUzw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 916->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqp8QsdDY2Pj6/YLgDiSY6XLC4nwGHHcToRzGHiDDB6RdSzMCj
Ble8YTMDhUb3GwnhiR4n2OQIpVGsfCLiA5u/kd3BgCRHSjpDMY+Anfj8DxPD
ZQ5W9UQCXGGJArC4DxMAAL6ZlNE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 917->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqp8QsrHJEmMGAyx1INNHhgsX9DDjsIEY/ijlYwgTdbTj9gscM
XG7AGk5EhiuyfVjTCwnhiR4nxMYtsp0ofBLSBqGwQQ4TUtIZshtICQt0/8PE
cPkFq3oiAa6wRAFY3IcJAH68llE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 918->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMwiZOjBnY1IEBEk1uuKCLkRuuyHLE6MclRq4Z8HDCEW/YzECh
0f1GRvpA10dKeKK7gVj9hMIGOUxISWfI/iNaPxb/w8RwmYMRfiQAbG5HAWh+
R3ELCgAACM2Ulg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 919->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACYvU32GOqJ8csvG4kVi02dyDRRNuJxf2k+AcnQJIjRj8uMXLMYECiccUb
rvDEFgakhCmKO9D0kRKe2OKBGP3EhA3RfsEVLqTYjS2t4DEHI/xwARxpF93t
2PShuw8TAADPKJTX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 920->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GVABEp9Y/Q32mOrRATXcSI46FD+RYicW95PiH1wAWY4Y/bjEyDED2f+44g2b
Geg0CiAhPNHjBJscoTSKLR4I6Sc6fMlIj8jhSEpYoPufUJhihB8JAFdYItuH
njawqmMAAJmulZY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 921->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXIrciMV8YtWBARJNbrigi5EbrshyxOjHJUaOGcj+xxVv2MxAp1EA
CeGJHifY5PDFK7Kb0cOC5DSFJWyI9guedIZNLVa7saUVfOaghx8JgGC6xBE/
mAAAdHOUWQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 922->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMwiZOtBnY3IFEk+IfFIAuRma4IssRpR+LGKlmYAtfBiLDFdk+
XOFCarxg8xehOEHWgy08iXEDvrDBl/6ISY+khgUDkn3EhClG+JEACKZLHPGD
CQDga5Ia
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 923->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMwuVOYvRjdYc9ApMdLmhixIQHrjAlJkyQ7UUXI9UMnGFFRLgi
24fLX8SGJ3qcEBu3DGh6sIUnqekLPXwJpQ8GLO7Bls6ITlv40gox4UcCwJuu
YW5hwLQLEwAAwiKRmg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 924->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMwiZOjBnY1DGgYXLDBUOM3HBFkiPGLwxYzERnE3IDTvOJCFdk
+3D5i9jwRHEXDjm8YYHFDcTox5a+kOMDOTyI0ostnTHg149NLQMWt+AyByP8
cAEcaZcYvdjiHBUAAF1skZg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 925->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgcoY
HyBKP5I5+MwlxSxs4sSYgU0dA5I4KeGHzf0ogNxwRZIjRj8uMXLNwBYuhMxA
p5H9QGyYItsDsxubHL54xRYPKG4jIX2hux/dTXj1YktnJIYFsn3IbsFlDkr4
kQiISpcMmHZhAgCM5pEY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 926->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAnoGhgcoY
HyBKP5I5OM0l1i14xIlxDzZ1DEjipIQftrAgJWxwAiQ5YvTjEiPXDGzhQsgM
dBrZD0THLQOm3djk8MUr3A1YwoLU9IU1fIn1C7Z0RmJYIIcBcljiMgcl/NAB
vvSGzZ0E1OE2EwDARpPV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 927->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPTXGLdgkecGPegq4PxkWmi7cTiflLCBidAkiPFLw1o+ogyA48aZLcQ
MgOdRglXEtIZit9wyOELC3S/o7uNlPSFHB+UpEeUtEFCWDCg60UGhMIPi3p8
gKh0iW4+VrUAt/WSFg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 928->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMwiZOjBno6mB8ZJqscMEiRna4IsmR4pcGNH1EmYFHDbJbCJmB
TmMLG2LCA8VvOOTwhQU2NxCjH1v6Iib8SI4bUuxGEiMmTFHCD4t6fICodMmA
aRcmAACo95NZ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 929->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMwjAbi/m49COrg/GRabLCBYsYLjcTDFckOVL80oCmjygz8KhB
dgshM9BpbGFDTHii+A2HHL6wwHADkfqxxRWGGaSkDVxxQ4rd9gxY0xUuc1DC
DxvAk+aISpcMmHZhAgCYjpGY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 930->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosHHwGLObj0o+sDsZHpskKFyxmkR2uSHKk+KUBTR9RZuBRQ6xf
kO1D10dKmCLbw4CEsaUdXGGB7nd0t5GSvtDdT1LawBU3pKQtNP+j+wlv+JEI
iEqX6OZjVQsAJhuRWQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 931->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4iSbhYPPgEUOn1+Q9YABEk10uCADLOFEkn4c5hDrFxQz0cwn
xg1Yw5MBux2E4hebn0hJJ9jik9iwwOYGYvRjS1+kup+UuCEqbSDHBxFhihJ+
JAKC6RJNHdx9GAAAUpKQ1w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 932->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGGQGLkCUfgZUGlkcDkhwC4bbkDBRfsHmN3vS3IHN/ejhRJJ+NH3EmAGz
D8NMexLMQFPDgGY2NjsIxS8GICE8ccYTkWGBzQ3E6McbPyTqIyZuiLIbOT6I
CFOU8CMREJMuUczHqRYAI6OSVQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 933->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBAglvwuZEov2Dzmz1p7sDmfnSzSNKPFqbEhC+6X9D1EWUG
mhoGZLOJ9AuyfVj9RUJ4ovuNAYscoTSK7gZsZpMUv1RKj6SGBbr/CYUpA7p+
EgAx6RIlDGHuwwAAztiR1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 934->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJcosHGIMWMzHpR9ZHYyPTJMVLljMIjdckeVI8Qu6PkJmMOBRQ4pf
kO3D6i8SwhPFH0jxTWxYYHMDMfrxxg+J6RFv3JBiN5r/0cMU3SwGdP0kAGLS
JbI6uBswAACJ6pAa
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 935->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGM1lwI3M9hjNx+XfmR1MD4yTXT4obkf3SxywxVZjli/IIcBgz1x
ZjBgUcOALkeEX5DdjNVfJIQnStiQELfofsEWnqSmL3QziE2P2NIZetwQlTbQ
45VAuGLEHQkAV1jiUgd3HwYAAAhPjlk=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 936->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyJxwzE
qsMDiNWPTGM1lwI3M8AwEe5hQDMDpo8BixwhN6C7H8UsYtyCJ0yJCV9s9iCH
JVFmoKlhQDObGL8guxmrv0hIZ+j+INoNaH7BFp6kpi90M0jBhOIG3S6s8YIr
reEIV4y4IwHgCkts6tDjBRUAAJOPjZg=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 937->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJdYtOMQYsJiPSz8DkjkwfejiZIWLPSpNbrgiyxH0C44wJdoMNDVY
w4UIM9Bp9HAhJZ00oNlNlBvQwgPdbkL6saUv9DghBeOMG1LSFnJ8YANEup0Y
gM3tuNShxwsqAACpPY8Y
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 938->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJdYteMSJcQ+6OhgfmSY7XNDEyA5XJDlS/NKApo8oM9DUMKDLERGu
yPbhChdS0gm63US5AS08kAG2tEdM+kI3gxSMM25ISVtI7sEGiHU7MQCb23Gp
wxXOEAAAeFyQHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 939->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
ovQjmYPPXFLMwiZOjBno6mB8ZJrscEETIyY8sAIkOVL80oDmB6LMwKEG3S2E
zECn0f1DbHii+wOOiQkLHG7AlvaISV+kup+UuCEqbRFIK0S5nUiAze341MHd
hwEA34eQGg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 940->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJdYteMSJcQ+6OhgfmSY7XNDEyA5XJDlS/NKA5geizMChBt0tRMUv
nnAhJZ0g+wOOifQHNjdgS3vEpC9S3U9K3OCyE5v/caUVotyOD+CIf/R0jM1O
dP0IAAARPJBZ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 941->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNJdYtRNhDSD+yOhgfmSY7XNDMIitckd2E5k5CfmlA00dMHOGyB91P
RMUvnnAhJZ3AzbBnQAkPYsMSF59Q+kGXJ9X9RMUNATtx2Y0NEOV2tHjAxcfm
dnx2IocrKgAAFL2P2Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 942->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNpZI7CapBUwfjI9NkhwuaGNnhiiSH7E5c+nGJEeMOXGrQ3UJU/OLx
F6nxB7ebyLhFtwsbnyg34AgDktMiFjtxmYUvbkkJU6xuJxJgczsGwOIXTAAA
2WGQHg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 943->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBADTeS4BdkPTD7SXUHtrAgJWxwAiQ5YvRjiOGRJ2QGul7k
8CIYvzj0EhMW6OkDrh+LHKGwxMUnNh3hMpPk9IgnbohNG/jSCrFuJwZgczs+
dTC/YAIAii2RHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 944->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNpdSNWMzHqQ6LPmSa3HBBFyM3XJHliNGPS4wY/6CbwYDuNiLCFa4O
l79ICE98ZhIblrj4xKYjXGZSmh5JMQc97LABYt1ODMDmdnzqYG7DBACRZZFd

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 945->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNpdSNWMwnRh2Mj0yTGy7oYmSHK5IcMfpxiZFjBgO624gIV7h9uPxF
QniiuAvNTKLCEj1eGYjTT4yZlKZHXG7AZj6Gf9DiA5tZDNj0EwmwuR2fOuRw
RQUAO+uSWw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 946->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMYM9
phipGB8gVj8yjctcst0Hw0SYAVOLwmdApckNF3QxssMVSY4Y/bjEyDGDAd1t
RIQr3D5c/iIhPFHchSft4AxLLG4gRj+h+CErTWKLG1LsxhemWNzEgK6fBIDN
7bjU4XcXAAG2kF0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 947->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJdt9MEyEGTC1KHwGVBqbHmx8DIAmhs8NeMMVSY6gX3CEKTqbUNzi
dBsR4Qq3D0+4kJJO4Gag0QT9gcMN2NIewbghMi5JjhsSwgKXf3C5iQFdP5Z4
wAWwuR2XOgZkjAEAHayNmg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 948->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNpcR9MEyEe2BqMfTak+4ODIAmRna4IskR9AuuMCXWDDQ1DDjMISp+
8YQLKekEbgYaTdAfaGkN2W/obsQXpshhS0wYkhQ3pKQtfGGKxU0M6PqxxANO
gMXtuOxkQMYYAAD/hI3Z
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 949->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNpcR99tjNJ6QexoZjEt2BLSxICRucAEmOkD9whimxZqCpYcBhDlHx
i8tfJIQnirvQaIL+QEtryH4jpB/D/2hhQE6axBo3pKQtAmmFYPiRArC4HZ+d
MD2YAAAcQ5Bb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 950->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNpcR99tjNJ6QexoZjEt2BLSxICRt8YUqMGTA3YzWTSP+g28OAwxyC
ZmDTi2QGyfHCgGou0W5gwHQDOWmDAYsZpKZJrHFDatrCk1aw6SGUtnABbG7H
pw7mNkwAANPzkFs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 951->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMJdt99tjNJ6QexoZjEt2Azf2k+AdfmBJjBjY3wwERZmBTw4DDHKLi
F5e/SIxHDPuJdAMDmlvQw5NsNxCpF1s8YHMjSWkLT1rBFQ/40hYugCtd4FIH
cxsmAACDPJDd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 952->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMpciNWMzHpxZDLwn68bmfFP/gBEhypPqZZDPQ1DDgMIeo+MXjL1LS
CYb9xLgBCSOHDdxtxLoBR/yQnB6x6IP5h1B6RPc/sfGKNfyIBNjSFT516G5B
AACRkpEc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 953->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNpdSNWMzHpxZFH5J+UtyBAexRabLDFUkOm5vx+RmfGfjcgG4PujlE
xS8ef5GSTjDsJ9INDMhuQPMbuhuJShskuh9fuCK7kaS0RUKYYg0/IgG2dIVP
HcxtmAAAR6uPHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 954->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypjxns
GXACovQzoNLI4nBAJTcSqxZFH7IfSbETHaCJEbIfJ0CSI9XPJJuBpgbDbUSE
K0wen79ISSdk+wPZDWj6iHYDjrAkOT1icTMpZqHbTUx4YHU7kQBbusKnDt0t
CAAAUmSQGg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 955->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj07jMpciNWMzHpxZdHzJNdrigiRGyHydAkiPVzySbgaYG3W3Y4g1n/OLx
FynphBJ/ILuFFD9gTRtIbiA5PWJxMylmodtNTJhidTuRAFu6wqcO5jZMAAC/
oY8g
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 956->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdiNWMzHpxZdHzJNdrgQ6Sfk8MAKkORI9TPJZqCpYcAiTowZ2PQS
ExY44wXZH0S6AcXNJPoBrxuI1IsvXOFipKYtEuIVl9uJAdjSFT516G5BAACV
fJAe
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 957->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9MEyse9D1MqDSZIcLkX5CDg+sAEmOoL/xhClRZqCpYUA3h4hw
hfuHTDdgjRdk+4l0A7Jd6GFIkRuI1IsvXOFipKYtEsIUl9uJAdjSFT51MLdh
AgDx2o6g
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 958->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttSDTR7sGiD5kmO1xw+AndTOTwwAqQ5Aj6A0+YEmUGulvR/UFE
uML9gydcSInLBnT7iXQDA5pbkP1GSD+h+CVXLzY3kqMfGyAq/IgE2NIVPnUw
v2ACAPG8jl8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 959->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9MEyse9D1MqDSZIcLkX5iwKUfizkE/Y0nTIkyA00Nhj+ICFeY
PDJNihuwxgupYYFmF7o+Yt1ArfSJTR/MPyTZTUK8Yg0/IgG2dIVPHcxtmAAA
sWGOIg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 960->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch99tjNJ+QemF4wIEE/znAh0k/I4YErTIkJF2xuxmUeIT+g8JHN
ISJckN1MjhvQ47EBi/1E+QM5LaDpI9YNWMOSnDSJxc2kmIVuNwawxzQLa/gR
CbClK3zq4G7AAADRi4+g
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 961->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9SJhY9dj0ggEl4UKkn5DDAytAkiPob1xhSqwZaGow/IHFDkLx
iw2QHC9k+AOFRtNHrBtwhSW5ejHEyLQbKyAm/IgE2NIVPnUw+zEBAGhujx4=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 962->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdiNUEysWnR9DDD3UBIuRPoJOTywAiQ5gn7GFaY45HH5AYWPbg4R
ZiCHKzZAcryQGhbobkDTR6wbqJU+semD+Qefv7H5H1d4oOvDGn7Y9GEB2NIV
PnW4zQQAOMOQGg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 963->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9SJgSvWBASbgQ6Sfk8MAKkOQIuh1XmBJrBpoaDH9gsQOnf/Ck
F1LSCbn+QHEDmj5i3UCt9IlNH6lhgTU88LiJAYt+YgG2dIVPHQNOdQCuwJCe

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 964->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9MEyGOQxo+hkoCRci/YQcHlgBkhxBt+MKU2LNQFOD4Q8iwhXu
HzzphZR0Qq4/UNxAoh8IxS96uBOrl5AYsXYTE6YMOPQTA7ClK3zqwACrOgAA
MY5h
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 965->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdiNWMwnRR8yTXa4EOkn5PAgBEj1M8lmoKnBcBsR4QrXQ6Yb0M3B
Zj/JbiDRD3jjl5z0iMXNpIYFsnpiwpQBh35iANY8gUcdLFwwAQCnFo9j
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 966->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9MEyGOTB9yDTZ4UKkn5DDgxAgxu2E4ooYP+B0GxHhCtdDphvQ
zSHXHyhuQPMbsW7AGpbkpEksbiY1LNDdTyg8GHDoJwZgzRN41MHCBRMAACx4
jyQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 967->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttyJgMc2D6kGmyw4VIPyGHByFAjNsJxRUxfiDkNqLiF1+4kJBO
yPUHuluQ9RHSjxym1Eif2PSRYha63cSEBy63EwOw5gk86sAAqzoAE66NJg==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 968->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj01jNpcR9MEyG/2H6kGlywwVdjJjwIASIsZ9QXJFiBkpYkGAGLCxx+ovI
uMDwBw5/Ekpj6PoI6ScUv+TqJSRGrN3YAFHhhxYHuADWPIFHHW7zANOVjeU=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 969->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9MEyGOTB95OjHFhbE+AmbWnLCF5ubSTYDTQ1yWJBiBsw9OP1F
QjpBMQOLG4lJY+j6COknFL/k6iUkRqzd2AC29IAvHWCLV6zuJEIdbvMAjQGO
5Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 970->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9MEyGOTB9yDTZ4UKkn5DDgxAgxn5CcUWKGdj8QYwZsLDE6S8C
cYCePsjxB7pbkPUR0k8ofsnVS0iMWLuJCQ8GHPqR4wAXwJon8KjDbR4AdHyM
5w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 971->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpch9MEyGOTB9yDTZ4UKkn5DDgxAgxu2E4ooYP6DwsZhDVPziSy8k
pBMUM7C4kSg3YDGD5LRBgtsJhSsuMWLSFrHxyoBDPzEAa57Aow4WLpgAAEHL
jaQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 972->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnSi8F+jEAkX5CDg9CgBi3E4orYvyALSxJMYNgeiEhnaCY
gcWNeMMUPV6RzCArXRFhNzHhikuMWLuxAWzpAW8c4AFY8wQedWCAVR0AvBSO
Jg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 973->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnSi+afgZKwoVIPyGHByFAjNsJxRUxfsAWlqSYQTC9EBkX
lPgD2QxkP2BzI6nxS65eQmLE2k1MeBAKP3wAa57Aow4MsKoDANbxjiY=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 974->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnSi+afgZKwoVIPyGHByFAjNsJxRUxfsAWlqSYQTC9EBkX
GGZgcSPeMEWPVyQzyEpXRLqdULjiEiMmbREbHljDj0iANU/gUYfhLjgAAAdB
juM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 975->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnSi+afgZKwoVIPyGHByFAjNsJxRUxfsAWlqSYQTC9EBkX
lPgDhUbzGyH9hOKXXL2ExIi1m5jwIBR++ADWPIFHHRhgVQcAeDKN5w==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 976->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnSi+afgZKwgWHn9DNRA4PQoAYtxOKK2L8gC0sSTGDYLiQ
kE5QzMDiRrxpDD1ekcwgK10RYTcx4YpLjFi7sQFs6QFfOsAHsOYJPOrAAKs6
AB1JjWU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 977->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttMHOwmE+OfgYqhQs+tyCHB7lmILudkJuI8QMKH4s5xMQv3nAh
IZ2gmIHFjXjDFD1ekcygJN2Tq5eQGLF2YwPY0gNGuiYSYM0TeNSBAVZ1ALFk
jSY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 978->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxJxwyE
5PEAosxnQKWxmUuOu2FuBwMs5pOjn1BYEBsu+NyCHB7kmoHsdkJuIsYPKHws
5hATvzjNICKNoZuDopcEN8BpLGaQnDaI9D8x4YpLjFi7sQFs6YHYtInPLGzx
j64ONwAA/i+MZw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 979->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttMHOwmE+S35DMoUa44HMLcniQaway3wm5iRg/oPCxmENM/OIN
FxLSCdZ4IdINMHsYsJhBSbonVy8hMWLtxgawpQdi0yY+s7DFP7o63AAAvXSM
aQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 980->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttMHOwmE+S35DMoThcCLgFOTwIAWL8TshNxPgBhY/FHGLiF2+4
kJBOsMYLkW6A01jMoCTd44sDYsIVlxixdmMD+NxCKsCWrvCpww0AkfiL6Q==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 981->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnyW9I5lAjXPC5BTk8yDUDrJ9AmBJlBpoalLAgwQyC4UJC
OkF3FylugNmD4gdK0wYFegmJEWs3NoAtPRCbNvGZhS3+0dXhBgBfoY1p
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 982->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttMHOwmE+S3+xJdwshQEx4kGsGst8JuYkYP6DwsZhDTPziC1NC
ZqCbg80MUtIYAxYzKEn35OolJEas3dgAtvRAbNrEZxa2+EdXhxsAAJSbi+s=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 983->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMzHqR6bG+xJdwshQEx4kGsGzB/4wpQoM9DUoIcFsWYQEy7E
phNy4gUmjy9uKUn35OolJEas3cSEJ9bwIxJgS1f41OEGAC5jjCw=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 984->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttMHOwmE+S3+xJdwshgOxGXOFBrBn4/E7ITcT4AYWPxRxi4hen
G4iMGwx3oLmF1DRGih8IxS+5egmJEWs3NoAtPRCbNvGZhS3+0dXhBgB+wYus

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 985->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttMHOwmE+S3+xJdwshgOxGXOFBrBn4/E7ITcT4AYWPxRxi4hen
G4iMGwx3oLmFqDSGxx2UpHv0cCdWLyExYu3GBrClB2LTJj6zsMU/ujrcAABO
gItr
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 986->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnyW/2pLuFECAmPMg1A6yfQJgSZQaaGvSwINYMYsKF2HRC
TrzA5BnwxC0laYNcvYTEiElbxMYrVr8TCbClK3zqcAMASE+NKg==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 987->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnyW/2pLuFECAmPMg1A6yfQJgSZQaaGvSwINYMYsKF2HSC
7i5S3MCAw2/E2I8vfknSh8PNpJiFbjcx4YnN78QCXO7HpQ43AAAPS41r
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 988->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnyW/2pLuFECAmPMg1A6yfQJgSZQaaGvSwINYMYsKF2HRC
rj9gYYLNb8TYjy9+SdKHIy2RYha63cSEBza/EwtwuR+XOjDAqg4A0MmM6w==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 989->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwnyW/2pLuFECAmPMg1A6yfQJgSZQaaGvSwINYMYsKF2HRC
TrzA5BnwxC0l6Z5cvYTEiLWbmPDE6nciAbZ0hU8dbgAA/i2M6w==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 990->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwn12/UCBd85iCHB7lmgPUTCFOizEBTQ5Y7iHADITPQzUHW
Q4obsPqFCmmDXL2ExGDxSMhuYsKTAYd+YgC2dIVPHW4AALVljC4=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 991->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttMHOwmE+u36gRLvjMQQ4Pcs1A9jsl/kFXQ5Y7iHADITPQzUHW
Q7Q/oGGC4Q4qpA30cCdWLyExXOah243uF0LmkAqwpSt86nADACCliyw=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 992->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMJdttMHOwmE+u36gRLvjMQQ4Pcs1A9jsl/kFXQ5Y7iHADITPQzUHW
Q7Q/cJhBjbSBHu7E6iUkRqzdxIQnAw79xABs6QqfOtwAAAFHiy4=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 993->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdR92Mwn12/UCBd85iC7l1wzwPoJhClRZqCpIcsdRLiBkBno5iDr
IcUNDNjcQYW0gR7uxOolJEas3cSEJ1a/EwmwpSt86nADALFCjO0=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 994->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwn12/UCBd85iCHB7lmgPUTCFOizEBTQ5Y7iHADITPQzYED
LG7EG6bY3EGFtEGuXkJixNpNTHhi9TuRAFu6wqcONwAAoiSMbQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 995->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpdh9WMwn12/UCBd85iCHB7lmgPUTCFOizEBTQ5Y7iHADITPQzYED
LG7EG6bY3EFp2iA3TeIIF1LTFrHxitXvRAJs6QqfOtwAAOw3jKw=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 996->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpZb7qOE3aoQLPnOQw4NcM9DNItc/6GrIcQcxbiDGL1jNwOJGYtyA
zYyBSFeExIi1m5jwZCAhbeIziwGPfsLmAwAiFY3t
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 997->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpZb7qOE3aoQLPnOQw4NcM9DNItc/6GrIcQcxbiDVL3CAxY3EuAGb
GQORrgiJEWs3MeHJQELaxGcWAx79hM0HAM98jS4=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 998->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpZb7qOE3aoQLPnOQw4NcM9DNItc/6GrIcQcxbiDVL3CAxY14wxSb
O7C4kV7pipAYsXYTE55Y/U4kQDeHkDrcAAAOfIyu
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 999->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUj09jMpZbbqOE3aoQLsjkMeMKDWDMIhS25/sFwKxnuIOgGLGqwmoPNDCxu
JMYN2MygJG2Qq5eQGLF2ExMnWMOPSEBs2iZsPgC2bozt
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 1000->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuypj/EB
YvUTMpdabqOG36gRLvjMgckRA0gNW1LNQFdDjjuIcQMxfqHUH7RMG+TqJSRG
rN3khAcpgFj9hM0HAP5Qjm8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False]}, Dynamic[$CellContext`i27$$],
                Alignment->Automatic,
                BaseStyle->"ListAnimateCore",
                ImageSize->All,
                TransitionDirection->Horizontal,
                TransitionDuration->0.5,
                TransitionEffect->Automatic],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
        GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}}], If[
        And[
         CurrentValue["NotebookSelected"], 
         CurrentValue["SelectionOver"]], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i27$$, \
$CellContext`i27$41452383$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 1000, 1}, 1000, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{309., {82.884033203125, 88.615966796875}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.773595979453616*^9, 3.773596768837328*^9, 
  3.773596832477297*^9, 3.773597011789155*^9, 3.7736027037163677`*^9, 
  3.773603929121544*^9, 3.7736068144668283`*^9},
 CellLabel->
  "Out[306]=",ExpressionUUID->"30a8cd2c-377e-4355-9c82-8bd1d5f1efd7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Image", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{"iSmallBoltzmann", ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "13"}], "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.77359739800218*^9, 3.773597551182933*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"d61886b3-b88a-4a57-9ede-6fb752ceb58a"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[
    RawArray["Real32",{{0., 0., 1.}, {0., 0., 1.}, {1., 1., 0.}}], {{0, 3}, {
    3, 0}}, {0., 1.},
    ColorFunction->GrayLevel],
   BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Tiny,
  ImageSizeRaw->{3, 3},
  PlotRange->{{0, 3}, {0, 3}}]], "Output",
 CellChangeTimes->{{3.773597426288801*^9, 3.773597552055311*^9}},
 CellLabel->
  "Out[259]=",ExpressionUUID->"7ad8f294-58ef-4e51-a1d3-94bca1dd5a56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "should", " ", "recall", " ", "Boltzmann", " ", "if", " ", "it", " ", 
    "halts"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"WatchImageWalkSATCRN", "[", 
   RowBox[{"memcnf", ",", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pix11v9", "\[Rule]", "0"}], ",", 
      RowBox[{"pix11v10", "\[Rule]", "0"}], ",", 
      RowBox[{"pix11v11", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix12v9", "\[Rule]", "0"}], ",", 
      RowBox[{"pix12v10", "\[Rule]", "0"}], ",", 
      RowBox[{"pix12v11", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix13v9", "\[Rule]", "1"}], ",", 
      RowBox[{"pix13v10", "\[Rule]", "1"}], ",", 
      RowBox[{"pix13v11", "\[Rule]", "0"}]}], "}"}], ",", "1000", ",", 
    "5000.0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7735971497218122`*^9, 3.773597173751794*^9}, {
  3.773597558854411*^9, 3.77359768234484*^9}, {3.7735978558792753`*^9, 
  3.773597869299316*^9}, {3.773598004447362*^9, 3.7735980065158043`*^9}, {
  3.773605135086097*^9, 3.7736051448627977`*^9}, {3.7736067582827997`*^9, 
  3.773606760683652*^9}},ExpressionUUID->"512aa3c8-1a45-42ee-8273-\
d8df241fd9e5"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i23$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i23$$ = 1}, 
     "\"max\"" :> {$CellContext`i23$$ = 1000}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i23$$], 1, ""}, 1, 1000, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i23$39050069$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            TagBox[
             StyleBox[GridBox[{
                {"\<\"\"\>", 
                 AnimatorBox[Dynamic[$CellContext`i23$$], {1, 1000, 1},
                  AnimationRate->Automatic,
                  AnimationRepetitions->1,
                  AnimationRunTime->0.,
                  AnimationRunning->False,
                  AnimationTimeIndex->5.,
                  
                  AppearanceElements->{
                   "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons",
                     "DirectionButton"},
                  AutoAction->False,
                  DisplayAllSteps->True]}
               },
               AutoDelete->False,
               
               GridBoxAlignment->{
                "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "ListAnimateLabel",
              StripOnInput->False],
             {"ControlArea", Top}],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZMGhc
GB2gi+FSi4uPrh5dLz55dHW43I7NfbjE8PmbkL3EiOFyAy634NOPL17w2UnI
b7jksPmNlHDC5l5i/YguhiusiPEbMW7CFab4wgAfG10/rnAgJgxwmYPPD8Sk
RUJ5FpedxOYfbP6EyAMAVY18hw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 2->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZMGhc
GB2gi+FSi4uPrh5dLz55dHW43I7NfbjE8Pkbrg+HvcSI4XIDzFxC/iPGj4Ts
xOc3vP7G4jdCZuFyM4p5RKonJi0Q4zdi3IQrTPGFAT42un6s4UBkGOAyB58f
iEmLhPIsGBAZJ7B4JeRPiDwApgR7hQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 3->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZMGhc
GB2gi+FSi4uPrh5dLz55dHW43I7NfbjE8Pkbrg+HvcSI4XIDzFxC/kPRjyde
8NmJz2/oZhPyGyGz0O3HFr8MRKonJi3gcz++tEVU/BAIA3xsdP3I7sRmJr4w
wGoODjl0N+NVhyOPosgRGSe40ie6XRB5AEX1eYM=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 4->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZMGhc
GB2gi+FSi4uPrh5dLz55dHW43I7NfbjE8Pkbrg+HvVjFcOjBFpYMuOzDwoaZ
jdMsXHqw+BHdzTj9jcW/hMxCtx9b/DIQqZ6YtIAeNhjuIdJNuMIUXxjgY6Pr
R3YnNjMZ7LG7j1DewOUHgmmJgQElbNDVMWBxFy434Euf6HZB5AEjY3mB
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 5->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZMGhc
GB2gi+FSi4uPrh5dLz55dHW43M6AxTxsbkZhY/E3XB8Oe7GK4dCDLSwZ8NiH
LUzQ1aMDrHqw6Ed3M05/Y/EvPvW44hHDPCLVE5MWCPkNWzzgSnNggBy2OPyH
z0248gx62sQV54TiApdbsYYzDjZWv6KpY8DiLmxuQPcbTnegqAcAERR4/Q==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 6->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHHoQr31Cv6APEL9gXxBBT4KgB/HWp7dCKXUyYxJINMnO7OxO
Hv3cjTcAa/lZurC1yxL2Z3FshjDV1XRc3r8TeDWIvm7yiM5MrNszN2Ov7jnO
aYfgYy0Rv6j7hzN55ZnBqF5y7/7zqZ64XrMOixG5lN+qNmTEOx8jvsz4nLeQ
qg2Uz2lSXrNO5c/VW1a1pThTXjitss/mX9aKsz4IXSe88sj5DY5/Ay0cd7o=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 7->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKQjEMHFyIW4/gFfQAD6/wPEEFXT0Qngtx59H1geI0mWkL/aRNJjNN
dufbeF0BuG8+y1gex3kuz9N6MS5lOuyn5XH7ncBrQNp5gs+/EWL4Pvnij1PZ
IRfb7Ofeo5/irvIqbgk/YnA+k5f1J80dDhzbwnQc1ejGiFzp7wQO62n5uzom
PNVLBrfXC1Yb90KDe8RF4CT1NTip2qjedJi9Wjiu8p/NWWpFzQ+CVxWvauTq
jdofwxtE5Hc2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 8->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+LNp2tBcbI70xhIk202s7Mz
2Z2v/bACcNu8P325H6epPE7rObiU8bAf58PtZwLPDmnlCd5/R7jD/1MufjhV
HGpxzHnuPOYp7qqu4pbwIwbXM3W5/9RzgwPfXcKscI3WkZvrK3FF3fOSzvgj
3/koewn5Sn+lj+OvfGDdWpyU15Gn81z6T0O9TYfp8pw+XEO9U7WXvUaMlgdC
U/U+lQfoXtBKdTQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 9->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENgzAMPPWB+u0IXQEGQF0BJkil8kJCoo+qP0YHJKI6zl2opQCJz/bZ
F+7PqRsuAN7X7dGFz2Oew7ev9s0rjE097s7bsYClRfa2C/Y7mouJtjAsfnmS
PcH72JLf4xh3xU+dsZ6zeqJu9CVnJAaEgz0v5Uzyih49N9VXxhVpz6U54w+8
0pH24vBs/mw+ij/Twc7tjBPT2vNUmlP9jfl/q5RT4dR8bA12TxmO9upznGlA
ZsruJ9MA7Qo0q3R1
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 10->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKgzAQXPpR/PUIvUJ7AOkV9AQp1C+hoB/FP4+uQqST6eziQqK7mexj
JrfXp+0vZjZV29am73Mc09xdd+edhsd92A/rvMyWZtua/M0+LsP/wwCLtigs
1Ch8gee70TnjVO9ef15MzfxXz6l7nBUxccdEDxiPchZ5SSM2xSPf4VqKO8Wz
ncB7OkazKC6YB0+rgiuhA9aKeuJ8GJfzRe/T0YV183J6OI8frKHeqcLJWTnH
CQ3UbJHeP38FU8J0cQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 11->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeoHiFeoIRdFUQ6kLc9ei2MGjm9yU4MNPJNPlJ
/s/h+ujvGzN77uajL6/zOJb3ZbsYtzKcjsPyc1+32dTNR1e/1fbb/F2Wvk2R
b8XROPVvYrUOW98zPKojejPFD3J/e4G8vmbF9THeh94zzAZXNNKlMSstIRdx
RzwrX+RP+ZV/7YW4oHmgnhquQAefK6sp0wf7y+Yz0EV1izAjv4gfn4PmlPyw
V8X4QwPqLdP7Z38AKzRzsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 12->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAQHVyUbnsEr9AeIPQKeoIIdhUo6EK669FVCO3M881gINH83mde
2uHdvRoRma/b0OXlOU3501/2yZjL4172zVvtIt+0Dal+61x30f/QcE3fMQ3W
GJe5L5b3sA96Iu1UH3pw8JH754Xwas2Ia3QkjoV1ZpgGN/Bp7ju+mI5D/QjO
2fOMH+uPXlgt2HtgnkytSA6aK9IU5cP8ee83ygVzczN3znn10RzsnbJz1Cti
nMiAeYvy/s9XH2tybw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 13->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYyRxdABuhiyHhSAJgbT14BmNoo9WOxGdxM+87C5A5s/kNVh8zOy2XB3YbEX
JocihkUPituxiGP4D5tf0cOGQNxgjUss7sAIPyzmEKsem/3o4Y/uF+TwwlBP
KC1gScfIdiCrwecmfPGDzX+40i++eEGPN5zpCIc6XOGDbAc2t2NTh9Wv6GYQ
EQfY/IYvvhF8AJZbcms=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 14->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOgzAMtHqouPKEfqE8IOoX6AtSqZyQkOBQccvTC1KX8WQCRMpue2Zs
Xx5D253MbKqWpY2v2zjG+X5eL8/YN9d+/aw/0yyFZQl+x4l/PBK+kY8b9Pb1
czjmz0Z83H/w2Cqe4pHID/Wr+Iz94yVwMQcc1/FgjfSe6VNaOTc7tVG6XF1L
+RNxkPeWvcLn/LMWzFdmv9cLoo8R4wh3xEFb9uM9y62RHhiqP4t9VLAr5Qcx
FHdlJ7VyjAM1UNq26v2/vwH6bnJp
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 15->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbiQbj2CV9ADBK9QTxBBVwWhXYi7HN0W/My8vEwNJG0yk5n3
yf5y728bAFM3L31+nMYxP8/bZXPNw/EwLMHdewIlzUvyXzttjEexZ3THDTr7
3HN94P9BeFw8+d6qnsJR6J7lr+pz7y8u0ddqwHUdDuZI5xU/xZW1WfFG8XK+
tvQTdSzuKF/1Z/2Zi9Wryl97C5FvQvMIU8sfxU/iAPExQ73PpucqL9Cn0hV1
jPMkV67xhweKW+T3b/8CLtNzKA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 16->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kksKwkAQRBsX4tYjeAU9QPAK8QQRzCogxIW4m6ObgIzdL9UzMP/+VFX3
6f7sx52ZvQ7L0g/v6zwPn9t+vTyG6XKe1s/jb5qVblm6uPvp/zjCO3zCwFvp
/nv1sXg24An/3i6Jp3AU+BEb4zN3tRd5vQZKG59PxaJ+1V9xpTZZbci7kcPb
Sd5Cg5a9yk/9NxxFL1HbtBdadROatzBl9VH8JA4DHzdUfyqMoTZJn2VYN7l5
JnbaMEZSA8VZ9hpjBt5fvtFyZQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 17->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkKwkAQLHIQr3mCX9AHDH4hecEIegoI8SDe5ulJQJLu6poZmL2Xquq+
PN7DqwPwOa/LkL/3ec6/8bRdnnm6Xafts/9PoKR1SX630/7xcO/k4wa9lXTs
uw/8GYTH5oB9q8UTOAr5MTbmzNh2e5HX4RPa2HwqFutnOQSurE2tNsxbxRX8
JW+hQcte5Wf9JRbSgrUNvSI4NfE0sLu4xtadRdyAg7jZEXoU5A/E2lT6rIY1
9ASfGTvbkJ2qS8ApuLXqfdwXuvNv5Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 18->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDC7ErUfwCnqAh1eoJ3iCXRWEuhB3PbotaDuZTKqB98tLMpPP
4Xpv2o2ZPXbj1tTnue/r67KdHrfanY7d9Ln/LLOhjFvxJy78Y3F68nFCuqEs
5+xj/m7EBzEMdVk84hbiMzeRM3PDWIzr+InaIJ6KpfCRl8MUfFnYJ40L/sFO
xEHeYVZUTRI7lYuaJa5tOgs/+vYPd4Uxi/BPa2uUD0iYUSN/yo37s1YfxJDc
v3fmzjZkp/oSeIrc1vq9vN9yCW9j
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 19->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKAkEMRIMLcesRvIIeoPEK4wla0NWAMC7EnUd3BvwkL9Wjgf4nqUql
N8dLd16Y2XU1Tl297Yeh3g/L6XCq/W7bT4/r1zB7lHEqcfXDv9HCPWKCFRFn
wLG4N/DxGObvWvnALeX33IhFDQy8BG7gJ7TxeImfu0+aq1oFXxpjmnldfPJr
1EZ/pZPCp/6SC7QgfvMv/OjbP9wVxsdEvNJM9t9Z+qOGOlAb+zOnT9KV3N97
cqcP/FRfEk9R21y/v+cnXA9wIg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 20->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMHHoovfYJ/UL7gMUv6Au2UE9CQQ/izaer0EMymdjArmt2k5lM
8nh/2/4CYLrtW1vnZhzr0l2Pn08dXs/huLz/FrCWfSv+a5e9Y3N+inFWRBwI
B/4M4mMxYH1ZPuIW8ltujMUagHgJXMdPaGPxAj/jD5qrWgXfYBST5jXx4V1S
G79XOq0iL+svuZAWjJ/Owp++nXGXM0waqllSmsn+G1O4Yaa5N0kvMq4Bm8+C
e+Cq5vekB6o22W+A6t4A6aBvYQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 21->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRAc/xF+P4BX0AMEr1BNU0K+CUD/Evx7dFkQ2byd1IWmasDOz
s3u4Prr7RtJzN29d/zqPY/++bJefWz+cjsPyuP8uaSrzVupvXPGNUd0jp4pi
8gQe1WdBT+RQvGvhQVvCj9rIRQ8EXYa3wjLeRL6kL9wnz12tRm8K5DRxoZn+
Wh3Gb3oxGVz6b7XAC/a+OQt/+ram3c4wPFQDz80M64/heNNMszemBucPOaj9
dzbak1Y3vys9cLXZfkuo+wPjg3Ag
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 22->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhR9diNsewSvoAUqvUE8wgl0VhLqQ7np0WxRJ3kvGgfnLzCTf
vOR0ewxjA+B53IahvPp5Lsv1sG/uZbqcp/2w/XZg7bah87Pt9oybs9Mb15K9
iwO/BvHYGLA2xOwgNvFvWTgW+wJxwduYOdLGxhM+YxfNk79W9Q44szwzM+sb
cgT5Yy3WwC/rL76DWuLcp7XwJ28ZO9eJ1CD0Hc/CQf+3TWoU9J7+JjVV0Ydj
MPtvXdMguFfTJ8uz3IWyfu69AbH7b18=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 23->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksKAjEQRAsX4tYjeAU9QPAK4wkiOKsBYVyIuxzdGRTpruqOgfw7qdef
w/U+jBsAj90yDPV5nuf6umzXza1Op+O0Xu6/HWhlGYqfbbd33Jo9ozeuJXun
A78G8VgNFK8dscNyRP9bFtbiv0Bc5D8zWybxP+Iz5xLzxNduvAPORlxRnEQ/
0LN/S61wTDp24d+U5yj3aS38yVvGznUiNQh9x7NwkP+2SY2C3pNvUlOd+LAG
s//WzM42ZNeLT5ZnsYVqfeze5HBuog==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 24->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRb96QFwZoSvAABUrlAmCBKdKSOWAuHX0tqIg+/s7REoTJ67/
i+32+ujvDYDnfvn05XUex/K+7FbjVobTcVgvD9sEpm75dH6109658T0nO/NV
ttOB34N4nCZpK3ZYDhXfsrAWxwJxwZ8xs2UK71d85jzkPHlrNd+CcyIulaeg
L/Rs7NArnJOKn4xNdVa1T3vhT90ydu6T0IOI//EaOOj9dqgeTWsu6lPLD2sw
+2/P7OxDfrX8pHZWbxPv4zcDcRNvXw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 25->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwkAMRT8uxK1H8Ap6gOIV6glGsKuCUBfizqPbosLPz08HZqaZSZOX
nzlc7/2wAfDYzUvfnudpaq/LdjFubTwdx+Vy/5vAu5uXLu48+S6M/7nYla+z
Qx7EbwhPyCm5HTuYw8VnFs2lsSBciGfKzEypfsdH50nzotZS74Kz1HWlfpeP
Y6e3opqs+NnY0ueq98EuNLE8hl3fSdIK+T/dU8+kfh7ujZY9Fz7VomJVnVMd
yq4+4reqj+kR15P6TfG+fh/0zG4e
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 26->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9klEKg0AMRAc/Sn89Qq/QHkC8gj3BFuqXULAfxT+PXqUtJLMzXVg1uyF5
mfF0ewxjA+B53B5DefXzXJbrYQ/uZbqcp/2y/W5g7bZHl99xx7u0fucUu1wV
pz7I3yCe1JN6K3YIjpWZRU1ZC8SFfMbMkama3/E5zc2sVm/DaXU19dJszCH8
Yy0il8qTtcln532KjSaSR7DD9GUNYepJz2j+uNQ/aj0nPtbCsbLO1RzMzjmU
91cf4VGcp/I71PvkvQHQOG5f
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 27->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kksOwjAMREcsEFuOwBXgABVXKCcIEl1VQioLxC5HpxUfxeOZVkpqJ5b9
PM7heu+HDYDHbt768jxPU3ldtotzK+PpOC6X++8CajdvXfy3q70L3++cfBer
/FAH0QbxhJpUW7FDcFRmFjllLhAXzFlTs7LNDMznNDe9Wr0Np9XV5At9M4eY
H+ukOFn/lJvm7GYf/JVaiUeww9RlDXmW6c0SX5oLYrzqXeqh3pHRh2sw+99m
do6huFV9xIzaftK8m3yfuDfPdW8e
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 28->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkOwjAMHHFAXHkCX4AHVHyhvCBIcKqE1B4qbnk6LYuwJ2NXcho7XiYz
OVwf/X0DYNotS1/m8ziW52W7OrcynI7Derj/GlC7Zen835o9exv++/rz4Wth
44h9Nwd+D8JjZyCJVYUXoj/ienUXhwtBjPO5Fgm+hHOub7ihPgpnyGvQz2rS
4IjeCpI61jLIYS6Uzs4POJF4DC9SBzGTeVV9G81AWM2n3mioOeFjLiKszHNz
D8bOOZSX8iM0SvU2/T55L63Ybxo=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 29->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHVHyhvCBI9FQJqRwQtzydlkXY43GI5CyOl/HY
u/O1H1YAbpt568v9OE3lcVovj0sZD/tx+dx+BKjdvHX+tGL/XoLfvX7f8L6w
euRvlwf+DsJjc6ChqwovRHzWiZptLQ4XEh3bsy8a+Bqcs3/ghuIonCmvSTzb
k4AjmxUIPwhOk1osdo6b2fzjhHHx7PFcB64Q/fgMPaP67VIzmvac8DEXGVbm
OdTB2NmG7Jr8iB7Jfotcb7snGe9vGg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 30->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAQszggrjyBL8ADKr5QXhAkOFVCKgfELU+nFRwczzhUStJMZvHY
c7g+xvsGwHO3bGN5nee5vC/b9XIr0+k4rY/73wLqsGy0qiwM4oPWl21VbSD/
5N7UQfuveLgGOraa4UWSX21Jz9xLgwvGpv4aiw6+DucaH7iRPBlOy6vJx5oE
HG5WkMQh4dT04uaQ+dF5+8eJ4tLZg+QMfSLG6Rk0k/75y2bUai74lIugq9RQ
7IrLxTMXzVtW02nk9KN8X98P3B9umA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 31->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhR8uxK1H8Ap6gOIV6glG0FVBqAtxN0e3xSKZL0kdyLST35eX
HK6P/r6R9NxNV19e53Es78t2ftzKcDoOs3G/iFS76TJSIergo9bX6ip1y6n2
bexNHbX/xGNraEVXI7wK8lMX9FyB9YeLfQFzwyv6T/GtcM54xw35DXCmvCb5
7EwcjmxXFMQp4DTpJdtDyw/37R8nxMXdE3K6PuXj+HUzQ//2RDuazhz4yIWb
K2oQO3Fl8ZaLxhbVzGaUzc/k+/p+AOt7b1c=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 32->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwkAQLDxIrj7BL+gDgl+ILxjBnAKBeBBv83QTzKGmenGgZ+2lumrO
j3kYDwBe3ToN5X1blvK5H7fDs0zXy7Q9nnYDar9OZFUMvfig9eW7qnf7qHym
96YO2r3i4RpI7qqHl3Fwftg+vX3Tg/aiK/trLBJ8Cecab7jJMOEPr5n2Tj0v
h/H3+lctvdwBFuYn5TrRTfVzdfD6hI3T1Wgm/fPw/mioueBTLoyuUkOxK64o
nrlo3ryakUaRfpTv5/sFshRulg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 33->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UjkOwjAQXKVAtHkCX4AHRHwhvMCRQhUJKRSIzk8nESlmZ2dtyXa858xO
LtNrfHZm9j5vx1g+93Ut38dpf8xluV2X3dkf26wO2wG70raBYszHoq2y7VgV
3+B39Q3yIdbZKNbZBG6JAzlY5Km+uZ/jwjdxY/4pvsbMOZ+1CpjIxjMMuZn2
op+qEeIVf9ZS1U6w4Hyas27oxvpJHRRPi3l8B82IPy71j6aaEz6eRdCVejB2
xpXl4yycT/XMNMr0g3r/2B9zsG3X
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 34->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UUEOwjAMszigXXkCX4AHTHxhvKBI7DQJaTsgbn06m5hQ4jid1HZNncSO
z4/XMB4ALN26DeV9m+fyuR+3y7NM18u0PZ72BdR+3cyqtNATBh5rY5Vj+1ft
3by7+jD5ButihHUx4o+Mh9WAqFP9cz+nhU/SxvpTfo2Zc77UajlRfZ6hnJPy
XvRTNQJe6WcvVe2Ei51Pc9YN39g/6YPSiZjHp9IXfIHHK+2tebAGNR/uwdyZ
V5Yf+Iu+/3jmUeafqffDfgENS26W
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 35->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwkAQC36Ivx7BK+gBileoJ6igXwWhfoh/e3RbLDKTSSzMbnc288hk
D9dHf98AeO7mpR9e52ka3pftcrgN4+k4Lpf71YDWzUuwRoaOMMjY6GvsW78W
z+E+5UeID9jkI2zyUf9wfUQOqDzVP9dLXHgnbszf9qdmTpxTXjdv0jPVhIl1
2ot6KkfBK/6sJQRH00vBmPz/dGP9pA6KJ2oc74pf0QUZX+ZqfOVNhVkUXakG
967mJrly/6Luz+80cvqFfF/sB72ibpg=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 36->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKg0AMHPwo/vYIvUJ7AOkV7Am20H4Jgn6U/u3RVSolmUwUdtfNTh6T
yeU59u8GwNyuW18+92kq38dpu7zKcLsO2+N5X0Dt1s2sSgsdYeCx1lbZtn/V
3s27iw/jb7DORli2cf2yDssBkaf653yOC5/Ejfm7uBnXhLOLm/EkPV1OJL6Z
9iKfihHwij9rCcExqSX0LYl/pBvrJ3VQPBH9+FT81PxZfOhrYgszZfoVdKUc
XLvqm+TK9Yu8f7uaVaW3yPXDLpU5b1k=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 37->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAQszggrjyBL8ADKr5QXhAkOFVCKgfELU+nFQRNbKeNlKWJZ8b2
9HB99PcNgOduWvr0Oo9jel+288ctDafjMD/ufxPI3bSEmWmiI0wZ8R51bIUr
NUIcKG95l/iYE4rlO+HgeAQs12yduV6lhfeIJ32i0fjJnrh47pVwovzsofXJ
9b6lYw0P492Kp0tcxLdG/qUa3D/bB6cTGse76CN+cWTmyD0355Zf0leqwdyd
b1Yr8zd1//fuXzV+OF+/2A/tIm+W
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 38->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRQcX4tYjeAU9QPEK9QQRdFUQ6kLc5ei2aGDy5icGkqbJnz9/
/uRwfYz3jZk9d8syptd5ntP7sl1/bmk6Haf1cv+bZnlYFjczpg3AlOHPrY6t
cCWHizPwlvsQ7zktYnkWNCgdDsucrT3zVbXw6/GoL9Qo/KQnKp69CprATw+l
T6r3jTroUcCb8O6Ppz0tvoYefy8H+yf7ILyvfBV88s1Anx+ZGtlzsW/5FfqK
HNSufJO1Un+Lu/VWhR/K1y/2A+hVcFc=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 39->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADFK9QTxBBvwpC/RD/cnRbMLg7OxsDm6bZ1+xM
DtfHeN8AeO6WbSyv8zyX92W7/tzKdDpOq3P/NaAOy2askmGgmLbsPXyui2s9
TB6obvOHfFsTMZbvAgaFQ9xZHOrM/dws/LXxNF+YUfDJnPTyJd+kp8sx/oBD
aZ/Mwf1DPAR3fzjtYbEz9Or3erB+UgfBveNV1FMYGZ9dlTGy5uKc8RV0pR6M
nXFl+QF/Vjt7q6wFYtyvxwcjpnBZ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 40->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEOwjAMszggrjyBL8ADJr4wXlAkOE1C2g4Ttz2dDVGROE4rtdNSJ7Hd
nO6v/rkDMB3Woy/zdRzL+7bffh5luJyH7fL428DSrUfnv3bbu++uy8bhcx2u
9jB5ED0rLq2JiOVY4KB4iJjSyVxsD6eFNDk86QsahZ/sSStf+p1wWYhr4KHe
PtGRzgpEnsArT1tcrIZW/VYP9ly+g/De+cr1oDkyP7eE99n8yZmiGoqri4u7
dC6gcWntbFb5LRBx/x4fTWdwVw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 41->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgkAMnHAwXnmCX9AHEL6AL1gTOZGY4MFw4+mCkdhOp9hkl7A7nc50
e7o9ur4C8DwuW1de7TiW6XpYf+5luJyH9bL+LmBulq3xX7vs3WdtweeUY2Om
PIiaG87lW05ELJ8FDUqH8KB8shZbw+pjTw5P/oLHf1rYHyJGeVJaWH/Qod4+
8ZHOCkSewKue7mlhjox/rwb3XL6D6L3rK/MJHqXPheh9Nn9ypohDaXXn4i6d
C2hcyp3NKr8FIu5X4w3NLnBT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 42->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbiQbj2CV9ADFK9QTzCCXRWEdiHuPLqtWJy8vKSBzLSTz3v5
HG+Prt8BmJr56MrzMo7ldd0vP/cynE/DYjz8FHi389Hau9ba9tVV+J1ijFAc
BObKxcTXOeF9QfGOA/Fw3JI6OU+NUfPjmpDx4xq3uCCPl/0OuDB/xyPAV3WE
uwIRJ/xBvtkuKUyoPBsY3HM5BzVr2G9VZ9YjJxFHlUftFOVQXM27sIV7Ae0X
5o52lWcB7/fH+AB6sW/R
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 43->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHoovfYJfqE+QPoF+4IV9CQU7KH01qdXRXEzmWgXsotmJ5mZ
TdE86+4E4HUZtzq978OQPo/z9NGmvrz1U/K6BPCtxq2yZx55bo518X/CmEU4
iJ4rF4PPa8LfBeEdB+LhuO3o5Dqs1egSOcmPNR5xwT5e+h1wYd8cj6C/0hHO
CgQu6gmhUXBRPaHqHPRgz+U7CO+Nr1xP1FH6zYo4/jFv7Fc0S7lvrIP7Sq3M
P6odzSq/Bfy9Df8DwT1wTw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 44->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHHoQr31Cv2AfIH7BviAFexIEPUhvfXq1VMxOZqOBTdDs7M5M
9vYc2tcFwFQuWxvmZhzD+1GsH13o71W/Xl7/AXzqZavtGUd894tt8X/CmEU4
iJ4bF4OPayLNhYOXfCG4ZXRyHdZqdIk7xS/RKPixJzm89NvhojzKvd+Rz3JW
IHAiH5SbmyXVE6rOQQ/2XL6D8N74yvVEHaXfLI/jiXljv7xZin1jHdxXamX+
Xm1vVvktkObt+C8oI3EQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 45->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOgkAMbPww/HoEriAHIFwBT7Ak8kVCgh+GP48uKxjb6RRsUh7bne7M
bMtubPuTiDyK5dGmZzNNab6d8889DdV1yMXLlkvUa77UW6euffIbuA4YE4Bj
Z+ZweN1T/F4J8BEPt1aTPkwL0Wp0kRrFokbCDz0x32QP08S47HpE+h35jBhT
E6+Z8XUaj/qymQz44BnoOb0H4r3xFXmQPky/iYjjH/OGfkWzpH1DHXQWUSvy
j3pHs4p3IX7fD/8G7xBwjg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 46->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgkAMbDwYrj7BL+gDiF/AF6yJnkhM4GC88XQBMWmnM26TsrDdGWa2
Pd6e3WNnZmMzP7ryugxDeV/3y8e99OdTvxQPW87RfnNyq09fW/MXuA+YEIDD
nLZ6wntOy2cVXulIey3hYV6I1+CL1CgWPSp9wjPiqU+hBfmSDtbzP5oQE85b
9sz0Jo81XjaTRCP7B9457QPzafGd3Y+aRewv3r/iVPNW7aGBJtCOunAufAT9
iruim50NfOveB7xnbc8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 47->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKg0AMDH4Ufz1Cr9AeQLyCPcEW2i9B0A/xz6P7qIVkMlkX4mOTyc7s
5P7u228hImO5Pdo0NcOQ5tdt//mk7vno9mR1xrbqXyzqrUPnjvgv3AeMWYDD
WM68w+ue4msjfMTD7dWkD9NCtBpdJEexqDHiF2hGPNUZcMF+jgfzPMMJMaZe
vGbG12nM9MW7ZP1D36Am9IGdKfab3Q/zms2fO4P1zMzbpYcCnIC7uQesi2aR
4KknipfzQtWafsfeCnVzbow=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 48->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRQcX4tYjeAU9wOAV6glG0FVBqAtx16PbaoXMy89oIB3aJL//
/8zufOuuq5TSfTM9uvI4DkN5ntbzy6X0h30/F7dLTpE/OZrTpq298xv8jpkq
MMccl7qbt5jJ90bzEQ/3LQscpUVorXSJmuunhha/QDM9kjoDLsSjPuK1fFYz
VT+8jvg6jQ1c7kHhh3vjPpLQD29cCC0KR/EjjvThj/v2c4cJnMDd+uj6oruI
WrgTw4t75H+rM78AqVxsTQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 49->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeoHiFeoIKdlUQ6kLceXQ7/sCbL0ltIJ3pJHnz
8jK787XtV2Z220yftrsfx7F7nNbl59INh/1QgtuvT9Z8/Cmrusbe/jOeo6ay
BXXFXL1ims813VvMXc2dgQv3WUz5qYZGTklNqKcF96FnahT2mXAhHvsjntMZ
GKyp8qF1xtf1OIPLOUT4c3dQc9c/tHEW9BLhRPyIE3Jc8N7+ztDACdxVR5eX
vUXE0pkIL86R91Zr8wJcUWxP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 50->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8uxK1H8Ap6gOIV6glGsKuCUBfirke3oxbSl0QNpJ02yZ+f
n+zO17ZbSbptpkdb7sdhKI/Tun5cSn/Y9zW4/fhkzdtH87ZuYy+fbf4PjJF5
SuqaZV01V28x5XNlz4q5W3P/wIXnLGb52f5FTklNqKeC+9AzNQr7TLgQj/0R
z+kczNthKahTjG9zs50gb5FfwjHiTM1d/9DGGXC4c9/4ESfU4Y99+zlDgRO4
Wx1dXraLiKUzMbw4R9673IsnqM9rzw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 51->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeQLxCPcEIdlUQ6kLc9ei26sDvS1INpJ2ZJH9+
/mR3uTXtyszum/HTlMep78vzvJ4219Id9t0U3H59tOPHB/mra+zt1eo59gPz
LKkTrziuXjHN55quLeau5s7AhesspvxUQyOnpCbU04L70DM1CvsMsCMN2R/x
nM7AYM0sn1onfF2PC7jRnGY4EWdq7vpnPQ04nLklfsQJdfhj3n6+oYETuKuO
Li+bRcTSNxFefEfeO5+LF4qMaxI=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 52->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAQs3ggvozACjAAYoUyQZDgVQmpPBC/jE4LVHJ8Phrp2iSXc2zn
dpd7d1sBeGzGT1eep2Eor/N6WlxLf9j3U3L7i3Ecv1Hpz8G5T8xj3pd11XNI
6ihmnFDPmIhnwXN47jzCnnDReZZjfuwhlFNSY/2EuU80q0dWp9bDe6j6FC/4
LBiK1WiA8Er4Bo2GSzUYWMBxnNXzoD/R0/gK74/rE9d/lqNi/um3xTeEcBLu
7GM4l/Wi5NI3IV76jnpv2xdvpn9qlA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 53->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFxItx7BK+gBileoJ3iCrgpCXYi7Ht22+mScTNBA2vfye5NJ
tqdrd1kBuDXTpyv3wzCUx3E9X86l3+/62bl56yTtS0f6s7Jv0SrVLvdR45Dk
kdY6IZ9rIsaCz/DYWYJNsOg58zE+5hCKKcmxfMK8Jz0rR9lc0hyqpzbtOfCs
8Yg5n3gI145TmB4N/w4jftRxmJUrjQv5KlLH7myCT+tYHv7Yt3SG8lbowexH
iMt2UXzpTAiXzvHLx/WWmCc+uGqU
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 54->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozACjBAxQplgiDRVyWk8kD8MjptIeh6PqdYctPEZ+fO
8eF6b7uNmT1246dNz/MwpNdlO21uqT8d+ym4//pozcczrOgYm71YOad9ZpwF
eeCljsvHmuaxhv+muaO5s4rOLPbIeaFLxByeNdT4BZq5R1In55vuIZ/JXlQ4
qf798Ea8Ar5Oo+i/4mgrdRRn7jnjXD5bcH80J2r+qj37Y97CN6S7nAYxHw4X
zSLFwjcBXvyOixjWmzFvAtpsEg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 55->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBxS/UF6ygp4JQD+Jtn25b3TKdTFYDadlkdjOZ
ZH+5d7eNmT2a8dOl52kY0uu8nQ7X1B8P/ZTcfX209uMZ/uiYm71YidM5M86C
e+Bce8FjjGoyrsSYO5qLVfrM4oycV30xzgSee6jxC3rGHkO9+b5pDTkmtahw
UvoteCNewVxcj0J/xdF+vKM4s+aMc/fZgvrRnqj9q2r2x76FM6RargexHw4X
7SLlwpkAL57jKofvzZg3xDBs0Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 56->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOgzAMi/iY+N0RdoXtAGhXYCfopPGFNAk+pv316ID2kHGdQKVQmqa1
4/p0f7ZdZWZjPX/a9LoOQ3rfDsvikfrLuV82j9+YR/OJDDMG7v3DIG/rdcYa
2OM6vI+xGSMLTK775Zg7jiIX9JnFWmmAGkp+nm4RP6dn7NHVG/H5DPWMOalF
wEnph7jeO6pazxMeR9u4R3FmzbmuOM/Dwfd8ovwXarbDb+4bElbRA/+zBlxj
xD/wkvTqlo9X5ycrm2zR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 57->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHoH6hvCBI9FQJqT1U3PJ0WrFoMhm7RHITL82M
Jz7eHl2/M7OpWT5dmttxTM/rfnXuaTifhjV5+NiyLm/LsKNh7mcGcSv9jDWQ
K85kjM0YWWBy3TfG3HFVsaDPLHylAfdU8fN0i/g5PWOPrt6IH2jIMalFwEnp
h7jeO6papW/E0TbuUZxZc9VrpRUuhW8OnjN/oWZ/zJv7hoRV9cBn5s41Rvy9
u71Z3Zrj4v8XOTBs0Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 58->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOgkAMRRsWxi1H8Ap6AOMV8ARjIisSE1wYdnN0IBLz509/cZIC7ZTp
65+eHq+ub8zsfVweXfrcxjFN98PqPNNwOQ/rZrvZsq5fy/BGw72fGcSt9DPm
bIvz2Lg218hOTczDGLNXHAFzJib2PQ24p4pP6RbxiZ6xR6k3aaI05JirRcDk
6Yd11T16uZ6+EaPtnBPy0Kx4WqPeha5CH29OvPkLGf+YN3mHVKvqgb+ZnXOM
+NXZalb35rj4fwa/wm2S
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 59->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQXHooXn1Cv9A+QPoF+4IU6kko6KF4y9OrVMrsOBsNrLLJZHd2
Mpfnu+1OZjZW86dNn/swpOlxXpJX6m/Xfjms15hX84sMfww8+4fBvvk8I2Zd
jOPg3twji56Iwz3mvuFR4JyJE+dKA55pwy/STfBTdVhn5qtmQk0iDXlPzc9z
OLzQD/tG76iwSt89jqU6RT7kFaU16u10FXcinyj/FTke8Fv4htQr8gTO4bgz
hmso/7EmwGvXx+7+F7aVbBI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 60->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHIL5QXhAkOFVCag+Im59OK3qYTMYukdzUiTMz
Xo73V//cmdnUzZ++vK/jWD63/eI8ynA+DcvlYbV5XX7msCszNIM3hOEYsy5H
n7EEN3O44MQ4vk91iDMnHY2WpAacU6MvqpvQonCqf6G3ySmpiawR8Db5mj6T
/SHeqI9Z3zj/TONW/0M94FdYqla4FD/hRPoYR2r8Y97CHhJXNBOYR6WdYxhD
zR/XBHRtznH1/gs57GwS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 61->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwkAMi3ggvozACjAAYoUywSHBqxJSeSB+GZ1W9OHz2UektE1zSWxf
Drfn8NhExGs3P4byvkxT+Vy3S3Av4+k4Lsn96rOdf57wVh7oATXUI/HMaokx
9xKzOZdiJs7hfBeH+JeEQ2FxGjCnBp/TTWBRfapvqpc8O5pIjWBu0zeEBsSb
Maj7cffScDQ74TB2uTo8EKsZlS5oBpfbE7VrXYyGP2O2esIstxPIo8LOZxSm
MDVqV//tcVX/BagTa5A=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 62->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS7ErUfwCnqA4hXqCUawq4JQF+IuR7dFC29eXqYDaSeT33tJ
TvdnP+zM7HWYP315X6epfG77RXmU8XIeF+PxL/PpfuLwz2T1XeMc7sZ+cBz1
LgrXZpuLmk5Y0N7EId6ccCgsjIvrVn4m/JkDvyd5qjvFS55Yn3oiewR1Q14T
PSDejCGbj5pL4JjsBOYLs8q4ZnhA5xqhV3gauNSs1a41MWbxGzyZV5UPsROP
Cjv7KEyWxKhd3drjKv4LB3Brzw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 63->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozACjBAxQplgiDBqxJSeSB+Hp1WULiczyGS2yS2z3d2
dudbf12Z2X0zffryOI5jeZ7W8+FShsN+mJ3bj02re5vDP7Mldslz2BvHwXI8
d9G4Nvtc1MQ67G/yEHdOPJQW5vXVQpoCv6xvfK9wCJPzpc5GT2SPoG7AtYSH
wqa6Fa9kLmGuyZtAvDCrTCtxrfBNzF31CleDl5q1emvNnmX5f3SyrgoPuZOO
ijvHKE6W5Ij+BR0W97/8F/foa88=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 64->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+5ei2YO3uZDYNbJ77mJnN
6f7s+h2A12Gauvy+jmP+3Pbz4ZGHy3mYH48/A0qapuTXyLAYTAzWe+dnRrHn
VBvX5rfSqOnyK7yMQ9yxBooL4/pjIE4l8mcOfK/y8J7iJc+GJlIjU7fKC4GD
eEudWOugL1Vfgz+x+MpeRVwJq8sPkUtpZccGLu61+mtNzaL4DZ7My+Wz2ImH
w84+ChOCGKFfxQP1fo3/AvJtbI4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 65->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6rUTBGY/TSM7iOM7M
2Kf7q3vuAIyHeerydB2G/L7tl8Mj95dzv1wevwaUNE+pXiPDajBv8PdXcWYU
e07e+G++K40/q/wKL+MQPtZAcWFcPwzEqUTxzIH98P+7Pb2XPBuaSI0MfpdX
YSLeUifWOqhLxJexrLGyVhFXwso6uVxKKzs2cHGtVa81NYveb/AsFKO4uj33
EscoTMYv+8bmC3pG9Q/SB0YbbI4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 66->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAQEzmUXPOEfqF9gOkX0he40J4CgeQQevPTm5QutkYTG8bLeBZJ
9vE29o8GwNyuUx+XyzTF5/WwHe5xOJ+G7bL7GJDCOoVy9QxfQ5aDv7+Iy0bK
z8Ea9+a7tNOzqK/wMg7hYw0UF8b1w0CckhfPHNgP29/sKV/yFP2VhlxT1lWY
iLfUCdan3sXjy1i4BmtS5Qark6nF+TwquPit1V/b1czLr/A0byK4mj3/JY5R
mDJ/kSP0Mzy8Xu+YF4ozbI4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 67->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwjAUhAcX4tYjeAU9QPEK9QQRdFUQ6kLc5ei2opJ8b2ILL03e78wk
u/Otv64k3TfT0qfHcRzT87SeD5c0HPbDHNx+TMrdtHT1v2X6mooa1edMv2Ie
jbMZy25mgYXxqg9xGJ+bzx7E9cMATrmVTw70o8buUW95mvlOQ/a0fR0m8LY6
KfrcvbT4Egt7UJNFboo6hV6s57eAi3ft3tpfzVr1CzzDnRiuYc+3xByHqfBX
NUa/wKM1653zAk9dbU8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 68->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwkAMs3pAXPsEvgAPGPGF9gWDBKdKSOWAuM3T2yKQJo4zPWQ6i53E
Tk+35/DoALyO6zLk93We82c8bId7ni7naXvsfwGUtC7JfqPAP1BxYM+F7+Fx
HFyb34qqWfXC7yYP91HzYbHR3nBFDqdF4VlDq78U7IkvdYr6ykPnhcqreiLd
0if4OzWXSC/3wjnYk11t0D5xDecVLL7VF89a/X9NzyL+jk43k0Ar6zAeMIZz
UG7DEf45HVGtL2YBk+dskA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 69->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfELU9nQyA1jtMd0q2pncRu
D9fHcN8AeO7mZaiv8zTV92W7bG51PB3H5XD/C8DKvBT/zQL/QMOB3xvnEXEc
3JvPTPVsZjGBt3ZWEA6e29OuenCNoEXhWUNvvpL8E1/q7HjS8oMXqq6aSegN
PiHm1jzl2kZ55queqTZon7hH8Aoe35uL71q9v2zGLn9Fp/MNuVbW4TxgDNeg
2vKu2nrJvYZeX8wHSkdtTw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 70->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfErU9nQ0xK7KTjkK7tHMdx
erg++vsGwHM3LX15ncexvC/b+XArw+k4zD/3vwBqNy2d/2aBJWBy4M+V76E4
jprswXy0X7RwvtPLOmw+PDbtGarLckgvEZ57aOnLPKH8sM+GJzZfvEhqyh2U
V3yC3q15GnGznzwrrvlXb/BYru28gse3dPGso/eXaWzmr/TpfAPxQf+Fb5Ex
zEHc4awsXzJXqfXFfAA3tm1N
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 71->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwkAInHgwXn2CX9AHNH6hvmBN9NTEpB6Mt326rbEJDMPaA7vLAgMM
HK6P/r4B8NxNR19e53Es78t2Vm5lOB2H2bj/CVC76ej8nQkWgYmB1yv/I/qx
1OQNxqP3UgvHu3q5DhsP75v2jFiXxQi9KP+sR1Vfxgm8LvtscGLjAxdJzvCH
iBt4guauxanCZj55VpxzVW/wvpzbcQXv36ornbHA+btbCjPp0/EGwkO0ub1b
s4sCW85K4Smbxfv6fAALpG1L
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 72->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwkAMszggrjyBL8ADKr5QXjBI9FQJqRwQt3k6rUTFxIkDh8wex3bm
cL33wwbAYzcPfXmep6m8Lttlcyvj6Tgul/tPALWbh87OKrAGmhzYfeVz+Hcc
VazBeLReuXB+yqPNh9UmNcPzajGclui90hjxU57A7pkj68o8dF6Imu4MHtf5
hNi7zNOo7+wn94prZjUin7iG0wn7PuMlexzg/PxbEabQabiD8ODvzL/75y8G
2NIv1Uf49Tf/DXINbgo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 73->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAFSuUCYIEr0pI7QPxy+i0EhXxnW0eTmwntu8u
Od6ew2MHYO6WZSivyzSV93W/Bvcynk/jenj4GlD7ZentHhk2Q1MDG1fOQ++x
1cAH9yN/w8L1KY62HpZbyNnRqe0hXKA82nuiJeOLNIGNGSPzyjQUHsFMyUH7
ik6ItfPy0buznvxWPDOb4enEM4Qn7P0MF8hkHs2NdIj0iHga7CBM0DP+j3//
Ytbb0c99R6j/q/8ArPVuyw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 74->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKg0AQLDwErz4hX0geIPmCecEE4kkI6CF48+lqiNBdvXjo2ae2mevr
0/UVgKnemq58H+NY5udln7zLcL8N+2bzL2Bpt6bVfVQ4CuIO9HzhddhzEgOE
rXgYj8YHDt9Pdcj70N5Cz05OEoP1sqbMr6svygR6zhrZV5ah8RFwmjVYXJOT
6Dk7L9Po3TlPfivmzDi8nJjD+IQ+n+kCleEj3iiHKI/Ip9IO0gS7x//x9C9m
2E5+Z/9O4f3OrTqUbs0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 75->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsOwjAMs/hA/HIErgAHqLjCOEGR2NckpPGB+OvR2RCTGsfJpLTrI47t
5nR/DuMOwOuwDEN9X+e5fm77dfGo0+U8rYfHfwCtLEOxcxTYAl0O7LrxPvy9
HgOEbeowHv1vOJyf8ujzYbWFmoVPPQbzZU6ZXskv8gR2zRxZV+ah0xHUdHvw
uM6nbmbvlKfRu7OfrQh/kWuT7yZ8dD7wF/BS3GU9qhv5EPkR6VS9ZN4bcLpV
L4W9SPncS5kXqu8M3u/eF1aVbk0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 76->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszigXXkCX4AHTHxhvKBI7DQJaRwQtz6dDajUOE5XKWurOU7t
5Hh7DOMOwLNbPkN6XeY5va/79XJP0/k0rT8P/1hW/4tc7VEUbMnL5QyfWy/G
1RwgblOH+ehceDi/+Y46H1ZbqBkWozjM++F1sCbjA3sTeSIwmXkantQeKk5V
U2lrvSHTzt4pT6O+s5+5F/6irU32DZA1nE5YfJSjeu3qUd3Ih8iPSKeaJdNv
wOkG8ahZdPOhuDe8UHNn+L64D3KAbQw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 77->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KAjEMhR8uxK1H8Ap6gOIVxhNUcFYDwrgQdz26M2ohefmxkPmhyUvf
1xyu92HcAHjslsdQn+d5rq/Ldv251el0nNbN/S+WVb7RxDuKntvrWv+GrZWr
iRrWAGmrPqxXHC3Y+vQcsh7aW+gZOsfTUOeH9cGeFAdiGDKB1WmskzCRPTxN
r6fnLfQD8k/cI6bRvTPPVhy+yL2F95b44rnxGJmZTJiwTsYh4hH59GZJ3Tf0
nspNZtHw8rT/sPDmTul98t5qbW0K
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 78->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAURAcX4tYjeAU9QPAK9QQR7Kog1IW4y9FtRSF/MhMLSfjNz/w/
Lzlc78O4AfDYLdOQn+d5zq/Ldg1ueTodp3Vz/x1AScuU4uoGfgPVGcS48H9U
sdAAaYc6rJeEFtrz3T7q84jerGfBiTVC/2h9sKfAgRhaJmh1itIxTOoaSlPV
VN6sH5B/6sUxdffOPEsSfNH3pvJl/8yBP9OX6r25M9LpcXA8nE/1lsJ9I+6F
3M5bbHgp7T8s1LsLep+8N5xKbQw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 79->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT7cVhexkJhY27TbZ2ZnZ
HK73YdwAeOyWZcjP8zzn12W7Jrc8nY7Turn/BlDSsqT4doFfoKpBzAv/R5UL
DBB26MN4SWChre/yqOsRtVnNwifGCPzR6mBNwQfy0HqCFqcoHONJ3UNhqp5K
m60D6ScuzlM3d/azJOEv+trUeTkP1sOP4aW4NzMjnJ4Pzg+nU92lMG/EPf52
d1H6y9h/vFD3LnD4nHsDGKBtDg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 80->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRb84IK6MwAowQMQKZYIg0VMlpHJA3DI6LQJhf/tTKjmpk/g7
fvHufO36FYDbZhq6ej+OY32c1rNzqcNhP8yb27cBrUxD8bMyfAwmBt5vvA7j
JxogbZeH9UqihRj/8x42Hr42WXPCiTX4/lwH1+Q4EEPJBFGnZTqCic2RaS7V
4dhncfieseyZb8ZNMbJ6jXzOKXNAM1Q9Fz7VB+Kt1bv8yyGsiTqzXnLvDb8X
/kUvpnxZO+mLpb5zd3idewL7e2yM
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 81->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3Pt1WFJPJZOlCts3uZiaZ
5HC9d/0GwGM3b119nsexvi7bxbnV4XQclsv914CpzFvx38zwM5gYeH/icxhf
YICwHQ/jFYGFGN/MQ3C3ameOgCH4VR1ck9OBNOQ6Vd6cOy+licXLtGjV4bRX
cfi/sdqzvko3pZHNW/nMmXKs4Ao+r2wOkl5nfVmrQzhL6lSz5PoNfxf+k1mU
+jJ2a1aTuXM5fN69AXiobUs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 82->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADFK+wnqCCfi0I64f459HdBaXJZFK2kD6TTGaa
w/Ux3DcAnrt5GurrPE31fdkuh1sdT8dxedz/DPiUeSp+zQx/g4lBu3e+ZrAf
RJzag/MJTMtB1R/qSGrOuDNGyCHwFQ/m5HRAy+fi6Y415BozrkrDTIseD6e9
ikPzsdqzvko3pZGtm3VRmCnGCqxw5pH1gerJzr+s1SHcJTxVL7n/hn8L+6QX
pb6cu9erJfrq/vkCpfZsjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 83->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+5ei2EO1mdrY0kHd2Znay
p/uz63cAXodp6PL7Oo75c9vPm0ceLudhvjzWDpQ0DanOdR91/DraGBiMYs+x
YNp3EHFqDcYTnDYH1iB1BJpVbBEcDkPwqzw4p8YHLHj8H5JTaOfG2hkv8kJ5
AqFJxf15ofVHnkYeWd3si+IMc9vA5fbcojpQNbnyL1t9cGdBnqqWmv9Ge+fW
QS1Kfxl7rVaTf6vr5wt5SmyM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 84->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKwjAQhn9ciFuP4BX0AMEr1BNEsKuCUBfiLke3haqTyTfSwqR5zfyP
zOF67/qNpMduGrr8PI9jfl228+KWh9NxmA/3S0glTUNa/ss6Cn1CdY5MjWL3
9atp7wnyaC5fDzCtBs8BeQScKbcARlMD8EmH11T54PmRZvDQc0ROYg8jL8gT
4kR5X1wx/8jTyCPLuzgOhBlqW4HVrP0X9QH1JL2LqbPGh2Yv0Em9VL236rNm
HvBEf33tf72a2rvcP28HIWyM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 85->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwjAMfeKAuDICK8AAFSuUCYIEp0pI5YC4ZXRalILz/FylUlI7jf0+
9eH66O8bAM/dtPXpdR7H9L5s5+SWhtNxmD/uywJyN21deZc8WlgW6hqYHtme
49/T3oOoUzG4n8C0GpiD5BFwVrVZYLgeAl/pYE2VD8xPaRYeMkfJCdrDyAvl
ieKk6n640PwjTyOPLO9MHBRmqK0By+X8RHOgZlL9F9OnxQd31qhzuVdpWItX
eDpc7s08ROzmwHL43vsAcZZsDA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 86->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPyQ/noEr6AHKF6hniCC/SoI9UP8y9FtJdXt7CxNYdNsso+Z
yR5vj67fAXg209Kl12Uc0/u6n517Gs6nYb48FANyOy1t+Rc/MiyGdQ5MjWzP
8a/Jcc4Xe3A9kWs5MAaJI8CscrPo4WqI/ooHc1ppyfgUZ+YtMEpM0BpGWihN
5LuJvF9faPyRppFGFncmDKpnyK2il/P5i+ZAzaR6F1OnRgd3VslziZMcKG4L
p+vLtRmH2Ls5sBi+cR+TEWzN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 87->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfEbU9nQ2Vkrg2tlLZpm9R2
sjvf2usKwH0zTm16HPs+PU/rybmk7rDvpsttNmBoxqnJa/ad4WNYxiDkGOI5
vjn5XeGL/cI3f3J+iTniMJhBK8fzmzkHNH7mITkpnYRGCjdjnwdjAtVExRn+
sjbwcbEWCr/T1GnkaqP4/eRW8Vfh83B9wLqoPqE8NToUZ5U8WRvHI+ZxOIt/
8aeXxL7og4jh/e4FBV9rjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 88->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszggrjyBL8ADJr4wXlAkdpqENA6IW5/OhgpLE5tBpXTL1tiO
m9352nYrALfNuLXpfhyG9Ditp+SS+sO+n35uSwC5GbemPEuuAu9AXQODke13
zJifJerAeGwuait8pdnqEJqZjuw5iJ4Kl2CxCF56fU3syesOfhl/fa+Z4Ckv
vvVRec/qMJ9h+pWnyiN1N6w/2tsfXCH3S82B94XNicP5xQfZg8CwXJLbnVvS
GXixMEvkPcyB1fA69wQvz2uM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 89->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADJr4wXlAkdpqENA6IW5/Ohgqkib2tUrpla2zH
zeF6b7sNgMdu3Nr0PA9Del22U3JL/enYTz/3JYDcjFtTniVXgW+groHByPY7
/pi/JerAeGwuait8pdnqEJqZjuw5iJ4Kl2CxCF4Sfb4nrzv4ZfxlWMwj5sVc
H5X3rM7oZvqVp8ojdTdLXgXcFVyhH7/UHLCZZPdicNb4IHsQGJZLcrtzczqp
v1iYJfIe5sBq+Jx7A0+ma44=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 90->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbqtbCHJzlQtZLtpk8lk
ksP13vUbAI/ddHT5eR7H/LpsZ+eWh9NxmH/uqwElTUeq7+orw2LwOdYv8Tt4
3HJH8hxcHeuLXIevOFsepHYRPEqsQfg4XILFrNHS8LNzcD3HvkWPDaeAS/MI
L9aH015grfFXmiqN1GxYf5TPH7UaHeKj9oDtJJuLwflFB9mDwLC1ZO0Qt8aT
6osvu0TuzR5YDp+4N96ybE8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 91->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfbiQbj2CV9ADBK9QTxDBrgqFuhB3ObqtJDCfNwELk2aSmffe
zOT8WMbpAOA1bMuY37d1zZ/7cXeeeb5e5v3yVA0oaVtS/Vc/MjSDzpF+sefg
cW2PpDUoHukHuQo/wpI6CHcJdBTLQfQoXILFzPVS6GP5THdUo9MkcRHkdTjd
GXQe7RM8Xxjb6VE0G1Yf7ckfXK4P9oveAcl3MzM4xXAwbWENFsPOBB1uE9fT
yWba9my20RtysVLDL+4Lg6xrzQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 92->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtz6dFiWSl3FoKzmNE894
bOd0f3b9DsDrMC9dfl/HMX9u+8V55OFyHpbLYzFgSvOSyr/4kaEaNEb6kz0H
j6t7JK1B5ZF+gFX8EZfUQXJbjKvZ9klyQGt2ccRcL4U+hme6oxqdJsmLANfI
6c6gcbRPK2fyr0fRbFh9tCcbcrl67Be9A9sXNjPDY3MwbWENlsPOBI3cJq6l
k8207tlsozfkYqWGX9wX4NltTQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 93->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxBBvwpC/RD/cnRbMZBMZlIL27xmd3Z2
93B9DPcNgOdu/g3xdZ6m+L5sl8MtjqfjuDzufwakMP9CvTpDNhQ+qM+J76Fx
ea+4Edo351tqsLFAOOJW2plb3a3xw1hTyyK/yh/QnB2NDQ7UE+Un8lI6qtqb
WInWXk/WamR7Ax9HzdA/XI0e/twccF3UnFAc5lC5WQ0cg3uCDjfhenmqnua9
nE1TlwZb5vDFfQAjwWyM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 94->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPyQ/noEr6AHWLxCPcEK+lUQ2g/xb49uKxayszN1IftIMptk
kuPt2T92AKZu3vr8uoxjfl/3y+Oeh/NpWIyHnwAlzVuqTydYBQGD+l1YD+23
3lVspNbmsCCMvMc8RGxVO+OVjm1cC4w0XIb8KjygYyq+Ar+VH6gnCrfBXaOj
GPxXodP2F/85sr2BjqlmqPF3/WA8LzcHzIuZvfgPx1C5NbqtOkN+zI2rI/6j
fCW/0LPk8pa+MYev3wefqmyM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 95->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMPPIo+XaErtAOYLpCOoEL7SsQSB6lP4+epDSgnE5OQHYs30kn
yZfn0L0bAFO7LF3+3Mcxfx+n9fDK/e3ar5fnvwElLUva75FhMxgO9ufCfmjc
9q9yI/m7iAviSM1WR4XPPItXPr7jWAjM9dLoU/yabq7R4UAzUbxKTuejHByr
0B7OF8c94n7YOlRO9YYcPpoH8/mL3gH3Rc2M4nAOpc35anUafdybqA4bR2Fl
f6HfUqRbYq2GH24GQTJtSw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 96->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfbiQbj2CV9ADBK9QTxDBrgpCuxB3ObqtVJi8eZMGpiXJvLwP
c368+uEAYO6WT5/ft2nKn/tx3TzzeL2M6+VpK6Ck5ZPqf1T4FwwG9b7wOQyG
cQE3kr+LsCCM1LytsoMPPYucrC/mZ01cLkvWJzxVnCovzpq0W98O1+B0Z8Qh
c4LnC3sbGXEe1ofiVDPk+qNiPK9oDnZmSr3DHEqbO2v5NPo4m8iHfUf1ynyh
ZynSLXuthl/fF/EybUs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 97->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHxy+i0qJWc8zmN5LRxfPb5
4svz070PAMbTvHV5ug9D/j6Oy+GV+9u1Xy7PqwElzVuqv5FhMxgM6nNhPwyG
cUFtJH8XYUEYyXldZQcf9ix0sn1xfebE5rRkfqKnqqbSi7Um7rZvh2vUdD60
c0UxYWxDI9ajMAdRk2fIxUfvwf3wiuZgZ6ZUHq6huDmf0FTNImsT9WHzqFil
7/av3jaaIRdrOfzjfrJfbss=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 98->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFxItx7BK+gBgleoJ4hgVwWhXYi7Ht1WrMR5M2ngpWny5s28
z/H2aLsdgLGZtzY/L8OQX9f98nPP/fnUL4+HrwFTmrf0/3WG1UBnRGy5JuFX
xmBupPjmsCCM1FzoqOFtzqJOvxiI/EqT08t1quKFbs5R9YfzDrgKZ7hDPZbz
sb7GuAc8W46TZ0jlobhCPrzcHGzMlIrDHEpbuNuoO1Q8tWhWnK+q73pWvXUz
FHxLDR+/N5Mgb4o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 99->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszigXXkCX4AHVHxhvKBI7DQJaTsgbns6G2KoOHZXKW23xomd
5Hh7tN0OwNjMW5ufl2HIr+t++bjn/nzql8fD14ApzVv6P51hNdAdEVuuSfiV
MTg3UnxzWBBGci541PBWs6jTLwZifsXJ8eU6VfGCN2tU/WHdAVfJGf6hHsv5
WF9j3AOeLZeTZ4h12Jysh5ebg42ZUnFUP5R+5rfZQ8TaOB0hNy1V3/Ve4851
Cb4lh4/fG9xfb8k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 100->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4ZXRaBMg9n91ITpvEZ599
PlzvXb8B8NhNW1ef53Gsr8t2PtzqcDoO8+P+a0Ar01aW38jwM9A/PNauJvxs
DM6N4t8iLAjjOBOPDB/WLPr0jwGfX3GK+Ep+EV7wbhxH6MN1O1yS090hjxX5
ZL62JqWjmq0oJ88Q18FaLHQI5sb2NeuL1FjEUXooHsxvVUP43kR1uDy0pE5Y
4S764nwth4/fGz4jbww=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 101->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT7cVlXRmNg0kacnO7szO
Hq73rt8AeOymo8vP8zjm12U7/9zycDoO8+P+u4GSpiMt72jjt0HfUGy9iomr
c3BtJH2LsCCMcCYeLXyo2fTpnwNa33GK+Fp+Ed7wLpyHORndgmv4ID1AO1cU
04qtNTkf3WxFNXmGWAd7sfAhmBvXV6lBOsSXKo/zw/FgfqseQnsT6ZA6tKxP
WOFu+iKxNYdP3Bs2Wm/N
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 102->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx7Eq0/wC/qA4hfqC1bQU0GoB/HWp9uKyphkti3MdkszM5lk
dudbe10BuG/Goy2PY9+X52k9fVxKd9h308/tJ4ChGY/m/50FvgG6Q3PjMxgc
5/AdxMvlCibjHHjU8tOZjU6/GtD+jlPGl3Wq5hvePKNwMnNnXjofRANorSWY
GjbO5Hx0u5X1nPONvWAdZEcSXcUfmkN8CXWW+CE8jaZuF1kb15+5OKz1CTPc
jS6CjRzeuBfHSHAM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 103->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwlAMszggrozACjDAEyuUCR4SPVVCKgfEraND+YjUdiiV0ry2Tp3Y
2RzPTbsAcFk9bk297vu+3g7L8eFUu922Gz+u3wEMBd9cXjkLfAJ0htbGazA4
ruEzwjsUXyuYrOfQx6/6dGbSZ6IBlJ9x6UxGJ6l3nE6voO+E08ydeel8kDko
W53g+TJsnMn56HYr45zzjb1gHWRHEl3FH5pDfAn/+ccP6dNo6naRtXH83IvD
Wp8w07vRRbCxhyfuDgpmcA4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 104->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOgzAMs/iY9rsjcIXtAIgrwAmKBF9Ik9jHxN+OzmMDMtcpkUKBurXj
JG+eVZcBeF3nRxXe5TCEsb4sH23oH/d+2bz9EvgUONbiu3qJLXFg92CsCYXj
M/wO809yKoyn2ehInXdrJn+sHrvHd6l91ss+MVZyKr+Mv3+com7VS+WDrINW
6RM0n4fleqNZUrPlcLKHXIfyl+dL9sebg5OZikLUkey541fUe8PlchMupVP2
Cefa2ZcIazWsuAnPJ3BL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 105->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwlAMhAcX4tYjeAU9QPEK9QRP0FVBqAtx59G1+NM470sbSNM2816S
mWyOl/a8kHRdvR5tue37vtwPy+HjVLrdthuS649Lj0ZjbN4xc31dI/Znjg1G
OD/j7wr/sCZhpvqV9Qbn05mNn9hPzPldlPd+nSfHYk3iK/D7VxPmJi2JB5zD
IvIkrpdhfV7SsdqtpKZz6HMQv75fqE+2BzM7VRnoOal5wlelPd1Hlmjuhndr
ZpeAlwpb9fAElU9vSQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 106->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKgzAUHLoo3fYIXqEeQHoFe4IUdCUUdCHdeXSVWg2TmfggvphM3mfm
Fe9P3V4ADLflU4fx2ffh+7quP03oyke3Xt63BUwVDl/9vFv4LxzY3RgbmcLx
G94jOpM5FSZXL6g28d72TPzE9cR3rm7bk+DpLBafTxzH5GfOWUvFg+yDvOQJ
Op/Dcr9Kx2S2TE7mkPtQ/PJ8OX1cnNxMJSb0zGou5k1qr+IpM5qzydg4mSXB
S4JNapgBONduiA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 107->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOEGR2NckpPGB+NvRYTy01rFLpKydmjhO
nN352vUrALfN69Pl+3Ec8+O0nn8ueTjsh/lx+3VgSljO9Dmdg/yX+zaORf3G
cZzD96pG0rkhxvHF0mMr3/ZM8yn5lG+Ot+2J5tScs+E9MY6pzzOHwFQ6lFq2
dqXqFbqei+V+FXbgY2ryDGW+ciByJH0cTmunggk9m5qLfZPaKzxlRnM2iY0/
uyTmEmIDhydIwG3H
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 108->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkKAkEMLDyIV5/gF/QBjV8YXzCCngaE8SDe5uk6Lkx3pSqB9EKSSmXZ
nW/ddQXgvnkfXf84jmP/PK3nz6UfDvthNm5/CkwFy12+t1OQ/mM/wr5obezH
MfxuchQdG3g4rlhqtPFZzdSfmk9tc7xtTdSntM+G98Q4Jr+qmzHVHOpZZrvS
1Io2n5wvEk4CO/AxObmHMl4pIDk2YnCyncowwt/tCO2b5KnwlJiZSz/GRtwl
5sl9Cb6Bwwu1E2vJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 109->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHmLjCOEGR4GsS0vhA/O3oMB5b69hdpLSqkjhO
3N351l5XAO6b99Gmx7Hv0/O0Hh+X1B323Rjc/hwYGsx3872dg/xf+zGqL4zy
pjhhqz7TW9QGHo4r5hltfW1m2k/OJ48xlooHz6y6Z8N7YBzTX83NmEqHXMva
XylmRdlP6osKJ4Ed+BgdlnZotQAkR7fXoDnNITEgYkuaizklT4WnzGgu8xgb
8S8xT95LyA0cXlDNaog=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 110->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgkAMnHAwXHmCX9AHEL+AL1gTOZGYwMFw4+mIKOxOp0uTsllKp9MZ
zo9X0xYAhvLzaML71vdhvJ+WyzN010u3FKtfAlON/azX00tQ/nu/Qf1J0Hdb
nbDVnO0ueg0Pjyv2Hd3+3M6kT8wnrjGWqpuMIquzw3tiHGe+2psxlQ/GY2i9
khrSedJfZDgJbMPH8eFIQ9cLQHL0dDWe0x4SA6J25LnYU/JUeCqU5yIkNuy/
xDxZl5xf67sZMPtpyQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 111->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0OgkAMhV9cGLcewSvoAYhXwBOMiaxITHBh3HF0RSVMO1+ZJmWA/r15
r4frve02kh67z6NNz/MwpNdlO33cUn869lNw/3dpbLScze+MXM7n2q+5emOQ
N7/nvWnOCPmmj/uHWLXcMaxfu7PjJ8eTx6I84s5jM/gqHBRcBzqgJjQ/4AE1
FvNlYrLzUF+tYILeBZ5gZo3DUAsJMUa8en5Jm6KHIFbTHPYNcVI/MtIcDHur
3CWPs7p3BYY35HFpyQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 112->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksOwjAMREcsULccgSvAASquUE4QJLqqhNQuEDuODuXTNvZzY8mJoont
yUz2l1vTbiQN1Xtp0v3U9+lx3o6Ha+qOh24Ed7+UnrXmvf7uUcrkv/YTpj4L
c2/CTW+aM52h1vGIuGp+Y1i/9majz5LPEovukXaWW8avoIHTOvABPaH5gQ7o
sVivDFM+D/3VCifo7fgEM0sahpiEHCNdrb7kjeshwEr18N+QJ+iNQZ5DYG/5
v2R5Fv+d4/ACbVdqig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 113->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0OgjAQhV9YGLYewSvoARqvgCeoia5ISGBh3HF0xB/ovL6hTlJKM33T
b157uHbNvQIw1K9PEx/nvo/Py25e3GJ7OrZzcv8dwBiwzuEzewM0ftp3kN4E
7VvyVFuds6yFNuPwWLH26Oq3eiZ/Up405+2T/8Rm+P7xQDCmfY2kV30jaA3f
iakN7ZfJwZ7n8bpMonbG45xZ8tDNAZLR85X95T5kDYhcSS/em+QUfstQdy5C
1kb+lpiz+O4yhgmbSmtL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 114->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAQszigXnkCX4AHRHyhvCBIcKqE1B4QN54OFbTMYhdGSpPGGY/j
yfZ0bS8rAEPz+rT1duj7ej+ux59z7fa7bgQ3nwE8Cr5zec9qwIx5bwq1P2Fm
PeOBW9VB4bnuDOGDzUXQRmrIOwd/rB6LqXN0HbQ5ff94QDTae1FPkLlTDumJ
4wb3y2HI9ZleqYlwJz2i5i8PJRa9Cr1Z4ll6UylUP1U+eW9UJ/GbBus5CcpN
9Ead0RfWL6/hCfC+aww=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 115->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFyIW4/gFfQAwSvUE1Swq4JQF+LOo9uALcmbmTTw0jTvN28m
p/uzG3YAXod56/r3dZr6z22ffx79eDmP2Xn8G/BN85bqrzMUtt4ty90vvuK8
+kNt1wdJ51Yxoh7K3K381syCp3KurTh5jthgsDsOBMZyLskJuDblCE2q2tB8
VT5wf4XXYhK1CY/Qn/AYjVU/4ipo06rTelO0nJ4uX7w34kf4ZO8Q5/TNK2Ik
/LGX4YVmIww/bctrSQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 116->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+eXRbsGUzO7sNbJpmH5md
2dP92fU7AK/DtHX1fR3H+rnt559HHS7nYXYe/wZ8y7SV9hsZjK13y4ruF585
r36qHb2DonObGFEPNncrP+tZ8GT72oqTZ8YGz0XKgcBo+5KcUN8oIkdo0tSm
eMkTxUZ4Q0yitsMj9Hd4Ao3Ve44r0iark82UW0KPNF/Mm+Mn4FsupTn7oOdc
4WWczIvrzWH4ASvLa0k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 117->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg1AMHFwUtz1Cr9Ae4OEV7Aleoa6Egl0Udz26WqTEyeRp4H3kzcTJ
JJfHq+0qAO963tr8aYYhj/fT8vHM/e3aL4/ndQHfNG9pe0brF4T7h8KaN8Yx
h+8gXYq7wYh8sNw9flTzimefbF17OHlnbfBeFD0QGm1d0hOqG0lwRE+sPsZL
n4BDekNNIrfTI/rv9AQ9Vv9zXlFvSnlKM+VC9KPIF/Pm/An8lqF6zm/Qc670
sk72xdXmNExg/mwK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 118->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwkAMRAc/xF+P4BX0AItXqCdYwX4VhPoh/vXotiKSzkzWwG637CSd
vPRwvXf9BsBjN29dfZ7Hsb4u2+XlVofTcVgu998FTGXeyvqZrU+Q7hdOG+5Y
xzl8BvlyuSuNqYeYm+S7709cx3CKff3T2TN7g3ppMjAeuS9h0uCW1Y2zzNhJ
f4FNy6/zlNUWP6YP8WMYujv2KkwTRhlHmRnV4Xk0883/JnwS3i7szGOPUce1
jV/2yVykN/KK8gauK22K
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 119->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUEOgkAMnHAwXHmCX9AHbPwCvmBN9ERiAgfDjacDRk13dlqb7FLodJhO
j7dn/2gATO129fl1Gcc8Xw/7yz0P59OwF7vPAZa0Xal8eucdhPuFwpoa47iH
c5Au1VtgBB9sr9Ov/r8wj/DJzvUPJ3PWhlpL6EHktedJ4JvkJf5vrvwq5jPe
eLwVVuxd+RHNUekRHqoaay38Vr6q/UB8Yw5nH+5MQh9zRH6rkDu3M1occwu9
rJM9qGYjrUgrw7duSw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 120->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kUEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtx59FtRSTz5yWBmUmbn8/P
z+F6H8aNmT12yzXU53me6+uyXT9udTodp7W4/x2zd1mu0r7R+Ybg/kFYV1Oc
9mhuoot6Gwzwme8N+r1enNnVSI+vRTjMVZv1XqQeZF5HniS+Ia/we5+6fZcW
k+olLOyd/Mjm6PSAh1RTrY3f5Cvtx+CfcgT7CGcCfcqR+U2BO49wyg161W/N
u9lEq5UP6xZuTQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 121->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKgzAQRYcuitseoVeoBwi9gp4ghboSBF2U7np0tZQy/rxJIMnI/Bn/
/5PrY+qGk5ktzXZ0+XWf5/zuz/vHM4/tbdyTl982+6TtSMc72t8luP8irMsp
Tms0NuFFtQUm4Br9W/Go2eWIj89FOIyVm7H+0IOa15HH5JvWwEw8P9WIPjlv
anyJk86F3meko+ADHlJOuR78Jl/hzXlfiplJH51HqAn4aY+a37Rw5hFOewNf
9VvjQptwtbQC+LVtjg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 122->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklEKwjAQRBc/xF+P4BX0AMEr1BNEsF8FoX6Ifx7dVkTSl5loIGnKzm5m
Znd3vnb9KiJum+no8v04jvlxWs8/lzwc9sMc3H52xDNNR1p+3X4v4L5LYYsY
cczhPcBL5RLjuLq3qUNqLmKKTxlzOHknt9D6rQctr53HyjfmiJ6U/KiRHBY1
f/BVnNgXNZ9OR9U3MyPqvcqrlq+oQ1+qnqHOPz7IORE8W36rJXvucKxd1qcW
40ulDVwjvQAIjW2Q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 123->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAQCx6kV5/gF/QBi1+oL1hBTwWhPYi3Pt1WRGYzCejCbrdMdibJ
zP5y728bAFO3HH19nMaxPs/b9edah+NhWIO7zwbmshyl/br9XoT7LoUNMcbx
G76DeKm3jHFcXW3WITWHmOITYw4n78wNWr+s6XpAupLHyjd+I3oS+bFG5tBg
YPIiY5TmxOOf/hsPVYznq/Fb+Up52JfUM8rziw9yTgTP2cRkbVErzU/Ece6Y
n7UYX5I24oryAiMUbc8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 124->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKgzAQHHooXvuEfqF9QPAL+oII7Uko6EF6y9OrUmQzOwttIInJrrMz
s7kOr+55AjA369LlpZ2m/O7P2+GRx/tt3IKX7wRKWpdU79HcB+Udw97Ze9CZ
sIqoDTMrPMEj4l7lBLVZh9RsYoqPjUV58lv4pPTLmlEPSJfzWPnG/4ieWH6s
kTlUOQhw4XOUZsfjn/6Tx64vqg+i79JXwmFfXM8I5xcf5DsRPEsQk7VFLfd+
bB5jW3zWEvjitBFXpA+mRG0Q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 125->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbqteJidTEAD2bLZNJmZ
5HC9D+MGwGO3HEN9nue5vi7b9XKr0+k4rY/7rwOtLEfpv+wc+5iLQWIch9yl
lu1D3tUzODLsXU7SW3kod+6tOjGvlmAJ74j82Bx/2zObgfAKGjus+o+ZCeNT
LRRDl4OkLmKO4xxw/DN/0TjMxc3BzN3qWryObg+C/aiD3RODsyVvtrfpFfaH
87Q211cuiS6Bm2BFeQOIT21P
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 126->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwjAQfXQhbnsEr2APELxCPUEEXRWEuhB3ObqtuHh5eSPSwqRkJsz7
zBwu9/HWAXjsl2PMz9M859d5t16ueRqO01rsvwGUtByp/nNw7vO5HCTHechd
elkciqqf4RFx57ryjnSodsZWn1hXCbg0dQTcUONDosGMZhDoVI2/vLBzIH7q
hXKo3hC+4+tmqdrUz63zb+YS7Ij1NPBIfXR74Pr844PdE8OzBDWLbbCsVkgP
fmO4W92On+GK9Aa2u2zP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 127->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfEbU9nmzg4jsOBSmnVpE0c
O4fro79vADx389a313kc2/uyXS63NpyOwxLcfw2Yunnr4snGvnU5H8THfshd
ctk6ZCGfwVFh57jirvrQ3rm28sR9TQWWFEeBDbE+xFLNSoOiT+3xFxdWB8Kn
XCiG8IbqO7xOS+1N+fxX/6RLMSOW04Ij5dHNgctjZwtIOBw+5i5gdX/NsppX
70xd/VPNbOLS5Vt9H3A0bBA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 128->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwjAQfbiQbj2CV9ADFK9QTxBBVwWhLsRdj25bXLy8eaPSwqRkksz7
zOwv9+62AfBopqUrz9MwlNd5O2+upT8e+vlw9wlgbKelrf8cnFs+l4PkOA/Z
Sy2LQ1HVMzwy7nyuvDMdqp2x1SfWNSZcwjkSbqjxIREwsx4kOlXjNy9sH4hf
6pO5w/iOr+ulalM/1/Y/9CWZEetp4pH66ObA1bGzBQQejh97V3H9R4Ni/bpn
cPVN4JDNp6u35N7cPGzR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 129->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAQazgYrzzBL+gDCF/AF6yJnEhM8GC48XSBeOh2OwjJLJlh6LTd
uTxeXV8BeJ+Xo0ufdhzTdD+tyTMNt+uwfqx/AczNcjT5m4Nr2+NqkBrXIblg
2TkUNofvUd5gLsH/rEO1sxb1iXXNARedrb3qk+UeYbk7CHSqxj0v7D0gxlQO
2RwEuCh7nGbdjX/3H+0Q63b+qsbC08CjIzWHY3cLKHg4fuxdxvWIBp21w7PY
OeGvPBjT7qfD22pfPUVsTQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 130->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHDwUrz6hX2gfEPoF+4IU2pNQ0EPx5tPV0sNmMoMNJLKbdXZm
NufHu381AKZ2O/r8uY1jnu+nPXjm4XoZ9svut4ElbUcqv3HH3HepHCgX86CY
sGSfsGUMXcO8Ebmo/1HqYO1RC/vEGIpLdQ/DDcTFeSB0L4ShdLJG56WdAzwm
cyj6wOCirlGa+W0czd+9oahb+XvoqfHon5zCkW8Lod5oiHiV92bevNzMZZ3o
iyRmaOZY8RNckVYsYGxN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 131->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwjAQhR8uxK1H8Ap6gOAV6gki6Kog1IW469FtxcXk9ZsaSMLMJJP3
k8P10d03kp67aenq6zwM9X3ZzsGt9qdjPxf3vymNZVpKu8cZc99BOVku5mVx
PJO9Y/VFLD7juBWx0H21PJx75OI6eQ/CsqgrwSbDkmkAvEfrQTydY6Yl+eB9
vCfqJLgHeMlL5+Z6rvmf/aHIm/T9q2nQlvqs5bIepFn0GP+JaddgTfz2kXmO
5+BdFfAw8XGBD7CqfACS1W0M
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 132->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDxIrz7BL+gDgl+oL4igp4LQHsSbT7cVhc3MbA1s2mwmu5OZ
7C/3/rYBMHXz1NfHaRzr87xdFtc6HA/Dsrn7BvAq81Tab4yY+wyXA+ViHrSO
mKwP7csaHsO8Ebm482j58t15j/FSg7hkPYQb2v6gkJ6ZB3xPgxOu5gx78sPw
/1+dkNSFYtydhcea/8SLNRZfkrCaBm1dnbVcVsNpFj2274S0a7g6DczIPLc4
0xfFeJj4KPwMV5Q3O+BsTQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 133->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAQC36Ivx7BK+gBileoJ1jBfhWE+iH+9ei2RSHNZLoD28dsJpvJ
7On+bLsdgNdherTlfR2G8rnt559H6S/nft48/hYwNtOjWb95cW4Jl4PkOE81
jAs8Wt9ELIyOTLs7N9RjrVd71z3FBw7Rkp3B2jlc/8ql+VE4nG+MC1pNjc7k
j9Hvqk9IeBExruegY2v+oks9DnNJlvWUwvFUZ8ax4RnP2N4T8S70qvyZfqCq
M9w50Z/iMi8d35L7Apb5a80=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 134->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgkAQazwYrz7BL+gDiF/AF6yJnkhM8GC88XSBqOl2OjDJLDDb6XY7
HK6P9r4B8NyNS1te574v78t2+riV7nTsps39N4GhGZemfmY5h+D+wTWuUw/j
Ao/2NxELoyPT7s4N/aj12jszTvCBQ7QsnVFpQ7JnuLQ+CIfzjXFBq+nRmfww
+r7qE93L6XWzVM3qZzp/0VXxIfJkaT2lcDyrM+NY8Ixn7O7AfMF750GmH1jV
Gf450Z/iMi8d31z7AMkHbI4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 135->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4ZXTaiiDnck4iOU3ji30+
+3R/DuMOwOuwbEN8X+c5fm779ecRp8t5Wp3HnwEpLFsov55ti3DyLt+j9Ofz
H0NvEvkYC5HT467yVu9R8pU1WxzhqxihgaMcBTc4PtZA1J0ohtItKV6eNqIn
GcPnrk6mLsVX9ZI5J8FN6cC8uEaO07JKU7NUnG7P7GpoZvvh9snwkLPkzYXl
D3R5VjNH/F2cN58q3nb3BYDKaw4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 136->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHPWAeu0T+AI8IOIL5QVBglMlpPaAesvTu4ggZzomkZKm8dge
j31+vPtXA2Bq16OPn9s4xvl+2n6ecbhehs3YfTeQwnqE8uvtfRFOvuV3lPZ8
/2HIJ5GNsRA5Pe4q78EfJV7WbGxWL47B8Q84zid0UvUjOLG4VtJaagwRX/hw
TzKG71WdTF2Kr+olc06Cm9KBeXk9UvpKvZ2l4lR7ZtcfzSxnt0+Gh5wlby4s
f6Baq9Kw4ObhvPlU8fa3Bbl7axA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 137->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfEbU9nmxhKXZtGapc1buI4
PVwf3X0D4Lmbti6/zsOQ35ft/HPL/enYz8H9dwFjmrZUft1ajHDybD1HGV/9
H4bujBRjLERNx13Vre6jxMueQyzqxTksP/KrHoOp/pFETTUD0lpq3OCq5hAx
7Dd1gsmLGqN6Vm/Dzp94uRkpfaXexlSe5syi/dEscq5yxjiE9koDxx9o9qo0
LLg5nHufKt9y9gHYqWvP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 138->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vhA/HF02Hhlrt1G6rqmTuI4
3Rwv3XkB4Lp6fbp82w9Dvh+W4+GU+922Hy/XnwU8Ev57eu9uTUY4JOOLFn2V
GJezOENjHFfm/Ttjjpc9R31A/bGvUXtWT+ik+kcSNVkvoTVzKvibmaqZfDH8
39QJJi9KjHsXzdkaXm5GSl+ptzGVpzmzaBXNZLzoxfbD+R3/UKuKE3U5xr3N
gofKN/memxZrDg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 139->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vhA/O3osIFEcOw1Ul9pmsR2
d+dbd10BuG/eU1cfx2Goz9N6Olxqf9j30+X2O4Cx4LeWz+rGbBSHYnzRok/E
c22OSWeRJ+UzdUfqLcZLzJEfED72NWr/1RM8KfwooibzJbjmnlL/RlPWIcbw
vskTTF7kGIVZ/Q2rP/XlNFL8Sr6NqTxNzaItcCbfCywWT7hzGKTmCzi5Lr9x
fzPprfLNvheT32sQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 140->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADFK+wnqCCfi0I64f416PrqmCczrQG+srOZpJJ
NsfLcF4AuK6e25Bv+2nK98NyfpzyuNuO88f1ZwEl4Xum9+nWywiHZHzRok/g
C/kYU71FnCqe4S2UW8TLmqM+oPrY1+H+4WOdjKZINSfXK7VWfenkWsUlDN//
0qmRr+qlmw3bW5OX65HSV+ptTMXp9ixaQzP5v6iFNeVZknMR8w9cTRzzRm6H
M3Pn6kB6AB+0a00=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 141->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEQCx7Eq0/wC/qA4hfWF1TQ04KwHsRbn66rgrNp0g50S6fZySTT
3fk2XFcA7pv3Z8iP4zTl52k9Hy55POzH+XL7W0BJ+O/pu7v1CcIhmVyMmBN4
5mZMdRZ1qnqGt1BvES81R39A+jjX4V7wsU9GP1LNKf1ir81cWr2quoV5qdeu
T6ouaozruTtb05ecu/FX+m3C+tiaWYyGZ/J/8d6sntCj0yBn3tC54I3cDqfe
XbwD419OAGzJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 142->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgkAMnHggXH0CX8AHbPwCvGBN8ERiAgfjbZ8uoIbSnVmblAI77Xam
bW6P7n4CMNfLo4vP6zTFV1+tH0McL+24Hp6/DqSAPYZPVL6ZwyGIf3CReHI5
qmaWC45Rvfq+rVl8xtfke50sv+R7UZzBa//wjP9BA4Dy9XWUzl5PNlOKB3/P
tGI6Ffqls/2zG0xf1hedu9onppUwqWNpZtYKmtF8sm+Sj+lRcaAzL/A83Gvv
VjilpeCB8Aa3mG1F
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 143->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPyQ/noEr6AHCF6hniCCfhWE+iH+5ejaqrhMZiJdSJcm+5iZ
3e3p2l9WAG7d69Pn+2Ec8+O4nn7Oedjvhulx8zlASfj59PbuzEZxSOYO5MUp
lONqVrnQMQ4r444W4yu+IZ91ivwKY3GcoWt/41mLSgNA8uU6Tud/WFXdwn0J
K2OwfVzswt1Q+ipccu5un4xWyprzcTOL1tBM5ot9czjim+MgZ97gyX05R2kt
tVT15rsnV4ltRw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 144->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwjAUszggrozACjBAxAplgiDRUyWkckDcMjq0gPpw7BApfWnez/bL
7nzt+hWA2+b16fL9OI75cVpPP5c8HPbD5Nx+NlASFpve1u15URySuQNZsQvl
uJpVLnSMw/o9//iw8I4aMCYEX9Qp8iuMxXGGrl3hS6Im8ZB6m77M0WFVdQv3
JayMwfZxsWa27m0ofRUu7qF0/aeVWs35uJnF1dBM5ov35nBEn+MgZ97gyX05
p4pzWqp6890TeVhuCA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 145->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAESuUCYIEr0pI7QPx6+jQgoRzPhtLaVLHPp/P
2V/u/W0DYOren74+TuNYn+ft8nOtw/EwLJe77wLmgt9ePnu0VqM4FO9rYnmP
4hNMzmMsxb2JAeEbsz7Xr8lnnWxfM3MRvYJqNNyYXxGY1IfTy+BEOluu0Uwl
D+iz00rplPDNZhu9DaWv4sU1lK7/tFKWzieambVEM5kv3lvEw95FPciZJ31y
Xc5xcZGWCm/1vQDTT27J
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 146->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwkAMszggrjyBL8ADRnyhvGCQ4FQJqRwQN54OZc04dok0TZs6iePM
an/qjjMA58Xj0dXLdhjqdTcfPw6136z78efyfYBbwc+Xl3fnaYRDybEGy97h
Q4wxnMe1FPcGA+IcLMbSvCGfdYpzJf5iVlCPhhvzc5oAcl6u43SOXN1OJQ/o
96SV0mmC79RuubbdreHFPZSu/7RqzNRzNdNeQh2nmcwX9+2T4+6SnUH0msSJ
vpyTcE5L3t0XfwebJ2+I
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 147->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IW58Og6Flrt1JXdrUSRw3
h+u96zcAHrvPr8vP8zjm12U7HW55OB2H6XI/L6AkLDb9rFqYcSAcUu0rEcvW
4YOPMRzHuTi+MAbiDkvfUQPFSekU+6r4i15BNVbcmJ/TBOtz9TamrtLE+SQP
6L2aj0qnBt/W23JuOVuGo6tt58lpFT/iLHtyb0Z5nGYyXszbP8bNku1B1Gri
RF2OqXCNuSuc74t7A1KGbsc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 148->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzwdCoW49kyo5KZuZryM
vTtfu34F4LZ5vbp8P45jfpzWk3PJw2E/TJfb2YCSUM/0OZlhxiFVKyn6Pzwc
x3EDvhHT81p1hPzme3GH2rfq3fK9TravUD/p1WJ97FCf0gRLP8xG5GWaqH9U
B5sXAqN0atTbmq2PTXeLaK72ien6Vyv7uJppT2pmLo7SjPLJvn05apdkDyRX
E0fyek7ANfau+Hhv3BM7TW8G
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 149->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6VLQksWfSSm4Wj+Px
2Kf7q3vuAIyH76+L03UY4vu2nw+P2F/O/ew8LgakgLyG38oMCw4hWwr+/MfD
xJhYh2+8aeNaPFz+Yl/5kOtu1b7GW53Kuhx/UmuJTebO8VOaoD673oi8TBN1
x3So8kJglE5bWNFbNRtMX8aL1STnSeUoP8OZ9kD1zLyjNKPxZN7WGDVLTifU
vjIXrRWGP5lTidvqFyz+AysKb0U=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 150->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwjAMfeKAemUEVoABIlYoEwSJniohtQfELaNDoSWO/ZxUchPbz78X
H2+PftgBmLvPr4/PyzTF13W/KPc4nk/j4jysAqSAfIbfyQQrDiFLClb/46Fi
VKzBV3LquFofpr64Fz7kuWuzb/GaJzmX6Z/MKrFJ2Ux/HicodfM2Tl3GibTp
moYDWRcOxuOphXXeVuPpbhHOvX1ivDa5kl+DK5YHTh6PMxpP9m2LMXwon7az
WnRWqP7Jnrq4xt4V+b62NyilcAY=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 151->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAQszggrjyBL8ADIr5QXhAkeqqEVA6IW54OhZZMPU4SKU0z8Sz2
zOF67/oNgMfu8+ni8zyO8XXZTpdbHE7HYXrczxtIAfkMv1NtzDiEvFPw9z8e
5EO+Dl+JyX61Olx+87/igcy7xn3Bs06Wl6tfcLXYRDZbn63F8SMerjeFvEoT
a+OcTgObFwVMSacWttBbxsvZEpqX5knp2tTKroZWKg7PmqwRFU6i98uSetAb
21UuyRXlvOzjcI25W8X72t7Qh3AG
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 152->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vhA/O3oMBg0dZxuUtaX49Ru
dudbd10BuG/evy4/jsOQn6f1tLjk/rDvp8PtHMCYUMb0HVVgxiGVGJNf//Gg
HMp1+AYn57Xu4eqbeaUDte5I+w/PPlld7v6itsVWmlAw9kxykg73NsLjyBO7
xzWdB7YuAkzk0xI2eFvGy94Snkf9pHxd9Mp+DT7FqXpN3hENTcxj+KQfdMb7
qpbUirgu5zjcQt9VfJ+9F+y/b0c=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 153->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAvfIEvgAPiPhCeUGQ6KkSUntA3PJ0qCgktsduJNdKM15m
7OPt0Q87AHP3+fT5eZmm/Lrul8s9j+fTuDweVgNKQvXp65lhxSFVK8ne//j2
kFiDD3LquKgPUV/hBQ9I3h73H17r1PIy/ZPaLVZwgsQU5UVOWIw3G6azrsNm
z3QQdeFgPJ22sM5sNZ71wzT39onpuqlVe4J8LCfbNdojAk5svqgxRg/1pv+z
WpQr/Lo6Jto/Oi9o/BsXIG7H
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 154->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzwdCkhxxuO2kRxnGW9j
H673rt8AeOw+W5ef53HMr8t2utzycDoO0+f+L0BJqDr9dCTflaqU5O8NFsaG
bB2ezlEM5asInw0GhDNL2XJeiidbF/tQsS22qQktppBufMJjXD5CFCf2jWNG
fefzKp6WsEFvo9lw/AZ5RXzKmBFXds34Uz7VrMkcMVOT6i+qjeOD/vhdxZK1
gt7V/FlcMH+yX2D8GyaBb4g=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 155->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKAjEQC36Ivx7BK+gBildYT1DB/VoQ1g/xr0fX9YHTNOlCd+g0ZJKZ
2Z2vw7gCcNu8fkO+H+c5P07r5XLJ02E/LY/b7wFKwj+mT3QHdDhXYeOXQnR4
U0fVZS7JgRZf4h21b+f9h+c+RV/MoWpHbOWJ+hR9NJwC0+gxc2JdMcc1mx7E
ujAY16eO3t5s3W40/TW6VG27T65XNBvHpzjVrkmN6HhS80Xdu2LeVF7Vkl5B
ebV/pIP1u72r+N65J+klbwg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 156->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwjAUHFxItx7BK+gBgleoJ4hgV4VCXYi7Hl2Lii/zZgykIcn0zSdv
f5n6YQPg1r0+fb2f5rk+ztt1c63j8TCul7vPBJaC31req5ugyWcNNo4SVoc3
PIqXa8kayPgl7tH6Vt7j/5xT9MU1FLfUIXKKPlJNgUl6zDuxrnjGnCmHyAuD
cTkZT4xRGal3TfkaXY5bcrqs6G1cPVVT9ZrUiD+eRC7f0egQd9JDxKneCoN7
jvWzDtbv+i5reALCO2xJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 157->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAURAcX4tYjeAU9QPAK9QQR7Kog1IW4y9FtoYWfyUwbSEKSyf8v
83N5vrv+AOBzmoYuf+/jmH+P47x45eF2HebD89KBkqYh1bProM57lTa2FGan
N3lUXo61F2PVl7heWjE8he6XRHrQWeQFNCtzCJ+4HlVMoWl4TJ2YK+7t/YEq
L4zG+WTexBrlkapr46/hcrllTucV1WazPiJOU1/FiI03CV/W5jxdz+QbYgzz
t6r4kYn4mYP53b9rGf6F4G0E
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 158->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDH5Ifz2CV9ADLF6hnmAF+1UQ2g/xL0e3hRayszPbwL6zk8kk
19enH05mNnfL1OfvY5ry73leD+883m/j+njZhpmnZUrlqobBwLvCN1oKq/IX
cVhcxDrC2P09njdzwcfhvyfwF3k53pE9YkedsB4FJvGp+Ij/yCveHfUA4021
YjqxnJgO5I3VtdKXcGzFpjGVVlCbZn0ITlVfxtEaORFddqP5hDeaQ8QQvVXg
R07AH3kgf9V3NYc/zNNtQw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 159->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkjEOwjAMRS0GxMoRuAIcIOIK5QRBgqkSUjtUbD46rcRg//yfVnLTJo79
/O3L8zO8D2Y2n9bXUJf7NNXv47j9vOp4u47b4flvZl7WV8mrMgPDveQbnxJW
5S/ysLwYcy9G9DNgc8HjcN8L+Iu6HPfIN8aOOmE/Ukzi0/CI+8gV9/ZmgHFT
rZhOrCamAzljfW30JYy93DRn0DflgN50+wPGZo0yWqcmokvkVLMka4gxxGyl
+JEJ+JED+dXctQw/Jrdshg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 160->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMfbgQtx7BK+gBilcYT1DBWQ0IM4vBXY/uDLhIXl5qIS3N9+Ul
l+d7GA8AltN2DXW9z3P9PI7751Wn23XajeefAK1sV/FvJiBhnfO1p5g38+c6
0DVcLsQ4iZVzmdMSPI3iWyF/kM1yAkSsWU/EE8/D5RQ+AU8Sz7is7t8OKNyS
K8WT6knxIGxqroFfgbFXW9Y0/LoaNJvufEjUrkmM6PQkeLE4s11Ke7A5kt1y
+YWeY7L9y/YuYvgCt4FsiA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 161->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMFH2UfDtCV2gHMF0hncCF5hUIJI/Qn0dvAn2cTqfUIDuR7JN0
uutr6oeTmS3dtvV1fcxz/TzP+8+7jvfbuAcvPzNrZduKPzMzMva5u7gKnNl9
zmM6h8Oy+E7WyliwWlJPo/fME9bAGK5X8c3YyFPIw3z+4UvNpom60Hekgaxu
yZVFTNmT4kHE1FwDv+Tj2aneQk7g1+Wg2QScgz6U1hBfcZbNj/WG/CotpT0g
RqIt1xP7RSzTX6a7WMMXrERsxw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 162->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IG09nQxxcxymR0m5p5Mau
D9f7MG4APHbLMtTneZ7r67Jdf251Oh2n9XD/S+BdlqW0e5ag7NW+dY5Ce3JX
wETb2yRij8XIsCi4N+VrdOIZFIO5um/FZp3CPaLnP71U46YPvtbzQDa31QoR
03JyOpgzxzXoKzV9O8ct3On01XA4HR7Oa4zvNMveT/3G+jovpRwYw3grvI3W
zVnmv8x3cYYPQZ5uRw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 163->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRT8upFuP4BX0AINXqCcYQVcFoV2IO49uW1xkkpcayAyTCT/5
Pznenv1jJ2nq5qOvr8s41vd1vzzudTifhuXz8HPpU+ajtHfmMr4VW+PWirmT
WgFTbW7jijmIkWEZs7kpX9DJ9uAxmpiU9wE6hTpOz396eY2bPKeX7zWbC/WN
Wgn4EyfSAf6Iq+UR9IHZETdfE/X1RjgbPGjXLD5pls3P75vVl3Yp5WAxgHuY
jY/DX7Z/tHeBxxr7AtzLb8c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 164->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBBq9QTzCCXRWEuhB3c3Tb4iKf9wYLmaFJ5r28
JKf7cxh3AF6H5Rjq+zrP9XPbrz+POl3O0xo8/gxoZTmKv5XBWM+3+e1XzC24
EiZ8rjPkHIpBsGJtNlfqJbXbWMRwPmSchI0cY5iq3sRD3rfAb329HVB1016B
6GeaWB/ErGhNTGt4p7gZZ+xv3BHL1wQnxSQ4vZ6p+bn5Kpx/NFgMoj3NJvpJ
TO0f27ukY/N9AcPCcAY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 165->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhPRRvfbpt8ZCdzHQhuzRJJ5NM
Ls9P9z4AGE/L1dXpPgz1+ziuH6/a3679Gjz/DZjLcpX2dYZge77NH08Jr6mV
MNHmNoacIzEEFnOLubZnwT1iM0bjAxL/mbmFObEeEdPxVXVkHs2BuTpdlBZu
Tql/1ZPAc1pJTqpX+s/VVjV5vrwjsZ7Vx2lMZ29mdkdiXOGYmDxUq8ljbdgv
Ym7/1N6lPjbfD1qScMU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 166->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizigXXkCX4AHTHxhvKBI7DRp0jggbn06G+LguE4gUjqtdVzX
yfE2D+POzB7dugzleVmW8rrut597mc6naTs8fNOs9usCWZNUuKjWRQ9fqGNu
x2ke69JaTKaVcRiIDXmEduRmDrdn1uivrA18qgKDmpVedY/ECb+QU/WF6yKv
nBfKk397+2M2UE/jj+i/epvsB/eAI+EJOQVP5lk4I3iueIIzGXQXv116kPgT
zZ+au+Ydn7036uFxBA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 167->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMDB6kV5/gF/QBxS/UF6xgTwWhPYi3Pt1WPCSTmSxkSzfJJDPJ
+fEaxoOZLd12De19m+f2uR/3n2ebrpdpd57+Zrb22+VsLYzFqdxwevd1eYgd
MC3GBrMcU/WKcf74WIlDevfYiBHeCv4GvaA2iOkxlF6sRuBN5oQ1kwZkFkqn
xJ9xInjM2G5IfMs5rDarifrijnht5XwYJsGpNFPzS3uEOMKnOCQ+3s80KPRR
+8f2LvH4vX0B00dwhA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 168->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKAkEMLDyIV5/gF/QBjV8YX9CCngaE8SDefLozg4csVbEh3XQSKklV
DtfHcN8AeO7ma+iv8zT192W7fG59PB3HJbj/GfBp89X8qwzGKt/qt6eZV9RK
mPC5zpBzql5jnj02V+KQ3i12xHC+Yn6EXiI3EdNiKL5YDTc30enfDjAtFE9p
/oJPqq2YT/Xs+CH6s9lYnaRB0EXhlZgRh/UI33+1ZxaP6RNjrDbdRRtnHBT8
qP1je5fmWH1f6ldxQw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 169->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHoQr32CX9AHLH6hvmAFPRUK9SDefLotKCSzk9hAdtlsMkkm
OVyn4d4BeOyXY6jP8zzX12W3Pm51PB3H9bP/KvAuy1H8HSmMbrL9pJg7yNXE
w/uCccknq5X9rFjfEEfUbrEZw9mS/kG1MDeMaTEivlQO1zf3l8wFIi7iynGR
8Pp3tkF/XLPkR8yf+VQ5mV/eEcWryiH5Z0k4i+bX7BGCGdKfyi130f4zB9wH
xTT7R9gSx9k+cxFwAg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 170->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhR8upFuP4BX0AMEr1BNEsKtCoS7EXY9uCwqTl/eiA5PQzmR+
vpnjbeqHHYBHtx59fl7mOb+u++3jnsfzadyMh48CS1qPVN5OEfSvf19J4Ta5
qvcofcFxyadVK/tFib42juAEYUOIz32o/iFqUXmKmh1vYav8BK/WXCDeOVYF
iwbXn7M1/XHNko+YP/NUOZkv74jiqnJI/iwNZm5+1R7BzJBsKrfcxWhnBqKP
hXJV9Zm9035vh09www==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 171->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX0q1H8Ap6gOAV6gki2FVBaBfirke3BYXkz5vQQBKSmcyf
vJnz49UPBzObu3Xp8/s2TflzP26HZx6vl3Eznn7TbEnrkuo9mlbMXXf/kYo9
0HLvrfY1jSs+rVzVrxylbxgHOBnY9G+Uq4shuZBOlXPEG2zOD3i16mLwLmJV
sdjJBGtLvWF8dnyg/qpNmspXe4S4kgby19FgFtXP9RHwIBtpYy+WdmUA/1hE
y+UX9B37fQHB/3DD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 172->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX4tYjeAU9QPAK9QQR7Kog1IW469FtQSH58yYkkIR0pvN/
XuZ0fw7jzsxeh3UZ8vs6z/lz22+HR54u52kLHn/TbEnrkuo9mlbMrm//kYo9
0HL/W51rWldyWl41rxxlblgHOBnE9G7k1dUQL6RTeY54Q8zlAa+ed2nVRE6d
TPBtyYPx2fEB36pNmspXe4QYkAay0tFgFrF2fQQ8KEba2ItlXBnAPRbRcv6C
vuO8L1jxcQI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 173->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklEKwjAQRAc/xF+P4BX0AMEr1BNEsF8FoX6Ifz26LSgksy+lgU1Idzsz
O9nT/dn1O0mvw7x1+X0dx/y57ZfLIw+X87Akj7+QpjRvqT5boSI2ffuvVJwN
rvC/6lo5rtU0tSrWlYv4Aw74JMh5b6Q1YKxoqepVY7T8Io6qb+9vw7usYaJP
Gz3BtyUN4nvwB3Q7N3G6vz4j5IF7hZiOQxpV68cZ8TkCPyhH3DiLZd49gD4m
4wr6GnPHdV/UYXHD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 174->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwzAMEz2MXvuEfWF7QNgXuhdksJ0Kg/YweuvT28IGtiyPBpKQWJFt
RefHu381AKZ2W/r6uY1jne+n/fCsw/Uy7MHuO4GlbEvxezZh5qG73yhmT3KF
9/BYMC9h0loRcXbYu5RH6AQR495AuRjDcdbC4Ykj00vlcH1zf6KuTEvFKXU6
okn2t8ob0Oegz5+a0/8T+rJHlK6sleRkHlUjfP3SIzYOrYeKqdzsleAt1kD0
sVCuUF/iO41bAWZ3ccU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 175->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKgzAQHPoh/vYIvYI9QPAK9gQp1C+hoB/SP49ehT6ys7MaSEKym5nZ
yV7uz64/AZjqdeny3I5jft2q7fDIw7UZtuD5M4ElrUuyezRBk+9c3nekYg+4
3HtoDoMFj7On4RcrhuJ3OMIniBjXBuKSvu1oMfmEEfmlOEzdXN/Bv6jawhz8
MaPcw79Vb6DPzp9Ac+Rr5C/3iPKVvZKYjKM0wuqXPVLGof1QMcXNveJ6iz0Q
dSzE5fQFfafz3vg+coQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 176->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOEGR2NckpPGB+OvR2SQejeO0ldpqS2rH
Tg7X+zBuADx2yzHk53me8+uyXT9ueTodpzW4/2ygpOVI9o42aPM/l/ddqboD
LvcemsNgweO0avjFqqX4HY7wCSLG2kBc0rdGLSafMCK/FIfRzfo6fVHawhz8
MaPcbm8bs1F74WKkrYfjvILFUH1T/VU+hv1XNaLznvsLq780YoqbZ8XNFnsg
dBTicvW1vHF5bxipcoQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 177->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKAjEMRT8uZLYewSvoAYpXGE9QQVcDwsxC3PXozoBg8/MTC22ZSZqf
vOR4e46PHYBlWI+xvi7zXN/X/fZxr9P5NG3Gw3cDraxHsXe0QZv/Gb9+le4O
tNz7QMPEQpwzOI/e1i2l7+IIThA2rk1yiPITuRh/iiF5B9xM3Vzfn76o2kIf
/GJGvtw319tkNnoWGatMW2kyX54RxZVZhfx5Jczk/HB/YetviU1p86y42WIG
oo5GWi6/jI3z+wDucHND
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 178->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHoQrz7BL+gDFr9QX7CCngqFehBv+/S2ILg7maQNZEObIZNM
cn6M/asD8D4uT58/t2nK3/th/Xjm4XoZ1uTp50BJy5Pa6DnI+V+DrS1V0eGC
w6N4uWbYKyyuNsVv6gidIHI8G4hLzhT00uCphtFL5AxO6LW1FzWbi8G/pofl
ve26JY4bWkXc6p5YX74RpStr5erPFmgm74f3i3b+EuQUN9+KhzMzVVaIy/QX
aWNwM+XSdAQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 179->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhPRRv+3Rb8JCdTNKFbGgzZCaT
vTw/w/sAYD6t11CX+zTV7+O4fbzqeLuOW/H8D6CV9Sp9jgIU/K/D2lNMDrgQ
8Che7plqhcfZo/hdH+ETRI1nA3HJmRItHZ56OL9sTWhqBuP2tPMGlO7Up4Cf
tUa91Xxd3vEq4454nA9ib2q/ysdw/+Q/eybfD+8Xfn7F7WawmGxWQHpiTyMd
Tl/ircf9AIgVcwI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 180->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDxIrz7BL+gDgl+oL4igp4LQHsRbnm4LgtnZ2XVhE9qd7MxO
crw9x8cOwDKsy1hfl3mu7+t++7jX6XyatuLhm0Ar61LsHiUo+Z/B9lG6nc41
wZ1xmF6INRss4fpQ/K6P8Amixj6CuORMiRaDpx7OL1FzOOGX0hV5qXpKn4Qn
SmvUO3obSmPEFXFHPM4HcW//dEj/ORLP5Pvh+8XvjJrFaVJzZLMC0pM+Gulw
+hJvPe4DXxBzAA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 181->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksOglAMbFgYtx7BK+gBiFfAEzwTXZGQ4MK44+hAdNFOZx40KY9PmZlO
e34M3asxs/dxuXTlcxvH8r0f1odn6a+Xfv14+ucS7S8nd6o0SHwXan20RrkM
sBkP40XMqlbLdT4Yf8KxWINasB+Df33vCaOiJdQLnMAjOELfbE4bO6AwmYbJ
n2wvQEdtzsyPxCu4FLfiST5g7NBB/SehPKP7g/NlGMo30cOeXlNPoD/co76K
t7luBiT4ccE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 182->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDV2IW4/QK9gDSK+gJxhBV4KgC+nOo1exi8nLS2ogDurjfTJ5
9nM7PkRkLY9Hm7b3sqRPV5wvQ5pe9XT+rH59VHP1np1eCzR+U9i8GqFaAtxM
h+kiZ+hVLC4vpm+4RGPQC+ZRuHwGjCPwovAOj9JxNFRudk9/dsDjZB5wXkYv
4gvysTPS8rTpPrE5YN3wQbOR8mZG9wf9MQ4y1yjDnawmE/hX3tFfdK8G9wUu
5nIA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 183->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRegU9QPEK9QQj2FVBqAtx59FtaSmZ5CU0kA4z8/k/
/3eax6vrDyLyPk2frnxu41i+9+O8eZbhehnmy/PaU7VL/9QatZi2ZxVWVyuo
JYabdEjXcqazisfpIn3HJTXGzmL9VDidAXEkszg88GR3Dgd50X+Jsox86hls
Xk4v40v80ZppRdr4nigHWzvmwDcBFWWG78fORxyQa+Zhj1fUV9roM/JB2tvZ
H8YVcr8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 184->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKhDAMDS4Gtx5hrjAeQLyCnqAD40oQdCHuPLrKiKSvL9FALLbp+9H3
d2i6TESmfP80Ya7HMSzt6/j5hb789MdhcfZe1b9XtVot0LgXzeqqhHIJYDMe
xhthyo1WpYFpY/wJlsQzqAX9RHM6A4bhaEnmCY53lsxBDivcs3LwMFED5pXw
OXieP7Z6XBa3qQFzwHqgg74JUlZm9P2gPoZBPHkennil/Iqb+rR8MO5rbwO9
pXOA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 185->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksOglAMnLAwbj2CV9ADvHAFPMEz0RWJCS4MO48ORBftMC00KS/AZD59
Pd9f3bMB8D7Oj65+2mGo4+2wvDxqf730y8/Tv+cqv/6aM2pQ8zeHtVUgtUDc
SkfpOk5seDUelDelv+KCx7AXzuNwdgaKI/Hi8AGP0wk0XG51Txs7kHGyB57X
Si/hy/KpM9OKtEMPPAeuHT7kToiKZib3h/0pDpEpyiDvPMKxvtGWOXfsGONQ
JmY+dEE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 186->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0OgkAMhRsXxq1H8Ap6AOIV8ARjoisSE1gQdx5diC7aN1+HJoUA5f11
TvdX/9yZ2XRYLn2Zr+NY3rf9+vAow+U8rB+P/16q+/XH3bM2aX0XZn11hlwm
2MRDvAHTNrQ6DaSN+CssizOqRf2EOZ8BYTS0hPkEJ/AkHME37WnjDGSYpEHz
qvhaeA1/ilFlpTtu/IcaNAetZL+UY/APlWWG50f1EQZ4yjzgzrM55Xfc6BOw
KZs49wUbNnPB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 187->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AQG3oQr32CX9AHSL9gX7CFeloo6KH05tOr1MMkZlY6MIqaTTIZ
m8drGC9mNtfrZUjv2zSlz73aHp4pd23ePl73Xqv/9eLuURs1vwOsr96klhG3
0lG6wGknXp0H5U3pH7gMMeyF5wGcz0BxFLwAPuABnUAD5lZ7OvkHIk7lgfP6
i68wH58/ZMU7LpyTOXEOXMF+VY4wv6gos4gf/CkOwiyFGeTOIxxzO205p+BW
2SDuC2i6dII=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 188->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRYMLcesRvIIeoHiFeoIRdFUQ6kLczdFt0cUkeX8cSEunn//z
f3K4Psb7xsyeu+Uxltd5nsv7sl0/bmU6Haf15/5Xyxm+VZu3KgsV7xy2PYOh
lgVu0iFdx2mi14Ax0RvpE1dV/Vj243BtBsTR6cXhBY/TERoxE8ypkwPNBu8t
56X4pMc/u0G65I20aX6UX9wRlRFlm3YCjspM8bv+iCNgascDzlzhInejjT6B
O3lLuA+6I3VD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 189->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAQCx7Eq0/wC/qA4hfqC1awp4JQD+Jtn26LHnYySTswLd2GZJLZ
0/3ZDzsAr8P86Mv7Ok3lc9svH48yXs7j8vP477m6X9fm7RrUfBawbXWQWiBu
paN0AyfMrISBmU3pK67q5kH2E3BtBsrjyiyBk3hSPjDnIpPKvBt3wO06+UHO
y/FZjxt3Q+myN6e95iPlwGX2y9mmOyHKZeb4w3yKgzB1xYPcucMxd6MtfQpu
lU3EfQFlBXPD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 190->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsTbPt1WRZLJZBtIS7ezk8wk
h+u9HzYAHrv50ZfneZrK67JdPm5lPB3H5ef+l3N036zmneUHC49D5zn+5zbM
PdC9KmozJzgtJ5JeCYOkN1VfcdWsH0Q9Dmc9UBobvThO4gn+IDkXnlTmXdkB
pVvODNGvjC/VuLIbqi5ry2q3dAQfONR87cxs7yBeiswztT+hP8VBmNrQIGee
4Zjb1JY6BbfyxuPeKipzxQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 191->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCexBvebqtiiTZGdpAWrqdTDKT
Pd4eXb8DMDXzoyvPyziW13W/fNzLcD4Ny8/DL+dov2nurfKDRcShjRz/cx+u
DqnOSO/MiZyeE2LWhIGYjfVnXKbmQa0n4LwHol7NEmoST8UHcU48scy7cgfY
3HRnqP1SfFs0qt2wf16b6q10UB9ysP2C1wf9JJRn7P5U+2UcCWMrGrZopdyu
N9VJuJk3EfcGnr1zBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 192->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXHmCX9AHEL+AL1gTPZGYwMFw69MBNaY7O0WalA3bdqbT
7fH27B4VgLFePl16XYYhTdfD+nNP/fnUr8Hm64u1Hzd3Rv7ORZ6HNsf43Xtz
daA6E9yMCXaPiaBXykHQm+JXWCb64RjPkfmlno1emMfjFHgI7sVMjHH/7IDq
W74Z4pkUe7RDY/Q2Kua1RdyRDjkHNvW+0PWZfmHRzNT+FPgKg3bANjTs1Sqx
HbfUKbDVbPK8GfnbdIY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 193->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXHmCX9AHEL+AL1gTPZGYwMFw69MBNaY7O0WalA3bdjrT
7fH27B4VgLFePl16XYYhTdfD+nNP/fnUr8Hm64u1Hzd3Rv7ORZ6HNsf43Xtz
daA6E70ZE+yEKbn6HObsTPVXWCb4cIznyP2lng0u3MfjFHgI7sVMjHH/7IDi
Ld8M8UyKPdqhMXobFfPaot6RDjkHNvW+0PWZfmHRzNT+FPgKg3bANjTs1Vrs
FfGXOgW2mk2eNwPOinSG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 194->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg1AMDF0Utz2CV2gP8PAKeoJXaFcPBF1Id+/o9dNF3jhjDUQxiZNM
JvWzb98XMxur+dHGqRmG+Omuy8crpsc9Lcnbz2cLm2f3Vm6hrFexNe4tGO2F
OArT0AGTzuproM4b68+wMpkHc7hH7E/5HMyCfTzODs9EnOwkIy7hg7orXTLM
oHbC7ugfR6UNy3luqrfiofZQGNPX+P8Ff2J4h1Ibpi9i4C0hJ+Bwlqvqi9xo
3cFu93VflW9zxw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 195->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2I1z7BL+gDFr9QX7BCeyoI9SDe9um2KjI7nSkG0qVJdpKZ
7OF664YmIu77+dPlx3ma8vOyW376PJ6O45Jsvz5b+niB03mkut7F3nG0FLIX
4zjMYCdMOSvWUB2a6q+wipgHc5z/1aEGis/GLNwHcVZ4YeJCk8K4ho+bR72X
gLuol9LVzai0UrtROeTmejseTofK1H5D36/4C+N3aHej9ssYnGNOxOFfrq4v
c1vxJ2ylTV33AiMKdIg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 196->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMHDwUrz6hX2gfsPQL9gVbaE9CQQ/F2z5dbUvJTiY2EMVkmGQm
Hm/P/tEAmNr10efXZRzzfD1sH/c8nE/D1uy+uUb6ZDHvKJFqfFR7120kyFnM
E3GCkzjlrhZDOBtqvuIqYh/b4/4PZz1QenZ24TmWx/EhqAtPCvMGevZuI+vw
filfox2VV+o2qme1qX9I+epmq10CX93tLQ61JxyFZoS3UfdlDu7xvUnHX620
B89lbU4/cStvatwCEe10Rw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 197->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOgkAQa/gw/HIEr6AH2HgFPMGa6BeJCXwY/vbogBoz2+ngJgNhHu20
y/H27B8NgKldH31+XcYxz9fD9nHPw/k0bMXuG+tJnyjmHQVS3R/l3nl7EiQX
40SY4IDvcbtaXhC+OYpfYRWxj61x/ddnPVB6dnZhHtbteALf2JPCuIGevbuR
eXi/lK/RjsordTeqpmaiOemh8EF5zt65/431Mw7PoJ4P9zTzFQbX+L6J/69W
2oN5WZvTT9jKm7pvARA4dQQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 198->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFxItx7BK+gBHr1Ce4In6OqB0C6Kux7dtorkTSbFQFqaz2Qy
zfn27B4HAGOzPLo8tcOQX/1x/bjncr2UNXn6+mLp47N5R45U10exLW4tQc5i
nAgT7PA1jqudC8I3puYrrFnwsTnO/+qsBmqfHS48x/JweEITpzHgOTI3iP3F
v5FxeL2UrhFHpdU/txLV8OzoniIdmI/Szt0b78843IO6P+Rp+isMzqnbA+X2
dlUY4k7lLgJbaVPXvQE3OHSE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 199->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx7Eq0/wC/qAxS/UF6xgTwWhHsTbPt1WRaaZRByYLp0dMpls
dudr168A3DbTp6v34zjWx2k9/1zqcNgP8+X2k1OUd7ZwukRZ9rvaqx6jQM5i
HIcJTuSexDXOBeGHUPMVVhN84h3ff/uiBmqfH1x4TuSR8IQmSWMgc2Ru8Dok
TlwH6UW6Owze0XnMecX18GznJ6cD81HaJb+59wcWGinNpH/4faExIDBS/LOr
wqAe5t4EB+U7xRXlCWl6dUM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 200->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFyIW4/gFfQAxSvUEzzBrgpCXYi7Ht0WP6QzE5+B9PH6kslk
kt352nYrALfN9GnL/TgM5XFaz5dL6Q/7fn7cvn2y5uVjODNHs4yv/vtYA1uL
czJMsENjhGusC8IP5uo7rNHwiW/8/o2LGrh+fnDhOpGH4BlNRGNAOTK3iiaZ
5gi58axhuB6zfcp2JYvh2tk+ZTowH6ed7Fs2f2ChkczUzYb3hHJk9oQh9k+v
DsPsqe3FYIs2EvcECEd0ww==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 201->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+5ei2qGGd3Um7sA3NTmZn
H4frves3AB676dPl53kc8+uynX9ueTgdhzm4//pk6ePFnMqR/vGLdz9LCHPx
G8UJdniM02rzgviNRfkjrhLosTGOV1yg1dUitHAeq8PxNfJwTwrzinpaOxDe
g/qFBlbV2Ji/2hWF4dxqn1QfqgV63OxV/5mH3wS9kntCb9zsicPZmlojDsLw
vEugwe0dxyvuDYChdQI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 202->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDggrjyBL8ADIr5QXhAkeqqEVA6IW55OKxY545m0ltyoyXg8
Xg7Xe9dvzOyxmz5dfp7HMb8u2/nnlofTcZgf91+fLH28uFO5pRq/ePezZDQX
xihOQ7eICVp9XgN+Zyw/4ypEj3/D9z+OaA21CC2Yx+sIfI082JOCvKKe1g7Q
e4N+WQOramzsk9oVhcHcap9UHypj8/UzU/1HDowhvZJ7AjFh9sDBalhbK5tp
pVfVD9xVLMW9AUzNdcM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 203->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADFK9QTxDBfhWE+iH+5ei2qLCPmdjANk12dmY3
u4frvR82AB67+dOX53mayuuyXQ63Mp6O4+Lcf21e3ceq2ZWh8/i/d78V/quI
UZyIhoxJuQrd6GP6jKuqfAiHw5FcUy3QPDA52DwSX0Mn1l0jbzivmQF6j/Be
aGBVjY15UrOiMFFbzZN6B7dYf5H1aF8sh42xPWW9iXOi5gB+p9rWt6JW1tOk
HWsh3C6W4t5xQnUC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 204->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHPWAuPIEvgAPqPhCeUGQ4FSpUjkgbn16W7EoHo/TWHKTNPaM
J/bxNnSPBsBzv3y69LqMY3pfd+vhnvrzqV8vD19frP34lK2Ro7Xxm/9+RnvF
VcIEO3yMqzXg5TvF7zTDxnAtjAHKLerJTOH89/BYtTyse2JcOtfMQPGd4Pki
DKexME/RrEQxzB3NU/QOxlR/4flkX3KMPAf6rcI5oRzXe8JQGmq1qp6aepUW
gW1yZdwMvTN1Ag==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 205->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA/HIErgAHmLjCOEGR4GsS0vhA/O3obOKh1nZKI2Vt19SO
k+zOt/66AnDfzJ8+PY7jmJ6n9XK4pOGwH5bL7cdn694+ZWvk6Mr4v/++RnvH
VcMEOzRGcg14+c7xi2aUMZwLY4DeVvVk5nB+eyhWKw/rnhiXzi0zUK0TlC/C
EI3BbPB8RDV3+UR1rXGLuf5Cc7R9yTHyN/C1CueE3kjvCcNpaNXqelrk67QE
PWT9ZdwLJbZ1ww==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 206->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPoh/noEr6AHKF6hnmAF/SoU6of416O3xQebyWS7gbT7yM5k
khxvQ/doADz3y6dLr8s4pvd1t27uqT+f+vXy8PXF2o9P2T9ytDZ+8+xntFZc
JUyww8e4XANevlP8TjNsDOfCGKC3RT2ZKZz/Gh6rlod1T4xL+5oZKNYJni/C
cBqD2eD5yDVF86TO1DxFdTCm+gvPJ/uSY8DmrmoVzgm9cb0nDKWhVqvqqclX
aQl6yPpt3Awe0nXD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 207->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPIo/WaErtAOYLpCOoEL7StQSB6hv4yeBFqwTidjgezEtu50
ki7Pz/DuAMznfRnycp+m/H2cjp9XHm/X8bjsfw6saV+S3SNH4U1nf6NvxVXD
BDv8G5drwMt3it9pFnVCijFAsVU9hSmcGlYrD+s2HKAY6Dpwb6p1gueLMJhb
4av5KjVF86TO1DxFdTCm+gvPJ/tSYsDmrmoVzgnFuN4ThtLQqlX11OSrtAQ9
ZP323QYTZnaC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 208->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPoh/noEr6AHCF6hniCCfhUK9UP869HbgkIyO7tNYNNHdndm
Z3J+jP2rA/A+rlufP7dpyt/7Yft45uF6GbbD0y+AOa1bqp9eoIimf/9F7wor
6gkO2BzDVeBCnCl8M7PQibnMXp7gauqhuZga6tWKw5pUGEKbljsQ6gSL5/WQ
vuxgRncl4uneJ0eHalE9axX6InqUGK43il9RY7ynHmoGz3OZx16WfHl+4qDm
VFyRFvKvdME=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 209->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwjAQhR8uxK1H8Ap6gOAV6gki2FVBqAtx59FtQctk8k3UwKT56cx7
815252vXryTdNtPU5ftxHPPjtJ43lzwc9sN8uX2H9EzTlMpvFDLx09lnuDVh
tWou+bSOuAKu4I7wq55BJ8+FdIy4VvliLk0N/sDxmhQYoE1Lk0jzQifVeFEN
9KXxNr69lRZP1B/0W7jYQf6KeVS+QA2LEXpD/ExO5b2rQT1EnuN/3kvL1/fv
OFCfxFXpBYRTdME=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 210->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOgjAQRX9cGLYewSvoAYhXwBPURFYkJrgw7jy6YISUmTeFJm0p7cz/
8/8cb4+m3Ul6VsPSpNel79P7uh8P99SdT914efhP6VMPS73co6lsbvo3DfNN
WKWcc/x0ln/juAKuixfju5pBJxEv2ImrixdziTQo6UM4VpMFBmizpQeKOsnj
RTnQl0JvrPVKiSfqD/rNXPJB/op5OF8gR44RekP8shjrq81BNUSe4zvrZc7X
1m84UJ2ujt+7LwGPdkE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 211->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRb84oF4ZgRVggIgVygRBoqdKSOWAuDE6rQRREj+njeSkaWz/
728fb49+2El6dvPWx9dlmuL7ul8u9zieT+PyePiZ9AnzFsrTM2W2+i9fofwm
rFbOFP+/y/oYroBr4sX4pmbQScQLTuJq4sVcPA1a+hBOrUmBAdpsmYGmTrJ4
Xg7sS2M23FnROk/UH/RLXPJF/RXwoL5AjhzD7Q3Ul8fUfa1zUA1ez9EPcNO9
rr/iQHUK/b7503ZD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 212->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRb84oF4ZgRVggIgVygRBoqdKlcoBcWN0Wgmq1H4OjeSkSW3/
728fb0Pb7SQ9mmlr8/Myjvl13c+Xe+7Pp37+efia9E7TltZnZCrs71u50vqb
sGo5l/jfXd7HcQVcFy/GdzWDTiJecBJXFy/mEmlQ04dwrCaoU3HfMgNVnRTj
YV2VWdo8K+J3irMaWv0W7uWi/gp4mHmJcpQYVqtoTmyM66HJQTVEPUc/wLW1
RRyoTqHfB5UadkM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 213->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHqQXvuEfkEfsPQL+oIV9CQU7KH05tNVaEtMJnGFrGZNJslk
7v2zHS8AXtftaPP7Mc/501W7M+Spqaf95+1rwJK2Ix3fnkHY6Z180vGb1Yow
//k/HzbG9Erqmnzw+mZmwhOSj8H6NvMQnhhOhFVaR3NCeRJ+iQZCnuDXo3MF
WirWCvg9y9Mcap0s0hf3Zr8gfSi9eBiyhuYq0pnMMTtUGGwGb+duHGyM3jfr
gc0JGrcCv4N2RQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 214->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEuyoI7ULceXRbcCCflzADmelMk7zk
5Z0fr3E6AFiHbRvr+7Ys9XM/7pdnna+Xef95+hvwLdtW9BkZmoG8WT+5iv5m
WDbeniq25UxqZrguHhzf9Ux4iriI6kYS3xbLk+XqxbGcUJ7EvUcDKU+I8Whf
iZZ6tGL1EdVJ+bdzkLxAv7v5IugJmhOWQ2JYrjKdyRg3Q5OD9RDNPPSD97Hz
ZjWwPkH9fj6udwY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 215->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAUHFyIW4/gFfQAwSvUE0Swq4JQF+LOo9uChWQy80jgJU3z5n3m
zen+HMYdgNdh2Yb8vs5z/tz26+WRp8t5Wh+PfwO+adlSfTrDZhD/2K9cqf5W
uRjPZ4XdYgY1q7wVHm0ftmfBk+PC1Y0A72ppMBSrNw9zInkq7j0aCHmCzyf7
CrTUoxXWh6tT8s+a6NGPmT1zyPOV8xBcRTorMc0MKUazgplLP5GXe3M1qD4h
/X7qnndF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 216->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQszwDADFjF0dcjAHpWNzS50/eg0il6YmXjcjM1eFP0MmP7A6Wcs4YQrLHC5
mwGPflxuwdCDZhax9qCHCdZwQuITlQbwhRMDbvuw+osIs/GlFfT0gc3vOOMP
LU0QlX7wxD2K/9HiF5+dyO7Hl87Q3YnhVvQ0gWY/rjjHqg6Lveh+w+UGjLhA
l4erAwCZwXeE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 217->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDyIV5/gF/QBg1+ILxjBnAJCPIi3PN0EjEzXVA1p6Fmrt+o+
3Z9dvwPwOsxLl9/Xccyf2365PPJwOQ/L5/GnwJTmJcXdKVaFeGNcKSmeVSy2
5z3Yrj4bOYe4hC1Fxa9qFjw5LlzeaNi7XCob8rU1DnMie1pgNs1Aiyf4ePzu
eHGzoWaF50PVbvvn7FG8AzpP0bNQP/VXcS3PZk6mwp/is+KVhfEp+qxwIi7X
5nKoesH/f9wXdgl3wQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 218->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEuyoI7ULceXRbsCXzkjdMIDOZTL4v
OT9e/XAAMHfL0ef3bZry535cH888Xi/j+nn6M/BNy5HKWzE2RqBjO0uplKNc
7M/3HodlVSu0raUov+s5wElhUa1b+KtanA/Fas3DmIQzNTZNO1DDCTof6xUu
ajdqc+AdavJT/jB6IK4zmFnRP83XxYGQK3u2UYSnwzXIbWO4N+uDvNybqsHN
gv93ux9D+nZD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 219->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmhK8AAESuUCVKpvCohlQfi19FpJVoll7vQSE6c2I7P
Zzfds30cALxO89bG920c4+d+XC59HK6XYTGefwJMYd5CfjrBKhBv7JeukOsq
F8fzuf3DusMK75sulb+oWfDkuKjiNvEOi8QsOP+XhzmRPU18ds1AjSf4fPzu
eHGzUesDc7grjviT8wNonKJnWf3U3+IfGL0yZ1xngZVngnLzLE3Kj/CzD9sU
howPZd/8vgomdYY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 220->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKhTAMDC4ebj3Cu8LzAMUr6Akq6EoQdCHuPLoKz9ImM9JAam1+k0m+
/dyOhYis5XW0fmuWxe/d5/4Z/FT/pttY/VXkcNfh0i9TeVTAm/aLxaV3VMvE
K1whj75nYDX5IkH1TR7AE+PC+KH6Gh/BAjHn8APij8gH8hT5ZO3AG0/C6+l3
xgvbDcPfyyxYHhaLuNK8691CGEP/ar6sBuKE7dkjiE/DK6lt+gGCZspsCEPS
J7IHvxMr7HXD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 221->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfEbU9nk1hpHRs1UruuSWPH
yeH66O8bAM/dvPXpdR7H9L5sl59bGk7HYXHuvwuYunnr6q9bWBfoDvXbfIef
rzwrrPCeeOU8fG7gGvIVpvBDHqGT0yLEKXzmZ7hIzi36iPdTESN1KmKaZuCf
TvB4fO90cbMR9BP4qnbbP9KPObLuPFuKY66f+uswlCZuzlZTegZdDXaoR5jq
qfMpDlWdyp/jPv/adgQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 222->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfXQhbnsEr6AHKL1CPcEIuioIdSHd9ei2oGPm5aVMINPp5Pfy
ktPtOTwaAK/jegzp3U9Tmq+H7eeexst53IztV4GlW4+u/EaKn4LeUMbmN/xt
9q5quXjClfPwvQKry2dE1Xd5BE8RF84vwFrgC7BIzDX8iPjF+EiejE/VDuzx
hLgevyu8e7vh+Bf1Ve/hfAR/FiPzzrNTGHP/YsZqBxQnCp/dA8Wn45WF/Xm3
jKiZRjaFwfXJ9uz3ARphdwI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 223->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADFK9QTxBBvwpC+1H869FtQWN2dyYksGmafU1m
9nR/9c8dgOmwbn2ar+OY3rf99vNIw+U8bM7j14ClW7fOfpXhZ3B3sLn5Dn9f
eWa9Qr7Dlev4cwPWUK9YrH+oQ3hSXIQ4gdXgE1go5hZ+SP5SxFCeipimGajx
hNhP4WB4a7Oh+GdaqDpKx8A34d1rxzAaTE5jNgMsR74TUSOD1c8E6U3f6hbT
NPgqGMI7vT/HfQCxv3aC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 224->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAQszggrjyBL8ADKr5QXhAkeqqEVA6IW55OK0FIPDYQKUuTGdv1
zO587YcVgNtmXvp0P05TepzWy8cljYf9uDxuXxPI3bx07e4m3hN0hza33OHz
Vp8VV8gnXQWHz39oBWHWmhR/wBE+OS9CnNHaaIHHKWdErF88gRMI/xlyoH1w
8dInRD6nQ+n91hvOf1ULh+PqGPwWvnPtlMZGE9VY9YDKUX1U90EmPtUDYXA8
91Y1HK/S6TRkxpdxT9pEdgI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 225->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXnmCX9AHEL8AL1gTOZGY4MF426cDieC2MxU32aV0287s
tKfbo+0rAM/jfLTpdR3H9O4Oy889DZfzsFzWnw3kZj4a+4021g3ng83dfPje
lbbCMvlrjsAg+w+uZazxQeNTHaFTpAXFBVwNF8R1Nhtcaw+HMAF6J+VA6xDF
S53AeBEPxffXbET6q15EdaI+kt5Cd987xdFw8n0W7/C6R/zKOcgOT80ALR/v
Z6tYqqd0t8Mh+/oybgIxFHYC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 226->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHgwXn2CX9AHEL+AL1gTPZGYwIF44+lCItpOp8Chy9JtO9Np
T/dX/dwB6A7jUZf+2rblfdtPP4/SXM7N9Hj8GjBU41H5b2aYDeSDz/358H+z
d4Xl8uccgRHuG7jaWOam8EMdoVOmRYhLuG7h4jRArLWGEzCB0GfIgdYhi2e/
rWHxMh6K79JuZPqrWWR1wj6QfpYj686zUxwdJ57zimYpT6spzchxTXbL5sle
VZzA5d6WOAxcX8Z9APOfdUM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 227->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwjAQhR9diNsewSvoAUKvUE8QQVcFoS6kux7dFlQyM+8lhUnTdH6+
eZPT7Tk+OgCv47aM+T3Mc16uh/3jnqfLedp/9l8D1rQtyb6V4WcgZ96vfJLd
s1omHjYn3JnZqxzC17Ox2NAz0UlpEfwqrC0WowFirladUBMIfYYYcB1q82as
vp7iYLy1u6H0ZxqqPOE+OP1KRq+7nx1j/DOxOTc0k5yiz8Aq7lYZ51mkH6nr
e6sxrD4/9fsAlVV0hA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 228->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCngpCexBv+3RbUNhMJsFCttvtJDM7
yfH2HB87AMuwLmN9Xea5vq/77eNep/Np2n4evgG0si7FvqPALyDOGNc/xe4V
l8mHrQk6M/s/tPZY1qb4XR3hU+SFwwVaUy2wmNbjhOcRj+ME3D1dDrQPWb+V
VuaLdCi92WxE/qt+RnXcPJB/vUb2nXunNHL/uE7mWTZH6p5OazBbfR5rCXGC
l++WaWhcX+I+KSB1RQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 229->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKwkAQRAsX4tYjeAU9wOAV4gkimFVAiAtxl6ObgMp0dVVMoCeTSX/e
VPfhem+6DYDHblqa9nkehvZ12c4ft7Y/Hfv55/5jwFimpcS3M3wN4oz96qfE
vaoV4hFzgs7CfgVr7ctsqn7KI3RyWiQ/w7qGJWiAnOtfnVQTSPdMMdA6LPVb
sXI9x6F4l2bD6a80dHnSPJB+NSPrzr1TjD8m0WM1A6y7myN1z8Tq6lZxzGL9
1PwhMzmGkWOl3xuiNHVF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 230->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKgzAQHPpR/O0ReoX2AMEr6AlSqF+CYD+Kfx5dhbZkd2dChU3WZB+z
M7k+pm44AXg1+9LldzvPeenPx88zj/fbeFxePgasaV+S3ZXhayBnPq78kvVZ
L5MPWxPuzPh/YC1jzRl4/1CH8KS4kHGMI8cTq/PzSy79neAk9ATCnCEHnIea
3gyr78dmV37tbSj+GYeqDtOF8WD0YflEMzM/0VjyQGpRfd2cAavqW+R5LDKO
vT9YTDUMq8+lcRu5InXB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 231->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfXQhbnsEr6AHCF6hPUEEuyoIdSHucvS2oDKTeS9YmGQ6me97
c7o9hqkD8Dxux5Bf12XJ7/Gw/9zzfDnP+2P/EaCk7Uj+VoKvgNhqP/slr7Na
Lh4+Jyqb0//o1fo6G3j9kIfgpLBQd5iH4MTy/HSLJctHMAm8EPxDDDgGLb5Z
r6pe8G30orhh+DMMVZ6wDwIHxw+LJ5y5+WtuAI0DyRX2hMwZehW7ZePsTKXl
x/bPvqHdQ6ljqd8KIyt0gA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 232->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhR8uZLYewSvoAYpXGE9QQVcDwsxC3M3RnQGV5OWlWmibpvnr
1+wv9/62ATB1y9LXx2kc6/O8XQ/XOhwPw3q5e09gLstS/J5NfCaEju3sKF5W
uZw/fEyQzsl/1GptnQ46f/ZesD6JoXbJiDipOF/ZsuS7hEnIKfgrH8Wh9d+q
1ixfsP3BKeuV8DeCYRYn9APxs7Uzd9UX4X2IdnZvMUvrpHokDwgfGtxLc8tO
9Z+9g3+z4sj5ot0LYrZ0vw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 233->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFxItx7BK+gBgleoJ4igq4LQLsRdj24LVvImM7GQpHm/eTN5
x9uzf+wATN2y9fl1Gcf8vu7Xyz0P59OwOg/fBcxp2VI83cK2IGwcV34p/ius
kI9YE4lyC7/rGZQHZYPGd3zBdlNDnVIj0knVCZwFF9ansgtdW705Hbhvp9WG
4/CqWOb4Zzac/kpDV6eaB4H9u0P4Gm8f+HNtwOsgasn+iKfEEbNV5pWc5lac
mr/Sh8hZ6ch4ddwH9Yl1gA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 234->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKAjEMHPwQfz2CV9ADFK+wnqCCfi0I64f416O7C7qk05laSF9JJskk
h+tjuG8APHfzNuTXeZry+7JdHrc8no7jotx/BShp3lJ9OsFPIP7YLq5U3wth
cOzVh/GE3uXsbCMW1/GvXvC/wVCn5Ih4UjhVHaIW5qf5F7z2cnM8cN6Oq9hb
Fa+xNb1y8R3/ikOH08yDiL2+IXSd3lf1MzZaO+bM5kn5SD4gfGjxLJWenZq/
qENbS8yhsK+0+wCKJnWC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 235->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4eXRaCSrnfE6lJE1sn31n
n+7PYdwBeB2Wbajv6zzXz22/Xh51upyn1Xj8LcDKspX2zBb+C+KN/fxX2n8j
DM69xTCet5OPqpWxQFjMI+UsdMq0yE6pEenk+RvFMOdMn/AudO3VpnRQdWez
0dQv8gXfpFdZ/kz/oGEHJ8yDyL3dIWyd3qv+NVhZPwSWrI94yjxitnyc52Q9
PzV/3obIxddgHCv9vpZcdYQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 236->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFyIW4/gFfQAwSvUE0TQVUGoC3GXo9uClrzJTCwkafLem5n3
OVwfw30D4LmbtyG/ztOU35ftcrnl8XQcF+P+u4CS5i3F0y38FsQb+9Vfiv+F
MJhb6eLYFbejtaToB8LiPGzeSo+phTtljahOis/lDMaHeac8/mlTdVC63WwE
/YKv8TW9cvyu/k0NOzjNPAju9Q5h6/Re9S9gcT8QY3pzBoqRs2Rmi7lqLdZP
zV9tA+VieljztX4f/Up2RQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 237->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPoh/vYIXsEeIHiFeoII9qtQqB/iX45uC1qS6Uw0sHnuzs7O
5nSb+qEB8DguUx+fl3mOr+thPdzj2J3H9bH9GJDCMoVydYavQdyxXz5CuU+E
wbkVL47dcP/gCuKZc+KcEkvxMVq4VWpEOql8rmYwPsw91fGLm9JT8XZ6W/7O
l2sU+OrM+u80rOCo/Jx7O0O8VXqv6i+wuB8oY1xvmI/UAyKGBv+lVPNT/y9/
A9Viepjn2/u9AZmPdkU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 238->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwjAUhAcX4tYjeAU9QPAK9QQR7Kog1IW4y9FtQSWZNxMDSdrk/cx8
7eF6H8YNgMduWYb8PM9zfl2268stT6fjtF7uPxMoaVlSu7uJ74Q447h6pPa5
UA3urXRxrurrtIJ01pq4p9Ik9RgWbpeMiFPwz56FF+YTzonrP22Kp9LteDMv
VddprD24/o5/YNipo/pz74Yn33W+vfL/y0eMq/U7naEGDA+IHBr8L5VeHPOo
8oJ/8qh8KhZIb057dYQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 239->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADLF6hniCCfhWE+iH+5ei2UGQzO5subNJkXzOT
nu6v4bkD8D7My1A+12kq39t+OTzKeDmPS/C4OlBtXqzdM4fzzTtv1n7X9cy9
K8XA/VxczZVYKbe5Q5ypMEk8Jnp09lQ3Z4E/cxZcWJ9wT7puYVN6KtyZ3qyX
6pth9Byy+Zn+QcNOH/kWNLvRk2Odt1f8//WIeR5/hjP0QKIHRA0Z/0u1l8d6
uLrAnzgqnkoL2A8ejHZD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 240->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBi1+oL4igp4JQD+ItT7eFIpvZ2TSQpNlNZ2dm
c7q/hucOwPswL0P5XKepfG/75fAo4+U8LsnjOoFq82Ltnk24uRnzw9rvup4Z
u1IOjOfyqq7kSnebGGJNxUnyMYHR2VPf3Aj6WbPQwv6EOPm6xU35qXhnfrNf
Cjfj6DVk9TP/g4cdHNkLqt34yblO75X+//+I9zz/jGfAAOkifPW2uFbQykP1
hnPoc2CdygvYD9yxdcM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 241->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMPPoo+XaErtAOILpCOoELzStQSB6lP43eBEJQpJMtkB1b4XR3
8vX16YcTgLlblr58H9NUfs/zeniX8X4b1+JlS0BlWeS4ZwmTzTsbcvzW7eyx
1dXg8Ux9x21xNf+FO8SejBPlIwSjsqe+mQj6K5pTTaSvxW1xY34y3pnf3i+G
m3FkPjFOzP/gYQWHzgIIGvY7X6vMnun3OCqRM8Oi83U6leCzt+V7Ua02yExD
DXUOXifzAvIHsIx1BA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 242->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADBK9QT7CCfhWE+iH+7dFtoZR0Mum6kH0lzM7M
5nR/dc8dgPdhnLryuQ5D+d720+FR+su5n5LHOYBq42TrNQu4aN75Yet9nc+M
XSkHxnP5BbfF1dWFO8R6xUnyMY2RralvbgT9G5pTTeJdj9vipvxUvDO/2S+F
m3FUPilO3Bfen7/+U/EBgobljnMJRvg/xkas8/wzngEDpEvw5N7it1p1oS9U
DtscWKfyAvYDxE51Ag==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 243->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADLF6hnqCC/SoI9UP826PbQinJZOK6kH0k2clk
dk/3ZzfsALwO89T17+s09Z/bfjk8+vFyHpfgcTWglnkqfs0Mxpo+O4rf1/XM
2JViNpfvbrgtriYv+BDzFSelk8UK+WJNdTMj9P+j57QnUdfitrgpPRXvTG/W
S+FmHJVOipPLh9fnr/dUNYHQw+bjWPKegRNjg+4Yzsyd6zgMUF+CJ/8trtXK
C/9CxeA5MDb3qbRA+QKRzXRD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 244->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+5ei2UMpmdjYJ5LWP2dlJ
Ls/3MB4AfE7LMuTvfZ7z73FcL6883a7T6jxvEyhpWVK9RxNmdm12pPpctjtj
F/LZWM7dcXtcTZyzQddnm9LJYrl4sYe6meH6D3p2HESfRdWkfMWtpYPCVHar
l8KNOCqdFKcqHrU+LZ7NmoDrYbexL3hPx4mxQTmGM3NXmKAcflfLk/8W1+rF
uX+hfKg5MDb3qbRA+gMlCXXD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 245->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssKwkAMHDxIr36Cv6AfsPgL9QtWsKeC0B7Em59uCx6SyWS3kG2bx2Qy
m/PjNU4HAOuwHWN935alfu7H/edZ5+tl3oOnvwHfsh3FvzMDGftcnn2K/1a9
XD3z4lqL2+Nq8oIPuj/7lE4WK+Q3dJP8QDgwc2YaZDMJnhaXOaqaTAeFqfxW
L4WbcVQ6tXbF6h807NU19oT1DrHkPgMnxgbVGM7MXWGCavheLU/eLe7Vywt7
oWLwHBib51RaoPwAkUB2Ag==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 246->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssKg0AMHHoovfYT/IX6AUt/Qb9gBT0Jgj2U3vrpKnhIJrOukFXzmExm
0wxLN90AfB770eXve13zr78fP2Oe29d8BJ+nAf+0H8m/SwYy9rk8+yT/rXq5
eubFtRa3xtXkBR90f/YpnSxWyGccwdVxAeHA10kNFEbhbphHaZaaDgpT+a1e
ClfNUdqlq12x+gcNa3UXe8J6h5jSVnFibCDqAK+Z2qOAAZpL8OTd4l61vLAX
KgbPgbF5TqUF0gafSXVF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 247->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKg0AQLHKQXPOEfEEfMOQL+oIJxNOAYA4htzxdhRymq8seoUfttbqm
7s9lnC8A3tf9GPPnsa75O3XHzyuXoS9H8PY34Jf2I9n3mYGMfSavfpL9VrNM
PePi2rpvC2uV53zQ89mneIp6uN0EVoMF1Ae2TnKgepzcDeNwuzQ0oHBLvuH5
Yu4UjkhLkVZ4Jt9FWBfoxGmMY4pbhUloxfFAnCkduR6gvQRO1hbPauU5XagY
LAbuzXsqLpA2vwp0iA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 248->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEXRWEdiHuenRbcZG8vEktZKaT70vy
jrdn/9gBmLrl6OvrMo71fd2vj3sdzqdhNR5+AsxlOYq/WwIS1jk/+xX/r2q5
eMbFsTbvFlbjF3TQ9Vmn5pTlCL0JrA4LKA98nJyByiF2xHNljGqf/3BA6hHn
pfKqPlpcyrjCNXkXaVzCk8AxtqnZKkyCKw6jeTP2jG/Wd2Zbg1tca8sv8ELZ
qBfOzX2GPr5+H9v6dIg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 249->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDgl+oL4igp4LQHsRbnm4LCjuTSWthk2Z3djLZ
3ePt2T92AKZuXvr8uoxjfl/3y+Geh/NpWIKHrwElzUvivWUQUx/h4pf4391J
+apLcyPvltaAq3xgvOOwejY4lMtpJS0QHnCerYHjMD3Surq6az//mQHrR12v
Vn/tOxr8rbPeqb1YzTPaSW+sqcYaHJUmMyukMZxV+9q8RWwxMTdbP7/Oo8VJ
vChG3kk9B+raxDzd0weX+HQI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 250->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUjkOwkAMHFGgtDyBL8ADVnwhvGCRoIqElBSILk8nQRT2eLwhknfja3Z8
HG/P/rEDMHXL0dfXZRzr+7pflXsdzqdhdR5+AsxlOYq/MwEJ21yc/Yr/V2+6
fObFuRZ3i6uJCzb4eIUh+WxgMBZzCPxEfTZP9kBhiBlxX1Xfmdc/OyDtiP3K
5ivrSPAznd/kWTTzBHfH1/aUfQlG4CR2xXE0OnNv7ZuNndmX7RaotlYc+8We
gjkjYnOdoY5v3AeQWnLH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 251->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtx16Pbgkjy5sdayExnkvxJ
fv7heu/6jZk9dvPS1ed5HOvrsl0OtzqcjsPi3H/MbCrzUuKemcF4F+L8V+K/
ejPksy7mety1Wl1cc2cxXmHIelYwiMUamvpEfz5PcqAwxIzIq+Kddf2jAXlv
LV/ZfGUfCX525puchZqD8lEnjcbo+8Gb8R3iGHgAZ0pH1JuPnejLtGXojXFC
iykW+gzcIjfl8hv3Bk9IcYg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 252->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBi19YX1BBTwvCehBvfbq7INJMZupC2m2TTiaT
HK6P8b4B8Nwty1he53ku78t2PdzKdDpOq3P/NaAOyzLE3RnI+C7Etd8Q/1XO
8J558dsW9x/XJi7dIcYrDMmHMHq1VMfB6BTymZpTL0gP1aeEZ/rXatLTVd4j
6+X6K+sw+O6c+oA+T8Ur4agZY5/STelgcCrlYN1tj0WdlX1utprcMk7MYm9O
wZyhsa2Wv7gPgl1viA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 253->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfErU9nkzgkjtNOarc1qePY
Od1f03MH4H1Yt6l+rstSv7f99vOo8+U8b8HjfwGtrFvx72yBFp+5PPsU/61q
uvvMi+9a3BFXkxfO4PMVhuRDGL1eWsYh0cnVS3oOXpAeyqeAl/hnNRnNQDhH
1EvqmvXRwZa+sA+IPLmuivGchBnjmNJN6TDCMZyZu/RY9Nk4ls0WqC7zELPY
m1MwZ0Ts1CeX9wMrgG/H
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 254->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqEVA6IW55OK3Gwx56kktPWW8Yz
Pt1f03MH4H1Yj6l+rstSv7f99vOo8+U8b8Hj34BW1qP4tzKQsc/l2af47+xO
V8+4uNb2HWE1ecEHn5/1SPFQj94sTWEQPLn7xMxBC+Ij0yn0E/pZTkY7EPyI
fKW8qjk6vVNdWAdEnHxvFmMdw47B1zD2nm/UhzlT2qg5G8fUblnOGQeSfLVj
8L7ALdWmOrm8HxPscUU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 255->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1C2g4Ttz6dTeKQuE42Kd2WtI5j
9/L8DO8DgPm0LkNd7tNUv4/j9vOq4+06bsXzP4BW1qX4dxQwsZuzT/Hfqqc7
z7z4rMXd42r2dTn4/Qqjlb6Xwsp0lBwCndz8ycwSI+jBPJirmw1az8xv6zn7
J3WF7p9hS1/IS8td4gS82MdOb/ZH9IhyHY6os+7ZPeM5G9eiu2X5Mw+ek3Gi
GoS2dFb65Pb9AJ7tcMU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 256->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkjEKwzAMRT8ZStccoVdoD2B6heQELjRToJAOpZuPngQ6yF9fDg3ISST7
60ny5fEapg7A+7wtQ/7clyV/x9P+88zz7Trvwf5nQEnbkup3ZDB26LNPqr9V
zuo8c/FZq3vEavY5H+r9SqMkn0tptfrIDI5P1Fd4P7yO01AxwcGsnOffO2Bn
HvI3OFrMsp9BTp6nmoOK8Rxdv3k+IkfkczoNflkf8XGdhWPR3bL8zMF1sk4U
g+gtneX+etYVrmZxhA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 257->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkjEOwjAMRb8YECtH4ApwgIgrlBMEiU6VkMqA2HJ0WonB/v5xiZSktePv
Fzun+3MYdwBeh2UZ6vs6z/Vz268/jzpdztPqPP4m0MqyFL/3JszctNlR/LfK
6eKZi2Ot7harORds8OeVRisxl9LK6sgMgU/cr/F5RJ2goXyCg1k5zz9vQNqR
8CccGbOsZycn91P1Qd6ZmEK9uT8iR89mtW2PejXr9YZZ5PuCiLFDvMcQD++X
WsTe6B5ZfSPrF1eUccM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 258->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8upFuP4BX0AINXqCcYwa4KhboQdz26LbhIfv6kDmTaJpOf
10zOj6kfDgBe3br19X2b5/q5H7ePZx2vl3ELnn4GLGXdin+2DMZ2fXYV/65q
uXzm4lyru8dqzgUfdH32cS2llfWRGQKf+L+FzyPqBI1GDeZgVq7zzwxIPxL+
hENZazYCO3x/Mk7mYp3ACBNLepf5rLa9o1bPWnfDLHK+IHLsEvMY8uHjUkv1
G1Fb9TeyfgGbynKE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 259->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8uxK1H8Ar2AINXqCeYQrsqCHUh7ubotiCS+fmZOpBpm2aS
N8m/DI9+OgB4ntatz6/bsuT3/bh9jHnurvP28/w1oKR1S/UzMhjb9dmV6ndV
qzrPXHzW5t1jNXHOB12ffVxL5Wr1kRkcn7hf4Xj4PC5HUIM5mJXr/KMB6UeD
v8GhLNKGY0fdnxYnc0VMrt88H1Ej8lmN2BlFPYtmwyxSXxBn7BJ6LCrO5uEe
BBz2HlKHzPiL+wAlM3KG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 260->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOwjAMBFccEFeewBfgARVfKC8IEj1VQioHxC1Pp5U4uOvdlEhOaydZ
Txyf7s9+2AF4HeapL+/rNJXPbb84jzJezuOyePwZULt56tZfZwi2GYsj+NXk
Wp1nrqDDvmNG5CDOyOR4Un6qE2u16sgMiU/cr/J+ZJ2kYXIwB7Nynn96QMbR
4G9wKHO9kdiR/x0nczmmVG9+H5HDxZKO4994G2aR/QVxJg7Rj1XtizpcA8PB
95B1kKxf2Kpyhg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 261->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkjEOwjAMRb8YUFeOwBXgABVXKCcIEp0qVSoDYsvRaSUG93/bIVLS2kns
5x+fH/MwHgC8unUZyvu2LOVzP27Gs0zXy7Rtnn4TqP269PtvNGFm02eHsWuQ
a3efuUwctiNmWA7itEwRj+QnnThWpKPHIHxOfZXPQ+NIDGPz/Zqwcp5/esD1
I+FPOCKNWr0itSLnZC7Rl98M+u9pl/kkTsTfeBtm4bo8DWXwee4tOuvljTi4
DlcHl/ULqpRwiA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 262->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkjEKwzAMRT8dStceoVdoDxByheQELrRToJAMIVuOngQ6yF9fdgyykSxL
T7Ie71/3vQCYbvvWpbkdx7T010P5pOH1HI7L+1+Atdm3Jj8jgZGqzS6jr0Gu
7D1zmTisR8ywHMRpmTinYuJcKlbUR8Xg+Lg+8lE1F+/g39s6VA4b68wMSDvy
GIpVcUQ9qs2KqxVlzhKXY7I9PfM/gc3Fifgrf8MsXJfqoVvsz/NDvipvxMF1
yD5I1g3aIHCI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 263->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KgzAQhR9dlG57hF6hPUDwCnqCFOpKKOhC3Hl0FbqYnzdTA0mYZPLm
e0ke72/bXwBMt31o69yMY1266xF86vB6Dsfm/deBtexD0XPUYbpdU3myiXgN
aqnzlkvo2DhihuSw7IIp4nH1A8+Ki3khDI7P+jM5zHO6B39e+mCsUuvMH6Dr
0BqMlXFEd/TvrzivyDkzLsck7/TM+yRMSifKTfTVWfg3Yvrub0l9y8FaUDfi
sD6YTzqXDYTUcIg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 264->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRT8uxK1H8Ap6gOIVxhNU0NWAMC7EXY/uDLhIfn46U0hL29/k
Jc3p/hqeOwDvwzwN9XOdpvq97ZfNo46X87hcHv8GtDJPxa+ZgYzPnM4Os29J
LPeeuYwf3nPcwGp04azDE+InOTuujIMYAh/nRxqVc/cO8b3NQ8Wwvrb0gDyH
96FYFUdWo7VeUfXsccr/y5hsTbf8j6qD8pNpV/6GWZxO+A+9BaHn/iFt6os4
mshD5SnX8gNdSnAE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 265->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwzAMEz2MXfuEfWF7QNgX2hdksJ4Kg+4wdsvT28IOtqw0CyRtHMWS
7Fwer2HqALzP2zLkz31Z8nc87Ztnnm/XeT/sfxMoaVuS/9YmaHLM4eww+5I0
p7vPukwe3jNv0GpwISb0sN+SIpfKVfUiNAR97I8wynPrjO9bH4rD5vrnDcg4
Yv/k+4DmV1jVG1mfSv+P7oUacs8Q/4/4Qx1Unhq20RvW4nyJ/OFt2fysQw3F
z17Q1lCUfodbAckVcAI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 266->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPoo/XaErtAOYLpCMoEDyStQSB+lP4/eBEKRTyccg20sybo7
Sbfh1U0nAO/LenT581yW/O3P22PM8+M+b87rvoGS1iPVd7RBm21VnF3mXZLG
rP4zL5OH34zruJo4ZxN8WG9JHkvlCrUIDo4f66MYpbnl4/9Wh8KwuY7MgLTD
90/OBzS+ilW9CevT4BlhSk62pkf6o+qg8kSxjd4wl0qX8LnZsvmZh1oKn7Ug
4KDmkP3/uB+H/3AE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 267->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksEJwzAMRUUOJdeM0BXaAUxXSCdwoTkFCsmh5ObRk0ApX99fTQ2ysSV/
Pdk6P1790JjZ3G5Tn9+3acrL/bRvnnm8Xsbd2X3MrKRtSn6NzMj4zMXhgH1J
Oqe7z1ygw/uI2ZCD2YGJeVijpDqX0gprEQwVH9dHMarmIx/fxzpUDtT6pwfk
uXkNZok4lKl/UL3Df/SLM8opmfBNYYT51TsonSj24G+YxdUlfFVvoT5zqKHy
cy0WMKg+ZP83bgUeQXDF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 268->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT7cFwd2Z3WggaZNsZmdn
9nC9D+MGwGO3LEN9nue5vi7bdXOr0+k4rZf7zwRaWZbiv9kETT5zcXaYfStx
TveeeRkc3nNu4Upx7izgwxiNMEQHoF9LwEH4cX0Uk9X8Sw/xpZPDYv3TA+E5
1L/M31DLTj+FvgQe9XhmOa2GzjOYf6orq4/jQpxEs543DgOqOwIMGaSV9A/F
Sn6uBeopv804fuPeDb9vhA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 269->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAESuUCYJEX5UqlQfi19FpJR72+dwQyUmduL47
2+fH1A8HAK9u3fr6vs1z/dyPm/Os4/Uybo+nnwFLWbfiz8xAxncuzi7jL0Vj
uv+Zl8nDPmMHrhTH3JiP1A2kmh0vpUVwCPxYH8Vkmlv1CH3ZwbC5/pkBeY/Y
v6y/spY788RYsj4NnhmmraHrGcw36cr0cVxYWWyjN44LYt0hcihsixXmR/CE
yqV4EAelU57lC5zhb4Y=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 270->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkjEOwjAMRb86INYegSvQA0RcoZwgSDBVQioDYsvRaSUG+/u7NJKTOnHt
9xOfbs/x0QF4HZdprO/LPNfP9bA69zoN52k97H8GtLJMxa+ZgYz3XJwdxm9F
13T/M5fJwz7XDqwUx2zMI3UDqWbHpbQIhsAn9DWOF5rDWcLJOpiVc+3pAbmP
Df4Njsyyt1H6bM6MM6tp79C9Gcw36cr0cVwYWeyft3EsiPcOkUPVtrVk/xBn
1qeBgxiUTrmWLzn0bwg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 271->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8upFuP4BX0AINXqCcYQVcFoV2Iuzm6LYgkPz+DhbRkkk7e
T3K8PcfHDsAyrK+xvi7zXN/X/ebc63Q+TVvw8DWglfVV/DczkPGZy7OP8VvR
Nd3/zGXuYZ9rB1bKYzbmkbqBVLPjUloEQ+AT+hrnC80hlnCyDmblu/7ZAXmO
Dn+HI7NsNkqfvTPjzGraHjby3fzQqa/6wLNR84HuSbZngTOJydpUS+4PcWZ7
GjjsuehNiP/yPqC6bwo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 272->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKAjEMHPwQfz2CV9ADFK+wnqCC+7UgrB/iX47uLigkk4kW0tLmMTNJ
D9f7MG4APHbLNvTneZ7767JdL7c+nY7T6tx/DLC2bC2elYGM30KsX+5uTWOC
coPP1eG7xPZGcSBuzEfqBkrNgZfSIjhYwcXrMxUvtBjXERjcF+Ya3lH3QdVk
nb/4cz/Vn1IzVfNN9ZFz/uWlfBDHbz/dWeKrPvB81Xyge1L9s8Sz8ElswmLt
zDHhez/z8O/V/5Rxb/5AcAY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 273->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAQCx6kV5/gF/QBi1+oL1hBTwWhPYi3eboteJjNJlqYltmZTpLJ
Hm/P8bEDsAzra6yvyzzX93W/Jfc6nU/TVjx8A4iyvkr7dQEKPmt685PyKBoT
9G9TS3M4l9g5qA/EjflI3YDUnGtWi+AQhgvP7PqFluA5hmfH2/iXd/LrDshz
9P45fxW+0qa8+eeD4+kw850KynnvFl/tgf1V/kDvpOOZuYB0iprEJizWrnhC
zXL7EndUcmz6PmVncAY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 274->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMHLqQbnsEr6AHeHiFeoIn6KogtAvp7h29LbhIJhMt5JV8Z/I5
P97jqwOw9Psz1s9tnut6Px3Ks07Xy3Q4h68ArexP8f9MQMI2F2s/o7eiMUG5
zmfqsK6wHS+KA3FjPrJvQPZsfWkvgkPgp/pT8Yj5jeskPFWO2p+dya8bkHb4
GgpPzSyTbDf/9pDxzDDtTTXSeX8pvpoD71dxhJ5J4Gm5INZgn8QmLO6deQZ8
62Me1p7dp4zbACqjcYY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 275->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBileoJxhBVwWhLsTdHN0WpCYvL1MHMm2+7yWZ
w/XR3zcAnrvp6svrPI7lfdnOyq0Mp+MwO/dfAWo3XZ3/ZgIRC7IvsfYYvYp8
xg68TB3WFbbjRXEgbsxH9g2E3kG+tBfBIfBT/al4gVW5TsLz3/3Zmay9gWCH
r6Hw1MwyyXaztgfmk+WFfBBH/Oq0Zhds8P/uNGbW2o3jgliDfRKbsLh35hnw
rY95WLuYTfAvcR9NNXJH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 276->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADFK9QTzCCXRWEuhB3c3RbkDF5+diBTJvve5Pk
eHsM4w7As1uuobwu81ze1/2q3Mt0Pk2r8/AVoPbL1etvJHBiQfYWK4/Qq5PP
2IaXqMN6xLnxEnHKxjWzdxMWmFv2FoeD4ce9ieIde+U6Ac+t85M8/u2AsUPX
8PC8nkXCu+LtjjcH5hPlmXyeAX51st4ZG/S/OknPstkoLrA12OdiExa/nXka
fOljHtLu9Mb4W9wHfzVyRw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 277->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbiQbj2CV9ADFK9QTzCCrgpCuxB3c3RbkJq8vAw4kGnze3mT
5Hh7Do8dgLlbrqG8LtNU3tf9qtzLeD6Nq/PwFaD2y9X7byYQsSD7FmuP0avI
59qBl8FhPeO88TJxzkYYllvAoloBq/UWwSHw495k8cJeGUfU+Gd+rT4oTObA
88vmyzFKeFfU7ridSPhkeSGfZ4AfTqt3wQb/zzhZz1qzcRiIGOzj3XI+fo86
qj6/BdSvZEcDRxf3AQcicQg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 278->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADLL1CPcEK+lUo1I/iX49uCyLJZLLQhX0mO5lM
cnmM/esA4H1al77O3TTVz/24XZ51uF2HzXj+TWAp61L8nk0IH2Tvdpj7UnRM
0F9nMzh8zzj/eRk/90YYllvAolgBq5WL4BD4sTbwPoyTxkh4qvqpXGzsPT1g
ObT4c28ELZN+Uj0X8BH/cC6yfoJT6DGha1NP+DPjZJq1auMwEDHYxr3lbJyP
Gio+5wLSi7BZE7mXLwhtcog=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 279->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfbiQbj2CV9ADBK9QTxDBrgqFuhB3PbotiMy8eRMxkKSTSd9n
Msfb1A87AI9uXfr6vMxzfV33W3Cv4/k0bsnDZwJLWZfi92xC3EF2boeJl6I5
Qf+6nMHhONP81WXuuTPCsNoCFnEFrJYXoSHoA1L/EDgph/KavJ/yYrn/6QGr
oaWfeyPUsqGbuQI+11B4ke8nNIUeA5q1C2fw3w5HcLD+Vp9lPhnfcYNy7EcN
xf/LC2FzTeRe3h2ucgg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 280->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDgl+oL4hgT4VCPYi3PN0WRHZnZysGkjTZ7czs
Zo63qR92AB7dsvT1eZnn+rru18O9jufTuAYPnwm0sizF79mEyEF2b4c5t6I5
Qf+6mMHhc6b5q8vkuTvCsNoCFnExVlZTSzQEfUBaPwROypHoVO+narHc/3jA
atjSz94IvUz8pDwX8LmHohb5fkJT8Jjo62Y/4b8djuBg/ZnPJEYSc9ygGNej
huL/VQthK+/GvDffWXLJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 281->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfbgQtx7BK+gBgleoJ4hgVwWhLsRdjm4LUmbevGkxkKTpZN5n
Mqf7s+t3AF6Haenq+zqO9XPbz4dHHS7nYQ4efxNoZVqK37MJcQfZfzvMuRXN
Ccp1MYPD50zzoovuQmkznIyx8JFWlSe9UH7AIG/sHxs4TeAwh3o/5cVy/9MD
VsOafu6NUMukn1TPBXyuofAi309oCj0m6rpaT/hvhyM4WH/WZxIjiTluUIz9
qKH4t7wkPRry3L0v2ldxSw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 282->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMHDzIXn2CX9AHFL+wvqCCnhaE3YN469PdXVZIJ5OKgbY0aWYm
SY+3Z//YAZi6eevz6zKO+X3dL5d7Hs6nYQketgWUNG+pPqMF8Wa1yA8T36wk
zQnKrWIGh++R5m+M30JpM5yMoWpkrKimYvlSgEG1cf34gVMEDnOo+alaLPc/
f8BqaOnnv+F6KfRwrtJuZ6T0RHkuH14j9z3kD3zKop61ZlNpERgca3G7epQp
fhtjHdYf9NZpXd98ABN/cUs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 283->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBwS/UF0TQU0GoB/GWp9uWCpvJTLuQhOxmZ2Z3
c7q/uucOwPswbl3+XIchf2/76fLI/eXcT8HjsoCSxi3Vp1sQb2ZzfoT4YiVp
TlBuFQs4fHea/zF+C6EtcjKGqpGxXE0l8iWDEUzVjw2cwjiCQ81P1eL6sPUH
oganX/2NppdCD/dTaY8zUnpcXpOPViP33fIbnzLXs7XZVFoEBsfWuJt6lCn+
GGMd0W9622id3/wAJFZyDA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 284->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgzAMs3aYuO4J+8L2ALQvwAs6aZyQJsFh4sbTgYlNqeOGSC2idR3H
yfX5broTgLFatyZ9HsOQpva8/bxSf7/12+VlX8Bcr1udf0sLAvON0jnM/R7M
o3IrXT+ejDvQDPvOYCG02ZzMoWpkLodnHZRf6ivwKA+4blWn6lfJ9+xc+HA0
A1YD909i4TFqsR+hP/BvuBbZP6HJzZjwlXOGPaOQsxFwOVzEgePcrh4VKr+9
Yx3qTeTlH78ABhFxig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 285->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgzAMs3aYuO4J+8J4QMUX4AWdNE5ISHBAu+3pwMShdZw2UlpBXcdx
+nzP/XgDsDbH0setW5b4He7nxydO7Ws6Dx9XAr9wLCHfvYTA/MP7j+T8CuZR
tZWutE7GW9HKWAhtaU3mUD0yl8GzDqov9SkewPdA1XB0qvmpXjwfam8g1cDz
k1hYjEr2Q/msvGI93j1zH1Yj+16aj/JYhXwbBS6DK3GgXjvrzcGZeagzkF8V
b1W/CDsVyXBL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 286->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDxIrz7BL+gDil+oL1hBTwWhPYi3fbotSMlOJhEXsmW7k8lk
ssfbc3jsAMzdsg3ldZmm8r7u18O9jOfTuF4evgHUftn69hsFBAbRf7vMmXlU
baVr47HciWarq8kV2qLeYfSwZsvl8KyD6tdAS1Q346nMI2qo+alerPf/vAGr
gecnsfAYFeyH8ll5xXqiPJcPr5F9z+ajPFZLvo2Ey+EyDvyu3fQm8ps7xSX8
lTmZlxv+A/8TcUc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 287->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBwS+0L0ihngpCPYi3Pt0WimxmZxMMJCXNzuzs
7F6GZ/c4AHid1qPL7/s8509/3C5jnm7XaXs87xtY0nqk8httiBhE/+0yd+ZR
uZWuH4/lZlygq8AKbVHtMHpYs+Vy8ayD8i+BFsUTeqByBDpV/1Qt1vt/ZsBq
4P7JWPgYtVVfQ3/gMS2cw8NrZN/VXDR7RkvORoXLxdU40M5d1CbwxZvion5b
L2reqnqRvkIJcUU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 288->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDxIrz7BL+gDFr9QX7CCngpCexBvfbotaMlOJrGQbbubzEwm
e7w9+8cOwNQtS19fl3Gs7+t+/bnX4Xwa1sPDN4C5LEtp31FA5EDsb3u/x3wz
juJWujYcxiVepauptfXIe4fRw5otlstnHcQvPQpwGg0CZ2acoD7znXmUn9kd
sBp4fjIXPkdFpCP0549OOT+hyfktfGVO1TPP13FYbMDj8z1ROoOzjLvpTdQ3
ZwqL5m29yLxV/aJ8AP12cAY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 289->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPoh/vYIXkEPsHiFeoIV7FdBqB/Svx69LWjJTibbhX0nk8kk
l+e76xsAn/O6dPl7H8c8PU7b5ZWH23XYPtvfBOa0LqncowlhA/G+v/2HOTOO
iq147TiMS3EVr8LX+qOeOwwf5myxIntnqzDMcDiMCY8zM07gX9Od4yg9az1g
OXD9pC28TaST4hHqc8AzqglzcnoLXV0eImfXaxzDYgMen/tE8Qz+arGL3IS/
rAe0X6HXgbYqX6QFMEtvhg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 290->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUkKwkAQLDxIrj7BL+gDBr8QXzCCOQWE5CDe8nQT0KFTXbMM9EzSS3V1
9fnx6ocDgLlbrz6+b9MUP/fj9vOM4/UybsHTz4AlrFfYvzmDyIHwJ9//mG/G
Ub0Vr4TDuBWurtbWozw7DB/mbLFy+S5XYZjjcBgTHmdhnEx9SXfXp6KJ9JsZ
0tuSWzDWQ+5W8M71zu2EOTm9ha4tM7u9cI9AsRLPVgyI3qCY5STq5T6g63Z6
VbRV8yJ8AahcbwY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 291->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUVsKwjAQHPyQ/noEr6AHCF6hniCC/SoI7Yf416PbgobNZDZNYJN2H7Oz
s+fHqx8OAOZuvfr4vk1T/NyP288zjtfLuAVPPwOWsF4hfz2DyIHwJ9//mG/G
Ub0Vr4TDuDtcuXax9ajPnuUzH4Ot8iUPhWFOgaM4e3oLTby9qB48a00T6Tcz
pLclt2Ksh6cpa+71lvsTnAq9ha4tMxd74R6BYjWerRgQvUExy0nUy31A12V6
7Wir5kX4AuGYcIY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 292->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENgzAMPPGo+DJCV2gHiLoCnSCV2hdSJXhU/BgdkNrIuZyBRnJIYvt8
PnN+vNtXBWCol62Nn1vfx/F+Wi/P2F0v3epsvgZMYdlC/vUMIgbiPb39ljkz
jqqteCUcxt3hyrmTzcd271k88zHYKl7yUBhmFTiKs6e30MSbi6rBvf7zD1h+
PL/dWM+EHp6mrLlXW85PcCr0Froe6bmYC9cI5NvieRQDojbIZzmJfG8eKi/T
K5T5rpYpbgaQQXCI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 293->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKg0AMRYOL0m2P0Cu0Bxi8gj3BFNqVUNCFuOvR1VIkk7yoAxlHk0le
frw+P827EpH+PG9NHuquy+PjtLy8cnu/tYvz8jeRb5q3VD61iTnbmN8K4tal
zjYP1SYuXafIC8whg2ZW3/d6d/dNfop3HNC3GBaXh5hhDmGfG/OjXnSvpGn0
D2g+O7/d2MhAj0hT4qbaOD9gcnqDrkd6dnOxNZLxbXEezSFQW4xPMwFDNA+6
V+gFOUIt17gJrydvSQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 294->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0Kg0AMhYOL4tYj9ArtAYZewZ5gCnUlFOyidOfR1VIk8/KeOjA/mszL
l2TOj1fbVWb2ruelzZ/bMOTv/bR8PHN/vfSLsflPszHNSyp3Pw3O6PMbwm8d
7ow6LDbj8nEKXcIsGTyz+7+Xe7gP+sw/cJC8DViCDmMmfZB5ChYWA3NlNVVv
wPNh/3Z91ST1UDVl3Kihcsb6IiO+vfAuNnIOfcEYCWxbnEc1jMQ2sHkmwqD6
we4V9SIaspar3wSh3m7L
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 295->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6ygp4LQHoo3n24rUibJTNtAttvudDKZ
7On+ap47M+sP49LU4dp19X3bTy+P2l7O7XR4/KfZp4xL8U9MC/uI+YXAzQH7
yMNqM11Yx/ESzVIDaobva71TPcCv8AnLOCASD9NM5iD7FFpULzhP5qm6A6gv
+rWKjV4s+Ko8Zbojh5wf0ZT8Jr5u6TnNJdYo/mxR50YOp4MEvUukz5TG/3N+
EQ7p5Yz7Ak6xb4w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 296->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAUfLgQtz1Cr2APIF5BTxBBV4JgF8Vdj+6HIi+TmZIHiRHHycy8
9xyWbirM7F0dWxc+7bqGrS/PlzHMr3o+Pz5+y+zbHFsTP/0yOCPmKoG7y52R
h93NdPl7Il6iWWpALsvzTvU4LoVPsIzDVcIDnOgj6w6iRXnx/WSZqhlI9Fke
VmlXuSq/TDdyyP4RTcwPzQ58sIwTHuwHZPZvznI4vFZWdJaIT9YP9l+UF+GQ
Wd64HRLMb0c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 297->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AQCz2I1z6hX7APkH7BvmAL9SQIepDe+vRqKTJmk7IDu67sbCbJ
zOUxdv0JwFyvW5eW2zSl173afp5puDbDdnn+LeDdrlt7/MYFOnPON0zeHuHM
OKq24hXrHHAFZ8uBsVCmXfIJWC4/y1UYITIcwmQdRTUEF6cl9lN56mYg44ey
XMfd+er0Kt6MYfvnvCI90jvSoTzOcLgf5Nnf/hdgRK4q5CwJnaof6p3kwPMJ
cb/nfQDSk3AG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 298->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAUHLoQtx7BK+gBSq9QTxBBVwWhLqQ7j95WpLxOZkIeJE2b18l8
cr6/+mcD4H1cpj59unFM0+2wvjzScL0M6+bpP4Bvu0zt/hkHaM09vzJ9W4U1
46izFa94zg5XcLYc+BvqtEs+ASvrd1wURoELiAPrcPjsm8pPaYl5Kk/dHcj4
oa7XcXe+Fv0k3oxh83NekR7pHelQHmc4nAd5Vsy/AiNyVSXvktCp8lD/SQ58
PyH2t74Z0e9wBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 299->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEQCx7Eq0/wC/qAxS+sL6igpwVhPYg3n+4uaJmmSelCu21nmkky
PVwf430D4LlbpjG9zvOc3pfturml6XSc1uD+N4DPsExD+Y8DtFZ7e/7/wppx
VG3FK+MwruBsOfAZ+rRLPgGryndcFEaDC4gD63D47Jvqn9KS6xhP1RuIPcv8
0JfruDtfe/wsclDfa96H1yO9Ix3K4wqH+0E1mv3vwYCoDYpFToKD64e653QU
vYCI57wvA3VwBA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 300->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUVsKwjAQHPoh/vYIXkEPULxCPUEE/SoI9UP869HbgobN7GxIIM/dmZ2d
nO6v8dkBeB+3ZUyf6zyn7+2wXx5pupynPdj/JrAM2zKUu52gs7qH7/9hzoyT
dYSuzMO8QnOogd/Q1rvUY7hcfqRFcVS0gDRwHxG/wjs+gc11Ak8Vp/2zrA9t
uZH2yNcWP4sceFwVj7gf6R31oTx2PPAa7V79/xYOiNqgmNUkNBQxxUV+Rdiq
lzlvBYxBcAQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 301->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF1Swp4JQD+Jtn24LuqSTSdjC7qabyXQy
6en+7McdgNdh2frhfZ3n4XPbry+PYbqcpzV5/C2gdMvWbU+7QDFjIO7r3f8x
cVZTY6Gr8jCv0Bxq4Du09S71GC6HTzxyHKIXxhSBc35zj8lcol6K4VGeRv+A
04c2rPIm87XFT/ZEzjOqR9yP9I76UB47HniN9kznL+bjOCC+DcpZTYJ7k1Nc
5FdUm3pZcV+cg3BD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 302->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+KtT7cFXdPJJG1hd9PsZJJM
9nB9tPcNgOdu3NryOvd9eV+208+tdKdjN13uvwsYmnFr5qddIJsxEP7q+33G
zmKqLeqqPMwrag5rYB/W9S7rMVwOn2jkOEQvjBkEzumt+hS6RjkgMJmuzm/z
Yx1WabP0Npb0ZE3kPKN4xP3I+VAfbmaKB75Ge6bzF/NxHBC5QXe2JsE9u1Nc
pFcUm/X5x30AzrhwQw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 303->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsOwjAMs/hA++UIXAEOMHGFcYIiwdckpO0D8bejs0lQUtfJYFIfS1zX
cbq/3LvbBsDYzFOXHqdhSM/zdvm5pv546Jfk7j2AqZ2ntlztAO0ZAxHPsc9n
9tGZvBe6Mg/zCs2uBo7ht9qlHsNV4QOPKo5AC0gD11HwqzqFr94dEJjI1yoO
4xP+wAZDvY01P9kT2U/vPGqN7Cu/C1tH1TPui8EX+ZXeTA5OckDcDcpRTcxd
5Jx3av3yzkZ1fnEv1ZJwRQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 304->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbn24rUrOTSYqFbDebSXYy
2cP13nYbAI/dtLTleR6G8rpsZ+dW+tOxn4P7rwFjMy1N/bcG2jMG4vzj28/4
Wc6yF7xULcXH8SKs4rbWu+Rjajl8opGrkXABceA+pN5B/lIjuAMCk+nqzmF0
wh/YxNTbWNOTNZHzjPLhOUa6qj7czHguBl/FV2YzBjhZA+JuUIx64tpVLHin
Vq8oN+vzh3sDMxBwRw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 305->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAQCx7Eq0/wC/qA4hfqC1bQU0GoB/HWp9uKYMxmZnFgd7vdzJBk
Zne+9dcVgPtm3vryOI5jeZ7Wy+VShsN+WB63nwVM3bx1vycvyLdi3uFwHHTn
OprDNZWXq+X4KFfFOm4t7ZYP1arwERdXI+EC4aA6rN9BPvcq0qKYzNfqP8gn
/IGVGWrNRstP9cT2M8pHzTHy1emoeqZ9IXylPenNpLishvoqYWcJwZnMKfsV
5WY6v7gXdz1vig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 306->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT8uxK1H8Ap6gOAV6gki6Kog1IW4y9FtQXDy58/UQpKmnUze
/D+H62O4bwA8d/M01Nd5mur7sl02tzqejuPyc/8dQCvzVPrVDtC72svv9jF7
PifvEVwqF+dgbhWr2NZqlzwml4uPWFQOxUI6tdLHpHqLO6yuzOi4AKlF1APM
EPE35gCxr/TTv3oqHuWPPE8esDdOO6rDeca+mHhXe+JN47gsB+tKj+wlBGvS
p53fwdmszl/cB3rSbsk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 307->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwzAMEz2MXvuEfWF7QNkXuhdksJ0Kg/YweuvT28JgjiwbFkhCEtmR
JZ8f7+HVAJjbfRnK5zZNZbmfjsOzjNfLeDx23wms/b709R5NCAyiezvMOYoB
xTIvlUv963gRFoJbVDsyPiaXwycauRyKC+lU6RlopzRxOFGv4wVILbIesBwi
/qo3Ku6BTv/qqfgof2Q8ecDeOO2oDucZ+2LwrvbEm5VxWQ7WlYbsJQR70qeV
30FsVucPtwHmLHBJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 308->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKg0AMRT8uiluP0Cu0B5BewZ5gCu1KKOiiuPPoKhSa+flJB8ZhNIk/
7+f8eA+vBsDc7o+hfG7TVJb76bg8y3i9jMfH7ruBtd8ffX1GGyIG0Xu7zD3K
AeWyLlVL/dfpolgIbVHvyPSYWi4+YeRqKC0wDJlnwI75Kr9Uv04XIFlkM2A1
WP0hV9Lq/Elm4x9PpUf5I/MVb+LOc5Exr/yleNd74s3KcVkN5kpLzhKCM5nT
yu8gN+vzF7cBm+9xCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 309->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKg0AMRT8uiluP0Cu0B5BewZ5gBLsSCroo3fXoVegi+fkZK2SGcZLM
y0/O43N4NADWdluG8rotS3nfT/thKvP1Mu+X3c+AT78tvd8zg/BB9t9+5pzF
gGKZS+VS7wYu8oVgy2q3/oGH7mo6gkzyWRYYDSt1uPykr+qXqjdwAVKL2gxY
Bsuf6kqsskfJbBzpqXhUf2Q89YB7E7Q70DzUZvz5TaUZz9k/OaSuoDuqycXz
3CVz6vqdxKaMzu8LC3tvyw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 310->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKg0AQLHKQXPMEv6APkHzBvGAEPQkBcwi55elR8NBTU90ToUemt6mu
6nZ6jssFwOu6H2N637ctfR7NcZnT2nfrEbydBnyH/Rjyv2cQOfD89jN3rwZU
y7hUr7CHqmMf4tltfoGHYhGPIJP4LBYYDoM5sv7Er9JLzVvgAiQXVb0Jd7gz
hFXN5ula4zN8t1ZPGrA2BXcVzkF9bT6/yX61Z//0kLyCYjQT12cxZ08zvbmH
t58y7wePKm6K
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 311->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHDwUrz6hX2gfIP2CfcEK9iQU9FB669Or0MPu7EyskJVNMrPJ
JOfxOTwaAGu7HUN63ZYlve+n/TKl+XqZ92D3M+DTb0df/p1B5MD58y+7OwwI
y3UprpBD4dgHjVUcVT0Ui3REZKRT0T9EntGO9VXzKt5wPQJSi8N5E0e4M1Sr
6s3NVekpezW4EE8z4NlU2h1oDuLN8/lN9qs9+4dD6sp9UE+VP4+ZPS3mzRxu
P2XeF+RUbcs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 312->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwzAMEzuMXfeEfWF7QOkX2hdksJ4Kg/ZQeuvT28IOsSJlASfEkRVb
9uP97YYLgPl2bF1a2mlKa389L580vp7j+Xj/GbA1x9bE0xkEBs6fr+zuYkCx
nJfiqnKoOPZBxyoOV7PiqGlUGOkU6ofAGe1YX9Wv8IepMcfUZkDWiJi/nRnK
VdXm+ur0l5qIONWPkAflyLkFnj+ag3hzPP/JflWn4tjMWzFbKHGOO7yZOS20
B51qPiVuB4Hzbow=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 313->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKgzAQHHooXvuEfqE+QPoFfUEK9SQIepDefLoKPSSTmYjCRrK7M8lM
9vkZ2/4GYK72pQ3Le5rCr7sfm28Y6tdwFB//ANZmX5r07wKiBy4ff9HeYUBY
vpfiKnIoHOegsYrDaVYcJY+yIJ8S/RB9xjv2V71XcobRyFqtJyovOEqzId/2
ZDac/9ITgeNaNmN0R75bgjnxHMQb9/OZnFc6FcdqatlsIe9z3FdqSoedT9m3
AWQyb00=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 314->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPoh/vYIXkEPUHqFeoIV7FdBqB/Svx7dFhSys5OsFrJl85gk
s3O6PYaxAfA8bseQXv08p+V62C/3NF3O0x5sPwas3XZ0+d8ziBx4fvuZu1cD
quW5FFaIoerYB12rMLydFUbEUWFqFhgOgz0yfOJXvde3XuXYnr9oQO4oMCJt
yLetaMPjX3Ii+nKs0BjNyLNlNRXOQbg2P+sR6KiGsTox1hb3sjsV/j9izJ2N
F/qUeW87W29P
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 315->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMHDwUrz6hX2gfIP2CfcEW2pNQ0EPx5tNVqJDMTtZWyOo6yexk
NufHu3tVAMZ6Xbr0uQ1Dmu6nbfNM/fXSb2DzDWBu16X17yggchD9t4/ZRzU7
Zr+tLsWVcShdlAvSpmoVR9Sz4ih5lIXSAuNhoQ/HT/6q+9rrVY4985cZkD0K
DukraVW9Rfca+S89Eecyls0YaWRtrubAcxCvzXdnFOboiGMOMJ4th1FPXP8P
xt5ZPJtPmbcAmRRwEA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 316->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKgzAQHHooXvsEv9A+IPQL9gUp1JNQ0IP05tOroJIdZ6MGkpDszmR2
suX7W9UXAF0xLlXsn20bf6/rdPjE5nFvpuBtnsAQxiXY3ZsQOfDu05GcPQwI
y7oUV5ZD4fgOGqs4vJoVh/SCcTktwidVh9FD/qr/WvAqZ8Ue9UTdH+Ugrao2
7189/6Un4l2ObXqMNLI2g9nxHMSb5ps3Mn20y+HEuLdMjGpi/JmYq1P1p9rD
H/+Lb44=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 317->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMHHooXvuEfqE+QPyCvmAFPS0IepDe+nQVetiMk1WFXdkkM5kM
eXdjMzwAzMV2NWGppyl82+f+6EMsP3FPvv4H+FXbVdm/dyBq4MXTL3l7XCAs
61JcWQ6F4xg0VnF4MysO6QXjclqg+zCP0QOLkx7jqJHnuOyJil/lIK1mtmRG
j0P5Lz0RfTl32DHSyL4bzInnIN603vTI7NEph5Pj3TI5monxd3JSg7efsm4F
flNvkA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 318->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRT8uxK1H8Ap6gOAV6gki6Kog1IW48+i24CLz+6bUQBIyM//P
/N8ero/uvpH03I1HV1/nYajvy3Z63Gp/OvZTcv/b0qeMR4l3tgU1yuLtat4Z
lwwb7sJcixyE85gYSxyZZuJALxy3NIu4j/OEeRRx6LHmM7qO1Z5QfC2HzRq0
NRozDvIfPYG+ngs+tP74IozrAO6gqan3nuTZ7Puv4EBfZTnT5Ph/cjhD9n9i
3RcuJG8Q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 319->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDQr9QXxBBTwWhPRRvPt0WRHams0UDSUh2Z7Iz
2eP10d13AMZmXro6tcNQn5f9crjV/nzql+DhM4FXmZfCezZhcpDdxxHOGRcE
S3vxXJscDqd3yLHKkWkmDqy5vl4obqsW+HeUh+oB46zH4JjTqFqzHrB9YDhc
T2mtpC1ozDic/9YTg9MY3UV/dDiM6jDcpCnk65vOs9X//8BhfYXERJPi/4nZ
GrL+tHlvQ7VvEA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 320->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDgl+oL4igp4LQHsRbn24LErKTmaKBJGx2ZzKz
7PH27B87AFO3HH1+XcYxv6/7Nbjn4Xwa1uThu4E5LUeKt9sQNXDv9apixwXC
hjtprk0OheM3eCxzOM+BAy1X6QXjtrRA/8M8QQ8iTvYYMac8slc3A3IOBIea
KdYavFUeHYfqv+sJ47gWVF9iXgrDPgR34w2txmaOjM9fOIIesWbWJPD/5KQG
NXecL3UfjcluUw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 321->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUl0KwjAYCz6Irx7BK+gBhleYJ5igTwNhPohvO7obyGjSxJ9CW9qvyZJv
2Z1v7XUF4L6ZlrZ7HIehe57W8+HS9Yd9Pxe37wmMzbQ0vKcJ8wbpvhzFOXFB
sLQLnngTh+Dg7pCxypE8EwdqrkWv4j5pgf+O8pAeMM72GFxzHtVryoDNgeFw
mVKt5K3wqP2w/wfB6zdc4IJo1L4TRn0Y7sobao1VjkLOfuEgPWaMqsng/6lZ
DS53Wl/evQDmhG8U
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 322->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDil+oL4hgT4VCPYi3PN0GNHQnM2IgCcnuzM4s
e7zNw7gD8OjWY0jPy7Kk13VfHvc0nU9TCR4+G8j9evTxdrvEv5jwJ7Bhbd6M
y6J21YVYd/tfeR0H4aD+4LHM4TwHDrRcVa/idVrwI8/0LvTH9RgxpjyyVzkD
yqPhUDPFWoM36pXSBFXT9MTiDBdII/c9YNiH4G68odXYzJGbkz84gh6xMmsy
ea4ux6QGNXccr3lvQd1vFg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 323->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDil+oL4igp4LQHsRbnm4DWrKTGWogabO7szuz
2ePtOTx2AOZuOYb0ukxTel/35XJP4/k0Fufhu4HcL0cfv24X/w8TbAIbVnVn
XBa1V16IdWu7qsv/NQ7KhrYm92NLs8ohe6HybnCRcU4rIk72WOC5j6xVzoDS
KN7NzRRzrbVxrxQnqJqmJxZncoE4Bm6MYR0id6MNLcdmjtyc/JEj8BErMycT
5+qyT3JQc8f+Ne4DWHJv1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 324->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPyQ/noEr6AHKL1CPUEE/SoU2o/in0e3FS3dyUzowiZkd2ey
r/O9b58HAGM1H22ammFIr9txeTxSd710i/P0U+Bdz0cdb6d/CbaNqtivCCxj
QNhwE37lLHEQDsoGj2UOV3PgQM7F+Sp8lgsKca5WRJzsscBzH7nWbAfcvGlu
pZ3iXLe1ca9UTlB/mp5YHNu4vywFTDYrMReeUfDzHrk92cER8hHCtbo49y/7
ZA5q79i/xn0AsGlvFg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 325->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/QL9gHFL/QviCCPQWEehBvPt0WWslOZqQLSUg2s7M7
u83t0Y8HAM/TvPXpdZ2m9B6Oy+WecnvJi/O8LuDTzVsXT7c2q94ENpjAMgaE
DSfhS06XMwgH9QbDL2LI2ORjPZ1GLheIOP/qCPkg4qTGiD7mKLntDBjdSy0U
j5ujqjbSSuUExWk0sTh+Ez3g3jhM1SvRF+5R8PMcuTnZESPkI4xrdf8cL/tk
Dmru2P/79wWdTG5X
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 326->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF+wDil9oXxDBngpCPYi3PL2t9LA7zhQMJCHZzM7s
ZC/3ZzccALxOy9KV922ayqc/rodHGZvruAbP2wRquyxt3t38DnMn7xHi26iB
K2JA2LQTPnI6zSAc1B0Mv8ghc1OM/XQeOS0QefbqSHqQcdJj5BhzRG7XD873
6IXiUb3B2hGwqh/k/8DUKv5D+k+afs7kexUYmzPWR++riNn++yNH0iMG1+re
OV6OSQ2q7yJ3ejcDOktt1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 327->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEOwjAMszigXXkCX4AHTHxhvKBIcJqEtB0Qtz6dDU2ocWwqtVWTOnGc
HG/P4bEDMHfLMZTXZZrK+7pfH/cynk/j6jxsG6j9cvTxdvu7jE3a0fi3VZtc
LQaEDTfh25yOMwgHZUPOyXqAfMHOOORalEaOC0Scf3UEPog4qTGij3M4HVzt
yQ6fR80Gc0eDhYgr+wNTq+iH1J84pTfpXgXGzWToHf2vwsd1pP6rmTPx02wx
V4rn6uXYikf6p+YOpNPv3wfbv2yW
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 328->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwkAMfbgQtx7BK+gBileoJxhBVwWhLsRdj24LKuZ9HJhOJ8lLXt5k
d7711xWA+2b+9O1xHMf2PK2Xy6UNh/2wOLfvDUzd/OnqmfZnic1gyzJYxoCw
5ST8b83EGYSDs0Frsh4gX7EzDtqL0yhxgcnzr4/CBxVnNUb1cY2kQ+pd7Mh1
0hxJb04ro7/UDJpwPMeCOMmddHeYNJPl7Sh+Mj7HTXKYN3L5ZbaYK+Wz/bp/
w0M4uLkD6fSNewF19WyY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 329->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDxIrz7BL+gDil+oL4hgT4VCPYi3Pt0GatlMZmogKdnsTndm
9vwYu/4A4NUsR5fet2lKn/sxX55puF6G/HhaNzC3y9GWX7fz+69mi2GNc25c
4V5gEXasZexYX8T3eo19qBg0dwgMiU1vrKfT6G8v2Mkz2hX6OI0FX8Zzniju
bjacrq6PgpvSSuhf/dNo4rhWOggP2BtXwx6r+WGPZvHGPCr/1cwxvtI1LObq
8qQvos71UM0dSKct7wssLWxT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 330->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwjAQXPwQfz2CV9ADFK9QTxBBvwpC+1H869FtoJbd2ZkEkpDdnX3M
5PL89O+DmU2n9ejLfB/H8n0c6+NVhtt1qM7zts2Wbj26eKtd/X/MbrPNjrF+
uXfIBbk9FnN7fLC3evV9MJuJ+iQHzQ0+5FNxpHoxkqc1B+qC9VOcRR/WUDyo
2dXfULyqPsJsjCvCf6opOFGzJh6IBqiNwqDG7P+gRgvx4RwJy/4ciUm8uoWz
qjiqC8G1+gx6G/C0x/0AyuxtFA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 331->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkKwkAQLDyIV5/gF/QBwS/EF4ygp4CQHIK3PN0MxDBTXTUDs/VaXd2X
56d/HwBMp/Xo03wfx/R9HPPnlYbbdcjK87aBpVuPrr7dzvq/zy7DJmfbchX/
xeQC+XLs0r+St7CWOJTM4IGIIWOTjvl0HDksEHFadXBfOH+wQ63jHI4HV7ub
DccrzwZj39+MT/AfchpOXK2BB9ED7o3zcTMpe4yI0dXBejlzwibwSrm5JrlU
X4RfC6fsd7D7AQisbRY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 332->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKgzAQHVyI2x6hV7AHEK9gTxBBV0JBF9KdR9eALZOX9zKQhMz3zZt5
jp9hrsxsa65rCHu/ruH7ruNnCsurXaLxcR+zo7uuLn3VifZfzF9ntx59vbj/
IWoZy+ly+/hEX8LqcTCdwGMkB80NNuSzxBHDgnOgmEnfGT8QjzhUDcWD6l3t
huIVdwOx48zlzhH+FSeST+QBZ4BSiMEZs/3xks1N9IF2unPEJ+MVaiNWKqRm
YkPMJIbOO/M7AaeGbVM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 333->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbn24LtWQnMy3stk0yyWSS
0/3VPXcA3ofp6urnOgz1e9vPP4/aX8797DwuBxjLdJX2HQ/o+49ZbVjsjIuP
wKZ4lZOwK99oF5zHknFQNsMHIofMbXqSWigthU6yfowVfSd9CM88XA23A673
ZA/zcXOOu8HcuUe7c0J/p8mWno2PZ8DPBmYrd5oxMkfXB/vdznFM0pVqN7lM
nKrZ+JizwMh5p7gfdkRuTw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 334->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAQCx7Eq0/wC/qA4hfqC1bQU0GoB/Hm022hlsxsshZ2285MspnM
Hq6P/r4B8NxNW19e53Es78t2/rmV4XQc5uR+WcCnm7Yuvnkhff8wawxLPOP4
EdiqXnEm7KqX4w0+xkHFjB4IDsltepJeKC+FT/J8ru0MF/uT8FmHO8PdAdd7
Faf5uDnz3cjac48h/8d/52/Lz5DLM8hPA9PirmaM2gfXR/CDNAQOUSPjrJW5
VK/mzJDLmgXG9RnrvvAWbQ4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 335->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbn24LWjKTydKF3XazmUky
yen+7Pqdmb0O89HV93Uc6+e2Xy6POlzOw/J4/G2zqcxHwa/fRv9/DNgEFpbA
Bn/Glohd8/X2Bh9g+e74VJ0T+be4FS5oobQUOsn4SR3cl1UfwnMeWYxsBjb1
22mR6cqzwblzjVtmDniET4pjHbgHvBqYFnfosUUdsjpAD5cDcAgfafe5eq7E
T8WEN85ZYLI60e8Lurduyw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 336->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhQcX4tYjeAU9QPAK9QQR7Kog1IW469FtQUvm5ZvQQtI2eW9+
3pvT/dn1OzN7Heaty+/rOObPbb/8PPJwOQ/L5fG3zKY0b8m/y2Xy/ee4M+C6
B7gVXrmp5q71lueNeI5bYs3Hoz4n4bdiE6/SgrQEnTA/9EG+rPoIX+uIckQz
sMnvQotIV50NrR292qh/pG/Ii3yAGaGaqA/Nix6b6NDow+kB2AiD52WtZawA
RzndndYMHPWbcV+fFG+K
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 337->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgjAQnHAwXHmCX9AHNH4BX1ATPZGYwMFw4+lAoqY7O1slaQvbGXZ2
do+3Z/9oAEzttvX5dRnHPF8P+8c9D+fTsF927wUsaduSPcsFev9wTExwzSO4
Ds/c5LlfvWVcaGZdJZ61RXUuxK/9W/GcF8rLH1ogcqm6nT/EZx1RjmgG/up3
4UXkK88Ga5e9inJxzsDfkBf1QcyI0qTq4Lyqx8YboFqH8UNgI4yMw+PcXNVw
fMeaBYf7rXErI7NwSQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 338->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwzAQEzmUXPuEfqF9QOgX0he40JwCheRQesvTk0CXGVnjxOBdo5E1
Pt2fbVcBGOtlaNPrOgzpfTusm0fqL+d+vTx+OjA1y9D42XbQmjGIzm37YqB5
szz4423sT689F5pZF+OZT71zImyJW8W52eTPOEwL8wfvcFzWn6BeKl7tlZ+b
9TZeRL7y32Dt/MY9f87xBHpkXFQH0ui0qboWPFc1dt6AMCpe+OI4BEaeI8dl
uUs4vmPvRQzXW+NmjX5uiA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 339->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAQG3FAXHkCX4AHVHyhvCBIcKqEVA6IW59OK7F4HDtESiaLZ7Oz
O9/66yoi7pt56cvjOI7leVovh0sZDvthedy+Z8TUzUuXLc6gPWPC3eP4YELH
rfLED4++33rxXtTMdTGe46k+J8K2Yiu/ZCF/FQOGzW/6SLGQH6OX8ldnxedf
vYELxyv/Da6de3T5FP8OY3VzOlCNqTala4Nz1hfxlR64Z3+BrbQH28qtcqV7
h+M35l74sN4a9wKZTG3J
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 340->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbiQbj2CV9ADDF6hnmAEXRWEdiHucnRbKCV5fRkDM5mZvOTl
M+fHu38dAEzdvPX1cxvH+r0fl8uzDtfLsBhP6wKszFuJ2i/QmTHI3r0IjIoT
fAv5rmL8LnLmvBjP8VSdRthWbOUXtOPfxXCS8id1hFi+P8m8lL+6q35m8wbl
YE6nf4py3UT0Kq2XOf/8L9lPNQfKMeSm5troOc/X4404PcfOn+2gmgjT4lZc
4T3DsY17L3yadW64H0o4bUk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 341->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMtHggvozACjBAxAplgiDRVyWk8kD8MjqtVND5cnakJK19ts/n
nO7PYdyZ2euwHEN9X+e5fm779edRp8t5Wp3HbZu1shzF37iNvhljkR2XwKk8
LrZQ7LYa2wVn5qU4/OxRny3Aqdwqzt1Qv8sBK9Nc9eEwqE8wr2gO2VwyXbta
MB/VC78N5s49Ru9L6a8wirvSgTkgR8dNzTXRnOeL+EY1sUYXz34jLQiT1Va1
nD3CsY+1FzFpn3/cF/6pbkc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 342->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDxIrz7BL+gDQr9QXxBBTwWhPRRvebotqGzGmRhI0m5md2cm
OV4fw30HYO7WZchLP035edlvP7c8nk/jdnh4T6CkdUn1HifomzFw8ThS2E0v
cC7lfEbhuODMvBgf405nMThVW+XJOqpGGC3PlY4KE/0x98X6FTfnp7tv1ctp
4bfB3N07aeqA16q4Kx+YQ+RYceM6fzzn+434Qj1jj598Pgd5QZhWb9Wrijsc
n7H3Iqep84t7AUu/boY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 343->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHLoQtz2CV9ADBK/QniCCXRWEuhB3OXpbUHkZZuKDJO3LvM/M
y+n2GKYOwPO4bUN+XZclv8fD/nPP8+U875f9ZwElbVuqz7hA34yB80dL4TS1
wLEU87XCftEz98X46Hc8i8Gp3CpO5lE5grU0VzwqTNTHzIv5q96cnm7eqpbj
wm+De3fvpMkDnqvqXekg67Ipzn805/lGfFXDzLbyxxOkRStW8SA855Y4vmPt
WzxUzh9uBY2mbkU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 344->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRBc/xF+P4BX0AMUr1BNEsF8FoX6Ifz26LQjdvszYQJJ2M5nd
mc3p/my7XUS8DtPSlvd1GMrntp9/HqW/nPv58PibEWMzLc16zzPwTUy4eB7N
siveKg/uROIbGRc1sy7ic9zpHA1OcVf3hK+slbr+1eJ0rDDZH9Mv6le1OT9d
v1Uup4Vvg7VT46Z38Fr1kLUrH2ReDqV5w3P2N+NXOVL+iou+kMO8C5db4ckt
cTyj94bb6VxwX0exbwY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 345->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKAjEQCx7Eq0/wC/qA4hfWF1TQ04KwHsRbn+4uCDtNE2uh7W6bZpLM
4foY7hsAz928DPl1nqb8vmyXn1seT8dxudx/J1DSvKR6jxP0zRi48zjSuive
pg69QeArfC40sy7Gx3Onpxic4mYOlStrZV9OS4NzXDEf0y/2r7S5PF2/Va1u
rqS18oaW/6cPeK9Ku8pB1uWhPHcy5/5GfFUj1G+4OBfmIO292gr/F47vOHvD
7XyuuA8tkm8I
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 346->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKgzAQHHooXn1Cv1AfEPoF+4IU6kkQ9FC85elVaHEzziaBZHWdzM7O
entN/XABsDTb0cfPY57j+rzuL+84dvdx/9j+NpDCdoQ82g16Zgy8vF3hiIr3
j8/u2mj4EueFZtbFeJv39CQHp7iZQ/nKWrkvT8sJ53FZf5x5cf9Km+dndd6i
f9dX0pr1BhT1ef4rjNKufJB1eQmPap7zfC0+q2Hqn7jYF+Yg7bXa8l8q4RRG
ea/uFPo8cF8ylG8K
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 347->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAQE32UfjtCV2gHMF0hmcCB5BUopI/SX0ZvAoHeyTrbYDuxZZ0k
+za8uukE4H3Zhi5/nsuSv/15/xnz/LjP++b16MCatiH52XbQN2MQrduW/jPz
qtp8BoZv5XWh2elCibd7yqfiiDwrDpUray30BVpqPhzG5hPcF/tX2qI8m/ct
/Ie5klbnDajqi/JXGKVd5SDrchMZtTLn+7V4V8PUL7g4F+Yg7a3a8i3VcAqj
sldnVE4F7gdSHm8K
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 348->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksKg0AQRIssgtscIVdIDjDkCnqCCcSVENBFcOfRVQhJd0312DAfZ8ru
6qfX57vtTwCmZpva/HmMY5678/7wysP9NuyXl+8AlrRNya92gPasQXRuI/1X
zqtq/3zB5EdwLjw7Xyj19k71qXJEPascNX3oL/BS68NpLJ/kOUnfgbeI5+H3
DvqXXMmr6w2o+ov4K43yrjjIuhyCkWTOexHMwdYvcjEXzkHej2rLf6mmUxrF
Xr2jOBW6FTOwb8s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 349->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KgzAQhR9dFLceoVeoBwi9gj1BCnUlCLoo7nL0KpQ6eXljAvmdl/n5
kttr6ocLgKXZhj5+HvMc1+d137zj2N3H3dj+OpDCNoR8th20Zg28c9vCMbNf
FfufF4x/OOci5ywvlHprU3UqH+o8OT48vWLJnDzmqo5MI+4r5nxf7RXP6ntX
mKi/wbnzusoukB/xvzhHxUHG5SYYcR0FB343o0/KpvKEmEEsLD8Vm+ugmk51
zj8t2Ks7J3Ueui+8uHAI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 350->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKg0AQC34Ufz1Cr9AeYOkV7Am2UL+Egn4U/zy6CqXOZjK6sO9MdpLZ
6+vTdhWAsV6HNn8fw5Cn52XbvHN/v/XbZfPrwJzWIZWz7aA1YxCd25b2mXnV
2/+8YPgRnIuci7zg8fZO6VQc6nwOOCK88pJ9Up4XfkZcIl55zvFqr/w8rfeJ
J+pvcO68Zl6pAxoX1VP5IN/lJjxiHc4HrpvBu5oCnt/qizjYP/U26yBNh7jg
nzrvVcyBzh23AIflcYg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 351->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMPPoo/XaErtAOYLJCMoEL7StQSB4hv4yeBAqRzifHYFuWpbPu
rMf7134vAMbbtrR5aoYhz911P3xy/3r2++X9P4ElbUvyu50gm2MQ+e1Ix65w
i3dgMJLJV35Rs6sLZby9i+phDOVfAowoXmnJOinNnZ4RlshXmnO+Ois9T//7
RBPVG1w724wreUDHVbUMeoE58N9IfaGxHTd4m3UI/8/yizBYP/U28yBO1big
TwvtVU6F5xG3Arf0cYg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 352->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPoh/e0RvIIeIHiFeoII+lUQ2g/pX49uC2o3s7Otgbw2u5OZ
SY63Z/uoAAz1PLT5den7PF4Py+aeu/OpWw6bTwemNA+pnG0HrTkHUdy2tM4K
95vP61+twXNxwbngBZ9vzyI+jKHijreIRR45fsYf5ZPSUWCJeuU516u98nP3
vXc8UX9DcbIaGVfqgM7b9PKfe7kJzOjM3QMzw/sQvp/VF2EQd66VOsxaaiVO
6p8671XNhs417w0kD3HH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 353->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbn06rQTUGY/TWnKcOF5m
nJzur+a5A9AfpqXJw7Xr8vu2nw+P3F7O7Xx5/CowpmlJpbUK2nMMIr+VtFhV
9xfP+3+uqef8K1gLDKyI8XAN5Xe4hS+akcNn5qM4KR5FLZEf9hQxtT+w6b1X
ZqL+hsJkOSoOLgcx13CWW/qyiJrRnesDY+HnUH0/mFhRYyTsxTyUUF/JlTCp
fyp7cU6F5xL3ASUMccc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 354->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDyIV5/gF/QBg1+ILxjBnAJCPIi3PN0EBHuqq6INPWv1UjVz
uN67fgPgsZuHrj7P41hfl+2yudXhdByWy/3HganMQ2nn6KA1Y+DOo4W9ypvq
IOQoOb45N/1zHOMR6qxxZxzroHI4/Gp/8DwaPV2uqI95L6eZ01C5fe8fmqi/
oXqKHBWHFAPP1Wr5T102kdPdpToIM7IOEZP6RMCKHBP13uihjOpKrtST+qey
Fses8Pzi3pRwcQg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 355->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+KtT7cFwc1kJgls2iSb2ZnZ
nO7PYdwBeB3Wacjv6zznz22/LR55upyn7fD4C2BJ65TKbwzQP+fA7ccR1gq3
qoOAker7xb7hz/c4H6FOSzvnsQ8Kw+U3+cHrKPx0WNEf0y/nmfNQhe13xxP1
NhSnqFFpqO4gYCrfzF63Lg+B2eNbYQfdVU8Bi7+0MIhD4asaVFdqVZz4TNVi
Lg2d/7wvReRxCA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 356->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEQCx7Eq0/wC/qA4hfWF1RwTwvCehBvPt1dEEzTTOtAu9t2mkky
PVzvw7gB8Ngt05Cf53nOr8t2XdzydDpO6+H+O4B3WqZUfnlA/jUH0T4HrR1u
VQeEker7xX6DN9/TfFCdlnbNUx8cRpTvvOSIPC/8jLDYn6BfzjO3Vh/+6nfH
E/c2HCfW6DRUd0CYzrdgr1tXw2D2+FbYpLvqKRDiOz5V7zXfaRAeoVbHSc9c
LeXS0PnL+wBnpnHJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 357->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVoABIlYoEwQJXpUqlQfix+i0EgLnfE5qKWnj2Gff
OYfrNNw7AI/9sg35eZ7n/Lrs1sMtj6fjuF723wW807Kl8msX6J9jEPmtmbPC
dXVgMJLPL/yVvm0ex8PUqXHnONZBYUTxSktrkeaFnhGW1SeYl8pXZ9Zh07wb
mqi3wXg/HhUOLgclN6db4GvWZROYrX4dtuHtZgrU8akXN3vWQ3FgrIir6onv
VK3ojQnMv+8DhyRxCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 358->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPWB+HYEVoABoq5QJggSvCohlQfqr6PTIqjcsy+xlDRO7Tuf
ndPt2T8aAK/jsvX53Y1jnq6H1bnn4XIe1p/tbwFzWra0/9oFOnMM1L0140e4
jgcGI/n83X2hbpvH8TA8SvscxLHmCKMUL+sTtVhM1sE1bv0R84ryIz/qQ3Xe
Qr+cDTzepqOgQfX/n+f6Ju6qvGwBZq1eh21m5GYKlPGpFjf7qK+BMa/Typwq
JuJSb0xhf88ffTVyCA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 359->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXnmCX9AHbPgCvmBN5ERiggfDjacLRkmZTlmb7EJ325lp
t6fbo+0qAM/jvLX51QxDHq+Hxbnn/nLul8v6u4ApzVvafqMFEYPo3Jrxp4AL
lLtiJJ+/OQ90cx7Hw/Ds1c5xXLPC2IsP9QVaLCbXwRrX/gTvpfKV/88MyDmA
r1/WYmNFP5W+Uv9/eYpL8pd42QRmSa/DZo3QdxKftLi3V30VxryuVqFX8Uuu
aMYi7M//GyxocYg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 360->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwzAMHHoIvfYJ+UL6ANMvpC9wIDkFCumh9OanN4EssjRyKpCNZUkz
I7vuXu1wAfC+zksbP49pit9ntRz6ON6bcbm8rQ6kMC8h3z0HyYEXlybOycGC
qt17BFufxR3e0DwC8QKfTB98zaxHKd/EhNFZFHRojvt8nPdi9ez8zx+g/wBW
P9Uic8k8Gb+z+W91DIviM1zRwxjpecbXaNIcwe9of8XFvD2bKzGNa7QSvgxf
YiWvpqDziP0AwqxySQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 361->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHoQr32CX9AHLH6hfcEK9lQQ6kG87dPbgpZ0MlkN7JakyWQm
2dPt0Q0NgOdxubr8uk5TfveH1bnn8XIe15/t5wAlLVfaf6MDkYMobs34JegF
qt0wkq/fxQPeYB6kE6ZPTTvnsWaFUct3MWNyFoEOh2XnE+xL1Sv/nzcg3wG8
/mg3qv+mo6Ihmv+3zs0tiMm+BsOZwPzF12lijoRdxScubvc8D6WBsZRWwVf1
t71KVKN0Og4zC2ZzRw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 362->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUEKAjEQCx7Eq0/wC/qA4hfWF1TQ04KwHsRbn+4u6NJmklpoS6czySRz
uD6G+wbAczcfQ36dpym/L9vlccvj6Tgun/vvBkqaj9TebkPkwMXrVb2L4QLV
rhgp1jdx0ze4D9KJiqennfNYs8Kw+dCxnjdOB+c0/ph5qfrwhvbh77xpbj1f
Hf+qo6PB+f+rC76ZmOStMMISmKpfyYP2LswhPAn41EuYPfuhNDCW0ir6Vfw1
V3E1Smfo4QNIXXNJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 363->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT7cFKcnsTAxsSja7MzuT
nu7PYdwBeB2Wbcjv6zznz22/Hh55upyn9fL4C6CkZUvt1wVEDSi2fL2qczFc
3LthpNjf5M3c4DlIJyqennauC5oFhvUIOtfzxungmsYf816qP5yhfVDanU//
fHX89l/qzFBzSt9MLgRajLAEJlK8kzxAw1GYQ3gS8GmW8Pbsh9LAWEorcyos
4iquR+kMM3wBHZBziA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 364->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDzIXn2CX9AHFL+wvqCCe1oQ1oN469PdBV2ayaRuIS1tk5lM
kuPt0Q87AM9u3vr8ukxTfl/3y+Wex/NpXD4PXwNKmrdkz8ggfEC2vterupeA
i2NXjOTjzXsjV5MH6UTF09LOfk6zwAhrBP3Wqk2kg31MfYJ+/eKVT82zZQak
RngMVVfZi9YsNXLgmfjHG3LCYrgl+ovk/yQPYDgKc4iaOHzKxfWe66E0MJbS
ypwKi7hKFKN0uhw+FMx1CA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 365->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCPYi3Pt0WtGwmk9iFbNk0mckk
Od4eXb8D8GzmqyuvyziW93W/PO5lOJ+G5efha8DUzldrv5FBxIBs9denek8B
F+euGIRl/EnN4DpIJyqeTDvHOc0CI+wRtC/rTaSDY0x/gnn98lVMzbNlB6RG
eAyFJ2eR7VK2c/DaonmmnLAY7oj5/qvXYNOMspmafMpVOg0GyK90ZFqZU2FF
XJyjdLoaPssrdEk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 366->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe+nR3QaWZTIKBtLRNZjJJ
D9f7MG4APHbLMtTneZ7r67JdD7c6nY7T+rj/ONDKshS7Rw4Rg+i+t+7cAi5Q
7g+DsMx9UjO4DtKJjifTznGsWWGEPYK+y3oT6eAY059gXt98FdPz/PMHpEZ4
DIUnZyE8+yvc015bNM+UExbDmZgvin+TPIDhaMwheuLwydzsuR9KA2Mprcyp
sCIuzlE6XQ1vZNd0Sw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 367->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHHoQr32CX9AHFL9QXxBBTwWhHqS3PL2tqCSzM8XApk2ymdmZ
zeH66O8NgOd+mfr0Oo9jmi67dXFLw+k4rIftJ4DcLVNXf11A5MDtl6NYZ8MF
uvvDIKxqf6NmcB2kEwWP05ZFHmtWmqxHgo+1BS+MDs6p/DGa2APVP9bq3oDU
iIih8GQvRGy9Ffb064274zSHPrDf5HvAoTPJA1QcmTn+6A2P0Hv2Q2mgOqRW
rldhOS7nh8N+/8+W0nTJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 368->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPoo+XaErtAOELJCMoELzStQSB8lP4+eBNqinE5OBLKxLZ10
J18fr7Y/AXhXy9KmTzOOaerO6+GZhvttWB8vXwdyvSz1do8cIgbRvTVzzkEt
UO4fo7QXegb3QTxh6kTcsohjzopTqJGoZ01qEfDgGIvBPBVHpwVpv/cHJEd4
DIUnZyG89FdY0582UU7E2c2B9SbdHQ69yTrApkbmGgdmw+ZmL/6AtD2ujKew
WPsgR/J0Pcxzn3RJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 369->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+ItT7cFLcnsTGhgE5Lszu7M
7un+7IcdgNdh3vr0vk5T+tz2y+WRxst5XD6PPwNyN29dfTqD8IF7L1dxzyYX
KHbFaJ2NmsF1EE8UeRw3rkdxVpy2aFTGt7RxPAJWgcE8FcegheHqZkByRMRQ
eLIXwlqzwvr/tXExjnPoA+tNugcc+pN5gCpH5hwbesO1hN6LGQhx5Ge5ln4m
f6U918B6KMz17QsmNnVH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 370->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKwkAQRAsX4tYjeAU9QPAK8QQj6CogxIW4m6ObgEqnumpIYH6Z/r3q
OVwf/X0D4Lmbpr68zuNY3pftfLiV4XQc5sv9dwC1m6ZuuboBYQP3P37hXE0u
kO8/Rmtt1AyugzgR8jg2rkcxK6Y1GkX/ljaOI8UKMZhTMSYtDKt7A5IROYaK
J3shRuutsP4/bZyPY059YL1J9xQHWNQh77HcV86xojdcS+q9eAPJj+wsa7Qz
+ROz8JGcqYYPsQF1SQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 371->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKg0AMfXRR3PYIvUJ7APEKeoIp1JVQsIvibo6ullYyLx9UyGTGfN9L
ro9X258AvKvlaNOnGcc0def18UzD/TasxstPgFwvR11qT2D4wPsvP/HOTi1Q
7JYj0kHP4D4IJ0SdCFsmP8ZsYdrDkYyPuPFwqFwiB+O0MCouDu6AiVHMjWfp
7RECiXaF+f9z48V4mNUcmG/iXeVBqU07yrua247ZcC8eFxsfFgbqw8VKmKz6
knvJv7Rnzs9+3/sMQuR0xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 372->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADFK9QT7CC/SoI9UP826PbgpbsZBJ0IZt9ZZKZ
7OF674cNgMdunvryPE9TeV22y+ZWxtNxXC73HwNqN09d6yODeIPo3A6zr0Eu
UOyKkfmkZnAdxBMmT8at0jvmrDj9opGNz7SJeDgsg8E8FUenxZ9/QHI0fYv6
rOqILPsrrP9Xm6wXaU60GG5E2qH18h7t2vUt6w3FKp4K38WIOkKuxEnlt9pX
roF1V5jr2RuSEnQI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 373->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADFK9QT7CC/SoI9UP826PbgpTsZBK1kE33NZOZ
7OF674cNgMduHvryPE9TeV22y+RWxtNxXDb3nwBqNw9dm6OAOINo3X5mXgMu
0N0VI8tJzeA6SCcMT6QdVI/SrDB+8cjez7yJdDgsg8E6Vf+cF3++AekX2pz5
qvg5srfC/qsehV6qMP42fpPvDgdtlvto/13fst7QXcsTnXHcrOObVtKk+K33
lWtg3xXmuvYGRU51iA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 374->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFxItx7BK+gBileoJ3iCXRUKdSHu3tFtQUo6mcQ+yAvvk0lm
kvNj7PoDgFczb11536apfO7H5fAsw/UyLI+nnwG1nbd26yOD+IPo3i5zrkEu
UOyKkfmkZnAdxBMmT8QdVI/irDD2aGTjM20iHg7LYDBP1T+nxd4ZgMdVfUt1
hc7Pls0K6696FGqpjHvAK9IOWy/fAZ2D9PyLb7AkhsF3MaION1vqn8Ii7SvX
wLorzPXuC+sddYo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 375->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHLoQtz2CV9ADlF6hnuAJuioIdSHd9ei2ICVvMgl9kJf3nWQm
uTzew6sB8Dmv01C+/TSV+X7aNs8y3q7jdtn+DVi6depqHxnEG0Tndpj9EsQC
/d0xMp/kDM6DeMLEibiD8lGcFcYRjez/TJuIh8MyGMxT1c9pcbQH4HFV3aJ+
sRiMx5b1CuuvahTWUxnXgEekHWov7wEdQ/BP8YX26o2LzTzMWnIlTg6LtRc6
VDkqzP3sBz9NdQo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 376->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhR9diFuP4BX0AMUr1BOMoKtCoS7EXY/eFqRkkvdiB+Y/+ZKX
mfNj6F4NgPdxGbryuY1j+d4P6+ZZ+uulXy9Pvw5M7TK09aw6iA3UuW1mP4lY
cL4bI5tF7EoTavsq5yQfz1CaGWNPjTxDcZSOwDIM5h94Ire/fwCRy95N/RfL
8DyVR1ZPGzPzUZrlG/imagc3s3uAx0j8KJ/UntmE2F6HWVOtQpPPIcQS/4My
t7MZQ0Z0CA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 377->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAUhAcX0q1H8Ap6gOIV6gki6KogtAtxl6PbgpSXyUw0kIT8vO/N
+znensNjB2DulmVIr8s0pfd1vx7uaTyfxvXx8J1A7pelL3c3If7A3ccRztn4
AtlujNZufBcxofxfaG7oYYaLWTH+yREzHMfFUbECQ9lXPKPtZw+g5qq6uX6J
DOY5Ha18Rp8tGxezrQEPlzuhv3oHtA9hb/mkJbN20QNqcC/JWCNP5KjKPWvg
+inmdvcBQt50CA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 378->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKAjEQRAsX4tYjeAU9QPAK4wkiOKsBYVyIuxzdGRBJqquiDUnIp193
dfpwvQ/jBsBjt0xDfp7nOb8u23Vzy9PpOK2X+88ASlqm1K5uQLyBO6+t2hcT
C+T7ZfRWE7vRhPY9c10+zHCaFeOfGjHDcZyOwKoYyj/wTG4/ewCRq/7N9UvN
YJ7Lo1fPOmbPx2m2f8DmaifyD/eAjiH8LZ+scO6iB5RxL0mtHFNp4X8Ggp5Q
S6UnvQEYynNL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 379->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT7cFCclkJnUhCWl2Z3Zm
e7o/h3EH4HVYtiG+r/McP7f9ennE6XKe1sfjbwEpLFuoT7cgcuC+l1Hck+EC
1WaM3mm4K02o8xnX9cMYTrPC+McjxnA4TkeDhZbfcaqc7PnWP4AWt+wvEZb0
FYLf9LflZ8nZq5GaezPgcN7RTDivqmcOUW/xKXh2jK9q8lvRk9TKnEoLzxlo
9DReKj3hC/yocss=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 380->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEQCx7Eq0/wC/qAxS+sL6igpwVhPYi3Pt1dkGWaJu1AW9qmyWSm
p/trfO4AvA/LNKbPdZ7T97ZfN480Xc7Tenn8DyAPyzSUqxsQGLjzGGGfjRbo
7cbRWo124QklnnldPszhPPOd88Z5MofKpcoZDS7UfXSaCrPVvPcHUPPG/DJx
ybpC6Jv8evWMmq030nOrBxyudtQTxqlQfevyCw4YTE87epJeWZMx4s8UOO4f
8xRnPzy4cs0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 381->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMPPIo/WaErtAOYLpCMoELzStQSB+lP4+eBEqQT6faIBtb0kl3
8uXxGqYOwPu8bUP+3Jclf8fTfnnm+Xadd2f/M6CkbUv1GRlEDKJ3u8y9iFqc
f/Rlc9UZ1K44oY5nXNWPwog4s09hqT4Zg32sC/NwWPB5UU1V49C89QfgcW1/
hbCkrrbXYJZKj3/6RxrKeSpDjeFWpJ3o3/ktBvTcmviEw7OzMbK29bW4ck3F
g+cMOD78NySftALjInHL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 382->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwyAUHLoo3fYIvUJ7AOkV0hNYaFeBQrII3Xn0JlDCOI4qqOjzzec9
L8/P8D4AmE/rMsTlPk3x+zhuh1ccb9dxC57/E0hhXUK+1ybMG9TuedA5GS7N
33VxrtsbmqE69I54at4hepxnjTksp1UxNKZ1UR8FFsq8Gqfj2Gve+wMocVlf
EixbV9YqnlRfr57M2cqxnrUHqgv5va0dvI+kuMjfa99a+A5He8dvLDfHel6V
0/nQPgOFH/0b1k/4ARRIcow=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 383->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfbgQtx7BK+gBgleoJ4hgVwWhLsRdjm4LWqZv3kwDyZDPvM9M
Tvdn1+8AvA7T0tX3dRzr57afN486XM7DfHn8TaCVaSnrGE2IN4jO7TD7FnCB
cheMLCaawTr4zPBE3kF6lGe+i7yxVpv/1+N4Ex8OCz4v4lQcS823/gA8rtXX
CEvW1WolT6xvq56WM8uRnpM+uBHVDtpHY1ys32c9dfkCx/0h7oHyAM8rvTKn
8sF9BkXxN6Sf8gUV3XKO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 384->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfbiQbj2CV9ADBK9QTxDBrgpCuxB3ObotaJm8eZMGkpBk5n1m
cn68+uEAYO6Wpc/v2zTlz/24Hp55vF7G9fH0m0BJy5LqPZoQMYju7TDnEnCB
cjeMCCvgZbwqL3ncSA9jRJ75LfLGWm3+X4+sReDDYRkMEIfqH8dsNd/7A/C4
Vl8hLFlXq5U8sb69elrOVo703OiDG1HtoH0UxkUd3+qpyxc47g9xD5QHeF7p
lTmVD+4zaBd/Q/pJX+uFc08=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 385->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDil+oL4hgTwWhHsRbnm4LWjaTmdrAJiS7OzuT
3ePt0fU7AM9m2rr0uoxjel/38+WehvNpmJ2HrwG5nba2PJ1BxMC9xxXu2dQC
5S4YDsvUZbwiT3BzfBjDaWaf08Z8Y/6Pn/wLo4NjIgbXUP1TPDbNAGrcyC8T
lpqtgitpkvFr/4ka828/lVEfquX+DlpHZlyU8a6nMl/gVDPEPVAaGMtpFXGV
b42n6jf7l7cPxY1xTw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 386->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQHDxIrz7BL+gDil+oL4igp4LQHsRbn24LEjaTmWggDcnuzs7s
bo+35/DYAZi79TOk12Wa0vu63y73NJ5P42Y8fDew9OunL0+3IXzg3uMK98Xk
AsVmDIdl8jJeESe4OT6M4TSz7ac/vwV+shZGB/tEDM6h+id5/DMDxi/WIp9m
tgodpEn6N2Yu5mzFSM2NPlTL1Q5CE/clYkD8I60ZCXEVR64nAh+lgbGcVuFX
2Vo8Vb/Znt8+rGNwzw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 387->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKgzAQHDyUXn1Cv9A+QPyCfUEK7Uko2EPx5tOrUGQzmVEDSUiyO7M7
u7k83t2rAvA5z0uXvu0wpPF+Wg7P1N+u/fJY/ycwNfPS5LubEDZw93GE82S4
QL4rhsMyvIyX+YnYXDyM4XLmt117vgvxSS1MHmwTMZhD1U/GcaQHjF3UYt2d
rtC8Kj7XK6z/loaFloqP6lAMpx1ETlyXiAHxR/b8BU7RG8FGcjNXxDlgV7xt
xcn1Y5zs7gc7OnGQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 388->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKgzAQHDyUXn1Cv1AfIP2CfUEK9SQU7KH0lqdXochmnFGFJCS7Ozs7
u14er66vALzP09alz20c0/d+mi/PNDTXYTbW/wXkdtra8nQLwgfuPX7hnk0u
UOyC4bBMXuZZxAlujg/X4mpm264/vwV+Uovob+qOtlWM00XxODIDxi9qsZyu
PxB5uUdGD6f/loZSy4054Rlx3FT+VY8ZA+If2YsXOJm5Bx+Zm3NFHOWj+LHd
8eT+MU7x9gNpLXHP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 389->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEQCx7Eq0/wC/qAxS+sL6jgnhaE9SDe+nR3QWSaJnUttKXtTJrJ
5HC998MGwGM3L316nqcpvS7b5XBL4+k4Lo/7zwRyNy9dubsJEQN3H0c4Z/MX
KPeL4bDC3uJZ5Alujg/X4mrmt5/xfBf4SS1iPGqcTDhVjtNF8VjjARMXtYg8
ZH8g/hU9anmF9W9pKLVs+IQ9UnEzNcseMwZIB1G/7DnhZOYuPCDHH7XKnDU8
2XeMU9y9AViycRI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 390->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPyQ/noEr6AHKF6hnmAF/SoI7Yf4t0e3BZF0MlNqYDf7SGYz
sznent1jB2Bspqkrr8swlPd1P2/upT+f+vny8B1AbaepXXo3IGLgzqOFfTVv
gXJ/GA4reFknqI7IM5irh7k4znwn44GkU8xnHmoNg1MJJ+WY/5N1bOkBE8ea
u35JeiB71nCt52K801BqyXrQPyRz2kFwEv/C/PjN1XyBU7l20QPS/uAqc7bU
yX3HOIuzDzOLcFU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 391->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDil+oL4igp4LQHsRbnm4LWjbTmVAXkjbZze7M
7B5vz+6xAzA209al12UY0vu6nw/31J9P/ew8fBeQ22lry69bEDFw99HCOZta
oLdLDpfL1F0wgXBEnsEcHubiOLNPxgu88f3PL7UgToo368s1VP8kji0zYOJY
85quBQ/u6YYcSv+ahlJL1oP6sDKnHQQn0RfmxzWr70WezNjFDEj7g+vqn/0O
J88d1y7uPkwDcVM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 392->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkKwzAMHHIoueYJ/UL7gNAvpC9woT0FCsmh5OanJ4HWyOORSQXypm3G
0vnxHl4NgLndliF8btMUlvtpvzzDeL2Mu7H7KhD7benz3VMIH5CmdyvmHp1a
mQ0mh5fLwZMwgXBYnkY8PB62gjMO+BNejv/ZFRbbm8RJ+Fg+WYzTP/bhP6r9
hTsHKPnL/kDUxfEcxf+ZvVpXxfNMiBlhzrInlpPoC/PjmtV4kScydjEDUv7g
WpzZ7uHkuePa2dsKOYBwFA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 393->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbgQtx7BK+gBileoJxjBrgpCXYi7Obot6JC8eXHqQOaX33tJ
Dtd7P2wAPHbz1qfneZrS67JdHrc0no7jotx/BMjdvHX+jATCBiTl3y7zzkEu
p4OJEcUK8DBO5yewRXgibBVnrLAnvOz/1SsstjelLsLG8nE+UV2C/jVnANrO
4WvU1dWDe7oiRlU/c/7MG3DmOeEZYc6yJ5aT6Avzszma/iJOZuxiBuT6g2t1
Z73qKQId68vfG1n8cZI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 394->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPwQfz2CV7AHKF6hPUEE+xUQ6of0L0dvCyq709m2BpKQzD5m
dvdyfzbdAcDrNB1Net/6Pg3tcX48Uq6ueQbPnw2Uejpqf0cbwgbRv13mXYJc
DoOJEcUK8jJP5ye4RXwibqyZMWlPfNn/iysutje2X2xj9TifqC5Ky54ZgLZz
/Dbq6urBPd0RQ9V/rYaylitzwjPCmmVPrCbRF9Znc2z6iziFuYsZkOsPrdJH
8FxwUBjjv78RPEpyUw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 395->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+KtT7cFld3JTLGBJCS7O5md
yeF6b7sNgMduWtryPA9DeV228+FW+tOxn4P7zwTGZlqavLsJkQN3H0c4j+at
FEPAcFjmXcZPdYKb4+O4cc8ck/nEl+u/ccUlehP94pzYT6ox/nEOa7Skhf0H
qPtXeEkP9vQPDKX/koZSS9aDfKiG0i5qHnsSvnB/q+oFTsVD/AE5VvQqawTP
ioOKcfx39wYnl3JV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 396->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPoh/e0RvIIeoHiFeoIV9KsgtB/Svx69rYhsJpO1BvaZZHYy
2ePt2T0qAGO9Tl16XYYhTdfDdrin/nzqN2fzGcDcrlNr12hAxLzvIO5zy85z
8Jbxwa8OK+DD+CZPcIv4RNxyHSB8Mp74cj7rp/b5W1w362tygv5xDGtU0qL0
D1wvf2CYnmIfhtK/pKHUkvWgPjhT2hFfh8k4XNfefIHjeIg/IO2PWmWO4Ok4
KB/7v3cLkklyVw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 397->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhYML6dYjeAU9wOAV6glG0FWhUBfibo5uKy7eZL6oDcxv/l5e
sr+M/W1jZvdu3vr8OE1Tfp63y+Oah+NhWJS7zzIrad5SfUbLwOb9Z/CvIu8S
5Kp01p5NrACPj1/5AbYIT4RNeTDQoT3gVX/PH901l6/b8+tzUP8Qxz8zENhV
+H7wWvGhPYUacFaA/28cIpeeD9eHRog7xas1QV+0zrLWH+I0OGAGUFbUij76
pp6KfzOfVE96AYbqcxY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 398->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhR8uxK1H8Ap6gMEr1BOMoKuCUBfirke3FRfJ5EupgZkhPy/z
8nO4Prr7RtJzN11dfZ2Hob4v21m51f507Gfn/neksUxX8W92BDFfm8Buxehj
8pfzKb4hV8Knze9wYMv4ZNxsHwQ+jAe+Fr/ExcXLY8MMBBjgjLWI/VQbxTh+
4lqwH3amMCvcFej/mnlSL7KdCNLgbczijNscavqwBg95Ag/YAZQ/akWM1Wmm
Bh/2k+opH4q0c1U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 399->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPiPhCeUGQ6KlSpXJA3Pp0WsTBHo8DkZLIy9jj
5Xib+mEH4NGtT1+fl3mur+t+E+51PJ/GzXj4XmAp61P8n10In48OQm+PkZck
l7Mh/iFWwofjO5zQZXwybtwvtkl/wRcG3+KicnHd3F/O4fK1+vTPDkD7OH7Q
tch+2JmKWcldof4pXhnHgE/mEA7hrU9zxhwDupdNvIgjZ2f5qBo41o9aJcbK
aqYGH/ZT1VPe7xF0FA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 400->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKwkAMhoML6dYjeAU9QPEK9QQj2FVBaBfirke39QF5fBkamE4nzz/5
c7w9un4nIlOzfLryvIxjeV336+NehvNpWI2H31mk/Z5Z3dkR8PnoBPRa1HtO
ahmbxDvkSvD4/CYOdBmeDJvJDTb0B7yi4mtYqJbv28/X1zD1anPasgOJn8En
3AvOQ3MKXOGuQD9b+KRZZDwEcfHap8qxzyFxDuHfx0Me5E7joR58rqxX8EMb
cfq/aT+pn/YNVZ9zlA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 401->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhQcX4tYjeAU9QPEK9QQRdFUQ6kLc9ei2qDB58000ME2TzM97
b2Z3vvXXlZndN/OnL4/jOJbnab0cLmU47IflcfuxeXVvm9yemYGPZfd+ufOU
1DKJ1T3katT2+ao4uMvwKBfMDW/oL3gr3X5goVrKWfXVGs0+AcbmDCR+FT5j
LqiH7yn0KpuVoOefGlI89SEsyuM195ygL56n6hD+NR7yKI6Ahzhorowr+OEb
9fS703wSn+4FCelzkg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 402->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwzAMM/0Y/d0RdoXtAGVX6E6QwfpVGLQfY385elv2wJGltgEnJHFk
RfLp/my7yszGep7a9LoOQ3rfDsvmkfrLuV8uj9+YR/OJ7FYVRnIM4n/uh9tn
UQvf4hqwRF3EK96RM8UnEz4Bm9zRvwHfQrcNLqxW0Br0xRrok9RpTw+IvILf
is9BD+8p0WmtV4KnOzRELVRPhMFwvOaEuyEOaoP1hOcMB3kEPuwPiKX+SvLo
HfP0t7L+pH5P1Ut0kA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 403->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB5Krz7BL9QHlH5BX7CFeloQ7KF48+kqWshOJmkDu8tusslk
Js1z7IZKRN7XbevS5zFNae4v++WVcnvLu7M+12b3Yy3q9JaQGPHetan74tQS
+IunyRXU1vmKf+TNw4O90NzER3sDvAVvP7CwWtgz8os1Qp0IxnAGhMcU+AKd
DR9aU8JTNCtG0z84RC68mTAWzFaoMeQouMF6juYsD+IweFgPmMvrlcRRH9P0
e7L5pHqvwId2EA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 404->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKg0AMDP2Q/vYIvYI9gPQKeoIV7JdQsB+lfx5dpQrZ2ZkYyC77SDKZ
yb1/t6+LmX2u69Km73Oa0q+rtsOQxkc9bo+33Vdr/j67nbk1+d/Te2/uPIta
BrG4F7lEXcyXxZE7hQd7obnJG+2N4DUXH2HBWqxv5BdrnOmHGBUP/h+dD9BN
8Zr14TUN+pP8C1yKQ+RCzURhwWyFGkOOjBusF2lOsBTaeTysB8wl4tk/+sY0
PXY2n1TvBcowdU8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 405->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDD1Ir32CX7APWPoF+4IV7Eko2EPpbZ9eRcFknGQXouxuMpnJ
bDu8+9dFRD7X5dPn72Oe8+/ZrJsxT/duWi9veywrbVHUn4Ukm1s910vti9NL
sDYd+RTL6Yt4po6ceXxQC8Umd4XwEghzVuGCvZhunC/2qPlXANubg86jmpVf
0VyNDu1poM97c8g/7FurF7IP/DEzJ9wFcXA22C/ynHA5eaf5MA06L6hnb9PD
OHkK2FSHwf4DKr91DA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 406->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDV2I2x7BK+gBBq9QTzCCXRWEupDu5uhtUTR585IJpCX/5L05
3Z/D2InI67h9hvy+znNebofdeOTpcp72YP/VTdJHi/ozlWRzm34tyi7OLMHa
9M+nvZy52M/Upbre2wdvob1JTGPCMBL0qf0oFjCL3Y344owWfwV6ezjoPHqz
4ivC1dyhOQ3u894c7h/ObdULsQN+DOZkd8E+iA3Oizgnu1TcIYZEGNfNeucO
gwn4qxjGf74VK0R0jA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 407->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhR8uxK1H8Ap6gMEr1BOMoKuCUBfirke3BdHkzUuYgUxJMvn7
0sP1Mdw3AJ675Rrq6zxN9X3ZrsqtjqfjuDr3XwHmslzFf5XASJfdHqPPQS1w
bPm/l7mCupzPxZU2PurHzYcgt/BZJooR2Gb6kyyolpqb+XKNrv0JJpIH9Bve
V8bVzWF3SvbsX2l4JgwlSxUPoSf7cczFbsB5eC6ul+1c9MKxiiEf7rUrPpjD
MSF742P/z/YBA95zzQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 408->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUVsKwjAQHPoh/vYIXkEPELxCe4II9qsg1A/xL0dvC6LZyexiYBM2+5qZ
Pd0ew9QBeB63a8iv67Lk93jYnXueL+d5D/YfA0rarmRfZXDicGLmVH5xZoFr
0y9f9gowGU5o82vfw2P4wektYkorkBXGAh8Lz1K8WV+eEe4p0ETqAZ3D+4p0
NTzqnVa9ox5Sz0BDqaWqh/CD/RjNxW7AfZgXz4t2TqfBQRxUjcL6V73Dw2hC
/02M49+/FfGJdI4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 409->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbotCE1mJ8FAts1mk0wm
Od2fw7gD8Dosx1Df13mun9t+NR51upyn1Xn8KdDKchT/VYrAj8DnxNgtqAWO
Ldt7mSvB5HqCf99Kb2e9WxxdbuFTXIHU3Rl8kguqpfpmfrlGOieRO9oBy13G
UzZn5t/N1OTOcjg+oXFFGNN5UH0nyW51PYm52D4Vl+5fzZykw0EcqhiF9a/4
oI8QJ++niNvuvonvdI4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 410->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYg3n24LYpPZSWpgt93NZjKZ
5HC9d/0GwGM3bV19nsexvi7b+XCrw+k4zM79dwHvMm3Ff6Ol/DDL3Vsz5wgL
HFuW9xIryMt4Lo7xV2r71YcAW/isJkoj8J3hJ7UI6mjwjb6cI+0T1bE6A9Bv
uF/pzMDnVTpkGE5PaF4Rx7QflN9Z0pOmJtEXW6fS0v0LTmwNDzUjwpjrX/FB
HSFPnk8Rt9x9AD61dU8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 411->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKhDAMDB5kr/sEv+A+oPgFfUEF9yQs6EG87dNVFE2nkzYQta2ZZGZa
9b/2W4jI/NofrV+aafJrVx6LwY+fejwO31fu4c78q7eV7FxciHHv61BrC0uw
1j3/UyyjL+Lpugg/w+3mJwY2OdOaMI0E99h8GR4UX+mLPZI+AY/sHSDaoRYp
nxEj8FTpkMKgehoemb4xfaB/EAlPIk7EF80TdYi+yUwY0RzsjpBgHmbrDR7m
nHg/Sd2ztwHtJXWO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 412->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENgzAMtHhUfBmhK5QBIlagE6RSeUVCggfix+iAWoFzOSeWDCTGF99d
np+xHyoRmevj0fulmya/vh/n4utD+wpnsfnnEe6Xm3pbyeriYoxrX4daW1iC
ve7+n2IZ5yKe7kvwC9wufmJgk5rWhGkkuMfmK/Cg+EpfPCPrE/Ao3gGiHWqR
8xkxIk+VDjlvqJ6GR5ZvVB+J8aLIeJJwIr5onqhD8k1mwkjmYHeEBPOw2G/w
MOdE/0jfvbcDKpp2TQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 413->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT9diNsewSvoAYJXqCeIYFcFoS7EXY/eFqWd/PxJDKQlmcyb
zP853Z9d3wB4HZdPF9/XcYyf22FdPOJwOQ9rsP3NZYTvnMzfmyqOkDK2fTvM
2mOBc8N+XrKcusyzeRm/0tvWHxy2iFlNlEbgPXW/Sh+Sb/TlGkWfqI9/3oDL
MX4V3wzSukqHkjdST8cj1zelD1JeMir+K2/AHNaG6zn8jMO9gs6q2ibPnsvy
LQMiRrXkPdk/kbfvzdYTdwo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 414->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXnmCX9AHbPwCvmBN5ERiggfjjacD0UCZThebFNgtnc60
Pd2fTVsBeB2nR5Pf177Pn9thPjxydzl3c7D++WTp64N5R67iSFuM5d6aOUdY
4Ny0/i+xgrqMZ/Mc/o62RR9izRyzcVUPjKH47ehQ3G1/uUZxTqTjnx0Iccy8
ijujZkl9KM0Ggkdpn1wvg/xNfbYIx2gOMUkv74X7FpzYXD8FB2XM1eVbDIgY
1ZI8eX4ib70bAVkidks=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 415->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMbDgYrzzBL+gDNn4BX7AmciIxwYPxxtOBaKBMZxabFNgtnc60
Pd2fTVuZ2es4PZr8vvZ9/twO8+GRu8u5m4P1zydLXx/cWzmLW9piLPfe3Flh
Geam9X+KJeoins8L+DvaFn2mNWOMaiN8fX7gt6ODcff9xRrFOYGOf3ZA4rh5
FXeGzRL6UJqNER6lfQq9FPmb+mgKx2mWmKAX9yJ8E05odL+AAzPsf8g3clYx
xRPnR/LWuxGxp3ZN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 416->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsSbT7dFqdnJJDWQtrtpJjNJ
dudbd10BuG/GR1cfx2Goz9N6Olxqf9j3U3D79dHKx1/mHbmKo7QY8701c46w
wLnl97/ECuoyns1z+AvaZn2INXNMahN8bb7jt6BDcbf95RrpnEjHPzsQ4ph5
pTujZkl9yGYDwSPbJ9fLIL+pzxbhGM0hJunlvXDfghOb3C/DQWqA77/Lhzgn
McmT58d5zd0b9ax2jg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 417->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKgzAQHDwUr31Cv9A+QPyCfUEK9SQU7KF469NVWmEzO5sEokk2Ozsz
2cvjNYwNgHe7fYb06ec5LffTvnmm6Xad9uD5P7fR/ebX/KOp4oxx3MMRQ76O
sKAwYfaMZeqUuNq8GudQNzy21VjzSfFVHkkvhA7pt/GXazBnqQVx7Ui7Ozfv
Ve0ZfkvyocQDgkepn5yXQX5Wn0eEYzSHmKSX+8KtBScesr8MB6kB3n+XD7Ev
xCRPfj/Oy85WVrV2Dg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 418->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDH5Ifz2CV9ADFK9QT7CC/SoI7Yf4t0e3BYVJMrNdyL7STGZm
e368hvFgZku3TkN53+a5fO7H7fAs0/UybcnTL8xqv069X1WwvEGku/+AvcJy
9VBTEQexSF/KC+oS/o42/F5pjjmqjfBt8iN7p5/5Df7GHuqdIg/Ve++9a8Ro
vHPSgiv40OJhhIf6n6iXot71j0PhgGaJGfTKfgI/4RjxM3CgGgjXVG/k3MhR
ntH3WOfuvpxrdYw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 419->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAQG/wQfz2CV9ADFK9QT7CC/SoI9UP826PbgkImTboL++jOTibJ
9HR/9sMuIl6HeenL+zpN5XPbLx+PMl7O4xI8/mZE7ealy7ubKh4wV3f/AWeH
lfIhpyIOYom6khfkrfAb2vC908wxqS1yXpOfOCf9ym/wl2u4PjEPV7vV78oY
G31eacEdfNjiEYKH+5+klyY/1efhcECzxSS9smdCu/QHcpKfxEFqEFzdO+6J
i0me7DvnpbsvzHR1jg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 420->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKg0AQG/wo/nqEXqE9gPQK9gRbaL+Egn4U/zy6Ci1ks4nShdnnTGaS
2fPj3b2qiBjrderS5zYMabqftsMz9ddLvz02X4uY23Vq89WZeg+y7O43YO+w
8IwxM+IgFuW0dUFcgX/ADf0t59C5VTxrZesT+4y/8EF9uQ+c2+nkcjvuxX3k
fN3fkr0kHfbqkDoe9EDpUuiD+Xk4HOBsMYmv7NlevKiH/1cQhuQgcjk/7ol8
c3X+1e8FpyRzzQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 421->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwyhiMIDExmUWMh9ZTwMus9DsxOkuJH0Y5hPwG7J6Qn7GF04o/kDH
2NyHhY3ifzxhjR6fGOrwhBOxaQCnOQyo/sWVtrDGJVo44IsbrOGIQw22eMGm
D9ktKG7EEz/ofsZpJpp/MeQI6cfiHvT0hW4GVj9gcSsudVjdh8W9GO7EEvbY
9CHEAPOVc4o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 422->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQXDwUrz7BL7QPKH6hfUEEewoI9SDe+nRbqLg7mYkGkqbZzGRm
d8/X+zAdzOxxXJchPS/znF5js/3cUu7avAVP+zRb+nXp41dNFjc3i7PPcHvF
FfAOsygu8i7V5XAF/w9v/r7yrHLC8IiT+sg++IeaYX4xpuqE+H97QPJY9Kt6
i9YS8lCrDc2juMPqwnBeS9BYqQ96lpzgt4jh20QTDuwv5KAeiFZ1j+qr6PWc
mHuG+569Ad7CdQo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 423->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHDyUXn2CX2gfIP2CfUEEexIK9lC8+fQqWLqZzEgDm8RsZpzZ
TdM/u0cF4HVepy69b9OU5vtp+xjSeL2MW7LeA1jadWrz1YXKI0Rx9h1h77gy
PGhVXOK/UlfARX6l2fqG9+xqovCMs/rEPvNPPeP6cs71ifH/vgHLQ31zb0v2
kupw1BtVf3dH9cXhM908HE/w7DjZb5ELeMVf8IB8CQ7pQWh196S+A72Rk2uv
cL+zD2v+doo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 424->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMi/hA/HIErgAHmLjCOEGR2NckpPGB+OPobBIP13UsKqVrm8Sz
k+zO135YRcRtM299uR+nqTxO6+VyKeNhPy7O7dsint28dfU3M+UPsOb9s+Cc
YeH9yysMVvLfhhfkIT7nOu3ImzVnNVH5GG/5iXOl3+BwP5s4U6d/Z8D1m+ul
Zkv2kurgeqPqn8WovmT5FW9eGQ5oRj3oZ72NT+RVMYIPzxdjSA3M1cRJfoYv
YnLtVd7v7QW/HHdL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 425->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfXQhbj1Cr6AHKF6hnmAEXRWEuhB3PXpbsJpJ3gsGMp18+5I3
7fXR3xsAz/1y9OV1HsfyvuxW41aG03FYg4ePAlO3HF39VcriMBr8m5i76mXt
Ly4kvcR/Ay5TZ/sHXzY39MxqJ6ze5qf4yL2aP+nj+Qx5yZ7+egNI+jje1Nui
XLo9ZNyw/ascxouqr3B7UX3g9oIY9/P62ETqqhyCh3LicRJhHFJhPHmb4SS7
Z3U/3wzNZ3dN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 426->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHLoQtx7BK+gBileoJ3iCXRWEupDuPHpb8DOdTqKBvDZ5ZDLJ
vP3l1rQVgPt2OpryOPV9Gc6bObiW7njo5svdy4FnPR318hu5uwf5Kv82+o+w
OP7wQoIlfW1/qWP8VS6ZmXnrzNFOXKx8Q36uludPcH72S/b01xtAjsO6RW/L
ail7yLRx+1dOEce0nvurRTiQvcgMOhvv2dU7fBg+VhPlacxpaM3ppLHj6bQw
dd/cCIHCdkk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 427->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfbgQtx7BK+gBgleoJ4hgVwWhLsSdR7cFldeXNyMOJO0kzMz7
ZHe+dv0KwG0zbV29H8exPk7rObnU4bAf5svtewHPMm1l+Y2Wuwet5vwT9B/1
4vyLC0kvmWvnSx33b84SzoxbOUeauFznhfhcLfOXnqqv3v30qbS14RtA3od9
C7k7L0WHzBunv2KKMKb1PF8j6gPRRTgoN9Z54ZnhbvWhmsYTxWnCeWjD+aR5
hPMvv1++h3ZL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 428->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHHoQr32CX9AHLH6hvmAFPRUK9SDefLotKCSTyUoD2W02ZJLJ
9HCdhnsH4LFfjqE+z/NcX5fdGtzqeDqOa7L/OvAuy1H8nbnKw3h4/5n5zrBc
DnQrLOor+1OdxQ9vDc52Nuac7UTF3C+dT9Va/oTJ++XcX51KrE3/AbRxgpaK
k9KS9tDSxu0fsX/GQ+3Cvdn+bBkOaC/Egbm5eRHrFT7EPFITnlOY0lCa0onj
bM5Nen8AKMF2TQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 429->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKgzAQHDwUr31Cv9A+IPgF+4IU6kkQ7KF469NVaGEzOxtpYJO4605m
Mrk8pn5oALzaberzu5vnvNxP+8czj7fruBfP3wA+aZtSuUah6jDh8r9h9hFW
UQOtCsusEk/0WXyXq2i23Fgz1yIunK/yU71WP2Hy/XLt0Kfke8M3gDqO81Jp
irwM/Aw58xs58FPdRZGz5/OIcED3QhpYW8EXvl/hQ/CRnjBPNZT26D+1F2c5
nn/5vQJH3HWO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 430->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbgQtx7BK+gBBq9QTzCCXRWEuhB3PbotWMi8vKQYmF8+Ly/J
nO7Prt8BeB3mravv6zjWz22/PB51uJyHxXj8LWAq81baM1qrf6Mzy+lXMfcp
yNXYQKfCMqfkKuIsvtNlOIhrlj0R/pwj5adibf2Eyf1l2+acio/N/kCG42ap
aopmicA/+XOW99Y8VS8anc3PEuGA+kI1cG0NX/h4hQ/BR86EeSpRtUd+6i5y
OZ5/zfsLS951kA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 431->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKAjEMHPyQ/fUIXkEPULzCeoIK+rUg7H6Ifz26u2AhnUwqBvpK2ulk
kuPtOT52AJZhncb8usxzfl/32+Gep/Np2oKH7wBKWqfUrtGo9xufGc5fzexL
8FcTA60Ky6ySq3hn8Z2vh4M4Z6mJuM9/OH6BNkieMwiT9eXYzzol/7bXAz0c
V0uVU1RLBPc7PRfxVnkoLRjL6U28HA5IF8qBc7N8qxXxrhAnNlkT5qlM9ILC
V7zdOeL5V70/y0t1kA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 432->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAUCy7ErUfwCnqAwSvUE1TQVUGoC3HXo9uChTd5yYgP3vwnk5fM
4fro7hsAz93cdP3rPI79+7JdJrd+OB2HZXP/TWAqc1Pq3uV6vloLmdbXCOPJ
vFXtgXqFFXrJVdyL+GmthQNfs9REnOc3Ej+jDUrmDMJkfXnvp08l3239gRZO
8lLV5LyEOd/4c463qkNp4f5JCocD0oVqYI8j32ouapf6hDvJE+apQnio8FkT
hyF5/uX3BwemdNM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 433->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDgl+oL4igp4LQHsRbn24LFpLZmYiBzbbZ3clk
Z4+3Z//YAZi6Zevz6zKO+X3drz/3PJxPwxo8fA2Y07Kl2jvb8quzwsL5torv
2dxVxUBeYRVechV1JX44a+HAv1lxUPl8R+BneoMUOYMwub8c+6mT6HlrBlo4
QUv1JqclTH5j5lp8lJah3sxJWA4H1Bd6A2vMtVyv8AMGjCbMUy3RM4cfagSG
5PmX3h9n2XRT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 434->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAQC35Ifz2CV9ADLF6hnmAF+1Uo1A/xr0e3BQszmUyLA/veyWaS
PT+GtjsAeDVz19b3bRzr535cFs/aXy/9cnj6NWAqc1f8mLX1vtszLeyvYeZT
8pY7A40KK3k38DJ5Fj/sbeEgr5lxlE5K38Av0QYlcgZhsr58tusTvbP3B5RW
GYasXXlJnmx5o/RXdxTHkJ/8kxAZDrwuXAN7bD1ya1G71MfksCeBpwqhWcqR
cwSG5PmX31/TCnUS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 435->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUcEJwzAMPPIo/WaErtAOYLpCMoELzStQSB+lP4+eBBqQTydDDbItyT5J
d5fHa5g6AO/ztg35c1+W/B1Pu/PM8+0678n+Z0BJ25bqM7LjfRUz5uLHMvcS
1KpyoFNhBXVdX+afxXexFg7imRlH8aT4df0F3CD5nkGYzC/nlE5hHJqDirsG
307LCIO1JE1a2ij+1ZtoDijj+rwamlheeAY1Y0nCF7NLfswf1sT1qZbgLMJ3
f4Qv+/xL7xVDHXPT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 436->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwzAMEzuMXveEfWF7QNgXuhdksJ0KhfZQduvT18IKjizb4LRxElmR
cn2N/ecEYO62oa/LY5rq93neJ+863G/Dvnj5J7CWbSjtN8pjf1Mz6epHmP81
6AXRx/JzWEFfx8ucs/iuluEgvjPjKJ2Uvo5foA2K5wzCZH15TfkU1qE1aLRL
9GYMuVd5SZ5k3ij9s/ekfHDJ/TkST6wufAd1R15jXZvzrI/BYE8cTxVCswjf
nRHziIPkIf3+Aam9dVE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 437->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwjAQHDyIV5/gF/QBwS/UF0TQU0FoD8Vbnm4LFnZnZxPYpNlkZycz
vTw/w/sAYD6t01CX+zTV7+O4bV51vF3H7fD8D6CVdSp+zWK/73ImQn4f5rsl
vSD6WH4BK+kbeJk6ix9yPRzkb2YcpZPSN/BLtEGJnEGYrC+fKZ/SPLQGTruO
3owh7yovzZpp0NO/9z8pH0IYTo4j5ZUnVheHwRzJI/deqmtJrcVgTwJPNYRm
GX6oEfuMg+Sh3lN+qrl1UQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 438->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRYMLcesRvIIeYPAK9QQV7Kog1IW4m6PbgoU/yUsNZKaTZn5+
fuZ0f3bDzsxeh3np+vd1mvrPbb8cHv14OY/Lz+PPzWqZl9Luma/5TUw8xFeT
75rUMqij/AJWUjfwknuKH2JbOJb37HFIJ9I38ANttL+mf8hRDLwPZ4wba9Bo
t6G3x8BcmqXspNU//bfeU6ZrwJHeghGOau76qB7XXL57W+lsFNdh+JkEnmSg
GfKkOcE544A8qJ/yBbOcdBI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 439->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfErU9nQ4A8xymR0jZt6iZ2
d+dbf10BuG+moS+P4ziW52k9B5cyHPbDfLj9OFC7aeiWc+buHORh/2u0zrA4
/tWFBlbybqiL7jF+2GvhIO9ZcWqSH3ps1Sc5WjNMDvNr75vY7sNzoHVnfCuG
zXVa0uze/Md/6z9lvAYc0iGYw2HOpY+quJB8+VupNowrGAs+jTbWDGe2TqcT
x6pzgt3U+71+AVBsdU0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 440->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADlF6hPcEK+lUQ6of0b4/eVizMJpNVF/aVTSbJ
zJ6uj+6+A/A8LEuXXu04pqnfr5dbGi7nYX08fiaQm2Vpyj2am39ho+ns26Bz
DnJB5OH6HFaQ19VFcYzvbH/0DYv/g7/rsVaf8bE1Q/gwvzJe3KUdon9Rd8S3
xZC+SkvaVc5v/Nf+U8SrwyEd3FA4zLnpI1tcGH96V1oV8QLH8Sm0kUNwJutU
OvHd6hxgV/V+n2fwgXWO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 441->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENgzAMtPpA/XaErkAHQKwAEwQJXkiV6AP1x+gFVJBzPgew5MRJnLNz
l2fzrrqbiHzu81CFsRyG8K2zZdGG/pX3y+Hj7yJTMQ9FPHu+5Ud7ys3+Ziqe
nFpC6uj+DJZT1/Sl7ml8s3fh3YL4J/LNG1P9sbv6/YCJ/OJZxCHpSaAO4xL7
9vhGDJrLtFSzx4HH/9F/YjoYBx2MJTTZY8IxM9SNaYWaMYyIT6INNch3+2Q6
6TXq7GAn9V7jH5/0dk8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 442->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbn24rVpLJZIuB7CbbMJlk
erje224D4LGbjrY8z8NQXpftnNxKfzr288f914GxmY7G35kv9e7NeHhfzMRj
0guij+WnsFTfwMvUWvzw9sfcYPy1eogZa/xEzDMjwWE9XQyfK/2Ye8Y72zdj
yFrWku5af7X/tf8p7FI56RCsoskvFjtWxroprVgzheH2KbSRRvUpT6WTzVnn
BLuq9yd+A+JLdlE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 443->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfXQhbnsEr6AHKL1CPcEIdlUQ6kK669FtxUo+LykGMpOZCS8v
eXO6Pbq+AvA8LktXXu04lul6WA/3MlzOw/pYfx2Ym2Vp9B75lq/uhLv7zUQ8
B7VA6kh+DIvVdbxErsR3d3/0DYu/lw/SY8aPxLZnBDhWTxVDn5l+lnvEm84b
HoPmWi3NntVn89/7T26WzKFrO0s0+cVkxsysbkwrqxnDUFzJX6Qm8zOeTCd5
tjoH2Knen/gN47V2Uw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 444->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkUEKwkAMRT8upFuP4BX0AMUr1BOMYFcFoS7EXY9uKxYyPz+RBjKTmaY/
mbzj7dH1OwDPZl668rqMY3lf98vhXobzaVg+Hn4OTO28tPUe+Zpf3Rl396uZ
eApqQdSxu9JSdV1fJtfqu7sN7wbr/8uHeGPWn4j5zQh0mGcVoz4rfty7YqNm
BfOv1ZC5zJL2rL6af8Qo0oFy1BrOEiZ2LjxjZcxNsWJmSoOZuD6V2fysT8XJ
nplzoJ3y/sYf8b51lg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 445->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUsKwkAMfbgQtx7BK+gBileoJxhBVwWhLsTdHN1WLCRvXlIDmXwmvHze
4fro7xsAz9309OV1Hsfyvmzn4FaG03GYP/c/BWo3PZ23kS71Lme0yS9i/Br0
guhjrcJSfZu5TK3FV7l/9wbjr9VD7JjNJ3zeGQEO8+l8+Fjxl92hEobimzFk
rd1FWIWd3T/iKMKBUniMRhJO7F34xkqYN8UVc6YwmJPVHWjGdE7Fk42Z5wA7
5fvrfwAad3WY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 446->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBileoJxjBrgpCXYi7ObotWMm8vEQDmUky4eXz
5nC998MGwGM3H315nqepvC7bxbmV8XQcl8f9R4HazUfX3pGu+U3MqIuvYuwa
1IKoY/tTWKqu68vkWnwV+3duMP6vfIgZs/6EzTMjwGE+Gxutr/jL9lAJQ/HN
GDLXziJuhZ3tP+IowoFStBhOIk7I5h0r4Z0pTt17gOFqZzNQj2mfiifr07/m
OcD9ce1v7A1P93XV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 447->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbgQtx7BK+gBileoJxjBrgpCXYi7Obot2JJ5eYmBzGSS9L18
ero/+2EH4HWYj768r9NUPrf98niU8XIel+Dxp0Dt5qNr70jX/MZn1PlXMXYN
uCB4bH0KS/G6ukyuxedeVG9RDIz/Lx+ix6w+YVsusJ964hh/r3K2dzKHShhq
34whc3mXdCvsbP7RjiIcKEWL4UThwNs8YyU8s3Q3Ni4wHHfWA3GldWb8PHvx
b4LrY+7N9wWiEHaU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 448->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHoQr31Cv6APEL9gX7CFeloo6EF68+lVqCU7TkIXsq5JnMnM
enu8hvECYK63bUhLP03pfa/2l2fKbZP34vUbwNptW1c+vTj6ixxFkT+WOa8O
FwSPnU9hMaecy/RafNaitHk1MH6ghXX8NZ84Wy5wnjRxjb9XPex55IXy3MOQ
veoujTaFHfnv3ZGHAxUoMU5L4eB8Zo/VYs/Cu1E+sVbqcTUQVzhnxM/ei38T
PB9z/3IfsEp2FA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 449->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKg0AMHHoovfYJfqE+QPoFfcEKehIK9lB68+lVUMnOTkIXshuTOMlM
qv7VjhcA79t6tenznOf07a7bx5Cm+jFtyftuwNKsV5O/nh31WcxYET+O8Ren
F0QfO5/CUn2LuUytxWcuipuXA+MHXJjHX/MJ3/YCx4kT5/h/VcOaR1oozT0M
Wat2abgp7Eh/b0ceDpQhxyiOwkHps8bqsGbhbpROzJVqXA7UK5wz6k/aK/7g
+Th/xn7eWXbV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 450->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHHoovfYJfqF9gPQL9gUR9CQU7KH0lqdXocpmMrsY2JjsrrMz
o03/6sYTgPdl2br0ecxz+j7P62VI0/02rcXrP4DcLltbPr3Y+ouciSq/LXPO
ziyIOZafwlJzK16m1+KzFqXNq4HxAy2s4yg/25NpVpUnTVzj91WP4uh5oXoK
DPheWP8L/Uabwo78V7wiHKgw/mXm5WCzn8pjtdiz8NsonyD8PKKBZoU81T8n
apID+S9n77kf1KV2Uw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 451->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFA/TICK8AAESuUCYIEr0pI7QPxy+i0EkX25ZyKSE5a2/Gd
zznenv1jB2Dq5q3Pr8s45vd1v/zc83A+DUvw8DWgpHlL/oxszXc+Y5V/Xea7
BFgQOJafqqVwK14m19bnXlRvUQxUX2Gr+/iDn81xGig/9cQxvq9yFMdIC5Xj
aiDWwurv+hc6tN5KxZs1bMwRyox+ZYMXUo3p6rDmtFiz5mwCndRMNnsgrCZP
9eZETHLgt66wf74PlL52VQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 452->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4dXRaCSrnfHEayUlT2+fL
2af7s+t3AF6Heevy+zqO+XPbL5dHHi7nYXEefwZMad5SedZM+WHM/f8v813D
sveVF2IsVdfxMrEW33KxtSQWxxJ+SyfWeQs/xlpjSW/GcTkiX8VsngHoGKuF
4u8wuJdCh2hWWH+nYdBHKDP6TQ1eSL5mgcOa02LNwt5UdFI9ab4BFB/xVDMn
fJID6V/k8XvSF/2dd9M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 453->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRQcX4tYjeAU9QPEK9QQR7Kog1IW469FtQcPPnz+JBiZtMpOf
n5ccrvd+2JjZY7d0fXqepym9Ltt1cEvj6Tiuyf0nzOZu6bryG4XKG4Sb/zb4
j7RwnH1ZXUvt63xBLeqjF9xLanEt6bc4Medf/LFWriXerOP8ifVO9583ENwh
sohqmH9xfmhNnoK/Y1jxznyY36x8CW3mqRjXzlfcKa2T+YAR17T2zvU1n+rN
iZz0wG/DRD7PvQHdMHaU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 454->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmUWMh/uLgb8ZmGzF8NdSGqRzUd2C7JdWM1CV4tmPqFw
Qg9nYtyHbhZcLTZxND+hyxGln9g0gCMOkcMClxr08EfxPxIgGJ5Ywh8jDPG4
nQEbRrMbA2AxGz08sYUxPv/hcj+2OMMXRuhqCNkNV4/Pnej2o8cbejwzYKrH
Gd8oYgAYbHgU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 455->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAFSuUCYIEr0pI7QPx6+i0EkQX5+xgyUkbn+3z
Jcfbc3jsAMzdugzpdZmm9L7ut597Gs+ncQsevg4s/br05e65ioO8Ov8ZfXu1
uEbmhbhWkePxIuxC9ZkL95JzW6yp39JJcWzxU7k8M5w6VY7ILzANHSMt1DwR
xupfzE/2j55W/0rDgDuUm96Vqfs0eiqNo/k8/vLOA40sptU74yOe6s2JmORg
3wZEPJ99AIqQdtM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 456->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADFK9QTzCCrgpCuxB3Pbot6JB585IxkOl08nt5
yfH2HB47AHO3HkN6XaYpva/77eeexvNp3IyHrwJLvx59+fVU2WG0ev+JuXu5
bI6MC3GuIsbDZXwXk99isbVk3+xL+Vs8KYwtfFUs9QwnD9cr7kCFRcWEO+Dw
pObn7oyapZF/+GT+Kw4D7FBKtStR8yQ+FcdRfx5+NbOII/Zp1c7+EU6ur3YQ
DgbedQh7fvsAOUd3lA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 457->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+Jtn24LuqSzM6sGsm2TNDuZ
zO58668rAPfNdPTpcRzH9Dyt549LGg77YU5u3w7kbjq65dO5yiN4Ff9YeHe9
Yo+CC+1eoBqFNdZmimWK2bm5Nrr4z2JRPQy+1hygnswv5xYcir5/acDwpPZn
NaN2GewXPpn/isMGdpArTVTmtKX2wJyb+Rx+tbMWR1zz7e5S38LJ9ysNwmBg
rUPkS+wF3td4VQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 458->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQXPyQ/noEr6AHCF6hniCCfhWE+iH+5ei2aGV3nNkGtkmzr9mZ
7C/3/rYxs0c3ffr6PI1jfZ2388+1DsfDMDt3X5tW+VhzuzLmtxJrhPtlubOq
FXAY7KJWht3XWmIb3DW4k3NjrDeSJ7GwGgJfNgfOjfyiL3BI6iqMigupd4af
8P/HAdEleyvYE/lVOsp8IxiZPqRnmAU5F/P594N5qFnGEcas9f7FZzixv9CN
Ysj0xnnKGx3ndxI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 459->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQXPwQfz2CV9ADBK9QTxBBvwpC/RD/cnRbfLA7nVkb2KbJPmcm
u/Otu67M7L4ZP119HIehPk/r6XCp/WHfT87tx8ZV3tbcroz5rcQa4f673L+q
FeYw2EUt1hfr+9gGdw3uJG6M9UbyGDas4/PZfBkO1Az5RV/gUMy0+A0I3pl+
qu4MC6wlfM54QA4THWW+kRmZPqRnwIKcC3z+jHmoWcYRxvzr/YvP5sT+Qjc6
Q6Y34ikv+IF3FA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 460->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeYPAK9QQVdFUQ6kLc5ei2+EPmmzxpIJ1OMvOS
9zK78627rszsvpk+Xf84jmP/PK3nzaUfDvthTm4/Pll5u4dVeZa3UmNU8a+F
f4VV9WFYBVZWl/jxrCPmiEnePBs9uZdxI06832iT6ETOJnA8yVUaip4WvwGh
ezY/hdtwgS3Rk/pHbuyHuhrcgeVJT8RmzYoLNRf84p73OLMMg30wp2r/zv/r
k/XF3Jp3Aexm3uRTXvVkddU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 461->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vYx8dejs4lX4jrbImXdms6J
7R6uj+a+AdDvxkeTh3PX5edlO33ccns6tlNx/8kx0juLWaNUdSSP4fa/Yd4j
LDcH/itmsFRfxrdnC+0tcSs0j+LMtYgb41S8oPspHsoziwHq4fwIZlp9BwLd
lX8RbsWFYo2erL/lxvOo2ZWO7IGL6G4xNmmsQt1D/o89UxiyN5Z7/87Pzcn9
A98qbQm78pv5pBcoJHVV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 462->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKAjEMfbgQtx7BK+gBilcYT1BBVwPCuBB3Oboz4Gj6+tLRQNq0+b9k
d7511xWA+2Y8uvw4DkN+ntbT45L7w76flNs3A5bGI5V3xEoPx9X/TE62lv0s
43ujEUvF4Vq9rdHfUm9G9aieWadicV9G/lwPAt8Cj0DP8yxkaL+/diDAXc0v
3BnuhegXPBl/31u4Y4Sfwqeq0dUqZ8KxCWNFag/Zj2emYsjcWM79sW/VyfmD
uVXYUuxq3txPegEnlXYU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 463->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbotaMlOJlsNZNtumklm
ksP13vUbAI/ddHT5eR7H/Lps549bHk7HYQ7uPw6UNB2pfkau4jDu7r9m3iMs
i7H0BYMvsFRdxrf/Frpb41aoH8WZYxE3xlG8VL7iUWklOIFqVPMQ9f/agUB3
Nb9wZ5gL2S96uv6Fhi6P9FP6uB4b86n0BLTGwtQech7PrKUR67hWe8Fs9cn1
g7k5bQnbzZv5pDc4fXcS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 464->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OqFdGYAUYIGKFMkGQ4FQJqT0gbhmdVoIqefkmteS0jetv
/28fb8/+sTOzqZuPPr4u4xjf1/3ycY/D+TQswcPXzVKYj1A+PVdxy7y6/1n2
7mHlGGtfluELLFWX+Pm/CXctbgn9KM6MedyIo3ipfMWj0EpwMtQoeDs9bd4B
R3c1P3dnyAW2RU/qrzSs8qAfdSz6pnkzITY0Vqb2kHlFfkMj6tiqvWL+65P1
nblV2gK7mjf5hA/Im3gS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 465->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWEehBv+3Rb0JKdTFwayLbdNJPM
JMfbox92AJ7dfPT5dZmm/L7ul497Hs+ncQkevg6UNB+pfkau4jDu7n9m3iMs
i7H2BYMvsFRdxrf/FrprcSvUj+LMMckNHsfxgq6neFRaCU6gGhVvkbdpBwLd
1fzCnWEuZE09hf6Wm+Lu9knoyDOoLNotxiaNlak95Lwqv6ER69iqvWL+65Pr
B3Nz2hK2mzfzSR+QwHdV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 466->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3Pt1d0CWZTloMpN1Nm0lm
msP1Mdw3AJ67eRny6zxN+X3ZLj+3PJ6O43K4/zpQ0rwkv0euzmG8iv/MfEdY
FmPtCwZfYKm6jG/vFor1uBXqR3HmM8kNdbziFWijeDitBCdQDcdb5P01A4Hu
6v1UD5ILWVdPob/l1qzL+fY+RI+mV/kmjE0aK1NzyHkun3EiPSxeQ9sVs9Vn
p77UK5gPl8d46QNBdHeS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 467->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBS7/QvmAFPRWEepDe9ultwUoyO7EayLZNk0lm
Nqfro73vADwP89HmVzMMeez2y8ct95dzv/w8vh0oaT6Sf0a+5ruY8Sq+mnkv
QS+L8ZkLBl9gqb6Mb3MLxVT+L7wt50gTVQ+FgXoezmMeTivBCdTD8RZ1/+5A
eN9CL4VXcSHb1FPob7kp7tU+CR3d3GzRnTA2aaxM7SHXuXrGCfRxeF+0tTqE
c270l3oF++HqGC9NnIl4Uw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 468->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKgzAQXPwQfz2CV7AHCL2CniCF+iUU9EP6l6OrIGl2MtvgQuIjs7OT
2e1en2GqRGRtjm3w23NZ/Hesz4+3nx/9fB621xIJ7ticflqL4SRZiI2RvCMX
8gT3w8Vcg4vVzbQm2AD/GJ5yEWyqy6qN+dQ3yfUgTvmJXpE7CdRQ92Z5d2bA
8J31z5wZ6B9G0U/if9bjQh+Yj0o3hjVb6At4zILNIeZlPSdaSjNgeRs5/+ks
1Kd+GfOh8pDP7VO9d1E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 469->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADLF6hnmAF+1UQ6of416Pbgiyb2ZkWA9k+Mskm
kzndn12/A/A6zEeX39dxzJ/bfvl45OFyHpbg8efAlOYjxadzhUPljC1WvZc4
BJ5iJdfUUvc2vVbYif4pvKxlsBAxVYt5Dryh7YdxgU/mSswEuiPMrfL+0YDh
Xe3Paob2x7bJJ/HHs6nZeQ+Kx9A3m9MW80IcK1M65Lxm56aXNQ04bkvNtT43
7pd8GX2EPK6Xvl2VeBI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 470->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMHDyUXn1Cv9A+QPyCfcEW6kko2EPx5tOrUMLuZLLSQNZ1k0yS
SS6P1zA2AN7n7RjSp5/ntNxP+88zTbfrtBvbnwJrtx1d+Y1U+SFT9jXJ7maH
xs5tFhtgqbyu1sx3pbcov8MKfCFsCot5LniDr6e4M58Ch3sC5Sj6VnH/7EDA
OwizujM0P5ZDPok/7k31znMA+fAsnUScMy/EsRK1hxznZh7UUtuBiFvDrNV5
kF/yFe0ohN3evgVveNM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 471->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAURAcX0q1H8Ap6gOAV6gki2FVBqAtx16Pbgi3JZKahgSRtfv7k
z0vOj1fbHQC8m2lo4+c2DPF7P84/z9hfL/0cPP07MIZpCPnsuooj6cX60pLv
NQ6vvda15BotdS7rpXtHWqt5q9UKEVNazDnjZurb8sE67Al0RuZb5e15A4Y7
SFOxYv4FA3EvkifxY2/KO98DaA/fZdEcc8GFNZ0/la/eV6Fj+KT6W2zTWm2d
lfMlL/M+sjzWCz++u3nR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 472->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRT8upFuP4BX0AMEr1BNE0FVBqAtx16PbgpXJz//WBiZpM5mf
mZfZX+7tbQPg0YxTm5+nvs+v83b6uebueOgm5+5jwJDGKZWrM+VHsGp/HuE7
+pz299wca7TUvawXzw60t1Qb51NpC5/SYs4FN5XfjzrW+JlPvAe093cPGO4g
TcWK+VcMxLtInsSPa1O18zuAzvBbVsMxF1xY09VXxAtWiLomF9VLsr+iL+Rq
81y4X/Iy/VHEsV56A7lVec8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 473->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFA/TICK8AAESuUCYIEr0pI5YH4dXRaCZB9OSfUkpM251zs
s/eXe3/bAHh089Ln52kc8+u8XX6ueTgehgXcfRyY0rwkv0eucBgvzr9mvi0W
cf/iYHITXOpd5rOxE521auN8Cm6BKS7W2emm8qvUsQZnfZyedPb3DAS6gzir
M0P9Y2vqKfRXGtb6AIrhXhYWaS50Yc6oPndf9ACWN8hFzZKcL4uZXMM8G+9L
vYL5cPeYL70BmpF7Tw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 474->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRT8upFuP4BX0AMEr1BNEsKuC0C7EXY9uCxomf/40gSRtfvIz
8ybnx6sfDgDmbh36/L5NU/7cj9vPM4/Xy7iJp18HlrQOqZ6jrnSY7tb/zXxb
LfIu+2BiE17qXvazexdaa+XG8ThvoSkv5lxxU/E17pI6vM58Kp60Fp1RLMJ6
C17yzVD9uDV5KiaC4V4dQHu4lq5FzLmewrPkSvmp8yo/xyhgb/332BZPFSdq
Pbpf8greR3WO/dIXqSZ7jA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 475->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKg0AMfXRRuu0ReoX2AINX0BNMoV0JBV2IO4+uQlsyLy9jIOM4L9+X
3J6f9n0CMF62o81TMwx57s77zyv3j3u/g9evAkvajlR+I1U4jLr3n5i7xaLY
fzuY2kQslZfjWduF3o5643pcbIGpWMxzwZuqr5KLe+Y+nQ/3rfwqPoqLcN6C
L7kzND+WQz4F/4rD2hxANjxLJxHnghc3M5R3tYfs52Ye1KJ2Se6XxUytrk6U
eJRf8hXtaC1eWgG56XrN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 476->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAQC35Ifz2CV9ADLF6hnmAF+1UQ6of416PbgkpmJtPShX3Obiab
yfH2aLsdgGczDW19XYahvq/7eXOv/fnUz8HDtwNjmYZi56yrOKiH81+jNccy
7P89EDeBpfJ6PL47urO1v3k+AVvEFJbX2eim+C3k8nr7f4Y3/t/q3RYPJLqz
FqzJqi94L+qSYaicSt+sDkpHw9u3zFtCl1Az2LXyoaxpiW89F+Ul6S+OEdfA
Ezae5Zd6Jf5YxCsf98B6Dg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 477->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPWB+mUEVoABIlYoEwSJviohtQ/Er6O3lQDZl3MAS06bODn7
zj5c713fAJjadeny4zyO+XnZbZtbHk7HYQvuXw7MaV2S/0au4iB3528z/zYW
YX/uwdQmsDinwrN3Zzr7xo3rKbBFTGEpnWHecz2so9OTtGaeKo/jrd79MwOB
7laLiIucC9LgJz2VJkChW60PSkdXN1s0W6qnEVfiZ/eyp8yPailyCzy2qOeK
by2/1CuYjypeWgClNXgO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 478->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszigXXkCX4AHVHxhvKBIcJqENA6IG09nk2BKPbtjkdKuS+vE
TvaXe3vbAHg0w9Lm56nv8+u8HQ/X3B0P3RjcfR14p2FJ5e5cxUFe/P9Z+J7i
8NhTXXSfsTinwot3GWuJ21KtEDGFpXRGeD/TppKLtWaeKk/BW71bMwNG96iF
4yLngjT4S0+lCSB1c31QOhZ1s7nZUj11XIlfPMueMj+qZZZb4LG5niu+tfxS
LzMfVbz0AXCAeY4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 479->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXHmCX9AHbPwCvmBN9ERiAgfDjacLiZLu7NTapAtLy7Qz
7fH27B8NgKldjz6/LuOY5+thu9zzcD4NW7D7OLCk9Ujl03MVB3nx/WvmfY/D
x977onzG4poKz+YyVsQt6hUiprCUzjD/V9r8qMVaM09Vp+Ad6BPugKO71cLj
IveCNPhLT6UJIHXz5qB0LPpm83ZLzdTjSvzsHYQr+VEvVW2Bx6ZmqPIQ1Jd6
iTlwvQovvQGuW3mQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 480->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOgjAQRX9YGLYcwSvoARqvgCeoia5ITGBh2HF0IVHS+f3j2KSlMOX/
mTc93p79owEwtevS59dlHPN8PWwv9zycT8MW7D4TWNK6JPv0poqjmNX37yj2
exy+9p4XnWct5ct65VnWimqLcoWIKS3FGcX/FZsfXsyb61Q+pu6AT3gHHO7G
36lF9pIY/MVTMQEkN68PiqPJm4d3t1RPOT/YvWRGurI+yqXyFno8VA/VOQT+
kpfoA/tVeukNRoF6UQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 481->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+DICK8AAESuUCYIEr0qVygPx6+htJajiy7luJCdtbN/Z
55wffftqALyP89bmz20Y8vd+WH6eubteusV5+hkwpnlL9vRM+VFYdf9fxffq
h4+91kXxjKV4Ga+MZayot6hWCJ/CUjqjyK+02eBivblPxWP6DvQJ34Cju+F3
epGzJA126ak0AaRubp7Q0dTNy3tbOzBNjYKDZ2XuKJc5RxFj6qGlZqjiEPBL
vcQcmK/CSxN7qXpR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 482->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsSbT7cFXZLJZBvIbrsJk8wk
h+tjuG8APHfzMdTXeZrq+7Jdfm51PB3HJbj/OfAp81H8nbmKw3h4/5v5bnHk
2K0vymcsVZfxVB73ssY9y83qBy2Ezs0R+0FWCwh6O55JHcdb9GbfV3cg0d3V
T7jIWZIGrLXUk/UT3HpzAXmqlbXObnUxLVfi5zQj3DBz0Qv3ofDY1AxVntRX
xMJeEDbXC3jlC9M0eo4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 483->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbn24LtiSTyXYhu20SkplJ
TvdX99wBeB+mq6uf6zDU720//zxqfzn3c/D4N2As01X8m5mKw1jwL8d8r3Hk
tVdclM+1VF+up/IYyxb3LDfrH7RA9K+6IeLhPKcn9XU8xTwDb4HN+jd3INHd
9U+4yFmSBqy11JP1E9xacwFZqpU9jd1q1rRciZ/TjOqGmSdYRpETeoNiS77C
CR/P+sPgDBiSvZP1yg+Ut3tP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 484->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+KtT7cFDbuT2SSwabO7mcxM
cro/h3EH4HVYpyG/r/OcP7f9tnjk6XKetuLxF8CS1in5bxSqDhNV/j/Mf6kj
xi68qJ+x1LmMx30wuZ62Htfo/AgblHNaoPcr3qzH+tPiJ3XD57tvIPDdYQRa
5F2SB+x15KfbK7S17gUUoVd2NN5WE9NqJX12DcKt7jzgsqiewNeCa3oqngpD
nA/Ds+IQvDuJl76inHsM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 485->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKgzAQHDyUXn1Cv9A+IPQL9gUp1JNQsIfizaer0MruZDYGEuMmOzsz
2cvz3fUNgM95Xbr8vY9jnh6n7eeVh9t12A7b3wTmtC7Jf6OpzmFmEf8Ps1dY
nL/zgo8xlqrL+HwPJnakjfkU2BVPovuFb2ZE3jBv1mP9qfGTuuHjhz0Q+O4w
Ai3yLckD9jry0+UKbbV3YS9Dr+yIeguCE9eB33MNru9ilMtcZnUn8HXHVdqF
3lp9GJ4Fh6DvJF5aAPH/ek0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 486->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRb84IK6MwAowQMQKZYIg0VMlpHJA3Do6rQSV/e2fRnLaOM6P
/ZzT/dn1OwCvwzx19X0dx/q57ZfFow6X87BsHn8GTGWeiv8qy/ZhLPj/w/wr
Lbte84L3sVZ2L+txHIxvqzbOJ2g3mKj4wM2MlEWSd8rbaKj80rrh/ZtvQHB3
Go0+h14SA2ateLqzSW2tvjBL6ws5Qmszc+6Nq43i1XnLL9SX5DJlMYLrqitq
5zta96e8xPto6pUv9mF7Dg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 487->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKgzAQHPwo/fUIvUJ7gNAr2BOkUL+Egv0o/nl0FVrZnX0YSEwmcWZ3
di/Pd9c3AD7ndenq9z6OdXqctsOrDrfrsF22vwnMZV2K/kbTu4eYBv8PsY+4
5HmPCxpjLk+X+fgdBHaUG8djuBNP2J8IlyP6n+N2/RYcUXxu3tD4YQ8Eviv9
pM6mluQBe531ivKEcsjqwl5KzMRI/pjegtZ0ew16H9WMa2Dyc2KZvTeBr7tW
kDtrZPquX0F/pHxlASKaeo4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 488->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAQG/yQ/noEr6AHWLxCPcEK+lUQ2g/xb49uC1Zms8nUwmz3mWQy
c7w9+8fOzKZuHvr8uoxjfl/3y+Keh/NpWA4P3zAraR5S/VfBzs1Fs79+bq6w
/Pqny+o9xGK8iIf3mJat3NVdxW8wZ/4aaFHeNLqV3w5D6Vvfs3d/94DwveIP
6tzUEjxAr6NeMceFOUR1QS8RqxBNtCbgOdaG5cY4VJ9UOoWWwu5scKvckSPi
p36J/gjx0gfdrXqQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 489->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAFSuUCYJEX5WQ2gfil9FpJYqcsy+p5DRx7PP5
nPPjNYwHAEu3LkN63+Y5fe7H7fBM0/UybZennwG5X5e+/CuL7mHM+ffP7BWW
Pf95ofQxVlSX8Tgu4tLqnXkj2MtehL4gLkobx1vpbTAUvz3f6RP4a1o061fm
7GZJGvBcam8Fphb3UJsLyBgrB5zCmZDmClP1F+XLmQsuOYpp1LYxkmejfqiX
eB9FnuP6BUofeZA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 490->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYg3n24LWpLJTupCtt3dZDKZ
5HC9d/0GwGM3bV19nsexvi7b+XCrw+k4zI/7rwHvMm3Ff5W13mEs3P+W+VdY
9rzwgr9zWCIv49k45vVPbYEH6ZXFtfyDboh82M/xVnobDMWPdVD6pDOAiBvy
J30OvSQNuC/ZrMDk4hrSfpIxlpo3NVtrmKq+VrzsuV2qJ4wnci/+Gc+V/E29
xHy4OMYrH0/Dec8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 491->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS6kW4/gFfQAg1eoJxhBVwWhXYi7Ht0WtCQveRkHMt/My8tL
jrdn/9iJyNQtU19fl3Gs7+t+PdzrcD4N6+PhayJzWaZiV2bRuyhz97+h9gxL
nzdeYu8QK4qLeNoXef2Tm+MBemX/In+nm3g+6Gd4M70VBuOHOsxB/GYPEN0N
BsklrCVwwLpkvSIqFuaW1hMMscJ+S3qrhcnyQ81cbbTeerCaIB8Se/PPeDbi
h3qR/jD/EK98AIggeRI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 492->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDV2IW4/gFfQAg1eoJxhBV4VCXYi7OXpb0JK85M10IPPNvLy8
5PwY+1cnIu/jMvX5c5um/L0f1sMzD9fLsD6efiZS0jIluzKL3kWZu/8PtWdY
+rzxEnuHWFFcxNO+yGtPbo4H6FX7F/k73cTzQT/Dm+mtMFg9UYcSxG/2ANHd
YJBcwloCB6xLrVdExdK5NesJhlioC8NG3Rgmyw81c7XRehMuJfBpxd78azwb
8UO9SH+Yf4iXZllfedM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 493->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4dXRaiVbO+ZxQyUnj2Ofz
Oaf7s+t3AF6Heeny+zqO+XPbL4dHHi7nYbk8/gyY0rykco9M3cOY86+f+Y+w
7HnjhdLHWKquwlhjmdc/vTkepFctT8U73eD5cJzUU/TbmqfVwekKnaN0bdYP
epGzJA48l9pbganFvVXnScZYrEuEzbpFmFF/rBnPDcYfcZlETKv2Fl/j2agv
9QreR5HHeOkLBll51Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 494->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMPPVR8e0IXaEdALECTJBK5YVUiT4qfowOSCUy50uCJQcSO+fz
xffXp+0vAL7VurTh14xjmLrrtnmH4fkYtuDt78Bcr0t9/KZcxWHcne9m/lNY
dh954XjGWKquwthzmdeZ3hwP0it3T+U73eD5cJ7UU/Rbek+rg9MV+o7SNffe
Si+JYXDYSnPHmqjesu8p+gBhOEvMhdXNYSgceB2Yv+SZ4DKLnFLtmJ/jWahv
tXcceIYh4vFsAS2LeRY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 495->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFxItx7BK+gBileoJ3iCXRWEdiHuPLotSMmbTMILvH+SN5nJ
+fEaxgOApVunobxv81w+9+N2eJbpepm2x9N/AN9+nfp6jYZ6hxnVvTVzjnKB
Yu1a5eN9hBU+bsdLWLLaHA7iK4tT/syZtSiecWd8Z3paHpROTT3Q8n9Qi9SS
ewXCP9KFdW7VU9QByuEs6AvLm8uh8iDmTPYJ4PNEmjAeZVnt7Jf8b7l3GLiH
1d/73Q/LMXeY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 496->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDyIV5/gF/QBwS/EF4xgTgEhHsSbTzcjIr1UTdIwW09PTXdX
Ha73ftgAeOzmqS/P8zSV12VbD7cyno5jvdz/BvDu5qnzqxrsvvq+Fv3WzFlh
Iby1q8OL+4VcbazLF+tqS3mEfrXesXjrc7WI3rC82b8WQ/G5xNMqDYg4hyFq
oVxGrYDEK16CVljfWu8SlwYjWUNbjlOLwXCge0Z1AmQcwWvKh1mr9hgndGp9
NIeoYfb33/cB5bN4Vw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 497->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKAjEQLDyIV5/gF/QBg18YXxDBOQ0I40G85elORIZOpboT6Cy9VnXn
dH+O0w7A67BuY3pflyV9bvvyeKT5cp6L8fgXIA/rNtSnJ8pedL/FervM28sF
irVnlY/vHazWt8KLPjfGs8WLu8tF9BdW0OLheMat6toc3jzlnJzYXi+8PKpf
Koflwav377gnils0Fxh/pcsCUzSTaqZo7R6/pl6E08GShU9Um7l7MwjtxL3B
wH9Y1d50XxDveVM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 498->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPoh/e0RvIIeYPEK9QQr2K+C0H6Ifx7drohkZzO7Gsi+0kwy
k+4vt3HqAKz9tozxflqW+Djv0uUa5+NhTsHh48AzbEvId+VePL29jd+tmbvC
AuXaPcPjc6NX+23WL9rcuJ9vvnOuYbG+sI6yH4hc5s2atebJOnh6sC5KC4+j
OzeBkfEg+0dPW9PTrZZXzNLqw9aq72F4OCAdfpkN44i5WnxVm7mrGVTjxL3o
QfybLp/wAmACeJQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 499->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMFHmUfDtCVmgHMF0hncCF9hUoJI/SX0ZPAiWczyelAtlWbEl3
p3SPd/9qzGxq16XPn9s45u/9tAXPPFwvw3Z5/rnZnNYllbvn6t7Ai+9oEHu1
jHJxL+rx+QArvt3xEpYj7ozbxDmqxfqiZmhSC4HbqAbyjObJOig9WBdPC8VR
zs2pUfDAWPSP9EQ8Srcor5ol6sP2Z3/WWJmcB+VVOB0ss3gT9Wbu6j+sOIn+
PCtVW86b+aQFJuZ5UQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 500->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPwQfz2CV9ADFK9QT7CCfhWE9qP4t0e3BSmTdJJdyG6yj8nM
tJfnp38fAEynZerLfB/H8n0c1+JVhtt1WA/P/wBqt0ydXaNQ56Aw+zyojrDg
3vJq8Hze4Mp3N76OS0u75w2RZ1jeX/aMh/RC8IbDYJ3Z92QfqsD1WjMvIhzl
l8IwOrgW+Jmf3DN7I70M9gxHxNie7w5D4cD5oHLFM+Fi7jR6e+3qP9xpEv1Z
exUcDEfVe9v7AdTfeNE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 501->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAURD8uxK1H8Ap6gOAV6gki6KogtIviLke3BSnzJ/OTQtIkP528
mfTy/Azvg5nNp7Ub8nKfpvx9HLfJK4+367gVz/9mVtLaJf+OmqobNLeOD8yx
HmnvXCb0eNxhxb07L7H0vDsOyivKRLKo3Kzm4X3MjZmzz9Z9Yg5F6Kp7ibKI
dFReSsP5wLnQb+WJZ7a+kVkGa47RYm3mrTSUjlEOaqw4GyxuT+ds9q7+w8qT
OB+9l4BB3jf7ST9yt3mS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 502->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKhEAMK3tYvO4T/ML6gMEv6AtG0JMg6EH25tNXQaXNpOpAR6pt0qTm
zVB1LxGZsvWq4lyOY/zV7y1pY198++3jZw+RJaxXsE8vjnrzTgXWnkflHpYQ
HqxHLMaLeLr2nBdmudNu5gC/WF/iBdMIsyAH60XdZhaF4e0TfWB+oC+eF0wj
3ZuDYXTonOBf+ak5r3qSPrZL7Q+eO36GwXAEfHiyG8Qhvj/lNvXOf5hoIvxa
++LMQPeNesIffWV5Eg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 503->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB6KV5/QL9QHSL+gL1hBTwsFPRRvPl0FK8nsZKuQlazJZGbi
s/+0YyEic7kfbfi+pyks3eNIhhDrVzw+VmeIrM1+NPbtxa/e3KnA2utRuYcl
ZA7WIxabi3i69uILXP5pNzzAL9aXeME0AhfPG8Zbe446c/tEH5gf6IvnBdNI
9+ZgGB06J/g5P/XMXA/V7NwZjuJjI98Eg+EI+HBnN4hDfL87G7Wz/zDRROZr
7SvhYDhCj935BlVzeFM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 504->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRQcX4tYjeAU9QPAK9QQR7Kog1IW469FtQcvk501amLRJpn/+
/zOn+7Prd2b2OsxLl9/Xccyf237ZPPJwOQ/L5fEXZlOal1S+o/jnF2cuNHd9
3D7CMqij+YpFdRXP5658hcuW9oKH+EX/VV6QRuESeUO8veeqs9VP78MEuFGP
yYsIJ+KPs0G6oH7LT19T/Q1nwuXTWcHRYmz1vMIgHBMf6Jt4NrgUORu1VTvN
YaUJ6muvCLu6Iz3pCz+WeRQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 505->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRQcX4tYjeAU9QPAK9QQR7Kog1IW48+i2oGXm500NTNokkz//
/8nheu/6jZk9dtPU1ed5HOvrsp0XtzqcjsN8uP+G2btMU4nfLH75Yc+F5i7D
rTMsgzqar1hUV/F87sJXuPzTHniIX3Sv8YI0ChfSr3dVd+DiNGX91Drkh/qS
eZHhZPzxbZAuqL/mp6+p/qZvwuXTXuBI/Uk8bzAIx8QH+ieeK1wyDByivekB
aYL62ivCbs5IT/kAhm96Eg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 506->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksOgkAMbVwQtxzBK+ABJl4BTzAmsiIxwYVxx9GFRLB9fa0kM8PQz/uU
0+3RDwcReR6Xra+vyzTV97VZL/c6nrtxDbbfJTKXZSv2jNaWb76phbn7U35n
1IvFdI7rtb1HXEndzldy/Ey3xozwnRdMI3DBGKtF3YaL0hTNE3GYH+hL5EXU
h/nFehgd+k7wMz81JvM3q3OzVD3ck/xbbp5sZmLzkTPWOZ4JF5PzBxu1uxkw
TQQfZ8V6uxjTUz7hanlR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 507->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQHVwUtz2CV6gHCF6hniCCXRWEuhB3Pbot2Dp5816wkKTJTOZ9
Jqfbox8OZvY8LlOfX5dpyu9rs27ueTx34xpsv8NsTsuUylWNLb84cwNz9y/9
VlWLxXxOqLX9K67k3s7X6vg13R5T4QcvmEbggjF2F3UXXJwm1U/EYX6gL8wL
2m/VN1XD6/B7gl/z02MqD6WX4qzgaDyXeR5qsDoWfUD+lCdwCf37Exu1hx4w
TQQfe8VqszcT9KQPoxx4kg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 508->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB5Krz6hX2gfsPQL9gVbqCehYA/Fm09XodpkdkYUsqubbGYm
4+X5btrKzD7neWny9973eXiclo9X7m7XbknWvzAb07ykuKtY68OZC6zdnvTf
VS+W8zVFr/VdcSX3Nr62j7+n22NK7YoLmxvwY3XI2wi216T8RBw2D5zLYb+V
b2KeQQN4q7xUM2HaKC5qFmfhvzFeW+CzHqyPwRwIf8oTuBT+HcRG7YUHnpPK
g/aRcAgc4U70fAJmPXjP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 509->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUEOwjAMizigXXkCX4AHVHxhvKBI7DQJaTsgbn06G4KSunZXKW23OrET
H2+PftiZ2dwtWx+fl2mKr+t+/bjH8Xwa18fDN8xSWLZQnip++OKfC8TmFf5n
IlyYn3UZqYd3pZXkZS6re2nWMo6TvSstbG6gj+FQtxFu35PyU2ktco3PYNNv
5ZuYZ9EDeKu8VDPxNZu82HPDy2qRuRb8ULfyzK0EHKifaUItlX+oX3AzPMNu
8aNXqnblt8d97m/5tniK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 510->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOgkAQ7HAwXnmCX9AHTPwCvGBM9ERiggfjbZ4OGMFeqoZOZgG6u6qr
ON2e3aMRkddx3rr8vo5j/vSH5eGeh8t5WD62vyVS0rwle7K15pt3avncLdL/
LARLAI7GC73WO+MK6ja+EmepzW54OL3g7IwL0s3xQ3metwBsPRPzk3E1tYI1
2PWb+Ub8NTM4b5mXTBPds+Zn0LLiZQgwi8F3fYNnKorDQJp4Tp5L8A/VokD6
g9w9fP8PsN5hNp33vU8+3njJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 511->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOgjAQnPhh+PUIXkEP0HAFOEFN5IvEBD8MfxwdMIL7mC1Nti1lOzs7
0+vj1XQnAO9qmZr8qYchj+15/Xjm/n7r15+XXwBTWqak1yi2fHUmwubuI/3X
KagFUkfWc1jbPuJK7u184Xsp9a54GL1o7xEXppvhx/Isb5DasqfIz4iruguu
QQlD4jC9mL+qB+Nt5GWkicQs+em0DM7UuwHPdfUZBsOB0QFcE/u+LBfnH7vL
BtOf5B7Vt++AYVO/Zd53PwMbInmK
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 512->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8OjotosWx7xJLTtLG9vl8
OVwf3X0D4Lmbli6/zsOQ35ft/HHL/enYz5f7nwNjmpZU7sqX+OKfcR+7Wvrv
o8ACwbF4odZyVr2SvLVfRC417ipWcle9sLm5/lic7xsE23JSeqpei1xE/q0a
AR8N7p6D01ZpqWZia9b0DLOsvRNvhEuB7+oGzYypmQVN2YwIT5nLjM2fxLbw
/TtgtaneNu57/gDbVHmM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 513->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vhA/O3obIiNNLHbSH1sTWM7
7uH66O4bAM/dNHX5dR6G/L5s549b7k/Hfj7c/wYwpmlK5arGkl/8M8PnrpH+
6yiwQHAsXqi17BVXcm/li6ilpl3lSu2KC+ub48fyPG8QbKtJ+am4FncR9bdq
BHw0tHsNzlvlpeqJrVnzM/Sy9k58tPBd3eCZCdWz4CnrEeEi77Ko9d9xrOH7
d8BqU79t3nf/AWegec0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 514->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6I257OJrGRJnZbKe3auXEc
93R/dv0OwOswT11+X8cxf277ZfPIw+U8LD+PvwCmNE+pXFWs+OLMhMduI/3X
SXCB8Fi+kGv9btRqsVu9iFpq2hVWahd7r99rob0gdYNwW03KT1VrcRdRfytH
4EdDu9fgvGWcsv8oc9b8DL0k/Qv7ij8Fv8sbPDND9Sx4as9VjtZdosPjVY0S
Q94By0399nrSFxcoeRA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 515->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDxIrz7BL+gDgl+oL4hgTwWhPYi3Pt0WFHazM91AEpLszuzM
5vx49cMBwNytS1/ft2mqn/txOzzreL2M2+PpN4GlrEvxu5r/+PYOJNcNE7cI
LhAeyxewBC/DsNw2X/Fnuh1WokX5i6YW5Q2rG4TbalL9VLW6XET9GUbgB9fC
/kzQRfj3/HR9TvoZvCT+hfNOfxx/gxt6ZobyLPTU3iuMLJfoaONVjTKG/AOG
3eqkesoXEgJ5Eg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 516->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMDH6Ivx7BK+gBgldYT1DB/VoQ1g/xb4/uLogm05muhTZ9JJPM
pIfrves3ZvbYzUtXnudxLK/LdjncynA6Dsvj/jPNJp8Xz1ZN9m5hpvs4/GcV
lkFstAkP96pWq+O+9VrGbnE3176Suzgjf+RCtSB1G8nNNGF10LugB3L95w9M
DQz6Z5AD9HYtJ2oSMZt5kbPQL50b/Un5AbfqWRhKs6qn8V5hrMUSHuivapQ+
5C8xbORJ+fgbS+x5EA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 517->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBwS/UF1TQU0GoB/Hm021BNJlMti7spukmk8xk
d+dbd10BuG+mo+sfx3Hsn6f17Fz64bAf5svtZwMvmw6LttrqHm6H/37Zz1ZY
oFxvAx5/V70i5337RcRucYfVsSX3wmf+zEVqIfqGqO05VfOseg25yDF/6UQY
zTfDPLyP5ZqBf9G3rMuchX7Jb8wn1CdcOTOnkdIszdRybsJYyhU8OF4tpXPA
4HcqsOW8mY+9AU3NeJA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 518->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+eXRbkLqPmdTCJt1sdnZn
Nofrves3AB67aenq8zyO9XXZzs6tDqfjMAf3XwPeZVqK35WxOIy5c/uV366w
EHLt7vDiv+oVOW/pFx67xR1F35XchR/5Ry5UC9I3SG3LSc1T9epykTX4SyeB
Qd9M5GF9Ul/xsPdbGkotiX7Jb8zH1Q+4dGZGI6ZZmmnJuQljLZfwWOUaOcU7
5C05bBaL8eXsA6QleVE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 519->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDefLq7IDrJzmgDbWjSTDJJ
dudr168A3DbT1dX7cRzr47SeH5c6HPbD7Ny+D/As01Widkf5QSfYWcpXOyyk
WNYBj7BUXoXBuUG2Zm7mr+Vu3pk/1+J6o+qGwGRObp6u1hCbuLbswCI/fv/P
PPJs/+Xkvoc5N3ANnI3N7ZvDWczTzYx6pHqW9ynUmUTllLFZxM4pUX0OGHlP
GVv5sv9jewHAQnkO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 520->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQXPwQfz2CV9ADBK9QT1BBvwpC/RD/PLotSJ2dzIQGNiH7mN2Z
5HB9dPdNRDx309b1r/M49u/Ldr7c+uF0HObg/mcRnzJtJZ/OVDzAkh9X+Z8O
K6gWz4QHWKqvwsDeAb7V3Eyu5W7uzB9ncdostaynibfe082aaonrmj9Q9Y92
PvNId9Hf8cB8pWHrHZSOiFGtBk71nkJbXE4z/k9pToHBPWWt4MGc3Iysc8Lg
f4rYKsbxxfcFcMZ4UQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 521->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMFH2UfDtCV2gHMFkhmcCF5hUIpI+SX0ZPAqWVTidRgWxsySfd
ydfH1A0nEXk1+9LVdzvPdenPx+FZx/ttPIKXj4usZV+K3SNncVFu7rWV3x5h
CbzVu8FTWKwuw3C1xWJn3LAP1Ityj3CYbqy/oAejQRDP5hn1at4C13/+gKsv
eT7yMDMl9SMeOp9pmM2B6agxnCU4bp5EW22RZvifUBfEcNqxt4QHcgrz2D8l
tVbsk8Uw/r3bADNFeRA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 522->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB6kV5/gF/QBi1+oL1hBTwWhHsRbn26LUieTSaWBbbbJ7mQy
2f3l3t42ZvZoxk9bn6e+r6/zdvq51u546Kbk7rtGK581gM+WylvxGHMcrfx8
hmV0F73DAyxVV2GE2uaxl3pjHi6e9b5GN8Uv4eA0SPLMT9UMMbxrkes/jFDf
dC9ylsghqZ/1geeVhtkc1Bsywgi2gBPmKbRFczrQnmeLujBG0E7dFX1wT+k5
9U5FrYF5qhzn59gb1ld4Tw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 523->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWEehBvPt0WRJPJZKWB7Lab7CQz
2f3l1g8bAPduXvr6OE1TfZ63y8+1jsfDuAR3HwdeZV6K3zNXcRh359bKb8+w
QHft7vAMlqqrMEJteOwWN+6D9ZLc1+im+kt6cBok8dY8s17dXcRe/3EJ9dHO
Zx5upqJ+xsPmKw2zOag3BMII1sAJ8xTaWnM60DfP1urCGEE7dVfwYE5pXlZf
6OvyVIzj37M3JrR5EA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 524->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbgQtx7BK+gBBq9QTzCCXRWEuhB3PbotiE5eXqIOZIY2k/dJ
Zne+dv0KwG0zb129H8exPk7r5eNSh8N+WJLbVwBTmbdizyhUHk2Y/+0qn1Nh
cf1bFwReg6V4Gb+tY6xfvLEO7pf0/k/flL7MBywn57N5RlpNLbzWb14cP/L7
7MPMVPBHPrgue1NubsxPGG4lOG6eorcSh/lIt/PXLMUpawU/awnvif4qrinI
y3k7DU+HR3jN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 525->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHHqQXvsEv6APCH6hviCCngpCe5De+vS2opLMziYubErZzM7M
bo63Z/9oAEztdvTxdRnHOF8P+889DufTsBe7TwJL2I6Qf71U9XeIWhbJPdWL
8T9dEP2I09MMgeNeVW9B6KB5Se//zO2bSl/JB6wG9uTtU+IYC6u15sXwo3yf
fWQ7FfyeD8aV3pT07PQy83b2k+qVPWp9mE+9r9RfEopTYgU/a3HvifkqrsWp
y30bDSuNDHeO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 526->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQXDwUrz7BL7QPCH6hviCCPRUK9SDe8nRbUdlOZpIuJCVsd3Zm
d863qR8OZvY4Llcfn5d5jq9rsz7ucezacU2evscsheUK2686LP8JktuEezMs
rP/zMoIHPRVnI3WIVdUWCA+YF9W+Z26/w/iVdFjOATXhXhX3BBxQ614PqP5F
z8AO/W5rPVVdyVNUs8DK5i324/lSjBoO9mP+8vpcYE/qTRbEc/I/Ml/GM4k8
3XfG4Q1AP3eQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 527->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpAfDsCK8AAESu0EwQJXpWQygPxy+htEVTJ+S6tpSRNHZ/P
Z59uz+7RmNnrOG9dfF/HMX76w3K5x+FyHhZn+1tmKcxbKE+1mP9rxFdYdmdY
GL/yMoIHORVnI3GItVlbIDxAL1r7Ht3+i/Gr1WGeA9aEfVXcE3DAWvfOgMpf
nRnoYd7brZwqTmnotCQzhBjOKjiun0Tb3Aod4NvNV14fYJjgUMvNZk6+U/kh
V8J3zIf+9d8EuyV3kg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 528->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBwS/UF0TQU0GoB/GWp9uCyO7sbKiBJN1sMzsz
2cP1Mdw3AJ67eRnq6zxN9X3ZLsGtjqfjuCT33wm0Mi/F79lUeZjpzu0wcRP/
hxh+d3jF7B3OEPcYa422wIP8ktr/9C3w6+lA5MCa+F0z7s3WF56v7YGsfqqd
dLg3FfUzHXwv8zB4KXqIMcLo4LQMQ+GAfKDv0F9WH2H0PMhqu/NMq+Wi6hPP
JjiEHOd/Zx/zyXbR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 529->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMHDzIXn2CX9AHFL+wvqCCnhaE3YN426e7C7JMkknFQpsmaZLJ
pMfbs3/sAEzdcvT1dRnH+r7uV+Veh/NpWJ2H7wbmshzFymwrP2gbOy/SZ/E+
6LDS5CskG5gh4rZahOVXbwGH40v2/idvjM+/D30gYmB/a54yzsciYs1yqHkr
vrK3igNVP+vDx2UcNuOSOYSlZkJ4ZQ6VB44Hdw//i/tzOVocZLWNPeuVsaj6
4h94DMHn/ZvtA+MvdZA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 530->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMDV2I2x7BK+gBhl6hnmAEuyoIdSHd9ei2oOUleYk4kPklefPy
Mqfbox8aEXke16mvr26a6nw9bId7HS/ncXO2HxNZyjoVvUbG/AKm7nHAeSHx
7ix6VXgF1oQzYnzj97eAy6/aHA+jF639T92Qn41HDkqDwJ/1k+bZXPFcIwzW
b6ZXFOs0IH3J6lB/IdEwzQv64AbrCf4zhsFwxOhg9g4T6zMYmQbR2+o+qtVw
cVjkH1gOzmf9+90bRut00w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 531->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMtHggvozACjBAxAplgiDRVyWk8kD8OjqtBNXlfE7bSImT2Dlf
zj7dn027M7PXYVya/L72ff7c9tPhkbvLuZucx980G9K4pNJGU/kNZnGPA86D
iHdnK22Bl8BWOCPGP37OBVyW/uZ4kF7y71t0I34cjxwKDQJ/rZ7yHb81zzXC
UPVWekWxqB+Opb5z78Cu0lz0EGO4oWqCfaYwFI6RDrR3/YX/I4yaBlFu1XMy
Ry2/6APm4Hzsn+++4bd1Eg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 532->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYg3n+4u6JJOJnENtGmbZjqd
ZHe+ddcVgPtmnLr6OA5DfZ7W0+ZS+8O+n4LbzwBeZZxK66Oh4jCjObdm9gqL
82deEHjF+ISzxfjeZ6wlf2MerJf8+z+6KX4Bh0aDIJ7VU+ZxLjzXCEPV29Ut
uWv1s/ar71ye8Ys0Fz3EGM6i+oOw4eNsjQ605ho1/yOMTIPobdVz8o3sfdEH
zMHFOD6fvQFbEXaS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 533->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbn+4uiKSTmbiBtLRpZpJM
D9fHcN+Y2XM3L0N9naepvi/b5XCr4+k4LsH9181amZfS78pZ3Jx3997cmWFh
/q8uI3jF7UnNyIv4Hvtf7+qt4g+zyObG6mNcOE8Rz/SkeZhrsVaFwfQOuiVv
vYbe1syzy3P7qpmTP4QYwZT+BtgW42hN8RGNuv4YhpiB4sbem+LI+Mk/UNhB
b8QrH3bXdtE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 534->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozQFWCAiBXKBEGir0pI5YH4dXRaqa2c811KJcdNHN/Z
5zSPV9sdzOx9mpY2f27DkL/347x55v566efgeTGzMU1LKr0yFjdnxbn/3F5h
GeR6X+Dhv6qV3EWsvd6wHryr+Gu9Bd1YfYwL9RTx2jzpnDDXYq17GIG/Mucw
S9SB8Ks+tjzn/9Lc55GzoLfAXnPCPIm22B/lA31DfwxDaKC4sfdRcdT4yTtQ
2GHeiJd+zH53kg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 535->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUEKwkAMDB6kV5/gF/QBi1+oL1jBngpCexBvfbotKGQnM2khu91NdpKZ
OT9e/XAws7lbl76+b9NUP/fjdnjW8XoZt+TpF2ZLWZfS7ipY3lw09/5zZ4Vl
8NbvDR7+q1ldHmtxlj3uqlb1z7gF3RwXqoXSE/p7TspPIzn0BrmquanezLek
tuFhLcaensHbRMP0HblbEFdg//PBT6It8mO6B0/ZHIghNFC9kTvl6mfJcugp
wQ5+I175AlaMdlE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 536->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUEKwkAQCx7Eq0/wC/qAxS/UF6ygp4JQD+LNp9uCwkw22RZmt9tMs5Pk
cH0M9w2A525ehvo6T1N9X7bL4VbH03FcwP2vgE+Zl5J3VwpHqPQ9PuHsuED/
xj3x8bubNeDcy7OsaXe97v6etsa3oEV64fyk+6MmlycExtmwVje39Fvl1ulN
OpA51vxssu14KHMTPkaOxGu4/3iTp/BW6WPPoDh5DhBuPHB3s3aplWaxGGcq
uJu8ma98AWpIdxI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 537->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDxIrz7BL+gDil+oL4hgTwWhPYi3Pt0WtGwmM2lgkyaT7s7O
5Px4df0BwNQsU5fet3FMn/tx3TzTcL0MK3j6BTC3y9TmqwuFI0R2HkfYu1yg
f+Oa5ePvCtct6C5z2evd3XX1lRaWX+hFauH0pPqxJ+cnBBb1cVxdDuV34Vvl
buGR8KXWR+ZtRUPpm9CRddjz548XfnIdGk4zqJzMA4QbDVxt7l32Slxq2Kxy
8BtWtbezLxeXdxI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 538->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKgzAQXDyUXn1Cv9A+QPoF+4IU6kko2EPx5tNVaGUzmdkENjGZuLsz
k8vz3Q+NmX3O29Sn732a0vw47ZtXGm/XcQfbX5gt3TZ1+aqC4eYiO/fD7VUu
g3/9muXD76DXI+Au9lLjru6q+kwL2Z/jQrVQekJ9z0n5aQTz+qheVQ7md+Fb
cLfwiPgS8ci8DTSkvqn6vseKP3+88BPrwFCaoQcFP8gRaaBqI3fK1eE1bGE5
8A2z2sfZCjPQd1M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 539->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszggrjyBL8ADJr4wXlAkdpqENA6IG09nk6BKnLhApbTr3Dqx
09352g8rALfNPPXlfpym8jitl82ljIf9uIDbdwDPbp46v6rIcJhw/+0we8UF
umtXx8ffjVpr0Fmu5Zt2dVblz7yQ9RktqRfKT8pvNal+IsGsP6rWf/od+ib8
DDrgOZp+JrW3PGzeE31wvIL7g4d+ch4ewjPuQdBHHnHOX3PXVWk1uMRMHYEj
ecMBr1wvYe120w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 540->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AQCz0Ur31Cv9A+QPyCfcEW2pMg6EF669OrUJaZ7MRFYVzXrJlM
4vU59u8TgLlZb31aumlKn8d527zScL8NG3j5F/Bt11vrV1URDlPuvb3MXnGB
vrWr4+PnHa256Cxrqc2uzqr+kRdSn5kl9EL5Sf3tTCpPBJj1R2k9kneRm/Cz
mAOeY9dP0p45K3lGM3N/p7GSj+sfecm5ERd7xhkg0gHCgzO13nlVsxpcYqZX
wRH8wwWeuX7ObXeU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 541->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF+wDgl+oL0ihPRWEehBvPt0WJOxuZlIMbNJ0tzOz
s70Mj346AHie1q3Pr9uy5Pf9uF3GPHfXeUuefwF80rolf6pgeZhw7+0yd4WF
8K09HV58bmgtEWqjlr3eVa3iZ15IfaYX6oXyM/DbntQ8QXLWH6X1n3lXcxN+
Vn3AYzT9DNoL5s48Wc+Rv9LYmI/jZ14yHMIR9TtMgOIwzionuEt9Cne7WvzK
L4JN+3D/wBdGoXhV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 542->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAUHFxItx7BK+gBgleoJ4igq4LQLsSdR7cFKe8z02AgSZOXzsyb
9463Z//YAZi6eenr6zKO9X3dL4d7Hc6nYQkefhP4lHkpfleTxWGmu7fDnBUW
wr92d3jxu6F1fW/vgpZW7uqt4mdeSN9MLtQL5WfgtzmpetI6GX+U1n/qneom
/Ex5wGNs+hm0r5iNeqqesPxJ40Z9HD/zkuEQjqjfYQIUh3GmGBuqd1SPqRjL
JfjKeizhlS84gXkU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 543->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwijiyACJj8ssBjS9yDSKeehsAm6Fq0cWQ3MLPr+huwOb2YTCCZca
dL9gDQtc4YkW7sh+gtM47MQQQ7KfmDSAL74x4g2bGdj8wYBqBt7wxBL++MKQ
UJpAth/DjXjiB8V+HGGJDeAKM/T0huJOLGagpwMMOWwAV9rBlcZwyWHzC1q4
YktjGObZAwDYFHiU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 544->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYg3n+4uyJJOZ1oDabZJN8lM
crg+hvsGwHM3H0N+nacpvy/b5XLL4+k4LsH9T4FPmo9UWqcqjqCFP0q4u1yg
f6Mt8vF3p9f1ffRRLy1s3IfK3ePJvSmwGG6454jFYVqtqVn5UGLq7UBr3tXc
VA6FA/ifT8F/xNCdZzL1IXoMvTbrGy6VOM5435gXzsF7UMWUuN1xO+ZiCgvx
qnasype+mBh4lA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 545->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwjAQhR8uxK1H8Ap6gOAV6gki6Kog1IW469FtQcrk9b1EByYhmWR+
vpnD9dHdNwCeu2np8us8DPl92c6HW+5Px3427r8KjGlaUrk7VXYELe6jhLPz
Bfob95H+F34buS6x4x3lUquN81C+W5zcm8jFseGcYy3MjLkpxvIO+GsGav1e
9U35EHUs5194Cv6xhmY/k4kPkWPItRrfsFTimPG8MRf2AVa2OaEeyhi1+I4X
cVUztvKXPr6WeVU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 546->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRYML6dYjeAU9QPEK9QQj2FVBaBfibo5uC1KS7/+TgUyZSecn
ecn58RrGg5kt3boN5X2b5/K5H7fDs0zXy7Q5Tz8zq/26OasNY371Nix3VloG
b/23wvugm+S6x/Z3kEurNsyDaWec1D+ei2KDOftakBlyY4zpncWashmgrEh8
yZXU0eqnmhXP39eQ9rMX8T0HXFl8wZItxQznLeRJNEIc1BOxdz2cLTVjysdq
EX380wm8v8jWeZQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 547->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmUWMh/uLgZUMWRxuLkE3Aq3G1kMST8hv6G7A8NsIsIJ
XT9KuCEBrGGB7mYkv6CHGXq4YY0TXPFEQhrA6mcs9uMMVyz+wBefuNIKgz2q
nUTHpz0O+5HDAR0Qsh9HWGIDuMIMPb2huBOLGejpEF0OJ0CLR7xqsNmPZlcD
ujosaRhDHm4WAPhDedM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 548->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmUWMh/uLgZUMWRxuLkE3Aq3G1kMST8hv6G7A8NsAuHE
gEU/SrghAVz6G9DUMaC5AVv44ApjnPFEQhrA6mcs9uMMVzR/oGNC6Q49buFm
Ehuf9ljsR0sTGICQ/TjCEhvAFWbo6Q3FnVjMQE+HuMzH5heUNIRPDTb7cdmF
Fq7Y0hiGefYAOop6Eg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 549->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbgQtx7BK+gBileoJxhBVwWhLsRdj24LGjJvXgwNZNpJMu/l
d7g++vsGwHM3H315ncexvC/b5XIrw+k4LM79V4Gpm4+u/kaq/HDa2H/i/iMs
f7e8UNu83XCTXI3b29z7f7VxPhI76RPE+6pvTqL3E8WBclD9iXoczmnFDsia
BX+4M1QHa7Z3PFvDTOa5ZicaSeYPwq14SKKeee4mT4EhuQW+qkXWrmIUP+fO
cWKHG79hfQDcp3rR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 550->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmUWMh/uLgZUMWRxuLkE3Aq3G1kMST8+v6G7B6vZBMKJ
AYt+lHBDArj0N6CpY0BzA7bwwRXGOOOJhDSA1c9Y7MeZZtD8gY5xhQGuuIWb
SSA+SUkTGIBA/DOgmYtiDxrAGg5odmO4E4sZGGGH7k5cAN3t+NRgsx89vtHV
YYk/DHm4WQAzJ3mQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 551->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQXDxIrz7BL+gDil+oL4hgTwWhHsSbT7cFDZvZmYQGNm12m9mZ
6R5vj2HcmdmzW7YhvS7znN7X/Xq4p+l8mtbi4Rdmn37Z+vKpgtXNRcj/l3tX
WP6ceVmZ8/mMW+FU8PA5K/Fa2v136Jfqjz5I3xpcgg7UIvxRHsv/tGEGqGbS
X84M6MBQHihPMmblDvUS/RMzorDDnBEv2aI++HtGeBKMmn9Ug+/X0Ip6Qh15
gI7gDdYz1hfB3nlN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 552->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GJs8gz2qGSjiMIDExmUWMh+mDkU9A6o4utuxuQnFHchiDKjmEfI7sroGdLOJ
CCd0/SjhRsAtGP7AEWfo4YMrjHHGEwlpAKs5WOzHmWbQ/IGOcaUHfOGP7Aec
9hJKEzjSCC6zMdIZlrDEBrCGA7I+BizuxGIGvvDD6gdk+wj4Fd0/GPLo7kDz
B0bYoMvDzQIA5dx4zQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 553->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GJs8gz2qGSjiMIDExmUWMh+mDkU9A6o4utuxuQnFHchiDKjmEfI7sroGdLOJ
CCd0/SjhRsAtGP7AEWco4YMvTnDFEwlpAKs5aPGDN82g+QMd40oP+MIf2Q84
7SWUJnCkEVxmY6QzLGGJDWANB2R9DFjcicUMdDvR4wUvIOBXDLPR5dHdgeYP
jLBBl4ebBQDoKngO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 554->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GJs8gz2qGSjiMIDExmUWMh+mDkU9A6o4utuxuQnFHchiDKjmEfI7sroGdLOJ
CCd0/SjhRsAtGP5A8gs2PxGME1zmkpAGsJqNFj940ww2f6DHEYnhj+wHnPYS
ShM40gguszHSGZawxAawhgOyPgYs7sRlBprb0cMNJyDgV4x4QZdHcgeGOmxh
gy4PNwsAJsV3Tw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 555->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GJs8gz2qGSjiMIDExmUWMh+mDkU9A6o4uttxuRVuN7IYA6p5hPyOrA7DbCLC
CV0/SrgRcAuGP5D8gs1PBOMET/gQmwawmo0WP3jTDDZ/oMcRieGP7Aec9qL5
uQGLfmxpBJfZ6O7FFpbYANZwQNbHgKYfizkN6HZgiRe8gIBfMeIFXR7JHRjq
cKRNrObZAwC5wHgQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 556->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GJs8gz2qGSjiMIDExmUWMh+mDkU9A6o4uttxuRVuN7IYkn58fkN3D1aziQgn
dP0o4YYEsIYFrvBEsx8lfPDFCZ7wwRfHBOMbLX7wphls/kCPI3zhic0/RMQn
up8bsOjHSCMMuM1Gdy+2sMQGsIYDsj4GNP1YzGlAtwNLvGAFRPoVI16wmYHL
nTjSJlbz7AEBnHhN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 557->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksOgkAMbVwYtxzBK+gBiFfAE4yJrkhIcGHYzdGFKKZ9vMdgkzJMP6/t
6xxvXfPYmdnzMH6a9Lr0fRqu++lyT+351E7O6quj1B/N7lTK/FZHjGCfxf0r
LH+f40K8Rbuqi3gG8Rn6Ks2GfSywN/CE+YE3J5QLxSfUD/yonVjEQ35KPBSx
2d7Efhdz4I7W+CT8/7VP/8Ygn70RhY39Mi6ZUB48Hwb5BCdjDbIXKmuzWvTJ
+mpO0Qut/bO9AXwVd0s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 558->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXn2CX9AHEL+AL1gTPZGQ4MF426cDiZJ2dsrSpAvb0mk7
w/kxdK8GwPs4H1363MYxfe+H5fJM/fXSL8nTz4Hczkfrn5GrPIwX8b+Z9wjL
3te54GM2HvVlPND3meaq7cZzFNg7eOJ6x5sxyUXEJ/V3/ESawOMxPzUeqthK
t0DfYg/WaItPmp13q+pp64gb9Y9E2IyjuFQmebB8gOoFTuYeQhdpW7vC58L+
0Z7BLLL3GpsA/6Z3TQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 559->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDil+oL1hBTwWhPYi3Pt0WtCSzk9RAtt1kd5KZ
7PH27B47AGMzL115XYahvK/7ZXMv/fnUL8nD14GpnZfWfyNXeRiv4j8z/xGW
3a99wcdsPKrLeKDzE/W1xY37qLD/0InvO92MSS0iPam+0yeaCUSM4lt8Umw1
N4WnePCMMj2pd8Ut0jB9E8EbibBd/UBLnrHTRtSoMG1eYfBdpbO1jCt8Lqyv
eCoeGc819gEG43eM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 560->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmUWMh/uLgZUMWRxuLkE3Aq3G1kMST8hv6G7A8NsIsIJ
XT9KuCEBbOox/IHkF2x+whsnDFjE0MQJ+Qev2djiDZt52PyBHkf4whPN7dj8
ho1NME3gSCO4zEaxH0dYoscxSthgsQPDTGR5bGagq8EWzsgAn18ZUOVw2o/N
n9j8gc+fcDEAM3B2zw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 561->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB6K1z6hX2gfIH7BvmAL9SQU7KF469NVaJdkdpJ1IatOzGRn
spfHaxgbEXm32zakTz/Pabmf9o9nmm7XaU+efyHy7bats08vWF5UFPh/qXeP
y+SEYxrPvJWz5t4aU/U1bXiOgvuAT1hvfFOLeuH5Cf2NP95MhGCA1/SE3Gxu
jI/pwBlFfsLZmbZwnrof1LM74nGbesdLnLHxhvQoOHWeceA/zGe9Iq1ic25/
ppPpiHRmbAWpW3bR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 562->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMtPqo+DJCV2gHQF0BJkil8opUCR6oP0YvSDQ6O+eESAlwxmff
ObfXpx8vIjI329GH5TlN4Ttc9493iI973IPtsUXWbjs6/fQ2iwvsDP8vePe4
VEw4hnjirfSaaiMG+TVtto+M+4RPNl/5Bot64flp6it/vJkIwQxe01PkZnNj
fExHYZ6sZ+ydaSvOE+uZfHZHPG6V73hpZ6y8ITUyTowzDvsP85ktptXE3PpM
J9NR0pmwH3q7dxI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 563->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNgzAMtXqouDJCV2gHQF0BJkilcopUCQ6oN0YvSDR6dl4cLDkBf579
7Nxen368iMjcbEcfluc0he9w3X/eIT7ucXe2h4qs3XZ0+i4p8wtoZv8LfJew
lE+4De0Jt9Jrqo02yK9xs31k2CfmZPPV3EBYfsYDuDBO7k6E2CxOhY+Lzfbm
xCoezj5ZzzgTxs3dJ9Yz+eyNlLDpzCGW7VjNhtRQPZk+KYaNYe+FCeNqfKwv
t5aN93gm2w8xvXaQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 564->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQHVxItx7BK+gBileoJ4hgVwWhLsSdR7cFDS8vbyYNTNK++b6Z
Od4ew7gzs2e3XEN6XeY5va/79eeepvNpWpWHn5h9+uXqy9cTpTeQCv8f+PZi
FTrTGOI5bqPWnBsx8G9x4zqq2Bv6xP5F3+Ao/4oHcFGcwpmYwDiOM8vmvGk+
YV8VDzETt5/kp7iF88SdIH+1I15s2XOwZQztvRxFTcK3isE2al/UUVxJp+oK
c7F9xDNjX+57dhA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 565->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRS0OiCsjdAUYoGKFMkEq0VMlpHJA3BidVmqL4zzHkZK03/aP
v+2mf3bDQURep/no0vs2TelzPy4/jzReL+NiPK9b5NvOR5vf3ia7qF3g21Lf
HldmE8Y0vvMGue5va0zFR9psHsQd1cnzyWrk1KbQobSQpmpPBDDLE/S9yk19
Iz7SAT1x62niSFu1n3omTDzNiMeNNVe+FtP+3htZThBbcFgfmhdapNXYKC/S
QjlEtfxjP0eQdhI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 566->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmUWihwDdjFkcbi5BNwKtxtZDEk/Ib+huwOb2YTCCZca
lDDCETYY/kDyCzY/4YtPvPFERDgQE98Y8YbNPGz+wBInOMMTTR/cTGLjEzlN
oOnHlkZwmY0e5tjCEt0ulLDBYgeKm7DoxTADXQ229IINYPMrmhw2d2HzCzY3
EApLhBgALp120Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 567->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmUWihwDdjFkcbi5BNyKTS2yGCG/obsDPbzQ5Qj5DSPc
kAA2/eh2IfsFm5/wxSfeeCIiHIiJb4x4w2YeNn9giROc4YmmD24msfGJpB5d
P9Z0g8Ns9DDHFpYY5jDgCAfk8GDA7k5kgC3+cNqNDWDzK5ocTvux+R2bP/D5
Ey4GAOzadhQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 568->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmUWihwDdjFkcbi5BNyKTS2yGCG/obsDXS26HCG/YYQb
EsBqPq7wRAt3lPDB5Q588UREOBAT3xjxhs08bP7AEic4wxNNH9xMYuMTST26
fqzpBofZKPpxhCWGOQw4wgE5PBiwuxMZYIs/nHZjAzjSIFY5dDVY0htWf+Dy
J4pZAJvAdhQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 569->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPoh/e0RvIIeYPEK9QQr6FdBaD+kfz16WxCdZCeugWzZPGYz
mR5vz/7RAJja7ejz6zKOeb4e9ss9D+fTsCe7twNL2o5kv5GrPMhNnI3uEZbJ
Qcc4/sGtzKpqOVbj5ufwtT5X41bsjUzic73jojj90lPqlL6YtT0syb6vcArd
FJ7iITQJ9+n6eK6/9GQe0LzMjAG26Q92WeAg2APvA3pONqUf51SPseAflDlf
E73leUQ8DdYK2A11Vw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 570->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDV0Utx6hV6gHGHoFe4Ip1JUg6KK48+hVKPUleXEMZIZJ8l5+
c3sNbXcRkalajzZ/HuOY5+d1e7xz39z7zVn/VGRJ65H0HSnzC6iyo8A74lI+
4Ta0/3kLtbJYtJV6s3XYeVlfqTc3NxCGt7mwF9bT0T7pntLOWZrDknR+xuP2
xvhYH2Qn4TwNDus6tc8zeKwx4Fb4YJaOR45zOE6DdRwkxuVmEvxB6rMxUa7g
LzHcbvsCY8R2Fg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 571->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfwCnqAwSvUE4ygq4LQLoo7j24LIi/Je50GMmHyz0tO
91f33JnZeJifrk7XYajv2375PGp/OfeL8fhjs0+Zn+KlYmY3YKdHgr/K5WzG
daj/5230ynxR15ot9hHxirbWbAk3IBYfa6VZGD6qD6UzHZP6EbgjFmqWdBsl
SBP+KzeHNTfvc0s86XFt/26famewI4lDzBnxiTmIT6rNSNwgtUUfVYtgRed0
ub5blHbX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 572->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKAjEQLDyIV5/gF/QBwS+ML4jgnAaE8SDefLozINJLVWJDJ6R6r/Th
eh/GDYDHbjmG+jzPc31dtuvjVqfTcVqN+68C77Icxd9KmR1GHW7FvFUuZwPH
LP7L2+mV+VqsNRvrLfIVbb3ZEm9GWHyslWZh/Kg+FAYdk/oRvFsu1CxpN0q4
IfwbO2dr9v4Tf8TTvRG5Xbzgks3IuLf105+HPWnmQMCjkFrUp1Vf1SJcUS5d
rg87DnfT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 573->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfXQhbnsEr6AHKF6hniCCXRWEuhB3PXpbkDKfNxMNJCFvZt58
Xk73Zz80AF7H9ejL+zpN5XM7bI9HGS/ncTO23w3M3Xp0+o42s0Nshcsl3hGX
soFjEt95K7UyX4llvbHa7Lysrdabm5tYLN7mcr2w+UR1RBjiGKpDwuP8A76d
R94I/JM/J3PW9MQP8e6PkLqY/krPRGM7GzcHpvk/HDA46cPmoj5Z/igX0YHq
rbgWChZ3Fg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 574->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWF0tXCAxG/AYReKHAN2MWRxuLm43IruDhxiuNyDz9/I4YUrTIgO
NySATT+6XRh+weIWXPGJNZ7sEWYSowdXuCObg8svGGnDHguNJy6xpTm4n4mI
TwYi9GOkEQbcZqOHObawRI9j9LDB5n+MOCfFDAY0cSz+QLcLqxp89uOyC0s8
YI1vFLMAasJ2lA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 575->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWF0tXCAxG/AYReKHAN2MWRxuLm4zEN3Bw4xXO7B529kO7GGCQ71
WMMNCWBTj24XLn8juwVfmGAVYyBeD7r92NIBvnjGiBN0GkdYEQp/YuITRR8O
/RhphAG32ehhji0s0eMYPWyw+R8jzkkxgwFNHIs/0O3Cqgaf/bjswhIPWOMb
xSwA+c520w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 576->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWF0tXCAxG/AYReKHAN2MWRxuLm43IruDhxiuNyDz9/I4YU1THCo
xxpuSABrWKDZheEXLG7BFZ9Y48keYSYxenCFO3I6wOZ+rGnDHguNJy7xhT8x
8YmiD4d+jDTCgNts9DDHFpbocYweNtj8jxHnpJjBgCWc0fyBbhdWNfjsR7ML
mz/wxjeKWQBzmXeU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 577->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQXDwUrz6hX2gfIP2CfUEK7Uko6KF48+kqtLI7mYkNJCGbzezO
TM6Pd/eqzGys16VLn9swpOl+2g7P1F8v/XbZfKfZ3K5LG3c1f/kh5ibm7sOd
Z1Er3BmP+fiOq3rFPkRM9VPi7fWimoh8qpsbVAuolXEhvSg/kXPAPegVMSgO
0YTieR64H9SXnP/wM7wT77M/YhobNWdaosdBG6YD87yEQXIyfOCBtWhOqT7U
Yj4W/Q5YC8Gzd5Y=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 578->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADKr4wXlAkdpqENA6I257OJjGUuHagUtstSZ3a
7uF67/qNmT1289LV53kc6+uyXX5udTgdhyW5/0yzqcxLibuaa32IudnE1+G+
J9Er5IzHfPyLq+5adK2PqftkvL1eVBOsz3Rzo+FPenkuLJ/5iZwDbqKDEQyF
jZpQPM8D9x/9lf7/+BnOifPNGzGNjZozLdHjoA3TgXmeYZCaBh94YC9ak/WH
XszH1O+A9Qahc3ZX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 579->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUsKg0AMDV0Utz1Cr1APMHgFPcEU6koo6EK68+hV0JJk3osNZD5J5r3J
y/35bvuLiEzVurR5bsYxf7rrdnnloX4MW/K2u8iS1iXZnflRb2LKi/hh6rwQ
LpMTHNPxHy77a+K1Osb+E/Wt9YKa+PpIN2VF/4BL94Ly0Tx9zwY30EEABsP2
mkA83YffT/iZ/v/M07xLMX9hZ/xESz9jo43Tgc48wgA1BT4ypAPKIX7HhXQM
522wvliHdlc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 580->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRiwR9ANOOxCNhvuLjQxFLNgbFxuxaYPixgu96CbgVUcT5gQ
HW5IAMP/WOxC9gs2eXzxie5nFHOJCAdkM3CZjR4m2MzFiEsccYIzPLH5mZT4
RA9/LP7CAITsxxGW6HGMEjZo4YAzzvGZgUUNhvnYALZwwCaHzX40u7CFI0ba
wOEPBnsA/T51Fg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 581->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRiwR9ANWOxiQDMb7i4GPGbB2LjcimQWulpkMWzuwWYGVnE8
YUJ0uCEBDP9jsQvZL9jk8cUnup9RzCUiHJDNwGU2RlziMgM5LnHECc7wxOZn
UuITPfyx6UcHhOzHEZbocYwSNmjhgDPO8ZmBxQ8MuPyARR1WN+IKH3QzGHC7
AVcaw3QPAMdydNM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 582->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfEbU9nkygkqV1GpbRbljmx
3d351l1XAO6baevy4zgM+Xlazy+X3B/2/fxx+w5gTNOW/Kmi1LuciSpfVvqe
I+mFgP2ZCw2s8qxmNVix1ubYPAyD5huaLNbNrIo/6WW5KA2Vn5Gzw12gg8Vo
YTsu4h45L4UnUk/G+R8/o/7s/7h+9RdaRo+dNkEH6XkLg3CA4kDq6IxKn4gB
PYO6Y/U8L06udlM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 583->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszigXXkCX4AHVHxhvKBI7DQJaRwQtz2dTaLQuHG0SGm3NPNi
u8fbox92AJ7dsvT5dZmm/L7u15d7Hs+ncT08fBOY07Iku6ss/aZWZVMvkf77
7PwLhP2bCwFWeVazVljcW9e8eTwMry414f5Ityoa/uQNc1EaKj+Zs8HdoEON
EWEbLuIeGS+FJwrD6AOfW+gn6+99z6FwyCvWkj022pAO0vMIw+EAxcHpc2dU
+jAG9AzqjrXzfAC4KHZV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 584->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQXPyQ/noEr6AHCF6hniCCfhWE+iH+9ei2YHQfM2sXNmk3y2Rn
JvvLvb9tROTRzUtfn6dxrK/zdvm51uF4GJbD3SdFpjIvxe4sW7+pqQz1FuW3
T+AucdjfuSTBat9sVoXle3UNzYMwUJ1q4vsz3VQE/s4bz4VpyPz0nA3uCh00
RoZtuJB3ZLwknjAMo4/EO//66e8F2oRI3lbwM/HYaON0oJ5nGIgL4wD64IyA
D8QQPgN7Y3GeN+J2dlc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 585->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQXDxIrz7BL+gDgl+oL4hgTwWhHsRbn24LRjezM6ELm7SbZbIz
k+Pt0Q87M3t2y9Ln12Wa8vu6X3/ueTyfxvXw8E2zOS1LqneVpb+quQz1Eum/
z+QuA+zfXNbAKt9qVoeFvb7G5mEYrC41wf6Wbi4Cf/AGuSgNlZ/IucLdoIPH
oNgW+VI8z8PvZD7FI3BueBT8xHuZnhiNtxX8bHhcaQM6SM8FBt7puVAOpI/O
qLARw7Se6o3FeT5RMnXX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 586->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEXRWEuhB3c3RbsJrfiw1khqaZl+S9
7C/3/rYB8Oimo6/P0zjW13k7f1zrcDwM88/dx4FWpqPom/mSr2LCXXyx8rtb
UMu+//aFBAv+na3fSK6MRf1EGGGccWLzM96EufmDWnIWxyF8f7YPqtMKHiRG
hq1mIXuktCSaMAzFD3zNv3raumQHlSW75fRMNLbcyD6o5gTD1pSzhDOQmR0+
w7YY4HyyHfP9vAFzv3YU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 587->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpA/XYEVoABIlZoJwgSvCohlQfil9HbShQc+840UhLFie98
5xyvj/7eiMizXZY+vy7TlN/DYT3c8ng+jetl95kiJS1Lqnc2t/dVTE0X30b6
7QVw2fxvXRJgic+z/MW8LVHsDwaMM0/EaIt8U8PpB1xaN7qP+mk1V7g7fNAY
EIfoR/5UvQR1MH7mP+tRlOf4UY2qVva3XD+DHltvdB205wTDcmotUAPR7PAZ
tsUQ7if7Y76eGcaAdlE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 588->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpA/XYEVoABIlZoJwgSvCohlQfil9HbShQc+840khPFsc++
c47XR39vROTZLlufX5dpyu/hsF5ueTyfxvWx+5hIScuW6pPZFl/5lDn/ttLv
LKCWzf/2JQGW+Dxbv5jYEvn+YEA/00QMt0g3tRx/UEvzRu/RPC3nCneHDhoD
4hD+SJ9qlqAPVp/pz2YU5bn6qEfVK/tbbp7BjK02ug86c4Jha2oukAPgBGMZ
tvg705P9Md/DDMAadlM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 589->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDV2I2x7BK+gBBq/QnmAEuyoIdSHu5uhtwWomeS91IDM03/fy
ero9uqERkedxubr8uk5TfveH9eOex8t5XIPtx0RKWq5Uv8y2/MqnzPm3k35v
AbNs/ReXBL3E19n5xeSWyLfTA/pZnRhu0d7UcfztLMDbxiM9Leeq7x970D1g
H8If7afSEuBg8ylnolFU5+YjjAor+7ecnoHGdjcaB9Wc9HAcFBfIAXCCuYCP
i2scAYY9HpJmqrx2Uw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 590->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQXPyQ/noEr6AHWLxCPUEE/SoI7Yf4l6Pbgq37mImBTdokOzuz
k+Pt2T92IjJ189SX12Ucy/u6X37uZTifhuXw8A2RqvOkfmWx3nd7JtL+OvS3
VlAr5m+8pIElOS/Wr+Su3UN8EAbTDPMk94H2zYykP3gTtaDzlp9Rc8T91weL
AXGIftQf56X671b9qG/jDTyifiqpjzgaruxtJT8bHsfeWB7Uc4LBNER+dLC7
QE86tzwIF6bTY30AaDV00w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 591->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADFK9QTxDBfhWE+iH+5ei2YHWzO7MubEKSfczs
5HC998MGwGM3L315nqepvC7b5XAr4+k4Lo/7jwO1m5eu3ZWv8c2d8XC/Wvfb
K+nl87+4kNRCzPP9q4i1dwzPP95wnsWD5Dc1jAX+ThvPJTgcd4Ir00nNwWsj
9Rb82XwoD4KP8iCzZRrJP2F5gPcOlvytoGeisZ+N7S81FzUCB6JDaiqW8Anv
FofAoni2td7drXTT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 592->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhPRRv+3RbsJqdZLYL2dAkO8lk
erq/uucOwHiYry5P12HI79t++Xjk/nLul+Txa0BJ85Vqr2ytr2LGXHw96e9L
0Ivf/+ZCAwv+HfcvotbGonm2eIOsVY/gfYVhjuNP2jAXBDgtPZkz46o9sDZS
b8E/2k/Ig/agMHgnEbcWD5h69m5GBDmqcXo2NObd2P5Sc4HBPfmf3DyqNsLm
PM8BuFkUzxrrAw1DdBQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 593->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbgQtx7BK+gBBq9QTzCCrgpCXYi7Ht0WHEze5MWBTNp830vm
cH0M9w2A5265hvo6T1N9X7brz62Op+O4OvdfAeayXMVrJS3e2Yx09nbKT8+i
F6gPTL+wVvtWWG0tirU2hSfjDRLV22KXc0OPx/FW82SBzwtnjMAmcv/uRvDh
eYX1FA/43Oyt2JyIW8YDJp51hxGBj2K6fWY7ptnY/nLnogb35DeZniw2qs1+
xgF0WBRPX+sDoO9zkg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 594->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbiQbj2CV9ADDF6hnmAEuyoI7ULc9ei24GB+Lx3IpM1k8t5L
5vx49cMBwNytW1/ft2mqn/tx+3nW8XoZt8PTz4ClrFvRnlnLVzFhLt5W+fuF
YMHgQOCFtdo34yprmVwZY3wy3TDGsCV32jd4Pko366c16HthjxHEyN3d2RA9
tl9hvUiHWBm+6z9ibZkOiHzlEXAUXNnbcvPMZmx6I/HpzEkNi2nfZLqy3D38
SDvguDCdutYX/c5zlA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 595->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfbgQtx7BK+gBgleoJ4hgVwWhLsRdj24LFmfmzUsDk5BkMu8z
Od2fXb8D8DrMU1ff13Gsn9t+2TzqcDkPy+XxF8BU5qn4VcWa785M0Pk6yn+d
BBYCDgweiq/h6iqutlbItWeKT0s3Qihs64P0Dcwn6k79jAH/LvUYfEdvBVfq
jdATa6T+ZDrMaOGT/2BtEjdqTv4UcTRc1d+ifrZ6HLyx+LLnokbEjH9yc6jc
LfxMO0BclE5f6wvvoHLV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 596->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfbgQtx7BK+gBileoJ4igq4LQLoq7Ht0WLMy8N5MMTNImk3mf
5PL89O8DgOm0Dn2Z7+NYvo/j9vMqw+06bJvnfwJLtw6dn7Pc692aSVnfw3wv
CRYIBwYPth/3bXCNau1axqemG5SRJ+xD6huUD+sO/eSEPxd6DN2TswlXuZvk
vrlH6E+kw0QNX/yHaktxWXPwpoSj4Sp9yHMQj/COoZ45HTWe1IMx+U02I6tt
4UfaAeGS6fS9fny1chg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 597->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMHFyIW4/gFfQAxSvUE1TQVUGoC3HXo9uChckk0z7Ie+37ZD7J
6f5qnzsA78M0td3nOgzd97affx5dfzn38+HxH8DYTFMTVxfL/bBHkfaXQd+j
wYLggPDA+TSv48q55C7vOT5ruiHhsNkH6xsyH9Vd+qmB+K70GPksvTVcw90C
I9QLtReBh+qgseZn8h9Zm8WtdPCKgiNxdb1V9aitsXjD+LbmJodiak9ujq0+
dPiVdiBxcTpjrh/YLnDX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 598->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksOgjAQfWFh2HIEr6AHaLwCnqAmuiIhwYVxx9GFRMzr+F5pMi0M5X1m
5ngb+0cD4NkuW59fl2nK7+thfbnn4Xwa1o/dN4A5LVsqTxfb/SJH8ZffFj3P
hguBB8QHxou4Titjhbucc3pqvhHCcXMdbN1oRb5Cs/ACgVPrJ3tWuLUeF3cF
h8OQ9VE+RB1qs8L/RW+WV/ngE0IjaXWzpWbU9TjWhvltzw1G5PydzoPwJDXu
8SvvRsOeD6QPmqtw2Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 599->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbn24LFmaTSTaQzXabZmaS
7en+Gp47AO/Dsgz1c52m+r3t14dHHS/ncX15/Dswl2UpbYx8y2/OyN35ZrSf
k3zGQfH5zhLO4Foml88Ufk83jEfY3Iewb2SOu90bLRB1snmyZlU3m3GTKzCi
GrI/SofoQ1TDfme1hbhKB0cIjsQ1ultunsmMbW8YP5x5UMNiWq5dizj28JV2
mCj+AaUD5Qcv4nAa
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 600->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0sKgzAQfXQh3fYIXsEeIPQK9gQRdCUU7KJ059GroDB5eRPtwGQ0TuZ9
1Lp7tcMFwPu6LG38PKYpfp/VetPH8d6M68PblsAcliWk1cu9P9kzme3vYa7n
Qr/FQaB+FQXOUBzsfBDmH7pBqbDZh0N+8M9LPznJX6XJalZzS+846RUY3gzp
j9IhfPBm8DnW5uIqHbZCcDRcsznkOYiH0ub1877keWJGgl8K5/vJ+Ct8pR1U
xT+gdCD8AHoUb5o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 601->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfbiQbj2CV9ADhF4hniCCrgpCuyjucnRTsDB5eRM0MJk2mbzP
JOf7Kz4PAJahTDGt4zyn9+24/TzSdL1M2+bpG0AOZQp19mKvr9ZMNOv7MN+5
U295EKhejY5mKA0WH8T5h29QKO6f+4ZWj9KlvIBxxBnWoWqqu3G0ZuKR2AJD
9kf5QI3R7SedY28ur/JhM4RGo7XBsZ6de/A41J5dlzqpRx4+65NDvR8+7/Er
L6DM9+X4QPgAoORwmA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 602->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfbiQbj2CV9ADBK9QTxDBrgqFuhB3PbotWHh5fRPqwCRtOp33
mZwfQ9sdALyaeWnz+zaO+XM/Li/P3F8v/fLx9EtgSvOSyj3Ktb44o9ycr0HP
U6WecZCk3kWFMxwH7g/B/EM3pL/D3u0bhfUi8tPw0Dk6Hq6mmE1FD+PY3qaH
89XqMD6Efhr/WVuI63TwDsORuG76sOZgDqotqtdzy3NHjwK/Fu7+6P8RvtMO
2XVegQ6kLwnNcJo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 603->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+KtT7cVC5PJbKwLSZpNOrMz
m8P13nYbAI/dNLXpeR6G9Lps580t9adjPx/uvwMYm2lq8jUay/0sR6PIL0Hf
Y8AF4QHxZVgclZrhamB8COcfuiH4jnu1bxTWi8hPU4f20dXh7jD/Lz2R7xGG
89XqMD7U3or6z9pCXtWsK0yNVGuBw5qDPqi26L7mi56vxMj4a+Hej/7vsGUf
+qn9cjif3BsFl3Fb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 604->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEQC36Ivx7BK+gBFq+wnqCCfi0I64f459HdFYWYJtWB6WvazCTT
zfHSnxcArqtp6MttP47lfljOm1MZdtthDq7fDjy6aei+5+QuDvLq/GO0Tli8
5zcVFlujZrgaGB+Ss4WDzFljllu4o7ysFklPU4f20dWh/dLe/OKTdE8Y9s84
HkaH1l9R/Zl/zKucdYapkWqtcJhz6INyS/dVj6rn/2Jw/pa5/6PvHbbso57a
L4fzOnsCo1VwGg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 605->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgjAQ3HAwXHmCX9AHEL+AL6iJnkhM4GC48XTBiBmGmeImbdltmc7M
9nh7No8iIvpympr0unRdGq6HObmn9nxq583qOyLGeprq9eqG2g8Ym/oS8O2w
MP/xCoGFkeEcigPgL7WcNuajNPOe1GbOsC7phfNT8OA+Kh7cL+7Nnh7nu8OQ
b4Z1UOz6KfxH/fZe1sxrCI7AdYODmk0fnD4+v/JD9fxfDLw/F+r98P8Km3Lr
J/dL4Xxqb8w/cNs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 606->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOgkAMnHgwXn0CX9AHEL+AL1gSOJGY4MF44+lCImR2ti3apFvY3U5n
2q3aR9MfADxP89Kk120c0/t+XH66NFwvw3J4/jow1fNS59Fz6xzi2f5q9O1h
ZbmQyFhsAWdYHAh/3Yu0KR9TM+za/+RHveHZqJYCx8hRHjornc2eHq/vHob5
ZlSH2G4/Dd2s362rmjXC4EhcCxzW7MzB0+fx92bzMwbXjyx4hxs+39Vc5QEU
OibVYfb1AxdVbt0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 607->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwyjiMIDExmYWhl4GNBrZLGSAx80M2NyAZD5MDJcbGrC4B6ufGbDb
TYp+QmGDNTxxYHzxiUstsv2E/IMr3FHchsMvWNXi0YszPNHDD4nGay+6n9Fp
JDMwADZzkMMNzVycaRCHepTwwKUfCeA0A58f0PyDKx3CzUdzNzY+zvBEjy9s
5oDFANAgbhg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 608->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXHmCX9AHEL6AL1gTPZGY4MFw4+mCEdN2Z1aa7Ba62+lM
u8fro79XAJ71svXp1Y1jmi6H9eeWhvNpWA+b7wLmdtla79Vi5wjLxTcz3wwr
y0XwFstagTMYB4O/xRSHmfChmqFrq77F/H+9of2MZ2SOxboEl2nN+Ii+O25C
i7qrcnf3z/hi3ag5eoORGcOxfQu48g2K+z/P5kpMYpQ0BD3qHWb5Yk6OB9Hh
5sVwPrE3/NduVw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 609->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAUHFyIW4/gFfQAxSvUE0Swq4JQF+IuR7cFlenLTOKDfJq8N52Z
l8P13g8bAI/dPPXpeZ6m9Lpsl49bGk/HcbncfwaQu3nq1qsb6h40ivNv0F5h
xfofLwgsjgpnEFbM5TPHIQs+SnO8k3oqnnE0fQ5aIPBq/YTJ5f87PeyF7Ddz
a2kJua72b/9obXmYTR1zyJGXwV75FnCLs6DP8Zd9FWExahqCHvcOi3rTpxUP
oaN4u9LXN1wxb9c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 610->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUsKwlAMHFyIW4/gFfQAxSvUE1TQVUGoC3H3jm4rKum8mdgHeZ8kbzKZ
7M639roCcN+MW9s9jsPQPU/r6XHp+sO+n4LbjwGlGbdmfjpTcQSr/N8V7gqL
//94QWDFlXBGwOLc6HMciuCjeuZY1o/7n2lj9aS58VvhwOTG+q6f2Iucd+S2
tBeea5Kf6hfOf3VlfdKgMC+DPdONcCsfaeP4y7mKZTGA9F+Vo3LNTNXb6rlk
3m/fC/eQcBY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 611->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmYWun64uxiwmIUM8LiZAcksdLXIYvj8hu4ebH5Gl8Nm
FiH9+MIGZ3iixRs6H6s7cKhFtp+Qf3CFO4rbiPULerziUY83/JBoQvZitR8t
DBrQ3YXDbJRwQzMXQwwtbHC5H2u8YgE4zWBgwKsPQw02tTjiFBsfZ3gSE99g
MQBHzHEW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 612->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPoo/XaErtAOYLJCMoEL7StQSB4hv4yeBNoi6yQ5AtmJZZ9O
J92en/Z9AjBetqXNUzMMee7O+88r9497vwevXweWtC2p3D234hBO5z8T3xaW
fv/nBQNLWsAZAkvflWdRbZqPVbOOWVi195E2rp6Bhl4/kfit7k2tHk/3gtvR
Wqz9wNyRfmKv5Q3zCwyyYLYWgw+dKW08/l5vtLkYAOe1LJhD0sCIEw+A6nD7
XWCtM79xFg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 613->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3Pt0WVNLJJG4gm3bTTCeZ
HK73rt8AeOzmo6vP8zjW12W7vNzqcDoOS3L/cWAq81HWMXKVh3F3/zXzrLC4
/scLAstawhkGi7+1d1lvzEf1zDgK6299MptwnskMIz1RfC1rw1yb9bbcWntR
sWHv1Pxb9HQ9czQYzpLdmgQfd0ezifhH2rCFGID/r7JkD90MRN7xAFwfod4r
rDdVrnFV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 614->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg1AMHFwUtz1Cr9AeQLyCPcEr1JUg2EVx16Or0ELe5NME8uL7ZExm
cnnMw9gAeLX7MpR3vyxlvZ+OzbNMt+t0XJ6/Dny6fenq6Ll1D+Hq7Gfi28JS
+aAosaQFNUNg8Vt5FvXG9Vg9M46F9Tc/4KbKoV6YM9bRqoNzWRuuNaO34jnb
ixUTc2fxn9FT9cxRcsiWmC2uQ2ksuPHq97RhczEA/V/Lgjl0eYLeu3xGeldY
G2obcBY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 615->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPIo+XaErtAOELJCOoELzSsQSB8lv46eBFqQTyfXAluOZSmn
O10e8zA2AF7tvg3p3S9LWu+n4+OZptt1OoLn7wI+3b51uY+WisMsd/czc1a1
XD7I21rWCphhavFbe/evN4tD9cx1VC3OlxwF3GTvqRfmjHVUODiXtamZAcV7
hq22F+Ur5k7xrzQK9Yz+bzlkq5gtngenscGp8Je0YXM8KDwli3IZP3Tc4RB9
hHpntTbhfHEU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 616->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHoQr32CX9AHFL9QX7CCngpCPYi3Pr0tKExnJ9sNZLNNNukk
k9P91T8bAO/jcvTpcx3H9L0d1o9HGi7nYQ22PwWmbjm6rY3UxUGa+f5Cd1cr
y4dYrsVSwAyqpW/Zt9cb43A9a8zVit5oX7tzll50Zsqjw6G5yk3NDlh8jK22
F2cr9k7n73go8hn9n2eoUrFbXM9yTDidv8SNSjYHh6ckUa7ih49nOEwfId+b
WjNlbnHV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 617->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADFK9QT7CCfhWE+iH+eXRbUJjOTtINZLPdPDrJ
5HB99PcNgOduOvryOo9jeV+288etDKfjMDv3PwU+3XR0Sxup84O0evsL3V2t
Kh9iuRZLghlUS2P5ba03xuF6Vp+rFcVoX6tzll50Zsqjw6G5yk3LDlh8jK21
F7WI47P5Ox5SPnWfzP8radgtxmM5JpzuPeNGpZqDw5NJlKv1YfxmZ1wfId+L
Wl9vhnEY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 618->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYML6dYjeAU9QPEK9QQj2FVBaBfizqPbgkr65mc6gcx0kvTz
k5/j7dH1OzObmvno0vMyjul13S+PexrOp2FJHr5u9m7no13fkau8Oc9iP3Pf
/xrL65nz/KQVOJvDYq2PbfVGruyZOYUV1bCvzTmjF86MOioe/Jfa1OyA5Oe5
1fbCG3MI58n5BRqFenKfxE5kVrFbno/U2PFU8ZI2tAxf8SmZmqPCJzbeoZ4l
vVdYH8hfcFs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 619->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMMRhAYuMyiwGLPcjuwwrwuJkBySx0tchi2OzHZgYuP+MKE6LD
DQkQcgu6X9DDDD0esbkDXS963BBMA7jch+w2Yv2CTqOFA87wRA8/AukJIz7R
0xOWNIEBiEhbyO7BFccwd2LEJ5o5WN2JzQxsYUhAL4abCbkRT3jhjE988Y1i
FgByWHBd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 620->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMMRhAYuMyiwGLPcjuwwBY7MVmHrp6dDFs9mMzA5efcYUJilp8
4YYECLkFn9+R/YMrPnGpwSaOMw3gch+y24j1CzqNFg64zEAPf3Q/EIxP9PSE
JU1gACLSFrawxGYX1vhEMwerO5EAhvnY3IMPYAtHbOajm43Gxxmf+OIbxSwA
GtRwmg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 621->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMMRhAYuMyiwGLPcjuwwBI4ljdimQWsnp0MWz2YzMDl59xhQmK
WnzhhgQIuQXD72hhhu5edHNQ1KCbS2wawOU+ZLcR6xd0Gi0ccJmBHv7ofiAY
n+jpCUuawABEpC1sYYnNLlxhhh6vGHqRAIb52NyDD2ALR2zmo5uNxscZn/ji
G8UsAAqzcJw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 622->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQXHooXvuEfqF9gPQL+oIU6kko6KF48+kqVJjM7kQXkpg1mczO
7P39bbqLmY3VOjXp9xqGNLXXbfNJ/fPRbz9v/2E21+tU56sa+/ksB8Pl9oBv
hWXBO8jPBeRDroCF5zkXvR9hqJqVJtnZkm4QR1xc7aSZBfzYP/baRF72gOKH
3M7WwivpoDBYf67h0E/up6AnXJzorUhL95Zpzdi36C5iuLvMpxSRjowv/MG9
9LPkd4a1AOp+b90=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 623->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4hfqC1bQU0GoB/Hm023FwnQy020g2+40TSaT
HK6P9r6JiOduONryOvd9eV+24+VWutOxGz/u/x7xaYajmT+dT/EzDDxhk8G7
yxWiDvJLBrjkCrkwnjFVX+VwPTtNVusGVuOSeqcaPEfFQ8Uo3O6A44fcar1Q
rNPB6sn6UQ/VefI+iZ1ItmK3lJapVlR0WOJJOdK/zGfJlI6c38wH7zKOd9Pl
+WFfT3hwng==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 624->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMMRhAYuMyiwGLPcjuwwpwuAnFT8hqsYhhs5+Qv5H9jCtMiA43
JIDPLRjhiSXM0OMRmzuwqUG2n2AawOU+HHFCjFpc4YAzPNHDD81v+MIQa3rC
kiYwABFpC90d2OIYJWywhQM+d6KZgaEX3T34ALZwRDcfR/xgSzMYbsGWdrGG
KwB4OnCg
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 625->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAYyObhc1uuBwDFrOQAR43I9uDrhabXnx+R/c3sp9xhQnR
4YYE8LkFIzyxhBl6WGKNEyxqkO0nmAZwuQ/ZbYT8gqYWVzjgDE/08EPzP74w
xJqe0NzUgC6Pw2wU/WjuwRXHKGGDLRzwuRPNDAy96O7BB7CFI7r5OOIHW5rB
cAu2tIs1XAHzG3Dd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 626->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAYyObhc1uuBwDFrOQAR43I9uDrhabXnx+R/c3sp9xhQnR
4YYE8LkFIzyxhBl6WGKNEyxqkO0nmAZwuQ/ZbYT8gqYWVzjgDE/08EPzP74w
xBmWDKhmYAAi0hZ6vGCLY5SwwRYOuNyJxQwMvbj8hA1gC0d083HED7Y0g+EW
fPGNYhYAldVxHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 627->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAYyObhc1uuBwSjRXgcTOyPehqsenF53d0fyP7GVeYEB1u
aOGCyy0Y4YklzJDDFGecoIcPFr140wAu9yG7jYGAX9DUoviNmPBEDz8kmlAY
4gxLtHjAAESkLfRwxzAbzX9YwwGXO7G4BUMvLj/hMAMjHNHciCt+sKUZDLfg
i28UswCQg3Cc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 628->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAY2MziwGLPcg0VoDHzcj2oKtFdwshv2NzKxzjCBOiw41I
t2CEJ5Ywg4cXvjhBDx8sevGmAVzuQ3YbAwG/oKlF8Rsx4Ykefkg0oTDECEt0
+9HdiCaOL22hhztGHKP5D2s44HMnNjdiC0N8enG5GYsbccUPtjSD4RZ88Y1i
FgBUHHCe
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 629->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAY2MziwGLPcg0BsBhL7p56OrRxbDZj8vfyOEExzjChOhw
I9ItGOGJ5n8YIBgn6OGD5g+CaQCX+5DdxkDAL2hqUfxGTHiihx8STSgMMcIS
3X50N6KFOb60hREn2OxiIBAO+NyJzY3YwhCfXlxuxuJGXPGDzMeqDi38selD
iAEAKDhvnA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 630->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAY2MziwGLPcg0BsBhL7p56OrRxbDZT8jfyHbjChOiw41I
t2CEJ5r/YYBgnKCHDxa9eNMALvchu42BgF/Q1KL4jZjwRA8/JJpQGGKEJZr9
GG5EC3N8aQsjTrDZhc0OZH/gcyeS+gZkPWh+wGUvNv/gcyOu+MGWZjDcgi++
UcwCAO+EcF0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 631->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAY2MziwGLPcg0BsBhL7p56OrRxbDZT8jfyHbjChOiww2b
W3Cpx+N3GMAXnwxY5Bhw6MUZFjjUoLiNAVU9IbUofiMmPNHDD4nGay+2sESz
H8ONaGGOL22hxwtGHOOyA9kf+NyJpL4BWQ+aH3DZi80/+NyIK36wpRkMt+CL
bxSzAO1PcR4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 632->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHDwUrz6hX2gfIP2CfUEK7Uko6KF48+kqVLqZzG4NJGs2s5md
MefHu3tVAMZ6Xbr0uQ1Dmu6nbfNM/fXSb4fNdwJzuy5tHr2547OcmUV+H/St
7oLgsbEYDi/fx3jOKf5/ui2358lh31QvHl5o4bPof0KcebWuFw4m6w05PsSy
tiN+cp2JIa/yEig8kG9OeUe+8ZtU2iSH1RH1afCzrSENHq/SE/Uo76a9xPH7
FHW/3AIOrHHd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 633->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMtPpA/XYEVoABoq4AEwQJXpEq0UfVX0dvESDsyznUkglxzj6f
k3p4dNNFRJ7X36eLr/s8x3dfLZsxprZJy+Ftc5FPkGMN6+r5jjMx5Vl8N/hn
tYTw6DUzhxfrIR5jjP9Mt+amM0F8aW6sFw9PtOCZ0e5wIoblurNwMKY3sfgi
FrU52s/m/899Ms26Z9M3GpsdzA3fJNNGOVT/WT6zYDWjBo+X6Sn1SGvDnuLw
fZK8I/YFCsdx3w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 634->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXnmCX9AHEL+AL1gTOZGY4MF44+lIlNjOTndtUgq77Uw7
5XC990MD4LF/P/r0PE9Tel1268ctjafjuF62XwfmDr/YfWLkW547M56db0bv
CguCx8bMAl7G43w+U/y1uS034yisom7GqvliFr5zswecnKNqQy2CHNcbfL7a
L+9Q6RDqKfT/Z59qZlcP0aPQnP+jrKfCjkMdENQrs/UcLU7JlI7GHH9FL7WH
4pwOawHPhnCe
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 635->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXn2CX9AHEL6AL1gTPZGYwIFw8+lIlNjOTheaLGV3p512
uuf7q31WAIbj59Omsen7NN0Oy+aRuuulWy5PvwW8a/x9/fXRWnHuzKzsfDX6
V7kgeKzPLODlfIznM8W/1bfl5jwqV1E3Y5t40Qvfud4DTsao2FCLAONqg8er
+fIMlQ6hnkL/PfNUPbt4iBqF5vyOspoiHq6R+ffEW06OpVqLpnTk/Co37SWu
NO+sjhlV9HAg
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 636->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHgwXH2CX9AHEL+AL1gTOZGYwMF44+lKlNjOTndpUgrdaaed
5Xh7dP0OwNR8Hl16XsYxva775eOehvNpWA4PPwfmFv/YfmPkK87ljGf51ehd
9YLgsTGzgJf7MZ5zir+2t+XmPtkuNd2MVXVWu9DZTGeKkzGqNtQiwLjZ4PFF
bLBDpGek/5b7VDu7eogZDSb6t7KZIh7uw/xb6i0n19p+hVrmUljHX9FL3UNx
T9frDZgscF8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 637->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAQHboobj1Cr1APIL2CPUEKdSUIuijuPHoNbenLyxvjwJg4n/fm
k8tj7PqTmc3V9unC6zZNYbmf488zDM11iM76q5u0H13h9DRKZmtTjMT+E7or
LBM8eGbi8DIex7NN8Zf6Rm7GyXrBPhQGSHHOqhfyreRTdXOMynVn4e0bazM9
Cxm7MwcPw5Qe2KfqGWvmHXCM97ZUTZKHcZj/SD5yci7i7eQyl4pN+AvzyuL4
rYu8v+0Ns+tvHg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 638->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qAxS+sL6igpwVhPYi3Pt0tKk4nk9ZAtt10MpOk
3Z1v43VlZvfN8hnT4zjP6Xlal59Lmg77qRxuP77Y8PYMa+TFXGyoOar412iv
uEzo4Oos0GU+xnNM6ff6Rm3mcb1gH4oDrDtn1QudZTpTdTNG5YaziO4bazM9
C4ltzCHiMOV/3KfqGWvmO2BM9LYy6CPW6UQamN+qkzhcLvI1cllLYSv9zrwc
jt+6yPvFXtiXbmE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 639->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBxS/UF6xgTwWhPYi3Pt0WLCaTSbYL2W2zk5kk
m/Pj1fUHEZmaZevK+zaO5XM/rj/PMlwvw3p5+pnI3C5ba8/INrzxKXP+bcE3
4xKio0+3Al3kQzz6mH6tbq0d9QT7QP1QW7XPrBa4y94T45B31wwEGJObWHyK
TfoQcQizHe/JatY54xsgJpqtWelrrNOJNHR8lidwuFjNl8SiFsMa/Uq/HA5n
ncT9fV/d4m/h
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 640->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHooXvuEfqE+QPoFfcEW6kkQ7KH0tk9Xi6VJnGQNZNXdmUwy
7vUxtv0JwKtalja979OUPt15/Ximob4N6+FlSyA3yyIyB/nDqz2Hiw3/DfHu
1QLRkc9dFHpGY7jOHtMvzS21PU8Y3+opjwJvqJ9OnWzOWN8Ww7iuFw5G9QaN
D7FktqKfLA/8Tzaz7FnW2EVwt7LQVzVYHfieyXkivqep6gVcq8WwSj/wi+Ls
XSe8/94M/EBwIA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 641->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2IV5/gF/QBxS/UF6ygp0KhHsRbn94WrCSTSbaB7LbZZCaZ
3fNj6F6NiLyPy9KVz20cy/d+WH+epb9e+vXw9HORqV2W1u6Rb/kmptzFN1Pf
EZYQHr07C3hdX5A/QYzx1+YWwGfcrB75TH+JNlTPACe7T6xD3KoOieamN7E1
aS6Zraon8x33yWb+zw38zhgO1kMfyKPzmWaob1QfcRq8pBa5aC7o6s50H6yX
5G1YrBnFQG+g
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 642->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHHoQr32CX9AHFL9QX7CCngpCPUhv+/S2YDGZTmJgu91sMpNM
9nR/9c8GwPu4fPryuY5jmW6H9fAow+U8rJftdwG1Wz6d36O1xTufWTv/Zua/
BlwQPHbfWcDLeBzPvqierG/LzTiyN4geWSPEfFLPACebJ+cx7l8dEs1dbfA5
aazoLZql1D+YQ4ajdFczcJa8rWr4bSzzhBw2P6lT1sy7xclM6afuGZvOVcXx
Wxd5P98MsJVwXw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 643->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENgzAMtPqo+u0IXaEdALECTJBK7QupEjwQv4wOSKW9HGcTKXFiOznf
Obfnp3mfzGy4LEuTxrrv09Se18MrdY97twav32mWq2WpSuvNLb/wwdz5twH7
7GCZwEG7Gw4uv8f57PPqiXgjtqeJus94hUZQj6uz4oIx5u70inOwN6EOgeZF
beZroXrC3A71dPpw1E/F+ccb9vLPBX8rAz73gXWRGHg/qFPWzBbfiYbST8X5
bTpnlcd/Xdz7+2apZXFd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 644->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAYjfgsIsBiz3INAbAYS+6eejq0cVwuQefv5HtxhUmRIcb
A6Z7cKrH5hdkOXS/47ATXQ1y3BBMAzjUoLiNAVU9XrVY/EYwPHHEA6H4xOZn
uL+R2FjTHJ601YBkP3o8oIcLVjuQ9eNxJ1Y3o9PI5hACuNIhuhlY0imKO7C5
BU/aQDULAD3bch4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 645->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAYjfgsIsBiz3INAbAYS+6eejq0cVwuQefv5HtxhUm+PgN
aPrR3YMznLH5BVkO3e847MQW3vCwJpQGcPkH2QwGVPW41KKHI3qcEApPDP1E
hDlGWDJguh9rmsOTthqQ7EePBxS/4rIDWT8ed2J1MzqNbA4+gC38iJXHkmYw
3IIrvjHsAQCVwXPb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 646->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfwCnqA4hXqCUbQVUGoC3E3R7cFW94k7800kEln8nnJ
a073V//cmdn7MB19+lzHMX1v+/nySMPlPMzO41/NcjcdXWmVLvHFG2h4XwS+
s8AygoM2iMD19Xx8Jr20ZmexqwpOWrUxP3CjeGazoM/PLjAZ3yvXrR1Q82AN
K+NVrOcRZ9jCZ8jfwHng0mL/dOcqu5UB3/+HYlaFgfmVPmnP3mKdmjD+mN/X
dvfM4sR+cZwfvA90nA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 647->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAFSuUCYJEX5WQ2gfil9FpJYoc+y6xlKSNHd/5
7PPjNYwHAEu3bkN63+Y5fe7H7eeZputl2pyn3wJyv259eaq1xxd3ZoX73cx3
FlggOPYMJnB9Ph+fCZdW7SoWxNeqLeiGyEfqzGqxPsKPYTK9/1q3ZkDVY3Og
jFexrCdKK6k/qb+medASkT+ducpsZYPv+1DUqjDs+wpPytmfNk/NmH7M73Mz
HoyL6nfA+QJNSXVd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 648->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+Jtn24LFmaTGetCNu0mm8zM
5nB99PcNgOdu2vryOo9jeV+288+tDKfjMAf3XwNqN21d650t+c0ZWTpfFn1X
0wuiD/u0TN9YL+ZXgWWNu8uFiK1xS7oh47E6Ky7MSeCLPFSM+6/OgOPDNdDm
u1z1Jk4rqz9r84fmSUtk/HLmfswWaxs1bri6Hnyf9Is4JeboQx27lH4qHmsr
HAqLe+/U5wPPS3Vf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 649->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBi19YX1BBTwvCehBvfbq74MI0mdktpG2aNJNM
crq/+ucOwPswbX35XMexfG/7WXmU4XIeZuPxL0Dtpq1rTyeLf/NGkt6XRfdq
sCBw+ExL4Kp79K8iF1ebszG242RNr+F/4sbxrGrhmuKbqEPZGH9zBly/OQZa
f8Wn64njSukQssV54hI5fzlzK7PF3EaOEW0Kg32Iv5inzFnEV7Ol6olzLO0x
tspD5eL6nXB+Au50Hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 650->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozACjBA1BXKBEGCVyWk8kD9ZXQa0UrO5S6xlKaJY9+d
7cvjPb4OZvY5rZ8xfod5jsv9mA/PON2uU3aet7Va+K/kdrWyVXehzFHc7+b+
k8AyguP3ygQu5sP3iXBR2pTPY6uatM4J4nu1ofVkOvGO6GA+j9+dAdVvn6On
pdETpZ32NpR5rBFD44BzwRutMVu+tlhjQx/DQB3GeVLOJD+bLaYH55j6MTfj
wbioflc4P+azdB4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 651->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozACjBAxQplgiDBqxJS+6j4ZXQaAZJzvktryU1jJ2ff
xaf7q3/uzGw6LJ8+zddxTO/bvmweabich5I8/nyx7uvZrcqLhVhXY1Txv7n/
LGoZqePXYKIu4rGz2IvipnIeT2nS2me4v6YN1VPwzCSXG2c89qYZUO/tOKxy
YTxcbIuelX6kpxYO0x1rB1OzBfdRY8OcCR0ID+xT9Yz4bLYYn6AjyyM264P1
ot471PkAGFV0mg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 652->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GAQwxOxRzUARhwEkdgMOuxiw2INMYwAc9qKbh00tultw+Q2XHLJ5uMIEH78B
TT+hsMEanjj82YBFrgGPGmSziUoDuOIbyQ8E/YLNH0hixIQnSvhhcRMuezHC
EsnN6GkQBeBKW2j60cMY3S6UsGHA1Icet7gANjtRzMOjF90uXG7EajYx6tDj
ggFNHsUdAKR0dJw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 653->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GAQwxOxRzUARhwEkdgMOuxiw2INMYwAc9qKbh00tultw+Z3BHru/kc3DFSbE
mI0SRnjCBmt44vBnAxa5BjxqkM0mKg3gch+SHwj6BZs/kMSICU/08Ed3Fy57
McISyc3oaRAF4EpbaPrRwxjdLpSwYcDUhx63uAA2O1HMw6MX3S5cbsRqNjHq
0OOCAU0exR0A0Ep1Ww==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 654->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOgzAQG3GouPKEfqF9QNQv0BekUntCqgSHihtPh6iLZrFDLYXABGyP
h+Pt2T8aEZna7dLn12Uc83w9lId7Hs6noRx2n7UhvdeidrYKQi1ZDlP/Qt0v
REuAjt4DiG7wBd71XljvknDf4vjZd3vcJqNKNjBP4DHUiGbIW2ddm38lc8Ox
1wvqQ9X+ydPn730x3ZCl8izII/CF/qNfP24OXstkAzT8jBiQZuCpAeQIzz03
8oG8sHkHnRWNm3Qa
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 655->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQHVyIW4/gFfQAwSvUE0Swq4JQF+IuR7fBD/N5L+mDNO2kzPtM
Dtf7MG5E5LFbHkN+nuc5vy7b+nHL0+k41cP9dy1In1XUzlZFqCXbw9R/UO+F
cAng0XsA4fX90L9eC/MuCfvW/Vgma3qbjBrZwDyJzwLOPGfIW2fdmn8jc+2h
6wX5ULU1efr8vS7GG7JUmgVpBLrQPfr7cXPwXCYbwOFnxIA4Q58eGhpNvacD
aWHzDjxvsux0HA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 656->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAUfLgQtx7BK+gBgleoJ4hgVwWhLsRdjm6DCu8z8+pAmjZJZ96b
yeF6H8aNiDx2y2Ooz/M819dl2z9udTodp765/44F5TOamtnoCGvFcpj1H9R7
I1oCdPQcQHQ9Hzrra2G9S8F9az7myT/cxiPtDfPZ9Y76bGDPawa/tddZ/onn
uocsZ5MnyCTLIfPf18V0g5eqZn8HDdjdcv/7HBAyDZ8RA9IMPGtA/iOOtTpQ
LSzvoPMG8mt0Hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 657->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/oF/QBi1+oL9iCngpCPYi3Pt0uthJnJt0G0pBuNpmZ
bNM92vvOzJ6H6dPm12UY8vu6L8kt9+dTXw6Ps0+Wvj66GHmxEWot/ffwtT9z
Od5X+VLnI1kwl/CJWsQScbfEvJEzntW4UQ9jPGE9cFc8cTdqJunttV7b/4rm
nkOVi+Lh/m3RE/VHXNFc0tJcrjAKXOodqT40x9VHM3BHkdEbErpWTemvemzB
YRCjfdOcD/D1c10=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 658->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAMFD2UXPuEfqF9gOkX0he40JwCheRQevPTG9MFeTSSBYoRnkia
GR9vj3Haicg6bJ8xPy/Lkl/XfS3ueT6f5np5+OYW6ZNFnV7WKICV1PbQ2H+o
Gv9n9Q+nTxPOXLMfweIuHndJljdyxrseN9ND8enigTvj2fWE6a217r0Bbz+l
aeRz4yfxJPIh0h/38uYaLUXVbMfAH+SMfcwchfdmoLc02BsiunaD6c96BL0K
w6EXAvfNnDcSE3Oc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 659->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMDH7I/noEr6AHKF5hPUEF/VoQdj/Evx7dLT5IJ5PUgbSUpkln
JvvLfbxtRGQZ1mXMj9M85+d5Ww/XPB0PU73cfWJFekdRuxcVBXIltTV07g/q
jO/Z+ZundwOnr/kfycW/eNwlWd7IGe963EwNxaebD9wZT/TGeML01lr3ZsD7
n9I08rnxk3gS+RDp/5eGimMD9h7hzRb0R40Zoh7oLQWbIaJrF0x/ViOoVVge
zpfAfdPnBfqMc90=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 660->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwzAMFD2UXPuEfqF9gMkX3Be40JwCheQQevPTG9MFeTxSMiAb49Ey
ks73ZxwOIjJ36xHT0k9Tet2O5fFI4/Uyls/T11aEj2V1W1aQgSuhjqG5f6g3
+rP3j6fvBkbepj7CxVos7RJa3agZ/6g2g6P7IjtqQe1MJ86mmQnrt+711g5s
zNvaE7obZCbeHLz+7+qh0liB+SOs3YL82GMKJwfO1vXXHKzH8iX53FogNiIz
nrFfNE54A+huc10=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 661->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYMLcesRvIIeoHiF8QQVdDUgjAtxN0d3ij9kvr7UeZCWkN+X
ZHe+ddeVmd0309Plx3EY8vO0Lsol94d9X4zbj0xIbxndH0nBCF9L8xze9wen
M17pXz//VwjqVv0JX/YScbdU8yZn2iS3wMfPxRb0Qu6KJ3dT7UTN28/63w0g
D/cd3Ym8DbGT1h5a8180QwMHa8QT0W0hnjNWaNXgbiXUDbGfKFbUa/aC3ARv
gnmlfVbnBZ2KdB4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 662->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADFK+wnqCCfi0Iux+Lf3t0t/ggTibtBtISmiaZ
mRyuj+6+ATDulqPL03kY8vOyLcEt96djXx73H18svX02d+TFZspF+q9hc39m
Yv6v4m+evZ0Ffd18IpdnibAjedyMmd8ktiDH8oIVszB2hZO1cZoovi3XrR2g
Oqx3tCdyN4QmNR1q/K/iEIQB/r+bp6KP/E8ccy/mhnuwtpG5+mqeljXwqtrh
HKA72Bnf5wUP2nOe
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 663->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4hfqC1bQU0FoD+Jtn24XbUknM90G0u2yk2SS
yen+ap87MxsO46dN72vfp89tXy6P1F3OXXk8/n205ufZncqLZcBas8zhsbO5
O8az+4TzZzBRN/AjWORS651hZzddW8VniJ84rnFBLGrmcyg9Gcbn3rQDkAf1
VntCd4NoonqvzX/TDA16sBgf+KzoQ+NhxlgLZ4M1UFtlrGZ4q1mlX/rPeDAu
YmdinS95k3Og
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 664->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWF0tXCAxG/AYRcDFnuQaQyAw15087CpRXcLIb9jUwvHOMKE6HBD
8g8+t6CrRY8zZDNwxSc2NejhQTANoJmD1QwGAn7B5g8s4YAvraCHP1FhyIDm
BwZM/RjuwRM/WPWjhTG6Xehhg24HetziAtjsxJAjBAj4FysbmzuwuQVHmsG0
BwBDDHRh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 665->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBileoJxjBrgpCXYi7Ht0WXGTevJcayAwz+b28
5HR/9sMOwOuwHH15X6epfG779fEo4+U8rsbjT4G5W46uvp0qO4JW/1HC2+UC
xfLdiKnL+ZRvxPJP7xE398w22ZvxibwgiZ+FL+OOOVxPysfx4TiFqxVzYKMX
1YfgIdsV5l/NyM2x4jLESzzJfGQ8ccO1mBuuwbN1omo2ti1JMDb7luFQWNTu
yjpf4spzIA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 666->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbiQbj2CV9ADFK9QTxDBrgpCXYi7Ht0WXExf3pt2YBLCZPI+
k/Pj1fUHAO9mXrryuY1j+d6Py+FZhutlWIqnfwJTOy8hpyRV3fWuIpzdW6Be
3qvY4IzIg+5GLjB8WIvT7DzZ7VvQs3mftCudmSZ1x/nhPIXDim8kc17NU/Tv
9TNyYW0ZbuUlNH4V7m8RPnvDWOwNY/BsXShMqceF8LGqI6lHLMVF/V2J8wM5
qHLd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 667->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfbiQbj2CV9ADFK9QTxBBVwWhXYg7j24LIi+T92IcmIR0Jnmf
6f5yH24bAHO3LEN6nKYpPc/b9XBN4/EwrsXdJ4FXvyx9vrtUdVBm3zno7N5C
uBv3IgxufE/1MpcW7cw7anaeNPtGen72B+1KZ02T6nF+OE/hsPiNypyzeYr7
rX4yl6ithlt4CY3/5Sd4xdkV/W7G1K94xH9K3a1hSj0uhI9/1RlLcXHzLnDe
O1lzHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 668->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAQfbgo3XqEXqE9gHgFe4IU2pVQsIvizqNXoYvJy3vRgUmIM877
JJfHe3g1AD7ndRnSt5+mNN9P2+GZxtt13IrtP4GlW5cu312qOkJm32OEs5sF
+pf3Igwuz1O9kcsR7ZE3a3aeHPYt6HF4i+hl3nGG06R6nB/OUzisOAM72pUO
4UPNz8iFtdVwCy+h8Yuo3F32zsgbxmJvGIPv1oXClHpcMFalvstDcXH3XeD8
AGoccx4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 669->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDyIV5/gF/QBwS/EF4ygp4AQD+ItTzcBD901VcM09AyTXqqr
Oqf7a3zuALwP6zGWz3Wey/e23x6PMl3O0xY8/h1YhvUY8u1cxRE8fY8W3q4X
qJbvygwu91O5cZYe7nFu5uw06dYt8HF4i8jluWMPx0nlOD2cpqA+sgdyjeUi
dtKrZ5yFuVlcEH7Uk/Ara+wu/WekcYUFrVvUI9UbU5hVrGWM1YjLOZSeYq+8
27rPD+JVdBw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 670->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpAfDsCK8AAVVcoEwQJXpWQyqPix+i0Eo/L+WxiyYkSOz7f
Oafbc3p0ZvY6bstU1nFZyvt62A/3Ml/O8x7sf272GbZlqPfIVdzAq3s0OEe1
jN7y7izA5XoqF3tp4Y59M+dIk2bdgM/ffOKueGacVE6kR/YHuF9XI5kz1+CZ
tOqJ+jG3ENcIH/UkfGfJ7Kp/Rho7LNO6oR7V+8AUpotlxlhJXPah9BRz5dn6
Ol/FxnTb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 671->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKwkAMHDxIrz7BL+gDil+oL1jBngpCexBvfbotKGQnmbSB7LKbZJLM
nB+vrj8AmJrl6Mr7No7lcz+uj2cZrpdhDZ5+DsztcrT1rTyKw3j1b828FRao
lm9noi/jRbl2lj2727l55z9+xlPKGzyGzKfdoz2znaoc0D9073AOobfD3sBg
TVT+Fv+7OAT1B9UTP5yjtJvFHE7jhDfLR1UvLOrpYplxryQezhHxGejK2nqc
Lx4Sc5w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 672->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADLF5hPUEF/VoQ1g/xr0d3FxTSySQ2kJY2zWNm
erg+xvsGwHO3LGN5nee5vC/b9XAr0+k4rcH914E6LMvQ7pGrOIw399bMOaoF
yuXdWdCX6/H7SrP0YLdzM+Zf7YynlDf4GuF7hcVi4julicCk+Mi4kJhtDXRi
CXT69+8U/10cgvqD8okffhNpV4M5nMYJb5aPJj8w11PFMuNeSVzOofgUurK2
vs4Hetty3w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 673->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCexBv+3RbUEgnk7SB7LKbzSSZ
2fPj1fUHAFMzL11538axfO7H5fAsw/UyLMHTz4Hazku73iNXcRhf3Vsz5wgL
lMu7s6Au4/H7Sr3smd32zTl/7IynlDd4jPA98elwRH9OEzGTys24kDNbTrFz
lkCnrX9ntbd8bHIIqk98Mj/8JtKuBn04jRPeLB/ufwlzNVUsM66VxGUfik+h
K2vrcb6tK3Lf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 674->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUssKwkAMHDyIVz/BX9APKP5C/YIV7Kkg1IN420+3BQ/ZySStgeyyzWMy
k57uz37YAXgd5qMv7+s0lc9tvzweZbycxyV4/DlQu/no2jtyFYfx5rs18456
gWr5dhbgcj/OrzTLFu52bjVrxmVVN/geYT7p6fowd7UTwUnVZlpIzlZTbOQS
7Omv/w5w/MMaED7pyfpwTrS7GszhdpzoZvVo6gNzmCqWGWMl8dU5BH8ojhLn
CyVhc6A=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 675->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwzAMEz2MXfuEfWF7QNgX2hdksJ4Kg+4wdsvT28IOriyHTOCEVIkt
2b08XsPUAXift2XIn/uy5O942g/PPN+u8072vwBK2pZ03KNQPEwcvluYc5QL
9JZ3h6Au5+P7hbS0eLe6lVYQV/Pm+gadQ96nfro87F3NRHhSb6Oesl7ZUzR6
CebU8t+5PI09dD4A7YtRmV0JdLgZC39OR02ngaupuBoSxb+8rSX8Q3mUdVZJ
33Jf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 676->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsEJwzAMPPIo/WaErtAOYLpCMoELzStQSB+lP4+eBPpQTifjCmRjSz7d
Sb48XsPUAXift2XIn/uy5O942g/PPN+u8x7sfw6UtC3puEeu4jB+uLdmzhEW
6C3vzoK6jMf5hbhY7SEW6lxBsZo21zdoDJlP/XQ4rD2oyZrU26inzFf2FI1a
gjm1/DuH09hDpwO6vrPK7ErAw81Y6OMYKjwlZ5Ej+bMl8n/jtpbQD6VR1lkB
8Htyng==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 677->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDil+oL4hgT4VCPYi3PN0WFDaTmaCBJE13d3Zm
d4+3eRh3AB7degzpeVmW9Lrut8c9TefTtBkPnw3kfj368nZb2RF28T+u8HZY
oFi+q2XyMh77Z+IStVsseM1fbLb9XDdoDOlP9axwWLvJyZpUrKup62NRU2GX
OBzf8G/yMX2wM0EzxXMiZ67Ru2x4VD0mnCoP90jxcDnDt+Qv9FRz/I898hD6
oTTKPG91QnKc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 678->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDil+oL4hgT4VCPYi3Pt0WpGwmM7GBTchudnZm
N+fH2PUHAK9m2br0vk1T+tyP6+WZhutlWIOnnwFzu2xtfjpTcQTL/HGFu8Li
/I0XBFbErHAG8xA+pUNimbebrj841b5BY8j31M8Ch7WbmqxJ5do/YOYY/Sou
tXB+5b2bcezHnh4WvUTOv/g3Zj4RYzY8ihkTTlGHZ6R4uJpU3y7qteS4Jx55
CP1QGmWdLy8Acts=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 679->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4hfqC1awp4JQD+Jtn24LKslkZu1CdtvNJpmZ
5HC998PGzB67eevL8zxN5XXZLj+3Mp6O4+Lcf8ysdvPWxVMZ85uzdP9d7pvl
wvgfLnem1agdOMF7vFMYKsGDfFl9pYXUTWCh70HPlAe5i5qJE4mVMwB9ZPeo
l+SCPfnTy2aelRomLS3iTzMi+uNzVIEj9ZjlAZ81cFLMZC5acag9xbjG73EQ
/oEn1g513lTpcdk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 680->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDC7ErUfwCnqA4hXqCZ6gq4JQF+KuR7cFlWQyE33wfkleMjN5
u/Otv67M7L6Zl749juPYnqf1crm04bAfFuf2Pc2mbl66uKvJ/OZmsn+GO6tc
/v7F5fY0itqBE8SjDfFS3sb5svpKC6mbwELjQc+UB7mLmokTeSv/APSR2VEv
FZt68qOXUhPgUGmYtLSMif65oneTwJF6zPKAzwqcFDP5F9W7EKMw/uP3OAj/
wBNrhzov+Otx2w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 681->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAQHVyIW4/gFewBpFewJ0ihrgRBF9Jdjl4FhZk3nzSQRGcmeZ9J
917GqSKirTmWMe3PdU3fV33+fNL86Ocz2V6TKA/HMsjdm3e9iLGp4vdg39nB
IgOH72oE2EIT1GeDC+db0o24iO954frG+BXrwU91D2p3MJUm42z0BiyfeBz9
8mpVTwq99DxBDZGHykvSnMw3F/RO8AcvEUvdAzkKeJqcjXcRnRM1Hsd/8pyH
oV/oRGyB8wOKHnKc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 682->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAYjfgsIsBiz3INAbAYzeKn9DUN2BxC7J7Cfkb3V5cfsfH
RzEHyX0E1aOFJzZz8MUnehgg+4+UNIAtnFDsZyDgFzxxgi8ucYUJuh/whSFG
WDJgtx8D4Ik7ZPvRwxLdLgxz0OQY8LgTq5uxpAt8+lDU4HIjMfLI7sDifxR/
otuNYg8A/Uhyng==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 683->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKgzAQHboo3fYIvUJ7APEKeoIU2pVQ0IW4y9E1tIXJmzeTgRjz8f3G
2/MzvE8islyOx5DWfp7TNp7L4pWmx30qh9ffOKr7jqxmb5Qye12NUe3/S71n
h0sIj55NBdwaD+9nokXrbflGXs97tK5wlL7mfciT4VTeHU7jSfxvWBaoFzPF
vCIM1ievl16G6CHK0GQpQvtgKuid5scsmzioI9KpyvuHjB/Cj1yezvAcdRBs
2m/DswMv9nFd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 684->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOgzAMtDhUvfKEfqF9AOoX6AtSqZyQKtFDxS1Ph6iL7PE4YCmEBHtm
POZ0f/ZDIyKv4/ro0/s6TWm+HcrhkcbLeSwf2+9ao/usrPZolXB3ncUw979Q
7zngEsKjdxcBN/aC+ZloyQQn6ht5o95rZ4Oj9G3mg58Mh3nAejQ9SVzDvEC9
6Cn6VcNgc2K9Uy1Yv8ND56UInYOLyuw0P3rJgs5U+bFV/+cM/otanclhGETL
Lh0Em87b8SztdHDd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 685->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHVHyhvCBIcKqE1B4QNz+dRiyyx+MUS26axJ6x
x9lf7sNtIyJzt3yG8jhNU3met3VzLePxMNbL3ccX69+uZs28WjjrPYY7/5r5
14RLCI9dgyXc2AvGK6lFCU7WN/Jmvbf2DsfUtxoPejIcpgHr0fUkeQ7TAutF
TVGvFgabE+ud1oL5f2gYtBShcwjWmJ3lRy2Z0ZlCXiv/x5m8i1aei2UYeL+C
pywO9A/1OZ4XKvVw3w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 686->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOIIWEMcRhAYjfgsIsBiz3INAbAYy8Kjaa+AYtbGnCYhc3fDDgwLr/g
Cle4XiT3EVSPFp7YzMEXn+hhgOw/UtIAunvRwxQ9vPCZgS2esPkdq1vQ9RMR
hhhhycCANR4wAJ64Q7YfPSyxAaxxiqYPn364nTjSBT59WPXj8C8x5jVgU4cW
/hjuQ7EHAJAxcl8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 687->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMfbgo3XqEXqE9gPQKeoIptCuhYBeluxxdhSr5j4FMdCbJS15y
ebz7VwPgc16Ovnzv01R+w2n9eZbxdh3Xx/avAHXL0Ukb6eYv7pia+03YNwVY
cHC4NZLgCqv8yamFglxR33A06iXidY9l9VX9FZ9enmyemgPen47NdkDXa3Kg
0ksyk6h3txa9Iwc4NFwC7hyMJLPj+CKHlwe2foNdid8xg73I4tz4oN8j+cjz
U/yb+gTODC76cmE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 688->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKAkEMLDyIV5/gF/QBg18YX9CCcxoQxoN4y9OdARuyVQyk02tVKunT
/TlOOwCvwzqM7X1dlva57bfFo82X87wdHn8OyLAOg43M+32zpzzsd1NzIVxI
eHQMVvCa6O5LkosQLKZbc3dspoXV1bx3GPS+q2eGU/UT5Cx7S/8A06wx8EdL
0ROmvcpFkpwqHaaWQNqHYEXvNL/ByHBQ5+H7x4z9oaAnW/v3RC/Fy3A8P+t3
4PkChVNzXw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 689->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbgQtx7BK+gBBq9QTzCCrgpCuyjucnRbcCCZ5KWBzC+Tl7wk
l+dneB8AzKd1Gepyn6b6fRy3y6uOt+u4Gc9/BaSsS7E70/bfvCl1703UWUgs
BHH07iSJa/buvwS5CMFivHXshs247NYNHiPKI6pnhJP1E8QW+dIZYJw1Bna4
JD1h3LNcJMgp42FqCYR9cJL0Tsc3GBEO8jz6/jFhM+T4RPfeP7MT//RfNl+9
lB8BMHQg
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 690->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssJwzAMffRQcu0IXaEdwGSFZAIXmlMgkB5Kbh49CdQgyXqqQJZtfZ5+
99cyTBcAn+44hvzt1zVv4/V8vPP8fMyn8vZjoKTjSFoyrvbqT3DzX0ncC8GC
gyNlQwGuksa+OLkUEovVLbFrbFYL66vyNzGovemnp4vmCaLzfOkOsJrFn83N
6yebCas9ysXi/6tD9RJw59BQMDuJr2J4cRDnYefHiO1QU4/3tv6RnviHdtF+
WUo7sXx1Hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 691->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6LWrBmXgSS07ixMvY
k9P91T13AMbDvHRxug5DfN/2i/GI/eXcL4/HVYEU5iXku9LNP7sTsVj9v2LO
HOfZP1xmLyT8tYaH/ZODJYlcqm9be8utelG5s3jK4eHw5um9NTkR8+ZY+QdU
z+aOsXnzVJyo3mtYuH6rj2yWgMtDIRXubP0sh5cHdRzMnxL1h4p+PBvtOsx1
EwfXV3yzhA95i3Ue
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 692->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHDyUXn1Cv9A+QPyCfcEW6kko2EPx5tOr0JWYnYkN7MbdJGYy
s5fHq+srAO/zsnXp045jmu6n9fBMw+06rMH6t4C5WbZm79XK+bs74+HuNzPf
vo6dN1zGF0Z6sll8/kywMPzR3LZ3xIn6t6/P+FS94pPFIj0hYqxWvoGcTziy
/IazBJqo2Y+w/MMh5RKgOhTG9LO8ERxFH5OvcHj9lDEcdB52xnEfym+EA84r
vQusX2rTc98=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 693->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPoh/vYIXkEPULxCe4II9qsg1A/xL0dvC0a2m5nVhWSbZB+z
Mz3dHv3YAHge161Pr+s8p/dw2A73NF3O0/bYfhaQu3Xr9l6tEr+7Mx7u/mvm
W9UC6WN9ZaQnm8XHZ4KF4Y/mtr0jTnysyi/4WH7EZyZ1Ij0h3liu/AdKPOHI
6hXOwjQRdSNMNucfDimXANWhMqafm9njqPqYeIXD66eM4aDzsDN+96H8Rjjg
vNK7wroAa5xyoA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 694->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWEehBvfbotWEmTmdjAbrrZzGaS
6fH2aLsdgGczbW19XYahvq/7+XCv/fnUz5eH7wLGMm1l7dVa8lcx4+HiPzPf
HkexiD6YqUG5FoclMZ+v+le5qj7rTcUsP4bP5jmSdzI9Ie4YVv4DSz6ZkdUr
7YVpIt7NOFnMlhnSWQJUh2BMP9ez5xHqmHzFw+unjPGg/bAz/teh8814wHml
d+D6AVdUcqA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 695->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEuyoIdSHuenRbsJIm78UGZjKffF7y
crw92m4H4NlMW1tfl2Go7+t+vtxrfz718+fhu4CxTFtZa7UW+9Wb0XDvPzFn
70d9EXUQk4NiLc6XvHl7Vb+yVfmz2kIMg4/5Z/1kcTI+If6Yr5yBxZ70yPKV
1sI4EXEzTNZnSw9pL4HQPzpzCXejwBHy+BwEh+dPCZ0hUg+9438e2t8MB5xW
fAesHySQdCA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 696->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXjAkdpqENA6IW5/OhsaUJXa0Sm22No4d
t6f7s+l2AF6HcWna93UY2s9tP/082v5y7qfD4zyBWsalrKOa//zVnsBizv8N
8+1xSy7hsTEMw0G1Focle0Hvxr5Rcv6st1DD6GP4zE9Wp7oz1aP3W2GkDuKR
55e9sDsRdTNNFrPFQ+olEPyjby65uyp0BB7PQXRY7Qq/cKqcBOfxiof6m+mA
i+q+g9YvcGl0Ig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 697->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUVsKwkAQC36Ivx7BK+gBFq9QT7CC/SoI9UP869FtpS3TmWTdgX1PNpnM
6f5s2h2A12Gcmvy+9n3+3PbT4ZG7y7mbHo/zAIY0Tmm7qrHkb+4EFnP+L8ze
49h51WXWEIaDak0OS+6C3sq6kcr8qPjX4hd9yhvlJ/tncG+qRu+3wkgdxCPP
L2thPRF9KWmyWmo8pF4ClDvEn/4zHYHHcxAdVrvCr5wqp4CjeJJP/S39A7eq
fgetXwQzdCI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 698->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH3Y+HB3IdEYwB6BsbrVHk0vFjEM9xLpb2S78YVJ
AwE16GGEK2xwhicWc1DCDYed2MIblx6c7sDhNvTwwuoXPHFCKDxxuYWYMMQa
lgwMGO7HmuYIxD82d2DYg24HFnegpF0c+uF24lKDRx9W/VjUYw1ffOYwoNG4
4hvDrQAuG3Lj
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 699->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EGmMYA9AmM1wx5NLxYxDPcS6W9ku/GFCaFw
Qw8jfGGDNTyxmIMSbjjsRJdD0UsoDSDZje5HdPtx+gVPnBATntjcQkwYYg1L
BgaM8MOa5gjEPzZ3YNiDbgcWd6CkXRz64XbiUoNHH1b9WNRjDV985jCg0bji
G8OtANtXdGM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 700->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EGmMYA9AmM1A5sb7FHNw6aeGH8zoJmPK0wI
hRu6+/CFDdbwxGIOSrjhsBNdDptegmGKxY/YzMDqFzxxQkx4YoQJFjfhTV/o
aQpb+kQHBOIfmzsw7EG3A4s7kN2OSz/cTlxq8OjDqh+Leqzhi88cBjQaV3xj
uBUAQ1tzJA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 701->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EGmMQCSHVjNwOYGe1TzsKnHag4OtbjsxwgL
HGrQ3YcvbLCGJxZzUMINh53octj0EgxTLH7EZgZWv2DzBwOqGfjCEyNMsLgJ
b/pCT1PY0ic6IBD/2NyBYQ+6HVjcgex2XPrhduJSg0cfVv1Y1GMNX3zmMKDR
+OIbxa0AKGFxpg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 702->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOgzAMtHpAXPsEvkAfEPUL8IJUglOkSnCouPF0FlFkO2PHUuKAl5mM
03y+3fggornety7+3tMUl746PoaYXm06gs9rEa1h34L01vrni39GLV35p7Gz
rvNwuM+MYcAeiEOQ/TQm4oQwSPW3NCnppvl52kA9QUzoZmDqGKotauroxHvA
u4B7cCvpmWkCOLnvS78pMIfMCvNHPDIcdT/Eg3O36m9MK8epg/UgH+rr9SHl
vXkLrhuBoXGm
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 703->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKg0AMDH4Uf3uEXqE9wOIV7Am2UL+Egv0o/vXoarGSzE6iC7vxkclM
Jnt5vNquEpF3PR9t/jTDkMf7aXl55v527Zef53WLfNN8JBu9/c833xysrPm/
pZ4RF/HoWCzFQWswDcnWQ06miXEI1Pc82fMN9UXeFL0rDPq7RYcTNTHsrqeB
T6Z21EuCSOYS3ZUCfwBT3E3kZ36T2jh/HdlcWH9Mh9bu4TcuLyfAUTzJp/5G
dQRiNG+jdQLJdHGo
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 704->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAQG/wQfz2CV9ADLF6hnmAF/SoI9UP88+i2UstsJhld2KbtJpN5
7O58664rM7tvxkdXH8dhqM/Tevq41P6w76fD7bzNXmV8lBbV/vKbf0JrM/+z
3DvqMh+PYTkPGoPlUNp4jE/jCK7yD70QHMwv602oHTWupgWFJ+bEtHI2xBv7
1MTOaimAZC7ZXQn6PzThbqI/6zeJjfP3aMoH6mN5+NyVfvFSnERH9YT/6zzw
DDCbd5PrG0ZWcyY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 705->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EGmMQCSHVjNwOYGe1TzsKnHag4OtbjsxwgL
HGrQ3YdXPbrfseiBhxe+OMFiB4peHOGJEa94wgnFbBzxi+4PZEAoPLG5BSM8
8MUHrvBEMgMDYDEPm59RzMCRdvG5A5v5uMzASEPY/EOMfizqCcljqGNAo/HF
N4pbAQyWcyY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 706->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgyYNAZAsgOXWzHcgGQ+VvfiMocBh9k47McwG4ca
dPfhVY/udyx6MMINjx9R4gKLXnxpAGf4YTEDa5hi8QcyIBieWNyCER4E9GMN
TyQzMAAe+zHSKi570PyHzR1Y/YfDDIw0hM0/xOjHoh5r+OIzhwGNxhffKG4F
AFTGcqY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 707->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgyYNAZAsgOXWzHcgGQ+hnuxiDXgsIMBzXxC4YRL
Dbr78KpH9zsWPRjhhsNOdDuw6cWXBnCGHxYzsIYpFn8gA4LhicUtGOFBQD/W
8EQyAwNgsx+Ln1HMwJF28bkDq/9wmIGRhrD5hxj9WNRjDV985jCg0fjiG8Wt
AJ3fcek=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 708->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgyYNAZAsgOXWzHcgGQ+hnuxiDXgsIMBzXxC4YRL
Dbr78KpH9zsWPRjhhsNOdDuw6cWXBnCGHxYzsIYpFn8gA4LhicUt6Prwpi9c
4YnkLwyAzX4sfkYxA0faxecOrP7DYQZGGsLmH2L0Y1GPLXzxmsOARuOLbxS3
AgBH/XLp
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 709->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD1Ir31Cv6APkH5BX7AFPQkFeyi9+fS6IEs2mYld2I1rMslk
svfna5gvIvK+7seQPo91Td+xyZcpLV27ZOft2CJbvx99bdlGfobN97LUd5Sr
+MRbt1QNxtVxUPkdX/BvIzXE5D/TicVYfq5/yw9oYP0Mr2taTggbvQGqH8gB
NdUz0VZqLNUTcHF6/NOD5aFyuIXqg56rHGRuUAuDi/ClFosJcBAP4p2+QS9o
DvDtQq4/4kRyaQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 710->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgyYNAZAsgOXWzHcgGQ+hnuxiDXgsIMBzXxc7sfF
x+U+vOpxhAG6PEq44bAT3Q5sevGlAZzhh8UMvH6xR6MZcKjHk+bQzSEqfaGH
J5Z4wADY7MfiZxQzcMQbznjF5T8cZmCkIWz+IUY/FvUY4YvHL9jiAVvaxO5W
AAchcms=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 711->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMDS5kth7BK+gBilcYT1BBVwPCzELceXSnIEOTvPcw0KYlycvL
53h7jo+dmS3Deo31dZnn+r7u2+dep/NpasbD75h9ynoVr9lBdhbb/pt0b4W1
2SzrJF0OxjVx6PAhX4ZjBJvkT9jEJ/KT/qQH0e76Jmp0swCxagdg/wiGrKUE
bcRf7FzE+Wu/Yj/BHJKg/KBmh0HmRufK6iMYaYdiPSLe7TDwg/1VPGJeNW/H
4wt3vnJp
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 712->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgyYNAZAsgOXGRhuQJPDcC8O/6HbwYCMsdiPYTYO
Nejuw6seRxigy6OEGx4/ItuBTS++NIA1/HCYgdcv2OKJmPDEEjcY4UGMH9Dd
gWQGBsBmPxY/o5iBI95wxisO/+EyAyMNYfMPLoAlHWM1n4B5WNWhhT9ed9kD
AEeMcms=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 713->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKhDAMDS4Gtx5hrjBzAPEKeoIOjCthQBfizqNrYShp8l4bSD/kNXnJ
6/PzG+dGRLb2XsawD+sajukRL9+wvF9LDHZ/Fzn7e+nznTmKs7fxnkydS7lS
TPzuTNVgORwHE3N8SX+2hmgH9V1ugrH8ingyAxuvagJqZG/JPJ2ujB/ITXtB
OpFZsz+neQvAFHuwPFQOZ6g+mFuWg+hGdbUaER6pVgVTNPCPLUemTxVn5p9h
HY8Lq3Bx6Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 714->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKgzAQXPoh/vYIXkEPIL2CPUEE/RIE/Sj969FrQEKyO7NZyIvdzE5m
0s37tD5E5GyvaQqf13GE77uJhyVsQ7/F5PMeIr/xmsZyZQPl2d14TpHtPayU
E7uayHowDMNB5Qxf8j7dQ/IB+htsUqP5uToTDXS+6gngVNwlehpfGT+ATd+C
fCJae1yQp+7/0noCH0wAbKRbgUF8o75qjwiP1KtS4wb4x5oj86dap/Qvag2P
P0rhcqg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 715->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKAjEMHDwsXn2CX9h9QPEL9QUV3NOCsB7Em0+3BSndTGZroE1Lksk0
Q8+3R5wPAJ7HvMX0uqxrel+HcrmnZRqXEjz9FvAJeQtbr5YXV7XlXq0572HV
GNiTNT0UV+LQ4Lt8FQ4EtuiPTr3LrzMbNQMb72piZky1Yp6kq+LnYMu3BOPB
+TC8lTY0j3/eYHk0GGQOtje3DYbQTepqNRI8aq9ODp1FLy/Haq3MzbN/YI9L
+AIUsnFn
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 716->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgyYNAZAsgOXWzHcgGQ+VvfiMocBh9k47GcgoB+r
+wiEDTaAIU9MnKCFMbLZ6OI4wxVb+CGHM5rZOP1CIBzQwxpf3KC7CW/6Qg9P
NDdhDW8sZmMLNxS/ExtvWMIDp35kuwiowWDjsAubGvS4xgWwqkPPA/jcYg8A
N6ly5Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 717->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADLF6hnmAF/SoI7Ufxz6PbBSkxmUk7sK8mO5lO
9nR/dc8dgPEwT12drsNQ37d9Ozxqfzn3LXj8DeBT5qn8r2qwuLrbzgvMPuNa
YohrgKmhtAYNhp/qVTwQ3KI+Vu4rfanPBCG+pSfOY8vtv0tfmX/WZ8ct/4X5
sOKn6s0WD+nbBGgfAgg384313kNq8T0SOmytLCfsfU7C4XutQPO8D5mW8gVb
a3Si
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 718->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPyQ/noEr6AHCF6hniCC/SoI7Yf459FtQEqyO7PtQl7sZnYy
k/Pj1Q8HAHO3TH1+36Ypf+7Hcnjm8XoZS/L0H8A3LVNqVzVYXt0t5zWqfYS1
5uBXF1UPxdVxSC0eq6c4olb1x8Z9xS/UmYTL7/HEaGz1UHo6XxU/gi3fwnTY
0FN5s0dD+jcB6oMLgs10Y97bkFyIf4xH3SuqcXvDQenf5AMMWWd1iLikHzq0
dWM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 719->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgyYNAZAsgOXWzHcYI9qHjb1WM3BoRaX/QwE9ONy
H95wxgIw5ImJE7QwRg8PXOGJEa+43IduNj6/2KPRWPyFL60g24UrDPHFKYY7
kMMQHWAzG0u4YYt7dIDTLYTcieRWrGkIh39wuQE9HWOVx2MGTnXo4YDPLfYA
6IV1Yw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 720->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgyYNAawR2BcbsVwgz2qedjUYzUHh1pscuh+w2su
mvvwhjMWgCFPTJyghTF6eGDzD9Z4xeU+dLPx+cUejcYRDnjjGMndxOpFsQ+H
/RgAm9lYwg0j7rEAnG4h5E4kt2JLh7j8g8sNOPUzoNmPwwyc6tDDAZ9b7AFP
F3Xf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 721->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD0Ur31Cv9A+IPgFfcEW6kko2EPx5tN1odjdZCZ1IBuXJJPZ
xOvj1Q0nEXk329GlTztNae7P+fJM4/025uDlayKLbofWnhmKs9p831F8R1x7
TLx30J8xrU6D1nwoH/KQXBSzb4tyrL5wzgAubudHei5GU8mHtMK9Mn2WO3qL
Gk/mEO640H20tupH+jsgbjA3tHsLquWfzkIr+g8hAg1Rvd01A8yzc4i06Aq3
sHUi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 722->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMDB5krz7BL+gDgl9YX1BBTwvC7kG87dPdgqzZySTFgTQtSaeT
pMfbs3/sRGTqlqUvr8s4lvd1Xw/3MpxPQw0eviYy67Lo1kfG4tHdel5h9hnX
GhPvHfRnkVanQbd8LJ/yBLkshrVlOagv7TOBi2P/gjdn0GT5mFY610gfcme1
KHjCm/0V+1bUw2ymTgf0EHMcN+kb1s4QamnpNFrZP/wHrfs46yaPgM/mbaEf
OBF1JA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 723->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQfbgQtx7BK+gBBq9QTxDBrgpCXYi7HN0GpKZvPmkHJpMwv5c3
c7o/u34H4HWYji69r+OYPrd9eTzScDkPxXn8KZBlOmRpPbX8Xm55z1Ldo1qz
D9oqkb9GWDk+G1hyUAvix1o+/lsUwxyFPBuiuGb+nJ6ZMFm50Q4wXsUzVv5F
yBp1o12pe3kcRjNVOIgHjvF2y9pZsw+WftWnhbPCau3hFmnl86ybdUA2mnct
8gUIqHUk
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 724->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHooXn1Cv1AfsPQL9gVbqCdB0EPxtk+vC8XuJpPoQDYuyWaS
OLfX1A8XAEuzHX38POY5rs9rvrzj2N3HHGx/BqSwHaH2lrG49TbfdxTfXq09
Bu0Vwt+8XmV+Ir2ko1pGLkhMzublyB25eyZQu5b7MzjlTOytpwHZr9ozTs4S
hCd1Pa2UXNYOrXoVCL+Coy2mWcqDOq54jvoserU0dBZMx4qH/R+rDoSXM5o8
X4jmdWM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 725->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozACjCAxQplgiDBqxJSeSB+HZ0WFeGcz04tJW4T2+e7
+HB9dPeNiDx309aV13kYyvuynX9upT8d+/lyvyyRUadNax+tX3x1FuTKEv81
8415GY71zvS/aA2FXHLm+l3J22JnmoyNGNQo04aZ0xr1CzCRE8sN3wbiXX9Y
O+Oi4EndbFYs1hoN6WwG+M6S2WIzS3Gkvnc4rT5Nr5Yz5dEwNscOh2FEdQQ8
cgxxPhiAdWU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 726->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EGmMYA9AmM1wx5NLxYxDPcS6W9ku/GFSQMB
NehhhC9ssAFsYY0SbjjsRPcTsv3Y3IotXnG6D91sfH6xR6MZcKgnwi3EhCHW
tInDfgyAJ21hS7NY7WFAlUe3h6A7kdyK7Ges/iAAsKVjDHuw2YHLHAY0Gt2P
OO0BAA4EdiY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 727->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWE9iDe+nRbqZDNTpINZNPuJplk
mPPj1Q8HAHO3Hn1+36Ypf+7H7eeZx+tl3B5PuwNLWo9URsv/+cWdUYs9/2fi
W9d5ODJSc/ogqVpyV83buDekO5wsQY7myOOGWcW15o/1IDtZ9xavdB/JMxp3
CXiItCKxWjik2gQofmWOtphmKQ7Kd40TzilmlTvTPQJjOq5wGIbVByoS3XGc
L6WddiY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 728->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVoABIlZoJwgSvCohlQfil9HboiJc52zXkuMkdnL2
6U63Z/doALyO89Ll93Uc86c/LId7Hi7nYUm2qwMlzUvaRst/9Zs74y3W+q+J
vX7n4chILf3d7EvVFtJLcf7Rc0O7w0kJajRHHjfMqjzp0axBfE+5sOaRPGPn
LAEPkVYk1h4OqTYBil+Zoy2mWYoDPx/2KXqVM9M5Aqu0zHAYhvUPVCS64zgT
TQN05Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 729->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EHXiwHwmMOAZBa6WnS3wN1LhL8Z0DGeMGkg
oAY9jPCFDTaAIY/DjVjVMBAWxxWuWP2DHM4MRPoFWxzjiUt8biEmDLGmTRz2
YwA8aQs9reK0hwG/PEF3otmBze3EAox0gs0ebHbgMocBjcaS7rDbAwDQl3Om

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 730->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBi19YX1BBTwvC7mHx5tPdgtR2MmkbSNM2aWaS
5nR/jc8dgOWwLWNYr/Mc3rd9PDzCdDlP0Xn8KfAZtmUorafK772N5yTZPvlR
wcHfFnlYKpyR5eJY5pL4OnkK3qyiDlTemzwZv2qfhRi/w1HGoH3v9VXWk/cZ
nbWoP+6cO+Ziau2owfCgPnCMN1s8qy4OGv4WT8JQ3HvFzInCURheHpAVc6dx
viPDcuU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 731->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2XJ4Bjz0MCBrFHHSAx80MSGahq0V3C9y9OMzBpRabHHpY
4FODHkZ4wxkLwJAnFCfIahgIi+MKV6z+QQ5nBiL9gi2OiUx36G5Bjz9cejDS
Jg77MQCetIWeVnHaw0BAnpA70ezA5nZiAbZ0jGEPNjtwmcOARmNJd9jtAQBy
/3Rl
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 732->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2XJ4Bjz0MCBrFHHSAx80MSGahq0V3C9y9OMzBpRabHHpY
4FODHkZ4wxkLwJAnFCfIahgIi+MKV3T3YoQzA5F+wRbHRKY79DhDjz9cejDS
Jg77MQCetIWeVnHaw0BAnpA70ezA5nZiAbZ0jGEPNjtwmcOARmNJd9jtAQC8
b3Qk
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 733->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2XJ4Bjz0MCBrFHHSAx80MSGahq0V3C9y9OMzBpRabHHpY
EKMf5j684YwFYMgTihNkNQyExXGFK7p7McKZgUi/oMc1FnPxpUsGLJiQHoy0
ycCANR4wAJ60hZ5WcdrDQECekDvR7MDmdmIBznSIbBY2O3CZw4BGY0l32O0B
AFVgc6Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 734->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADFK+wnqCCfi0I64f459HdgtTNdJLuQPrYpNnJ
JIfrY7hvADx38zLk13ma8vuyLZdbHk/HsTj3PwM+aV6S3T1Tfu9tuVcsztWP
4D/47yYPI+CMRS6OZS6Vr5PHi1U+1iKKYY1CnQWaOns9gY3vffd0Zb6NzlhZ
C/da5I3mEsJ6b5rZBGQfGghdTR+c2hUiHl2erJnQcw3UHEt/J6+M414Qd4P0
BTnLc+M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 735->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxBBvwpC/RD/PLoNSG1mZ7MZ2Dy6j05m
93B9DPcNgOduXob8Ok9Tfl+25XLL4+k4Fuf+Z8AnzUuqd8+U38st9wWrs6pl
cvHfqzqMBmesanEsc1n4erWcWAifepsXwxo1dRYw74x6gjo++u7pynyNzuh8
C/da1G3NJYRFOWY2AdkHg8Zs8ay6/0Hg7+HJmgk9e6DmWPqDujKOe0HcK6Qv
lRF0og==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 736->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYg3n+4WZG0nk2YH0m53Jmma
5HB9DPcNgOduXob8Ok9Tfl+25XDL4+k4FnL/M+CT5iW1u2eK93zLeUH1rWIZ
X/z3Jg6jkzOqWKzlXJZ8vViOFoJjvasRNerWWcC8M+oJWn3036sr52vqjJVv
4V6LuL25hLDIx8wmIPtg0JktnlX3HgT8mjy5Zs4dEdQcSz64Q+q4FyC+RvoC
mj1z5Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 737->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRz0AEeNzMgmYWuFt0tcPfiMguHWgYscujq
carBEkZ4wxkLwPAnoThhQFVPSBxXuKK7FyOcGYj0C3pcYzEXX7pkwIIJ6cFI
mwwMWOMBA+BJW+hpFac9DATkiXEnljgnB2BLx1jlCdiBVR16XDCgySMDewDM
sHQk
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 738->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH1Y9TIgaBRz0AEeNzMgmYWuFt0tcPcS6W8GZIwt
TBgwwwGb+9DDCFd4oPgDCWD4k1CcMKCqJySOK1zR3YsRzgxE+gU9rrGYiy9d
MqBhYvRgpE0GBqzxgAHwpC30tIrTHgYC8sS4E0uckwOwpWOs8gTswKoOLfxR
1KIDewChxXTl
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 739->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH1Y9TIgaBRz0AEeNzMgmYWuFt0tcPcS6W8GZIwn
TBoIqEEPI1zhgeIPJIDhT0JxwoCqnpA4rnBFdy96mKKYjc8v6HGNxVx86ZIB
DROjByNtMjBgjQcMgCdtoadVnPYwEJAnxp1Y4pwcgC0dY5UnYAdWdeh5AFkt
OrAHAIL2daQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 740->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH1Y9TIgaBRz0AEeNzMgmYWuFt0tcPcS6W8GZIwn
TBoIqEEPI1zhgeIPJIDhT0JxwoCqHt1sXHGMNV5xuA/DbHx+QY9rLObiS5f4
4gGXHoy0yYDKxxneeNIWelrFaQ+6HVjcQdCdWOKcHIAt/LDKE7ADqzr0PICs
Fh3YAwAzqHWm
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 741->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EHXiwHwmMOAZBay+gYsboG7l0h/MyBjPGHS
QEANut/whQ02gOFPQnGCFgboZuOKY6zxisN9GGbj8wt6XGMxF19awRcPeNMX
lnSBEQfoAE/aQk+rOO1BtwNH+sTrTixxTg7AFn5Y5QnYgVUdeh5AVosO7AGU
unWo
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 742->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EHXiwHwmMOAZBa6Whgfw72E3IOmlgFJDpvd
DQTUoPsNX9hgCwcMfxKKEwZU9SjiDJjiuMIVa/ghhzMhv2BRiyyGLzxxxRm6
XrzpCz0ssaVPdIAnbaGnVXxxhleeGHdi8TM5AFs6xipPwA6s6tDzALJadGAP
AEl/dWU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 743->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcdIDHHAYks9DVwvgY7sVhDrK7kdVik0P3
Gz416H4jFM7oAMOfhOKEAVU9ijgDpjiucMUafsjhTMgvWNQiixGT7tDjDF0v
3vSFHpbY0ic6wJO20NMqvjjDK0+MO9HDDIcdhAC2dIxVnoAdWNWh5wFktejA
HgAiBnVl
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 744->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcdIDHHAYks9DVwvgY7sVhDrK7kdVik0P3
Gz416H4jFM7oAMOfhOKEAVU9ijgDbruxugOb2QwMGP7F6hc0tehphZh0hx5n
6Hrxpi/0sMSWPtEBnrSFHp/44gyvPDHuRLID3e2kAGzpGKs8ATuwqkPPA8hq
0YE9AAncdWM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 745->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcZGCPwPjciq4e2VwM9+IwB1s4MaDJ4Qon
fGrQ/UYonNEBepihxwWGH5HVMOD3I740gDX8kMOZkF/Q1KKnFWLSHXqcoevF
m77QwxKJj+FGLO5CT1u44hpbnOGVJ8adyHHFgEUNkQBbOsYqT8AOrOrQ8wCy
WnRgDwDoJXZh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 746->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcZGCPwPjciq4e2VwM9+IwB1s4MaDJ4Qon
BgL2IQNC4YwO0MMMPS4w7ERWw4Dfj/jSAFb/IIczFr8w4FGLnlaISXfocYau
F2/6Qg9LJD6GG7G4Cz1tYQtHXHGGVx5X2kGTh5mB7naiAXoaxpG2sMYPmjlY
1RGKbxQzALimdF8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 747->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkKwkAQLDyIV5/gF/QBg1+ILxhBTwEhHsSbTzcDkvTUVHdiQ89C7111
uD66+wbAczceXX6dhyG/L9vyueX+dOyLcf9T4JPGI9W3p8ruxZb/JOY92RHU
wXxXeaykWaNe2d/mbfp18nCvtraaAyLeq2dlac8svDPGoqlpfaBnXMMBOY/d
s5gFgS9zZQ3vGDOOjeZodunwk308bjGeEWah3eMO2VXNv4Q57HBL4kN5pN8S
3lWOL/jqdF8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 748->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsEJwzAMPPIo/WaErtAOYLpCOoELzStQSB8lv4zeGEoiyWc5EciysXw6
+XR5vru+AfA5L0sXv/dxjNPjlA6vONyuQ7ps/w7MYVmCjiVn96W36bya2K/3
cOpgiwpHWtjc42rzJW7Gt4BjucrarA+Q96V60tx/Jpb1WdMEOp/16P1ptR8g
+xPGRWkiI8H15s7TdFcPlgcIR8LLzpbVk9ZhNRiPGk+i1WGzM0wwmKYMh+bV
9FYYP5mEcx4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 749->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmcWXI4BQaOYgwxw2ItuPrp6ZHOx+QOfe7D5GV0O3W8M
BOxDBnjDGQvA8Ce637GZgcVPyP7AFw4E/cPAgBEm2NyCEifINBZziU136HqJ
8gO6OxiwuBGLu9DTFnp8YrUHmx3Y3EHInVjiiiyAJR0jA2xxis0MrOoIxTeK
GQAHF3Me
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 750->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk2dAwhjiMIDExmcWXI4BQaOYgwxw2ItuPrr6BixuaSBkFg61DFjk0P0G
dz+ucGPAlMcazlgAhj/R/Y7NDFxsBlR34UsDOP3DwIARJtjcghInyDQWc4lN
d8SEIda0iWY/zvDGk7bQ4xOrPdjswOYOQu5EsgM9HZIECOjHFqfYzMCqjlB8
o5gBADJJcp4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 751->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMfXRR3PYIvUI9gHgFPcEIdSUIdlHczdFVqHYmeTEGMhlN5uX3
nt3Y9DcAn2I9mvCtpynM7X37eIehfA2b8/FTIFbrUeXWUuZHour/Lsn9DOvw
4W8znFSMvBJfxkdSS/SwjFgQn+ztqN+aG7SfzpmI6lPOj2FYd+MN3bfVD6Bm
wriV7SS1BNflHXQ/Lr/kPBk/pZxwi9Wj8rAcrA6vTrFfxaOr4rxnO2UYNM7b
d4axAFI3cqA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 752->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRzkIE9AuNzK7r6BixuaSBkFg61DFjksPkN
Zj9WMxgw5bGGMxaA4U/08MNmBi42Dj3Y/IbTPwwMGGGCLX2gxAkyjcVcfOkO
2S5iwhBr2sRhPwbAk7awuQfDHizpDqs7CLkTLX4x0hGxgIB+bHGKzQys6gjF
N4oZALkociA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 753->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYMLcesRvIIeoHiF8QQVdDUgjAtx16M7BXXa5Es7gTYt+X8v
h+tjuG9E5LmbryG+ztMU35dt/tzieDqO2bj/HpEU5ivU2jtk92Lz/y/Fm3KZ
WFl0laeUsJxWr9o/QS+pl8vxFbDRbL/6mEOsHXEGMXNq/CiH93ZiaDZ3HhGD
Ce1HxUmpgZdWT2WtNRjibur6Ht6N3dJ8Yh3YO+yj16fi1+zRWunEE6eUA/0c
vhnXDy7ocuE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 754->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRzkIE9AuNzK7r6BixuaSBkFg61DFjksPkN
lxr0MMIbzlgAhjx6+GEzAxcbhx6s7mbAYjZafBHlFxxxTEy6Qw9bYsIQa9pE
tx9XeONJW+jxidUeLOkOqzsIuRMtfjHSEbGAgH5scYrNDKzq0P2BbCaGGQAq
JHRh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 755->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2ijwuvQwIGsUcZIBmBk53oalvwOIWdPdgmIVDLQMWOXz+
wWoGkvvwhjMWgCFPKE6Q1aCzGXDbjTVe8Ygjuw2vX3DEMTHpDtlOdP8Q8gdG
msISDxgAT9pCj0+s9mBJd9jcQdCdyH7Glo6IBQT0Y4tTbGZgVYcW/ihmYpgB
ANm3dSA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 756->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRzkIE9AuNzK7r6BixuQXYvVrOwqcWjB5d/
sJqB5D684YwFYMgTihNkNehsBtx2Y41XPOLIbsPrFxxxTEy6Q48zYsIQa9pE
tx9XeONJW+jxidUeLOkOmzsIuhPZz9jSEbGAgH5scYoNYFWHFv4oajHcAQDy
AHUi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 757->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRzkIE9AuNzK7r6BixuQXYvVrOwqcWjB1tY
YFODHkZ41WMBGPKE4gRZDTqbAbfdWN2BK77RwgSvX7DFMRFpC1ucEROGWNMm
DvsxAJ60hR6fWO3Bku6wuYOgO5H9jC0dEQsI6McWp9gAVnVo4Y+iFsMdAKuD
dOE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 758->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcZGCPwPjciq6+AYtbkN2Lzz0oavHowRYW
2NSghxFe9VgAhjyhOEFWg85mwG03Vnfgim+0MMHrF2xxTGS6Q48zYsIQa9rE
YT8GwJO20OMTqz1Y0h02d+B1J5I52NIhSYCAfmxxig1gVYcW/ihqMdwBAGlF
daI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 759->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2XJ4Bjz0MCBrFHGRgj8D43IquvgGLW5Ddi889KGrx6MEW
FtjUoIcRXvVYAIY8oThBVoPOZsBtN1Z34IpvtDDB6xdscUxkukOPM2LCEGva
xGE/BsCTttDjE6s9WNIdVnfgcyeSOdjSIUmAgH5scYrNDKzq0P2BbCaGGQAC
+nUi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 760->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRzkIE9AuNzKza16G5Bdi9Ws7CpxaMHW1hg
U4MeRnjVYwEY8oTiBFkNOpsBt91Y3YEjvtHDC69fsMUxCekO3U5CYYg1baK7
A1d440pbDNjdg2EPlnSH1R343IlkDrZ0SBIgoB/Fflzmo7sTSzhihBOGGQB1
n3Vf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 761->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRzkIE9AuNzK7r6BixuQXYvVrOwqcWjB1tY
YFODHkZ41WMBGPKE4gRZDTqbAbfdWN2BI77RwwuvX7DFMQnpDt1OQmGINW2i
2Y8zvPGkLWzuwbAHmx3Y3IHPnUjmYEuHJAEC+lHsx2U+ujuRaSzxjT1cAe8i
dWE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 762->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRzkAGSPD63oqhHE8PmXqxmYVOLRw+2sMCm
Bj2M8KrHAjDkCcUJshoGTLOJSgNY3IsefihmEzADgyYh3aHbSSgMsaZNBgas
8YAB8KQtbO7BsAdLusPqDnzuRDIHWzokCRDQj2I/LvPR3YkjHlHMxDADAAcB
dWE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 763->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcZIAkj8+tKOrRxLC5F597UNTi0YMtLLCp
QQ8jvOqxAAx5QnGCrIYB02yi0gAW96KHH4rZBMzAoElId+h2EgpDrGmTAZWP
M7zxpC1s7sGwB5sd2NyBz51I5mBNQ6QALOkYGaDYj8sOdHfiiEcUMzHMAACQ
nHYi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 764->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcZGCPwPjciq6+AYtbGgiZhUMtAxY5XGGB
TQ16GOFVjwVgyBOKE2Q16GwG3HZjdQeO+EYPL7x+QY9jAmkMV/hhiz+86Qs9
PLGkCQyAJ21hcw+GPdjswOYOfO5EMgdrGiIFoKdjNHNQ7MdlB7o7ccQjuttR
zQAAlD92Hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 765->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRz0AEeNzMgmYWuFt0tcPfiMguHWgYsctj8
hivc0MMIbzhjARj+JBQnDDjUYzEPZxrA4l7k+EYPL7x+QY5jAmGFL/ywhTM+
f2CkKSz+wgB40hY292DYQ0geSQ1OeSS3Yk1DpAD0dIxmDor9uOxAdydafOKM
bxQzALvgdF0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 766->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2NrMw9DIgaBRz0AA+NzMgmQU3B00Mw724zMKhlgGLHLp6
XOYi64e5D284E/A/shk444QBh3oiwhPDHTjiG5v/8ZmBHDf4wgpf+KH7h5A/
MNIUFn9hADxpC5t7MOwhJI+kBqc8kluxpiFSAHo6RjMHxX5cdqC7Ey0+ccY3
ihkAalV0Xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 767->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcNIDPHAYks+DmoIlhuJeAe9DVMmCRQ1eP
y1xk/TD34QtTQv5HNgNnnDDgUE9EeGK4A0d8Y/M/PjOQ7cUXVvjCD90/BNMX
enhi8RcGwJO2sLkHwx5i5fG5E1eYkQPQ0zG2MEEKV1xmNGBThyvtYvUPAP2r
dJ4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 768->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcNIDPHAYks+DmoIlhuJeAe9DVMmCRw6Ue
m/vQwwhfmBLyP7IZOOOEAYd6IsITwx044hvd/1j9jhwnSPbiigNC4UdsmGNN
mwwMWOMBA+BJW9jcg2EPsfL43IkrzMgB6OkYzRwU+3HZge5OZBpPfKOaAQCe
2HYe
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 769->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQtjk8elF8SHAyQ2PrPgcgwIGsUcNIDPHAYks+DmoIlhuBeHObjUYpNrwKEe
q7lo7sOrnoD/kc3AGScMONQTEZ4Y7sATTsj+x+sX5DgmEAf4wo/YMMeaNhkY
sMYDBsCTtrC5B8MeIuXxuhPJrVjTECkAPR2jmYNiPy470N2JFp844xvFDADa
yXYe
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 770->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EHXiw7wmYOhF9mtaG6BuxebOVj8zYCMsYUJ
FvVYzUVzH171BPyPbAbOOGHAoZ6I8MQWp7jCCdn/eP2CHE8E4gBf+BEb5lj9
wcCA1V8YAIvZ6OGGnh6wpT9C8njdieRWrGmIFICejrGFCXL84DCjAZs6NL+g
ux3VDACv/HQg
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 771->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EHXiw7wmYOhF9mtaG6BuxebOVj8zYCMsYUJ
FvVYzUVzH171OPyP7l+8cYKshgHTbILxgsO96OGEYjY+vyDHE4E4wBd+xIY5
Vn8wMGD1FwbAYjZ6uKGnB2zpj5A8XnciuRVrGiIFoKUTrGGCHD84zGjApg7N
L+huRzUDAJUpdaA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 772->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1KOI4dDLAFUPBkhsdH347EHXiw7wmYOhF9mtaG6BuxebOVj8zYCMsYUJ
FvVYzUVzH171OPyP7l+8cYKshgHTbILxgsO96OGEYjY+v6DHE56wwhd+xIY5
Vn8woPJxhjcWs9HDDT09YEt/hOTxuhPJrcjxSRZASydYw4SQHejuxBGP6G5H
NQMAoWd1og==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 773->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYyRxWDqscmj62WAqgcDJDY2czHMZEDQKOYgAwLmYOhFdiuaW+DuxeYHLP5m
wCOHLZxwhSu6+/CqxwKw+RdvnCCrYcA0m2C84HAvshyG2fj8gh5PRKRBXHFD
TBhi9QcDKh+fG9HNRg839PSAkf7Q7cCRPnG6E8kcZD+TBdDSCa64wGsHujtx
xCO621HNAAD/JXSg
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 774->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYyRxWDqscmj62WAqgcDJDY2czHMZEDQKOYgAwLmYOhFdiuaW+DuxeF/XGqx
yWELJ5zmorkPr3osAJt/8cYJshoGTLMJxgsO92KYwUCkX9DjiYg0iC380P1G
kj8YUPn43IhuNnq4oacHjPSHbgeO9InTnUjmIPuZLICWTjDcac+AGT9YzGjA
pg7NLxhmo5gBAAh1dKI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 775->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYyRxWDqscmj62WAqgcDJDY2czHMZEDQKOYgAwLmYOhFdiuaW+DuJeAedLUM
WORwqccWbujuw6seC8DmX7xxgqyGAdNsgvGCw70YZjAQ6Rf0eCIiDWILP3S/
keQPBlQ+Pjeim40ebujpASP9oduBI33idScWP2MAHOkFm1lY7UGzC6d56PrR
4hE9nLDbAwDps3Th
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 776->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8GJ0WtcI+2zFYStPEl7N9
9u58664rAPfN+Onq4zgM9XlaT4dL7Q/7fnJu5wW8yvgpepdL3i14z89vMeM/
Jv49XsOJ7654pCU8imPhKfrO5JtwMRaOL8J7urFGTbxjxp/1RGJgudO+BPka
DvxYC/c4iR/px7X9VQf0uZUjc7NuPA+sl4kRzGczT6dmY8G8SOM5cTlaMeC8
pz6yTn6cN/DgdmE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 777->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2C
hrEb7FHlwGwGVDl0vejicIDExmYuhpkMCBrFHGRAwBwGJLPg5qCJYbiXgHvQ
1TJgkcMVFtjUoIcRXvVYAIY8oThBVoMWF/AwxxcvONyLHqboZuP0C3ocE7Af
V/ih+40kfzCg8vG5EVfawuYebOGFYQeO9InXnVj8jAFwpBdkgJ5OsJqBzw4G
LPrR4hE9nLDbAwADXHae
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 778->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2C
hrEb7FHlwGwGVDl0vejicIDExmcWuhy6XhSAw14MdyG7AU0Mw70E3IOulgGL
HK6wwKYGPYzwqscCMOQJxQmOcEP2B64wwHAzDvehhxdev6DHMYF0gcst6H4j
yh/IAEf6RHcbrrSFzT0Y9mCzA0f6xOtOLH7GAHj8h+5mrPag2YVVngGLfmQa
SzhhtwcA4xB23Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 779->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKhDAMDB7Eq0/YL+gDil9wX9AFPQmCHsSbT1eXXU2TSWvApnaaZCbp
6zO2fUZEc3EsrV+aafLrOz9/Oj/U1XCC5e8j2tyxuNv/95sLse+eQkzGyvPL
2B7lUrF0+yAPNyNW8eIcxBniC3Ohu5GYWA9VDqHHvA9M4amZGH3jOqx+Ks4G
v9Rs1UyAt+pbXKS2Rzq4gTkgzHpbiI+q8xBP8gSalcX0Cc6wjqgFcQLx3IM+
4To7QFx1ng==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 780->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2C
hrEb7FHlwGwGVDl0vejicIDExmouul4GBI1iDjLAoRfDXchuQBPD5l6sZmFT
i0cPvjDEMAPNPzjVYwEY8oTiBEe4IfsDX3iiuBmH+9DDC69f0OMYTxzgCz90
vxHlD2SAJR6wyeFKW9jc04BuD5Hy2NIkLjMw3I7NP7j4aOkEqxn47GBAcge2
eMQSTtjtAQAVPHRd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 781->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPWB+u0IrAADRKxQJggSvCohtQ/UX0Zvi4A69tlYauLmYvt8
zvH27B8NgKldlz6/LuOY5+th+7nn4XwaNrD7fEBJ65L2/euXVGNvHzWmY/X5
z4RP8+pY7HuVR5oTa3hJDuqM8aW52N0gJtLQ5FD9uPeJGfzfTBzdZB+RnhVn
h5/WK+xFzziYQaSf7i2agdEdoHNgHL23xfiUoA7FHc4mnvRsLOpP5vHqqFoU
h+DB5kh04nUWV+1z3Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 782->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHRHyhvCBI9FQJqRwQtzydFkFwxmOXSFkcx/bM
OPvLrR82InLv5qXPj9M05ed5uxjXPB4P4+LcfaZISfOSfvv3XFLre5+l9WFs
gbd1KJvmJbE1B+ZSOVmswaUxwB2+Z/wYb9Ez0MSzC8RrPq7OZBj/Pz1x9K+a
B3o2mB18iJ9y1z0hO6sf6Yfc1npg/hTpA8Po/S2GJ6pD/Q5mE084mxHx03m8
OlCL+kXhYH0kOvE6L2J0c98=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 783->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHRHyhvCBI9FQJqRwQtzydFkFwJjMplbK4ju2Z
sfeXWz9szOzezVsfH6dpis/zdjGucTwexsW5+yyzFOYt/M7vPYXS975b6cPY
BG/z52yal8TmHJjL5WSxFS6PAf7he8aP8Ta/GpooO0G85yN1Jl/l/6cnQv+s
udCzwizwIX7K3feEnKq+woLc1npQzRTpA8OoZovhoT0j2qCfzWQRTzirOk0b
5oTmaNUwh4P1kejE67wACiFz4Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 784->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADKr4wXlAkOE1C2g4Ttz6dDUFJXbtj0rp2SRzb
6eH66O4bMxt389LF6TwM8XnZLodb7E/HfgnuP69ZCvMSft/vPoUy9t5bGcPa
BLn5cWeKS2ozBmI5TFZb8fIc4B/mSyyRayRG9Qh+hba1fOJnFf9nJsL/7Lnw
AHPVvNGvphacsfBTeVrwXvGQ6a14eH8IR3W3GJ9qZkQf40G99vVEs+rTPMM9
oRitHuZ4sDkSn3ifF4rQdJ4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 785->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKgzAQXPwo/fUIvUJ7gOAV9AQR2q9AwX4U/zy6Bmq6mcxGA3m5m3Fm
dm/ju381IvK5bkvvv900+Xm4xMvTh8c9xGD7myKL2xb33/fz4vIYnnEW7/RQ
9zO4iRe8RcwaJ0Ee5Bvmm1hGrpAY1WPwy7Qd5RM/izhqZxjMf+VHrcaJtxjY
qm6ntGCNDT8tT3X+kYcYY35m/hCOVm8xPkXNiD7Gg3qt32vNLAf1WHfoE4qB
9SEDe4LiI172nxVWx3Wc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 786->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOgjAQRX9cGLcegSvoARqvgCeoiaxITHBh3HF0IYEw/PlT26TQMtPH
/zNtHq+2OwB4n6ZHmz+3Ycjf+3HePHN/vfRz8LxMYEzTI23vdT2mfYzXPN05
O8y+igXDYJZhljhgHeIb54esIBcipmqmuPa89RN5UvV0Ptm7YiiN8LxSn1mv
Y6DSi+1xoZ7SC+XX1NB5YB22PkJjdLeUHtcziLjQ8Vcn9d7lsJ9oT/dEMmx/
gsF3QvKZt/vPD60Odds=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 787->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgzAMs3ZAu+4JfIE9APEF9oIisRPSJHaYuO3pg4lD6jqBSC2EpMZ2
Wg+v/nkB8L6uW58+3Tyn5VFtyZimezNtxdu+gG+7bm3+tAvOe9T3z22Y/BQW
DAZjGcyIM5iH+Oad8fhwL0RNeRZxZD2hJvIzm53wRM5EaLJ+RHPJeDjzLrAd
P62OIz+lFuo/46H0EpBzUBwZm31j/kUIb7h+yJNmX/SwHi+ne+LV5XkTfCck
PnHP//UDPaB2Gg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 788->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBxS/UF0TQU0FoD8WbT7cFhdnJ7qaBJKSTTGdm
93R/9c8dgOmwLH2Zr+NY3rf9eniU4XIeVvD4m8CnW5bO7jz/dyI8wsyg8yYu
EIdyEWeomT2xBvkWvcky4LtwMNUU8fJ79pN6kjxN7ZxMKt3wMc4jq4vREdR7
S8+oj1aeaQ1Qe2v2V9Kfbt8E3Jqb6q+Gk43iTZ1S++qO+onO7CPB3fc0tCdc
ftFu//UFDqF1XQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 789->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDil+oL4hgTwWhHsSbT7cFhclkJ20DSdjOZjq7
s8fbo+t3AJ7NdHTpdRnH9L7u5+CehvNpmMHDbwOfdjra/Ob9z3G4w7JF8Sou
EIdyEWeNB6oj+Kb5lsvkIsBUk+Pl91yP9UFrUe+CnhS6EWPcj5ovmQ7j95qZ
0TrU400eoKxtcb4q8xnOjeHWvuk8FCvojeKLOsX7IkfrcTHXUcHD97R0JkJ+
0Z7/6wvuD3Vf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 790->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPIo/WaErtAOELpCMoEL7StQSB+lP4+eBBqQzydhg21kSefT
SZfHe3x1AD7n7RjT974s6TedduOZ5tt13p39fwN52I6hvO0+Yjy/5yuWsZuw
bA5jGcwIB8xDvHG8i+XEQviYk4dr8209bh+4Fu6d0KTiDe2zekR9KXg4/W6Z
Ga6De9w0X6R/i4ZSS/4/4OjNluKT+Q8Iv+AR8iSMaoZUPco+3iI9qNfe4png
/MxvFY8VFkl0oA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 791->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHHoQr32CX7APkH5BXxDBnoSCHkpveXoVFOLsbJpAEja7O5nZ
3WZ8968bgLXejj58nssSvkO1G1OYH+28O+/HBmK3Hd31TvcZ4/k932UldhFW
msNYCWYOB8xDvHG8i+XEKhzmBJGvMDhHxlM9jU6hXdXV9BUWL9dn5msw8EcL
6eAeF80X1bakhrKW/H+Gozdbik/kPyD8gkeWJ2GYGVJ6lA3SoeKp197imeD8
yG+G6w/JDXSi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 792->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAUHFyUbj1Cr9AeQHoFe4IU2pVQ0IV059HV0sXLZN6LgSTGvAzz
eZfnp383AKbztvRpvo9j+j5O++GVhtt12C/b/wSWblu6fLcTzndU9zvbYc6H
sOwbxjKYEQ6Yh/jH9S6WU6twlGdeDYhf5I3yodAptCtf+U7hRTkz3wIDFS02
E7s7fsr+osyOeOh6KXJQHL3e4jwLnYQV8ahlbjGKHlJ6nJHpUH5Q1jWcrM7J
RnNdAXRkdKI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 793->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMPPGo+mWErtAOgLoCnSCV2hdSJXig/hgdqPpwLmcHS0lw7Bz2
nS/PT/9uAEznbevTfB/H9H2cdueVhtt12IPtfwFLt21dftoF5zvK+/nWjH8I
y75hLIMZ4YDrEHec72I5uQpHceblgOqLuFE8FH2K3hWvHFN4kc5cb4GBSi9W
E9Cd4ErOF2l2hEOXSztrTo0Km3ljrQsT3HC8pnnGmZih7Aws60PxQVrXcIr/
C210Pyv7yXWg
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 794->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMi3ZAXPcEvgAPmPjCeEGR4DQJaRwQtz19G+KQuHa2Sm2XLnUd
O6f7q382ZvY+LktfPtdxLN/bYQ0eZbich/Vn+59mU7csXdz9NPGd5f1iP1y8
C8vfQSyHmeEY8iBnmC+xRC7DUVqwHAN+mTZMB4/NNKGeEE4BL/El8BDnFbby
1+o7Sk9aC3i2R0Oppe81wZFho26+HqwJ61U8tjwPmpEeCnsysE+qN8DrLZzq
feINr2cGEhl2Xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 795->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPqPhCeUGQ6KlSpXJA3Hg6LeJgOzMOkbLYcSae
sY+3eRh3AB7dugzleVmW8rruN+NepvNp2i4Pvwm8+3Xp/W4nxDmL+9p2GPsv
LPsmYhnMDAcxD+KL8RJLxDIcpQWLQcgv04bpYLEtR6WN0w3BD/03zUP4K2xV
X9RvlJ6pJoRbs79Uf6q+EdhRN8sncop8VR6tmjvNSA+5PRmOB9Mj1LqFU/1P
asP5fACeCnZf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 796->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnyizkPWgm4VkJj5zGNDdgUUMXT1Os3CoxWYOrrDApgbd
b/jCBhtANhvZj7jCBiXcGDDNJhQvDchuxiGOYTY+v6C7H0d44kubKHFKQlpF
AWjhhzW88aQt9PjEGWdYwgaXHVjl0czASEP2aDQegOIPbOGBFteEzMGwH0vc
YPcPANhfdaI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 797->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnyizGJDMQDcLyUx85jCguwOLGLp6nGbhUIvNHFxhgU0N
ut/whQ02gDWs8MQnSrgxYJpNKF4akN2MQxzDbHx+QXc/jvDElzZR4pSEtIoC
0NyENbzxpC30+MQXZ+hhg8sOrPJIbsWahuzRaDwAxR/YwgMtrgmZg2E/lrjB
7h8ALYd1pA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 798->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnyizGJDMQDeLSHMY0N2BRQxdPU6zcKjFZg6usMCmBt1v
+PyEKwwwwgpPfMLUoLsJxTw88dKA7GYc4hhm4/MLuvtxhCe+tIkSpySkVWzh
iC1MkN2KK22hxye+OEMPG1x2YJVnQLUDIw3Zo9F4AIo/sLgDxWwCfsFQhyNu
sPsHAIq0dyQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 799->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnyizGJDMQDeLSHMY0N2BRQxdPU6zcKjFZg6usMCmBt1v
+PyEKwxQwgjd79jMwOImbHrxxTOyenRxDLPx+QU9rnGEJ760iRKnJKRVrOGI
HibIAE/aQo9PfHGGHja47MAqz4BqB0YaQk8PeAB6GGHYgRbXhMzBsB9L3GD3
DwBfinfj
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 800->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfEbU9nQxwS14lKpbbLGjmJ
7cP1Mdw3AJ675Rjq6zxN9X3ZrsGtjqfjuD7ufxuYy3IUf9uN4DvL+8Z2mbgL
CwaDsTpxwH2If5wfYgW5CifiQuXwbNlMEQeOI55dYYieHF6iy1zaWhKjdxbW
OuAz86bT9A+vSh4FJ7bXyFusZ6YZcxPVkO/wNRoPsR+SxRw1NRRugtPUF9ro
eT4e0ncm
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 801->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg1AQG7oobnuEXqE9gHgFPcEr1JUg2EVx59HVUsq8vEzqwPsPeZlk
ro+x7U9m9qq2qU3vZprS3J33wzMN99uwP16+w2ypt6nOVz8s2Ku8z9mHOx/C
MoeBWAdxDHmQO8wPsYJchhNpwXKwNlVTpMFvJT5STwinDE/4snjOET/EVrUE
XkdaqXvk9K9Xs2D9iW+it9BP5RlqgzwkT9Co6CHQUQVqVPzBcAVO8T/xhtez
AjSDduM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 802->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKgzAQXPpR/O0ReoX2ANIr6AlSaL8EQT+kfx5dLSKbycwayGOTZTI7
s/d333wvZjZW69Kk6TUM6ddet+CTuuej2x5v+zSb63Wp891PE+co7x/74WL/
LrHMYSAW4pzwyTjAHeZLLJHLcJQWLAdri2pSGhw78ZF6QjhleIHHs+es+CF2
VIvwWmkV3SOns15lOjJNPFfVW+hn5Blqo/6g76BR0UOgYzRQo+IPhhvgFP8T
b3g9C55eduU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 803->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESH1kep1kMSGagm4VuDgH3oLgBTQxdPU6zcKjFZg6usMCm
Bt1v+PyEKwzgNJZ4xBonWNyEzTx88YxsDob70M3G5xcccY0rrPCJo7uJUFpF
ATjSJ7oaXGkLPT7xxRl62KC4hZA70cIIm350/2AFWMIUqzy6uTj8gmEvjrjB
7h8AYnJ2JA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 804->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KgzAQhQcX0q1H6BX0ANIr2BOkUFeCYBfFnUdXS5HJ871xIInJDJ9v
fu6vsesLM/vctq1L38c0pflZ7pd3Gpp62J3Vf5kt7ba1+emXie8o7nf35u7e
L1nmGMhCzoWeTAO8YbxkiVjGUbVgMZhblJOqwXGSPtKeEE2MF/XZc076kB3l
InqtahXOJmi6mtXMxHxijJot7GfUM6yN+gf1Q41Qu7E3ZqSm1I9cYjgTjE+Z
B3sF07h2Jg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 805->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESH1kep1kMSGagm4VuDgH3oLgBTQxdPS7/Y1WLxS34wgKr
uTjMweoOHGEAp7HEI9Y4weImbObhi2dkczDch242Pr+gxzGBsMKbNtHcRCit
ogAc6RNdDa60hR6f+OIMPWxw2YFVHi2M0N2OzT9YAZYwxSpPhHnoaQKb+VjN
hJsNACgJdKg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 806->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHLoQtz2CV9ADPLxCPcETdFUQ6kLc9ehtRSUZJmkD75uXvMlM
DtdHd28APPfz1NXXeRjq+7JbDrfan4794my/AxjLPBW/2oFgn737nK0Vv//5
w1wwOTgXfGyECYyD78T7qH7Gypi2cCHzBnkkjoCD/yp0zGp0/4l8mc6SP8vz
1lpY4xWu0t4kTGu96ow4kHwnvcV6ZpoxN9Ef0k8cMXZVj7SIPxuvdBLGPeHi
SRuNdQLlXHUm
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 807->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDP0Qf3sEr6AHWLxCPcEK+lUQ2o/iX4/eVlQ2szNpYN/JZDLZ
0/3VPRszG4/r1OXpOgz5fTtsh0fuL+d+e2y/w2xO65T8Wg4T+8jvcy4t+f3v
XWJZgYFY5mMVJ0Me5A79Vf3Ul3CJtGC5FA7lITT4r6SPFQ/QALH3+uJqV/wQ
O6oFeyzyR71RnPb+qjPyJyoL/pbraYSBOQiPkCdohNxZPdSIRlU86xMx1N/F
J+BJuS6geHPn
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 808->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPoh/fUIXkEPsPQK9QQr6FdBqB/SP4/eVlQ2s5PYwL6T2Ukm
h8u9vzUAHu0y9fnZjWOezrv1cM3D6Tisj/vPAF5pmZJdywFnH/m9z6Ulu/++
u1goMBgLNtbjBOYh7tjfy1/6Ci5RLdRfHo7k4dTgtwodpSaCk8KLdC5xKn6M
HeXiaL2lvzhP5vSvV42Jnqgs6C2jaYTBfwgeIU+qEXNX+UgTNarihU7KuP4m
nvpOc50B69x0qA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 809->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOgzAMtDhUXHlCv9A+APUL9AWpVE5ISHBAvfF0kraq7OnYsZQEJ8N4
vJwf8zA2IrK2eRvSdluW9LqfivNM0/Uylcfuu0T2Pm+9PfUS5zvCvX1tytfv
LpcoDuRCnooeowHuEO/lT7FES1QLFsvjoTqcGvxO0sc/HVAD5K71xeTu6UNu
NkcEy/6NaorcqKk2q8ac+USMN1umpxEHxmA6Ip1QI9TO8qEW9UTpkCgG8Bgc
mTU275/7Azt7dOU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 810->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwzAMFDmUXPOEfqF9QOgX0he40J4CgeQQesvTY5sW5PFIWOBFthiN
Rrq+lunTicjWx20K+2Ndw/d5Sc47zPfbnD6H3xI5xriN5amXGHcvLvvalN+E
JQoDsQycKj/yIG8Yb9VPYwkXUwuG6eBQHoYGujbUwsqrNUY9WD2I+c9Z8SN6
MS5mTxryt3Ky5ovpTucTzZktxPV6htpUPJw5Q42QO6uHmtcTxUO8HIBTxJFZ
o7rn9xPU8nPh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 811->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJTZRZDAgaxRwG3OZgs78B3Q1YxFDci8NfyPZh8xsxYYGh
H90cAmGDKwyQ/YYeFrjsRQ5jZLPRxXHFMzZ/o7iDQPzgjBM89uMLZ2xuwpW+
sIU71vSJDvCkLXRz8cUZethguANXOkNzK3qYkQTwxQmSOxgI2YEl/NH1Y0sb
qGYAAOeEdCA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 812->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJTZRZDAgaxRwG4s1hQDILbg4WMRT34jAH2T5sfiMmLDD0
o5tDwE+4wgDZb+jxiMte5DBGNhvZPHzxjE0Nijuw+IUBXS22OMES1oTCEJeb
8KULjDSFLX2iAzxpC91crGZgswObGlzpDM0c9DAjFeCMEyR3MBCyA0v4o+vH
ljZQzQAAyvhzoA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 813->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJTZRZDAgaxRwG4s1hQDILbg4WMRT34jAH2T5sfiMmLDD0
o5tDwE+4wgDZb+jxiMte5DBGNhvZPHzxjE0Nijuw+IUBXS22OMES1oTCEN1+
otIXenhiS5/oAE/aQolTfGag24HNHfjciRZG6G4nBeCMEyR3MBCyA0uaQNeP
LW2gmgEALe90YQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 814->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJTYy5cHeh6UUGhNzEgGQW3BwsYijuxWEOsn3Y/EZMWGDo
x2MOVjNxhAGy39DjEZe9yPqQzUYXxxWu2NSguANL/DCgq8UWJ1jCmlAYottP
KF1gxB8DA9Z4wAB40hZKnDJg8SeaPXjdgc+daGYg6yEV4IwTZDPR4gWfOSjq
cKQ17P4BAE+8c18=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 815->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+LNp9uCLpM4idvAbnfbZDKT
6e58668rAPfNtPXlcRzH8jyt58ulDIf9MH/cfhbw6qats09eCM5Z3vdeg84t
uJWXq+X4xwmEVXEctx++AY7MJdyWWaheEY7EDGbA2ryPmUbuqfAyn1WO4SH8
gc/1nsDWLpmh4t2kAbavmol/r/4twwdCp+uT8sh4+hlRzdIIPWFM50uGY/IC
b7SeN3XUct8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 816->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBxS/UF0TQU0FoD8WbT7cFDZPN7DYLSZNmMszO
5HR/9c8dgOmwTH2ar+OY3rf9unmk4XIe1sPjbwCfbpm68ssDzjrC/fe5aN3C
m3WZu1xbmkBcmcdoq/Q6PBJLvC1eSF6HR+IdDwqPRO9ejwWe+RpyVn2zxyof
eFj7D9oD+b6cfqJ3UeUHyByqCt6WzdPNTHhTnUc6rUd0R/YSlMzE6OCst3gK
nJet7OcLlwBz3Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 817->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHHqQXvsEv2AfEPoFfUEEexIK9lB669OroLK7mU2ykJglu+Ps
TNrx1T8vAN7Xdevj57Es8Ts0WzLF+d7N2+VtX8AvrFvQX7ngnHN1R36GONfg
nrxMr4wSJzAOhhurpzisVuDWaFHDL1vvaKA0Mv3Uk6D7JHZOh2R2xo/oxbhQ
T6B7Sxoi8P7Su0j8A6gPSRBsppuanWBYbZL7HE+rkeXOcidcTwQPeP8gOKrO
8YbP8we7w3Me
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 818->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkKAjEQLDyIV5/gF/QBwS+ML4jgnAaE8SDefLoz4NJdqWTahmykq1Kp
7t352vUrALfNNHX5fhzH/Dit58MlD4f9MF9u3wN4pmlKfrUDlX0r73P+htmH
uPBbHQ/iPFAaSJvKlzwq1/BGvIjoa+ZXPHAeEV7WJHmc5V6qi/u70if8Ulpk
TeCxSx4iaXyov9hPUYciBDf7VvxdcLA3xX1LJ3vE2v+Iak2MDgTe4J5gvOoN
/9YLxmFz3w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 819->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJTZRZDAgaxRwG4s1hwOYGNLdhU4/VHGxqkcwlJiyIcR9e
9TjCACWM0PRjjRN7VH3IZhOKlwYc7kVxB1p44fULFvfgcgcuv2DzD8H0hR6e
WPyFAbCYjR5uGH7HYgZ62GDI43Mnehihu50EgB5G2NyBbic+c1DU4Ygb7P4B
ACimc+E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 820->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJTZRZDAgaxRwG4s1hwOYGNLdhU4/VHGxqkcwlJiyIcR9e
9TjCACWM0PRjjRO0MEY2m1C8NOBwL4o70M0mYAYDun4c7sDlF3T9RKUvLG5A
9xcGwGI2erihpyFsZqCHDYY8LndiMQOZTypADyNs7kC3E585KOpwxA12/wAA
FZJ03w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 821->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+9ei24CM7mU13IS8yO5md
zeF67/oNgMdunrr8PI9jfl22y+GWh9NxWC73nwFMaZ6SXcsBZ9/Cfc+/KPYh
LvxXw4M4D5QG0qbwkkdhhZaWFxF9TbzjgfGI8mVPyOOSe60vk6PX6GDuFQ5w
vqPDq4XzQ/9LaOC6qhDc7FtVu+Bgb6r7xj+rPIKDCQR7pHTwmy0eg1O98XjS
G/c/dCI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 822->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJTZRZDAgaxRwG4s1hwOYGNLdhU4/VHGxqGVDNJhQWxLgP
r3ocYYASRmj6scYJWhgjm00oXhpwuBfFHehmEzADmz+ICUMGdExEGOKLP3R/
YQAsZqOHG4bfsZiBbg5J8uhhhO52EgB6GGFzB7qd+MxBUYclreE0xx4A30Ny
4w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 823->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRT8upFuP4BX0AMEr1BNEsKuCUBfiLke3FYXM758kHZgkJZOX
Pz893h79sAPw7Oahj6/LNMX3db983ON4Po3L5uGXQArzEOycJ5x1re6b/8jW
TSysZ44aR2rI96DrJUfVwrI9L0q+sr5iveOB8ZfOKx3IeMyuvUty9BodzK4w
VB8tHoKzwcPS+3FfqxBsc171LhjM8e6Q++wRa98Q7JHSiYY7kqoT/5rLCR+s
HnMi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 824->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWAyaNDgiZg9UNyHIM2NVjNQebWgZUs3GFBb5wRXcf
XvU4wgAlfNH0Y3MHA5J56GYTipcGHO5FcQe62QTMwOYPUsMQWT9R6QtL/KH7
CwNgMRtFPza/YzEDPWxw2YFVHj2M0N1OAkAPIww7kO3HY0cDNnXY4gaXOfYA
LQ1z4w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 825->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMYeBeHOwugFZjgG7eqzmYFPLgGo2rrDAF67o
7sOrHkcYoIQRmn5s7sAmh2IennhBV4shjiW88PoFR1yTGobI+olKX1jiDz0e
MAAWs1H0Y/M7FjPQwwaXHVjl0cMI3e0kAFxpAMUeIuxowKYOW9zgMsceAOXi
c+M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 826->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMQcZEDAHqxuQ5Riwq8dqDja1WNyCy284zbXH
bgY+dyADjDBC04/NHdjkUMzDEy/oajHEsYQXVr8gxwkWfxBKX1j9Q0QY4os/
9HjAAFjMRtGPze84ACnpCJs7YGZguJ0EgCsNoNhDhB0N2NRhixtc5tgDAGUe
c+M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 827->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMQcZEDAHqxuQ5Riwq8dqDja1WNyCy284zbXH
bgY+dyADjDBC04/NHdjkUMzDEy+4wgPFHWjy+OxDVovOx5e+sPqHiDDEFZbo
bmpAk8dlNnK4Y/U7DoAvHaHbg80dKG7GYw8+gDNO0NyC1w5s4YCsF0d8o5oB
AJEDdCA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 828->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDV0Utx6hV6gHGHoFe4Ip1JUg6KK4m6NXS0tf4ks0kMkMyby8
fC6Poe1OIjJVy9Hm120c83w/r49n7ptrvzrrr4qUtBxJW1Rx7ntxH/0J3A9h
yd8qHJQdHMoB8JELxlMcFku4eLW5uIljRDxQNj0y/xkP5lN4wVy8fhSbX7a1
sHyIZd/RftF6DvTQ66XlVIzfw1b8SW88ifbI5mE8FOcgTyTuTAyXMIflidbO
xsNJb2lfdOE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 829->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMQcZEDAHQx+yP9HcguxmXObgMxtfWOALV/Qw
IqieAdNelDBC04/NHVjNRjYPT7zgCo8GdPsZMP3CgMU+ZLPQ+YTCFN0/xIQh
vvhDjwcMgMVsFPdjCRtcgJg0iivOcYUZqQBnnKC5Ba8d6O5EptHjBpc59gBn
4nWi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 830->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMQcZEDAHQx+yP9HcguxmXObgMxtfWOALV/Qw
IqieAdNelDBC04/NHVjNRjYPT7zgCo8GdPsZMP3CgMU+ZLPQ+YTCFN0/xIQh
vvhDjwcMgMVsFPdjCRtcAMMdWNyPK85xhRmpAGv4odtDyA48/sBqNlZ7AN4l
deE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 831->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMQcZEDAHQx+yP9HcguxmXObgMxtfWOALV/Qw
IqieAdNelDBC04/NHVjNRjYPT7yguAObGWjxh9MvyHGCxR+E0hc2/xAThvji
Dz0eMAAWs1HcjyWt4ALYwhJrmOJwB7YwIxVgDT90ewjZgccfKGbjM8ceAM1I
diA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 832->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMQcZEDAHQx+yP9HcguxmXObgMxtfWOALV/Qw
IqieAdNelDBC04/NHVjNRjYPT7yguAOfGQwE/IIcJ1j8QSh9YfMPMWGIL/7Q
4wEDYDEbxf1Y0gougC0s0e3AFee47CQVYA0/dHvQ3YdFDS5/oJiNzxx7AHK4
diA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 833->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRb84IK6MwAowQMUKZYIg0VMlpHJA3BidFoH4dr5jLDlJG+fl
x/bufO2HFYDbZh76cj9OU3mc1svHpYyH/bhsbj8OPLt56OzMjmCdxb39a7T+
i4XfbDhsCUdqID5r4XjJUbHQHKUp5Dp9aTzqe02O3HmlQ7KZ16iL0dFiIHkL
10S8I+uvKodCU6s/VP18HSoL2Jw3rz8ylUt/h9z3OQv6Qv4TGrgfJEPdH+lw
7zDsJucFCkV13Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 834->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzydFoGwp+Oklhxnccbj
SQ7Xe9dvADx209Dl53kc8+uynRe3PJyOw3y4/zpQ0jQkH60jmLfyPv4zM1+F
hX90ONYaOI6DWRfBpdD5Yl/lQuMoTiEuadTMx7Ku04juKx4S2+JV3sXxqGGg
0YvpWfXR+l9Ov+Tvc/4aLV195mi4KmyrG/OPTGnJNaI3j2qqnJrxf5AYzK/G
AxSFThrnDQ1fdhw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 835->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREcsULccgSvAASKuUE4QJLqqhNQuELscnRaBsJ1xXEv5Nc7L
eJrj7dEPOwBzt3R9fl6mKb+u+3Vxz+P5NK6bh28DSlq6pEfZ4MyjvE/7hZhv
YuE/Ko6MgKM0iHUhWorZr76Da2QcpsnlGo/CfNT3Ko/MeaaDsiWv8V+UjhYD
QS2iZlZH9L6Uf0mft/mbvDTvhGn02NI3q98L5iX1lDGcO2k9jbDvgTKsvpYO
oPLR+sQ5b0xNdls=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 836->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAFSuECVKpvCohtQ/EL6OTIqrazjnBkpO0Ts7n
s8/DMzwOAJYuLyG+bvMc3/fj+jHG6XqZ1uDp50Dq89LrXTqcc+ve1zcT57+w
sO8KR1oDB44nwiWZePEfnCPDYZxcXKNR8z7KvEoj857xYDGFV+mL4uHoIfvn
1iJqZnW05sv2NxFO1fmyWsr8DkeGrfiTWfGMaUk1ZRhOTlpPxYp5YBiWX40H
UOhodeI4H7zsdpo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 837->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAFSuUCYIEr0pI7QPxy+i0CIR9OSdYcpzWzuVy
9v5yH24bAHO3LEN6nKYpPc/b9eOaxuNhXJO7jwO5X5beR+sI9q26t3/N7P/C
wi86HGsNHASeBZdM+eI/NEeFoziFuKRRsx7lvU4jOq94qJzDq/TF8Qj0sP0L
32LerN7Rmi/ubxacqvPFWoo+FDmBzbox/8iUlnxH1HOnWaOmZsU8KAzmV+MB
igpb4rwACgN13Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 838->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBi19YX1DBPS0I60G8+XR3RTFJZxoDaVqSTieT
7s7XflgBuG3mpS/34zSVx2m9HC5lPOzHJbn9OPDs5qXz0TrEPqt7+9fM/i8s
/KLDsZbgIPKwfQYutp7igHNkOIyTxA0apfWo33UahfuMB8s5vMZcHA+hh52f
7MX07PoQerZ6cTNNNJRakjlUOYIddYt/RRnTMr6hZu40S2paVv0HlVd4kQdC
ZNgU5wXf93Xf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 839->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOgkAMnPBh/PUIXkEPQLgCnmBN9IvEBD4Ifx4dMBr7mFKadHfJlunM
dM/3V/usAAzHZWnL2PR9mW6H9eNRuuulWy9P3wTe9bLUepeJ4JzVffIX4rwL
C/9d4chIcGB5SJ2Gi6ynOOAcGQ7jFOIaj9J6+L5Sm/WE8WB3Cm9jLopH5Ifx
i2ohtezfzFM308TD0EsyB3dHsK1vTnsQzEvbI5q58oy8Iadng4Pzz/bZgRfp
YLPhembZhHWc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 840->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMQcZEDCHAd0dyP5EcwuyeqzmMOAWxyWHj48r
jAiqRwMoYYQlHrG5A5scinl44gVZLYZdSOLIYYLVL1jUYtNLKEwx4pRAGOIM
S2z+QpfDYjZ6uGH4HQfAcAeWNIorzlHCDEsawvAPHjdghB+6PUSYh88fOMMS
xR4AdlZ0XQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 841->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDS6KW4/QK7QHEK9gTzCCroSCLsSdR1dLxXxejIHMh8m8vLzk
2XzrLiOiMd+WOk3VMKT589gvberfr35/LP5OtJTbUsqdOznnKO7nh7HzLSw6
d4HDLcAhzYPXqbjw+Cs+Jh7gIE6erlqjMF6Z0Aj0EfFAbwLvoi+Ch87F6uCa
wFpALPobaWp6Gmjoagn6YN4AtuCv7ovOwcxoAWbU67mX0+AEZuYB5bmBp2dC
/PW0FHlWjG112w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 842->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBiE2UWA4JGMYeBeHMY0N2B7E80M5DV43MPhnos5mBzE65w
RQ8jguqxhAFKGKHpx+YObHIo5uGJFxR3oNuF5A9C8YNNLTa9xIZhA5qbCKYv
9LDEEg8YcljMRnE/Gr8B3Q4kgBEWWNIorjjHZSeGOQQA1vBDt4cI89DTBIpe
XGGJYg8AqwR2nA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 843->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJTZRZDAgaxRwG4s1hQMYMCHYDFrcgq8fnHlz+IyYscLoP
KYwIqscSBihhhKYfa5xgi1dk8/DEC4o7sIQRslvw+gWLWmx6iQ3DBixuwpu+
0MMSSzxgyGExG8X9aPwGdDuQAEZYYEmjuOIcl50Y5uAD9qgYq1vR4hqfXzDU
4TIbqz0AwOR3Ww==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 844->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOAjEInHgwXn2CX9AHNH5hfUFN9LSJyXow3vp0dxPtUjogJBRIKQxD
D9fHcN8AeO7mY8iv8zTl92W7BLc8no7jcrn/KlDSfKTWSoXhe3m/uIrwQ7Ww
2qYO4nUgFatfCBaZz2bSuXq+CBcmPsGRxUfHp+jbcKRxGz27vcp6URxkZxKL
OzvJZW+jHBaCyf1fmkuyh+6O/QuJX8VF91D1NZfV/tm51bOr40lqlWJl+Ih4
c9R7ja/p8wE7+Hbb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 845->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3Pt1d0G06SWoCaVOaTiaT
Hq6P4b4B8NzNy5Bf52nK78t2OdzyeDqOy+X+60BJ85LaXTqcuJf3O68m4hAW
6t7gII4D6ahxMbjIfKsnzuX+Ilq4/IRGnh6SM2vQaMS8nZpqrhLvHw+qpfiR
XmbvRq71NqphMTh1/xfracxBmfUvJH86ezNjnKY+z8XhYdVUOD1LrXv9RvB6
faz30HGt8wE8o3bd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 846->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRb84IK6MwAowQMQKZYIg0VMlpHJA3DI6rQSp7Xy7teTEUVL7
+bun+7PrdwBeh2np8vs6jvlz28+HRx4u52G+PP4cKGlakt6lw4mjd/9zNRHX
ewS5sOwqj7A1JkjHEhfCIt9HPF5/W7Rw+YRGnh6S2WqgNDL16EzYXGW+NQ5T
q+EzetHeyVv27VYNC2GK+mj+KTKHxkhuxW/O3sxsHlXfzsXhYDWbPJEl7YyV
8hGL+qj3aOOF5Qsme3ee
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 847->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbn24LuptMkt0GspuQNDsz
6en+7IcdgNdhOfr0vk5T+tz2a/JI4+U8rsXjz4G5W45O39IRxLW+f55NxLmO
yiyUW80R1sIE6Sjx7GCR/TU8Eb8tWoT4hEaRHhIza8BaMfeII5zZrR0r3hE+
0svl7vR6327VkPm3eJh/ytmDMWe2wk95tDOeo97nvQQ4zJ6ZR/Q2zTD6CXPx
OVbjkeuwccHyBWLud90=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 848->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUsKAjEMDS5kth7BK+gBBq8wnqCCsxoYGBfizqM7A1JfkpfYQNuUtHmf
HG/zMO5E5NGt21Cel2Upr+t+u9zLdD5NW/HwXSLvft16feKSIG+p1YC81sVj
2Zr9ixHhKnzkgTpND3yf8Yn0ZZ5lvlqPIj+cn4BrvbLaI41qdtivlQfxCOeV
aidv2d9WD63+fzqcl2QOLkhvxd/caQ/SR+HbuQQ8GKbrE2Cr3PoHQfmRyHTU
uvj8x+MDwrx3XQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 849->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQHVyIW4/gFfQAxSvUE0TQVUGoC3Hn0W1Bhpc3bxIH8mkmnfeZ
HK6P8b4xs+dumcbyOs9zeV+268etTKfjtCb3v2H2GZZpqFccluz/yXnA3vMW
sTjH/2JkuBU+8kCdVAPvt/jwmarT8ynwA48yP4KfgMtesfZMY9U7rNfwoeKR
+UF+Se3iLvqR4Wb9Zf2tdyG9FH0IIWr3+EuMxEtfOz3PMEMdFXyX/YOQ/ES0
dHhe4fvZF44Vdhw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 850->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJDZdnwGMWA4JGMQcJEHITAzY3IJmPbj8DPrOwuBWbW/CF
BTHuwxUeGOGJZC96WOGLTwYccijmERHP2NyLEs4E4gebWuTwIDp9occpgTDH
GZZY4gEDYDGbkPux2oEjLOE0gTjHZSeGOdgAulr08EMCWN2HBeDzB1wem/1w
MQAho3bd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 851->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJDZdnwGMWA4JGMQcJEHITAzY3IJmPbj8DPrOwuBWbW/CF
BTHuwxUeGOGJZC96WOGLTwYccijmERHP2NyLEs4E4gebWmx6CaYv9DglEOY4
wxJLPGAALGajuB+Nj2EGlnSHHJZwmkCc47ITp39wiWMLPySA1X1YAD5/wOXx
ucseADWTdiA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 852->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHPWAuPYJfAEeEPGF8oIg0VMlpHJAvfXptBIE2/W4sZTFdTKe
zPR0f3Z9A+B1XKYuv6/jmKfbYU0eebich7XYfgcwp2VKepUDZB+d++UlxL7U
EWDhvyocEXs48DiIO/YenDdEPTwukRY1/JgeGz1FX6tV5CdITeFV+OzxVTpD
n6faEa+r/y/r6Y7mVEvHBy8stuJvcoZhcVR/64uHQXrS97Dvnn6G44afE9E7
Sj3ilT6u6HVj
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 853->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADFK9QT7CCfhWE+iH+eXRb0HUzTpIG9tVkJ7Mz
3Z1v/XUF4L6Zpr48juNYnqf1fLiU4bAf5uT2M4BXN02dXdsBZx/Vfc81mn3N
I8DCbzU4TWScoDg0+NwfEZbgqrhEWizhl2mvNGCtIj/h5AzeAp8VX6Nz4o+q
VXfT/4s9TTR3tRQ+qGBsw5/OHgbj1P5Ce+W519N9j/dd6ce15IuKv3fQXeW3
7fMGMK504Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 854->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJDZdnwGMWA4JGMQcJEHITAzY3IJmPbj8DPrOwuBWbW/CF
BTHuwxUeGOGJZC96WOGLTwYccijmERHP2NyLEs4E4gebWmx6CaYv9DglEOY4
wxJLPGAD6GajuB+Nj8sMdHPg9mMJe2xxjstOnP7BJY4jDaDL4zWPAYs/0PRi
i29UewDkvXXh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 855->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJDZdnwGMWAyaNDgi5iQGbG+xRzcOmHp970MVg5hITFgTd
hyc8MMITST1KGKHZhzVOsMUrsnlExDM2f6OEM4H4waYWm16C6Qs9TgmEOc6w
xBKf2AC62SjuxxI2uAC2sET3D644x2knLv/gEscWfuhq0eIFG8DwB5pebPGN
ag8AD5N1YQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 856->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqYPx4QCJDZdnwGMWAyaNDgi5iQGbG+xRzcOmHp970MVg5hITFgTd
hyc8MMITST1KGKHZhzVOsMUrsnlExDM2f6OEM4H4waYWm16C6Qs9TgmEOc6w
xJE+sYU3eviihxtKPOAAGGGBxT+44hynnTj8g1McW/ihq8XjBxhATxPoerHF
N6o9ADS/diI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 857->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFgQ4z4s
dmCoxxIGKOGLHn447MSIV2TziIgbbP5GCWcC8YNsBkqc4AhrfH5B109s+kIB
WNIENoCRPpHTKJawwQUwwg2Lf3DFOU47cfgHpzi28ENXi8cPMIARn2h6saUN
VHsAxKR2Xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 858->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFgQ4z4s
dmCoxxIGKOGLHn447MSIV2TziIgbbP5GCWcC8YMzTnCENaEwbMDiJqL8gOZm
FHdjARjpEzmNYgkbXAAjLJBpAnGO004c/sEpji380NXi8QMMoKcJdL3Y0gaq
PQDrKnZh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 859->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFgQ4z4s
dmCoxxIGKOGLHn447MSIV2Tz8LgBxR04wgM9vLD6HVec4AhrQmHYgMVNhNIX
CsCSJrABbOkTOdww4gEHwAgLZJpAnCOHEbY0hO4fnOLYwg9dLR4/wAB6mkDX
ixHfGPYAAOtNdyI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 860->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFjgchua
33CFRwMWtShhg0Tji08GHHIo5uFxA4o7cIQHenhhDR9ccYIjrHGagx6O2NIQ
MWGJJU1gABzpEzncMOIBB8AIC2SaQJwjhxG2NITuH5zi6OkBm1o8foAB9DSB
rhcjvjHsAQAJFnXh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 861->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLAJqQNjGEBik2IW3H1YACFzsLrBHtU8bOqxmsWAXQxmLr6wwMXHcB8W
OzD0YAkDlPBFDz8c9mLEF7J5BOIb3S6sZhCIH5xxgiOs8boFh5sIpS8UgCVN
YAAc6RM53DDiAQfACAtkmkCcI4cRtjSEF2AJe5xuJdJs9DSBrhcjvjHsAQBr
fHVh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 862->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBJu
QMMMONiE1KEAJD4pZsHdhwUQMocB3R1o5iKbgaweq1kM2MVg5uILC1x8DPdh
sQNDD5YwQAlf9PDDYS9GfCGbRyC+0e3CagaB+MEZJwTiE1ccN2BxE6H0hQKw
xCcGwJE+kcMNIx5wAIywwOF/bHEOE8OwkxiAJezx+ZcYs9HTBLpejPjGsAcA
yId04Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 863->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFjgchua
33CFRwMWtShhg0Tji08GHHIo5hHjbmx2obkJX/zgjBMC8YkrjhvQ3ERM+kIB
WOITA+BIn8jhhhE2OABGWODwP7Y4h4lh2EkMwBL2OM0g0uwGNH+j68WIbwx7
AJGldGE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 864->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFjgchua
33CFRwMWtShhg0Tji08GHHIo5hGIb5x2obkJrxm44oRAfOKK4wY0NxGTvlAA
lvjEADjSJ3K4wczB8CcawBoWWPyPLc6R7cCWhvACLGGP0wwizUZPE+h6MeIb
wx4AFYB1Ig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 865->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFjgchua
33CFRwMWtShhg0Tji08GHHIo5uFxA4o7sNiF7CZ88YMeJ8hm4otPXHHcgOYm
YtIXCsCSJjAAjvSJHG7IYYDVDDQ7MNSgxwsOd2CzkyiAK+xx2UOE2ehpAl0v
Rnxj2AMAjpZ14Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 866->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFjgchua
33CFRwMWtShhg0Tji08GHHIo5uFxA4o7sMQVspvwxQ/OOCEQn7jiuAHNTcSk
LxSAJU1gABzpEzncYObgNAPNDgw16PGCwx3Y7CQZ4EmHKPIEAHqaQNeLEd8Y
9gAA3OR14w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 867->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXYFjgchsB
czD0YAkDlPBFDz8c9mKwkc0j1h1Y4grZTfjiB2ecEIhPXHHcgOYmYtIXCsCS
JjAAjvSJHG4wc3CagWYHhho0d2OLc2Q7sKYjBix8bACffgY84mgAPU2g68WI
bwx7AK5BdiA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 868->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYsAuBjOXmLDA6jYC
5mDowRIGKOGLHn44wgQjXpHNI9YdWOIK2U344gdnnBCIT1xx3IDmJmLSFwrA
kiYwAI70iRxuMHNwmoFmB4Ya9HjB4Q5sduLyD06AKx2iyxMA6GkCXS9GfGPY
AwD+m3Yi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 869->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg1AMDC7ErUfoFewBpFewJ3gFuxIEXUh3Hr1aqsRkxhjI05DfZJLb
q2/emYiMxfI0aXoMQ/o889VoU3evutVZ/lVkrpenPn61Cvk/i/vZWpSt/VGt
HR+QCJNsqjEYbCge1gJYdd0rXEBsQR2XAzhA/LJ9CvGh3BAH4cPOC/lhOwn2
yXY8A0xnczguwU04Ifepedvq0Bqmh4uxeyE4UE82DxV2h9YfiL0Jm+v27fp8
AXbZdiQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 870->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPyQ/noEr6AHCF6hniCCfhWE9kP88+i2oiWZ3cm6kDTpPmYy
u/vLvb9tAEzdvPX5cRrH/Dxvl8s1D8fDsDh33wW80ryl+lsuiHMr7nMvLdXn
f2ut/JxaESckGFwQNy/erQX/X/mephaKW1DH5JCtPOhNSmMIn5cb8hB6sF6u
PqonDe2UzpwfzYWrpTMTxsR8lrr96sgahGFiuC+CR4XpWQObscwcsj8wngnO
Nf02OG8AI3Wi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 871->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfwCnqAwSvUE4xgVwWhLsRdj24LDiQveRMD82t+r+/l
dH8O405EXod1G+r7Os/1c9tvj0edLudpcx5/S2Qp61bsqZeQexRnYrUVe/+n
VqvBamWYGh6TB9h6+I1P4m/6fxhn7B3hY3wsGKvwI789PYX4otwUB+ED+Qr5
YZokelKNA0zZfBkLZsIZmU/NW6tDa0APF4O6EBymZ2Sd3tjLzSH6E8OZwFyn
t+vzBfb2dSI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 872->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDgl+oL4hgTwWhHsSbT7cVKZvdmaQDSZNusjvZ
mePt0Q87AM9unvr8ukxTfl/3y+aex/NpXIKH/wA+aZ5S+bUDYl0799tbpHK9
NdfKj+RqcUJCqAvHjZ2neUD+u/dUe6G4NfIwHhYrD/cm1WOIGLvb5CH6YXWT
nnKa2Jw1PaXGhFPLXwWIJwKEP23fvFcUaC/I+5nmtoZELeZqBR/6eAPeE/5u
0DvU+QIxe3Rj
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 873->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYwZcLDxqQPzkQESnxSz4O7DAgiZwwDDyG5Acxs29VjNYcAijmQuwbDA5TYC
5mBzB3oYYAtfXPHJgEMOm16C7sARHsjxhjNNocUJspn44hNnHGNxE6H0hQKw
pAkMgCN9IocbelrBBbCGBRb/Y4tzZDtwAnxyaHbhVItPDgmgpwl0vRjxjWEP
ACtYdGU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 874->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB6KV5/QL7QPkH7BvmAL7Uko6KF48+lV6GGcZLIN7C7rZCdx
JufHe3g1Zja32zaUz22aynI/7ZdnGa+XcQe73zJb+23rj6daGc7YIeAe5bu3
wOG4Eh7mwLpGvMiB+SGPBd+Bt6qF6q3CE/XBGkT6Kj9NYNHbah9CD/RN8bEn
/+ggvRE9Zf/htAzquxDzibrxrEQciLsc9qXCISPDqJbMzTAIngl+6/x2db5t
KXPl
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 875->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZRJrDAMPIbkBzGzb1uPyC039EhBM2Pjb3EQp7
bGGALXxxxScDDjlsegm6A0d4oIcX1vBBixNiwgFXODPgcBOh9IUCsNiPAXCk
T+Rwg5mD4U80e7CGBVJ44ItzZDNwAnxyaHbhVItPDgmgpwl0vRjxjWEPADqD
dWU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 876->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZRJrDAMMMSGw0t2FTj88dWP1HRDihhy+ye/CZ
g+E+LGGAEr447MPmR2Q5FPOIdQeO8EAPL6zhg+RnYsMBl1+Q9eNTjzcs0dIJ
1jSHI10ghxu6O7CZgeFOdHkCcY5sBk6ATw7NLpxq8ckhAfQ0ga4XI74x7AEA
3F51Ig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 877->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgEAIlA7RtSf0hXpA9IV6wQZ1CoI6RLeeXkGBTmoruJto4+xo0c/t
mBDRml1HG7ZmWcLepXcwhKkqpzuZP0501NdRy9vyv7yo5cbiGCxiGB+sSBx6
ndg3cNPqPR7q+yJ00mLBz8Ax9WT8hb7I2+iLOYEXsQMaX+TkzYe/WdyODq6G
yoz+9ksY7Imqt7EXXDfkoWF8eGLe4wkYpnk56GXWejlmuBP4rzpv0ecENcd1
JA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 878->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCexBv+3RbEE3GTJqF7BImTCaT
Pd4e/bATkblbrr4+L9NUX9f9mtzreD6NK3j4hEgry1Xsy2ILN7X6qDzDJYrj
jyvJozmk/KI5WhrgTIc7X8InL9eeMB7qp9Jv/EXdpC9ihi/xBzy9qCnaj57Z
vIEP1EOlKap3Z/B0ML/Z3xLQI86c0IfuFfeywUFPhEEvWpvhENAJPn7xiLO8
ATHAdSY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 879->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZRJrDgO4OLGLo6tHNQncHVv8REU641KCHEdHh
ieR+lPBFdzc2O7HIoZhHRBrA5l50N+H1O3KcINN4wgGXXxiQ3EQozPGFPZzG
Fd540lYDDndgMwPDnejy+NyJZgZOgE8OzS6caokxgwHNnWjhCJfHZ6Y9ANUd
dWc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 880->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZRJrDgO4OLGLo6nGaxYDHf0SEEy416GFEdHgi
uR9b+OKKTwYcctj04osbbO5FdxNevyPHCZr7CcUnul/Q0wqx6Qs97OE0rvDG
k7ZQ3MOAxZ9o9uCMV/R4IWAGToBPDs0unGqJMYMBzZ1o4QiXx2emPQC8sHYo

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 881->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhPRRvfbotqHSHmd0EsmWb7GSS
yen+6p47AONhObo8XYchv2/79fLI/eXcr8Hj14E5LUcqv85/+REvbHOfA7VA
9ZS1cMA8xD/Ot1iib8XFcVK4IIzI7NUM1HydnjAx9bamjeLLnKq9bzUh/i09
uRfeleh+2Tm6eVd2q+AD0Sf1a3VlXRoY1moxqmVzIxggnjTHf7yGmT6dt3Yq

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 882->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYyRxWDqicEoAImPzVxcdsLdhwUQMocB3R1YxNDV4zQLi7+xuQWXm3CFK3oY
ER2eSPZiC19c8cmAQw6bXnxxg8296G7C63fkOEFzP6H4RPcLSpwSCHN8YQ+n
cYU3nrSF4h4GLP5EswdnvKLHCwEzcAJ8cmh2MaDbgy1O8AD0NIGuF2t8o7gD
AAMFdOk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 883->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYyRxWDqCWEGGIYBJDY2c3HZCXcfFkDIHGQz4G5AE8PmZqxmYfE3NrfgchOu
cEUBhMIURxhgC19c8cmAQw6bXoLuxuE+9PDCagZynKC5n1B8YqQxZDMJuB1f
2CO7H2t440lbKO4hYAayPIYaLOGPzwycAJ8cml0M6PZgixM8AD1NoOvFGt8o
7gAAHDN0aQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 884->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYyRxWDqCWEGGIYBJDY2c3HZCXcfFkDIHGQz4G5AE8PmZqxmYfE3NrfgchOu
cEUBhMIURxhgC19c8cmAQw6bXrxxi8W96G7C63fkOEFzP6H4xEhjyGYSCHNc
YY8tTWAAPGkLxT0EzECWx1CDHi8EzMAJ8Mmh2cVAwB5CAD1NoOvFGt8o9gAA
8nN1Kg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 885->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jYyRxWDqCWEGGIYBJDY2c3HZCXcfFkDIHGQz4G5AE8PmZqxmYfE3NrfgchOu
cEUBhMIURxhgC19c8YnLj9j04o1bLO6FiaOHFz77kM3CF574/IISpwTCHFfY
o7sJa3jjSVso7mHA4k80/+KMVzR3Y6QRNDNwAnxyaHYxELCHEEBPE+h6scY3
ij0AkDp1Kg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 886->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1BPCDDAMA0jsBiLsYkCzDxsgZA6yGXA3oIlhczOx/sbmFlxuwmYuA5oZ
xIQ9tjDAFr644hOXH7HpxRu3WNwLE0cPL3z2IZuFLzzx+QUlTgmEOa6wx5Ym
MACetIXiHgJmoPsPQx5fGkEzgyKAFoa47CEE0NMEul6s8Y1iDwBP1HXr
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 887->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1BPCDDAMA0jsBiLsYkCzDxsgZA6yGXA3oIlhczOx/sbmFlxuwmYuA5oZ
xIQ9tjDAFr7o4UfIj9j04o1bLO5lQLKPUPygxAkWGl984vIPupsIpS+s4cjA
gJlu0MSxpS1kt6D4HYsZ6P7DkMeXRtDMoAjYo2Ec9hAC6GkCXS/W+EaxBwBQ
hHXr
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 888->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPGo+mUEVigDVKwQJggSfUVCah+IX0anEQUZ5+zGklM1js/n
s0+3R5gOAJZ+PUJ8XuY5vq5d+bnHdB5SCR43X238eBZfy4t58SxwsL3/1cB/
vlcLqh6zPRyJUfWpMCTn1r4ZF4sTw4XCaNGeacD0teZpzZrlurMlfL/3Wi/a
u5yJmA1UbpOGBqe9/aI6CozK2G7Jngl/hqH7q+KG1gzDNC+maoHo0YwBg6fe
KQ9zfAO/KnWm
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 889->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GATwyTcgmcMAVQ+3gwFVPz67GNDswwYImYNsBoY/0cxAdjOx/sbmFlxuwmYu
A5oZBMPeHqEO2V6sYnjcgU0Om15C6QCr2Uhuwut35DhBihsGNL1EhSFa2BCb
vtDjDz0eMAC2tIXsZyzux2YGuv8w5AnEOXo4YwX45NDsYsASHkSbwYDDndjS
KC4z7QFNLXak
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 890->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GATwyTcgmcMAVQ+3gwFVPz67GNDswwYImYNsBoY/0cxAdjOx/sbmFlxuwmYu
A5oZBMPeHqEO2V6sYnjcgU0Om15C6QCr2Uhuwut35DhBihsGNL1EhSEOfYTS
F3r8occDBsCWtpD9jMUd2MzAcCcOO3DFOXo4kw2whB82txICWN2JLY3iMtMe
AHapd2U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 891->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GATwyTcgmcMAVQ+3gwFVP7pdDFjYMPXYAC5zsJmB4U80M5DdTKy/sbmFGL+h
2IcMiAlTLGGALXxxxSeuuMaml6A7cIijhxdWvyPHCVLc4ApPvGGIZjehdIEt
LNHdhDXNYUtb6O5H9zsWMzDcicMODPOxmEERwBJ+2NxKCGB1J3qawmemPQCE
pHVn
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 892->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoIbkGhc
GATwyTcgmcMAVQ+3gwFVP7pdDFjYMPXYAC5zsJmB4U80M5DdjNUvWPyNzS3E
+A3dXGT3EQxTLGGALXxxxSeuuMaml6A78IQTofhBNgM5bnCFJ15zcLgJnz+w
hT16PGAAbGkL3f3ofsdiBrr/cNmBNZzQzKAEYA0/LG7FCZDdgS0+ke3BZ6Y9
ABGwdOU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 893->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1BPCDDAMA0jsBhx2MWBhw92HBeAyB5sZcDegiWFzM7H+xuYWYvyGYh8y
ICZMsYQBtvDFFZ8MOOSw6SXoDhzi6OGF1e/IcYIUN7jCE28Y4nATPn9gC3v0
eMAA2NIWuvvR/Y7FDHT/4bIDw3wsZlACsIYfFrfiBMjuQHcneprCZ6Y9AIKq
daY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 894->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1BODGaDqwQCJ3YDDLgYsbLj7sABc5mAzA+4GNDEM95Lgb2xuIcZvWMOH
gYiwxxIOcHeg+QlXfDLgkMOml6A7cIijhxdWvyPHCZr7sYUn3jBENpOAenxh
jx4PGABb2kJ2P1oY4DID3X+47MAwH4sZlADk8MOWtrCKYZHH6k70NIXPTHsA
/IF2Zw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 895->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1BODGaDqwQCJ3YDDLgYsbLj7sABc5mAzA+4GNDEM95Lgb2x+IsZvWMOH
gYiwxxIOcL+guQVXfDLgkEPXi88tDEh2YhNHDy+sfkeOEzT3YwtPfH5BiVMC
YY4v7NHjAQNgS1vI7kcLAwwzsMjjUoMtrNHditWNJAD0MMQAhMxHdge6O9HT
FD4z7QF7kHVl
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 896->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQvD1BODGaDqwQCJ3YDDLgYsbLj7sABc5mAzA+4GNDEM95Lgb2x+IsZvWMOH
gYiwxxIOcL/Yo5qBKz6xqUEPD3zhgOIOHOLo4YXV72hxgu43fPGJHl8ocUog
zPGFPXo8YAAi0hZyGGCYgUUelxpsYY3uVqxuJAGghyEGIGQ+sjuwpEMUe/CZ
aQ8AsbR1ZQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 897->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA0LmIJsBdwOaGIZ7cZnFgN9/hMIJm7kMaGYQ
E/bYwgAlfNH9jsUf2ORQzCMibtDdi+wX9PDC6ne0OEH3GzFpD1kvut+ISV8o
AEs8YAACcYceBhhmYJHHpQZbWKO7FVeaIBaghyEGIGQ2NndgcS9KGsVqDwDw
mnXh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 898->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA0LmIJsBdwOaGIZ7cZnFgN9/hMIJm7kMaGYQ
E/bYwgAlfNH9jsUf2ORQzCPWHTj8gh5eWP2OFifofiMm7SHrRfcbMekLBWCJ
BwxAIO7QwwCXGej+w5DHEdbYzMCWJogF6OkEl1txAmzuwOJelDSK1R4AI5F2
og==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 899->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA0LmIJsBdwOaGIZ7cZnFgN9/hMIJm7ko4cNA
XNhjCwOU8EX3OxZ/YJNDMY9Yd2AJO2Q34fU7Wpyg+43o9IUepwTCHF/Yo8cD
BsDhX2z+wPAnmj1YwwLJHGxhjc0MbGmCWICeTnC5FSfA5g4s7sWIbwxzAEwv
dqQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 900->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA0LmIJsBdwOaGIZ7cZnFgN9/hMIJm7ko4cNA
XNhjCwOU8EX3OxZ/YJNDMY9Yd2AJO2Q34fU7Wpyg+43o9IUepwTCHF/Yo8cD
BsDhXxR/oLkfmxno/sOQxxHW2MzAliaw2YcNoKcTUvTidAcW92LEN4Y5ACi/
dqQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 901->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAUHFyIW4/gFfQAxSvUE0TQVUFoF8WdR7cFicm8ec17kKTJC9P5
5HR/9c8dgOmwTH2ar+OY3rf9unmk4XIe1ubxN4BPt0xdvXqj1ee7uYrvCFbm
g//K1cIpMTIHOjN8PSxs62v5pHArfxDzXnlQ+cvahQ7Vq/Ai2RJfFPzYL6md
MmFt4ffFmTY83/KeczDl/LvSQfwVBuszfcWTPYP/JqIldQiubikegq/J2+B8
ATgudqQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 902->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUFjAALmIJsBdwOaGIZ7cZnFgN9/hMKJAZu70P1F
IJwx1COHjT2qGbjChgGHHIp5xMQtFvfC3IAeXlj9ghYn6H4jOn2hxymBMMQZ
lmhuwprmcNiN4g8092MzA91/GPLY3IkeZgy40wSxAKs/sLgVJ8DmDizuxYhv
DHMA9Y51Yw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 903->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUFjAALmIJsBdwOaGIZ7cZnFgN9/hMKJAZu70P1F
Sngi2YsSvljswOVHFDchm0dM3KK5lwHJfejhhc089DhB9xvR6Qs9TvHEAd6w
RHMT1jSHw24Uf6C5H5sZ6P7DkMfmTvQwY8CdJogF6PGGy604ATZ3YHEvRnxj
mAMATel1pA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 904->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUFjABzmoIujuAFNDMO9uNzDQNh/+MKJAQsbRT8W
M/Dah+R+lPDFEQbY/IjiJmTziIlbNPcyILkPPbywmYceJ+h+Izp9oevHEwd4
wxJLXGIAXHYzMGD4Aas/kdThdQc2eSxm4UoTxAL0eMMARJqN1Z3oaQqfmfYA
6vlz4w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 905->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUFjAALmIJsBdwOaGIZ7cZnFQNh/+MIJm7ko+rGY
QVA9trBB9zs2M7DIoZhHTNyiuZcByX3o4YXV72hxgu43otMXun4CYY4v7DHC
EB3gspuBAcMPWP2JpA6vO7DJYzELV5ogFqDHGwYg0mys7kRPU/jMtAcAoKN0
pA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 906->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUFjAALmIJsBdwOaGIZ7cZnFgN9/hMIJm7ko4cOA
226c6rGFDbrfsZmBRQ7FPGLiFs296GGBHCZY/Y4WJ+h+Izp9oesnEOb4wh4j
DNEBLrsZGDD8gNWfSOrwugObPBazcKUJogA2P2BTQwTA6k4s6QGnmfYAkV50
pA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 907->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA0LmIJsBdwOaGIZ7cZnFgN9/hMIJm7ko4cNA
XNhjCwNsZuCKTwYccijmERO3aO5FDwtC8YMeJ+h+Izp9oesnEOb4wh4jDNEB
LrsZGDD8gNWfSOrwugObPBazcKUJogE2s7HJEwBY3YklPeA00x4AMw50pg==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 908->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA2Lsb0B3A5oYhntxmYXFPmx+wuU3bOaihA8D
cWGPLQywmYErPhlwyKGYR0zcYnEvupvw+h0tTtD9RlIaQ9ZPIMzxhT1GGKID
AvZiSw8Y5qOHOzZ3YJPHYhauNEE0wGY2NnkCAKs7saQHnGbaAwAYSnYm
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 909->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA2Lsb0B3A5oYhntxmYXFPmx+wuU3bOaihA8D
cWGPLQywmYErPhlwyKGYR6w7sIQRspvw+h0tTtD9RlIaw+EmQukLPdwwwhAd
ELAXW3rAMB893LG5A0dYo5uFK01gBTj8g1MOnzgawOpOLOkBnY2wBwAg3nZl

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 910->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA2Lsb0B3A5oYhntxmYXFPmx+wuU3bOaihA8D
cWGPLQywmYErPhlwyKGYR6w7sIQRspvw+h0tTtD9RlIaw+EmQukLPdwwwhAd
ELAXqxvQzUcPd2zuwBHW6GbhShNEA2xmY5MnALC6E0t6wGmmPQA6SnXl
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 911->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA2Lsb0B3A5oYhntxmYXDPlxuQTcHm7ko4cNA
XNhjCwNsZsDlsJmBxU0o5hHrDjxhgRwmWP2OFifofiMpjeFwE6H0hR5u2MIQ
W9jisherG9DNxxI2GO7AEdboZuFKE0QDbGZjkycAsLoTS3rAaaY9APOIdec=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 912->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdXCwdIbGLMgruHAUGjA2Lsb0B3A5oYhntxmYXDPlxuQTcHm7ko4cNA
XNhjCwNsZsDlsJmBxU0o5hHrDjxhgRwmWP2OFifofiMpjeFwE6H0hR5u6GZg
AAL2IpuJ1Z9INFZ3YEmD6PrQzcCWJogG2MzGJk8AYHUnlvSA00x7AEKWdiY=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 913->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZaOYQYwbcDWhi6OpxuQmXfbjcgm4ONnORwwTm
PkL+wRYG2MyAy2EzA4ubUMwj1h14wgI5TLD6HS1O0P1GdBpDj1MCYY4v7NH9
hQGw2IusB9lMrP5Eogm5A1tYo5uFK00QDbCZjU2eAMDqTizpAaeZ9gDeKXYo

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 914->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZaOYQYwbcDWhi6OpxuQmXfbjcgm4ONnORwwTm
PkL+wRYG2MzAFZ8MOORQzCPWHXjCAjlMsPodLU7Q/UZ0GkOPUwJhji/s0f2F
AbDYi1U/Aw5/ItGE3IEtrNHNwpUmiAbYzMYmTwBgdSeW9IDTTHsANtB2KA==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 915->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZaOYQYwbcDWhi6OpxuQmXfbjcgm4ONnORwwTm
PkL+wRYG2MzAFZ8MOORQzCPWHXjCAjlMsPodLU7Q/UZ0GkOPUwJhji/s0f2F
AbDYi1U/Aw5/ItGE3IEtrNHNwpUmiAbYzMYmTwBgdSeW9IDTTHsANtB2KA==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 916->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZaOYQYwbcDWhi6OpxuQmXfbjcgm4ONnORwwTm
PkL+wRYG2MzAFZ8MOORQzCMmHWBxL7qb8PodLU7Q/UZU+kL3D5qbCKUv9HBj
QDMDA+AzA41PyJ+E3IEhj24WA+40QTTAZjY2eQIAqzuxpAecZtoDAC/3dmc=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 917->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZaOYQYwbcDWhi6OpxuQmXfbjcgm4ONnORwwTm
PkL+wRYGWMXwuAObHDa9BOMWT1gghwlWv6PFCbrfiEpf6P5BcxOh9IUe9gxo
ZmAAfGag8Qn5k5A7MOTRzWLAnSaIBQ3YzEZ3C7HmoJuFJT3gNNMeAAF7dyg=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 918->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZaOYQYwbcDWhi6OpxuQmbfdj8hMtv2MxF1g9z
HyH/YAsDrGJ43IFNDptegnGLI77Rwwur39HiBN1vRKUvdP+guQlfHGALewY0
MzAAvvjAkR5w+ZOQO/DFObId+OQJAeQwwwqINLsBLezgNJJf8ZppDwAvk3Xp

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 919->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZaOYQYwbcDWhi6OrR3YTuDgz1ONyC0xwc+mHu
I+QfbGGAzQxc8cmAyy3I5hEbtzjiGz28sJmHHifofiMqfaH7B81NhNIXergx
oJmBAfCZgSM9oMgj0YTcgS/Oke3AJ08INKC5CQMQaXYDWtjBaSS/4jXTHgAj
2XVp
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 920->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCcmjqEUGSHxizGJAMgPDLDRziDED7gY0MXT16G5CdweGehxuwWkODv0w
9xHyD7YwwGYGNvvQ/YjiFmTziI1bHPGNHl7YzEOPEzjGEZ44wwM9TvHEAd6w
RBZDdyOO+EHXg839KOYj0YTcgS/Oke3AJ08INKC5CQMQaXYDejjAaCS/4jXT
HgAvSHZn
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 921->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCcmjqEUGSHxizGJAMgPDLDRziDED7gY0MXT1uNyEzT5sfsLlNwYs4sj6
Ye4j5B9sYYDNDGz2ofsRxS3I5hEbtzjiGz28sJmHHidwjCM8cYYHepziiQO8
YYnmJqxpDpf9DAw43Y9hPpawwXAHgThHtoMS0IDmJgxApPkN6OEAo5H8itdM
ewBVFXZp
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 922->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD0q
jQsTkkdRiwyQ+MSYxYBkBoZZaOYQYwbcDWhi6OpxuQmbfdj8hMtv2MIXWT/M
fYT8gy0MsJmBKz4ZcLkF2Txi4xZHfKOHFzbz0OMEjnGEJ87wQI9TPHGANyzR
3IQ1zWEJWwx/oLkfw3wsYYPhDgJxjmwHJaABzU0YgEjzUdyJTCP5Fa+Z9gAc
7XUq
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 923->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD1Ir32CX9AHFL9QX7CCngpCe5De+vRa0DU7mawJpJDs7mQy
0+PtOTwaEZnb92dIr8s0peV62It7Gs+ncT/sPimy9r+Uvqwx/50Xd3WoOoIl
CsNgAU4EI3OAHt73OLF5bCdvNyF9/f7LL6ynmssw2DzcUQh21GPGFznVfEZP
cjp6ev4aTyseeN5lHqghBtHW7AH8DT7RxvCo8VTh/ROh0NgeThB/ZViqR3Uo
5myGSHUq
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 924->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCcmjq4UDJDYxZsHkYOqxAWLsb0B3A5oYhntxmYXFPrifiAgnBiziKOGD
wxx0N2ALA2xmYLMP3Y8MWMwmNo6xuRfdTfjiGT1O4BhLvOBNX+hxiicOsMYd
sjvQwxAd4DMDh/sxzMcSNhjuwOdOJIArTRAF0NIvTjVEAPS8gG4+1nBAsQcA
Aot2KA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 925->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lY+OCcmjq4UDJDYxZsHkYOqxAWLsb0B3A5oYhntxmYXFPrifiAgnXGpQACnh
ieR+lPBF9zs2M7DIoZhHTNxicS+6m/D6HS1O0P1GdPpCj1MCYY4v7NHjAQPg
MwONj9WfSDRedxCIc2Q7yAZo6RenGiIAel5ANx9rOKDYAwBxTHbn
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 926->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpkFB0hsYuyCycHUYwPE2N+A7gY0MQz34jILi31wP+GxG59fUcIHhzl4
1SOHDZpb0GlsfkSWQzGPmLjF4l50N+H1O1qcoPuN6PSFHqcEwhxf2KPHAwbA
YwY2PoY/kWi87iAQ5yh2kgvQ0i9ONUQA9LyArhdrOKDYAwAxYneo
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 927->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpkFB0hsYuyCycHUYwPE2N+A7gY0MQz34jILi31wP+GxG59fUcIHhzl4
1SOHDZpb0GlsfkSWQzGPmLjF4l50N+H1O1qcoPuN6PSFHqcEwhxf2KPHAwbA
YwY2PlYz0OWxuYNAnKPYSS5AS7841RAB0PMCul6M+MawBwCnBXcq
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 928->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpkFB0hsYuyCycHUYwPE2N+A7gY0MQz34jILi31wP+GxG59fUcIHhzl4
1WMLG3S/YzMDixyKecTELbbwQ3MTXr+jxQm634hKX0j6kfnEpi/0cMMIQ3SA
xwxsfFzpFj1sMNxBIM5R7CQXoKVfnGqIAOh5AV0vRnxj2AMA+fZ2bQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 929->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYAQZYxDDci8ssLPbB/YfHbnx8jPAhEA/YwhMj
bND9jsNedDkU84iJW2zhh+YmvH5BixN0vxGVvpD0I/OJTV/o4YYRhugAnxlo
fAx/ogG87iAQ58hmkA3Q0i9ONUQAjPhE04tVHsUeAEqUdG8=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 930->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8qZkBjYwPE2AWTg6nHZw4xZoABFjF09bjchM0+uP8IhAMuPkb4EIgHbOGJ
ETbofsdhL0ZcIZtHTDxjCz80N+H1C1qcoPuNqLSGTT+BMMQZlmhuwprm8JmB
xsfwJxrA6w4CcY5sBkXAHo3GJU8AYMQnml6s8ij2AAAttHMw
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 931->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYAQZYxDDci8ssLPbB/YfHbnx+xQgfMsITI2zQ
/Y7NDCxyKOYRE7fYwg/NTXj9jhYn6H4jKn1h008gzPGFPUYYogN8ZqDxMfyJ
BvC6g0CcI5tBEbBHo3HJEwAY8YmmF6s8ij0ARv90sA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 932->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wODAiYQ5QZDLjFUNyLyyws9jEguQ+X3dj4DOj6GXCbQyg8
kf3CgGY2Lndgk8MWRnjdgi38kN3BgOlfnGrRwhJbWON0Axb9xKYv9LBHjwcM
gM8MND6GP9EAXncQiHNkMygCaGGOVZ4IO7DFPXpYYMij2AMAwI50bQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 933->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixiKe3GZhcU+uP/w2I2Nz4CunwG3OYTC
EyVs0MzG5Q5sctjCCK9bsIUfsjsYMP2LUy1aWGILa5xuwKKf2PSFHvbo8YAB
8JmBxsfwJxrA6w4CcY5sBkXAHgeN5hZCAFvco4cFhjyKPQDPc3Us
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 934->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixiKe3GZhcU+uP/w2I2Nz4CunwG3OYTC
EyVs0MzG5Q5sctjCCK9bsIUfsjsYMP2LUy1aWGILa5xuQNOPLw7whiWam7Cm
OXxmoPEx/IkG8LqDQJwjm0ERQAtzrPJE2IEt7tHDAqtauB4Al7t17Q==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 935->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHi1gDshgus7DYx4DDHGx+Y8DmLnR/kRGe
GGGDxQ4MM7C5CUsY4XULrvBjQLgTXzyjqEX2G46wxukGNP344gBvWKK5CWua
w2cGjvSAC+B1B4E4RzaDIoAW5ljlibADW9yjhwVWtXA9AERQdTA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 936->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8MxqUHJI4NEGMXTA6mHp85xJgBNweLWAOyGC6zsNjHgMMcbH5jwOYudH8R
4R9sYYDNDHQaxQxsbsISRnjdgiv8sMQPNvOQ3QvHWPQSdAO6fiLSJa6wxwhD
dIDPDBzpARfA6w58dqCZQRGwR6OxyRNhB0Z8opmJkb4w7AEAeCFz8Q==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 937->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8MxqUHJI4NoOvDph8ux4CgcZlDyF3I6rGJobgXl1lY7GPAYQ42PzFgcxe6
v4jwD7YwwGYGrrBlwCGHLYzwugVb+OHwC9b4RVIHx2j+IiZ+0fUTky5xhT1G
GKIDfGbgSA+4AF534LMDzQyygD0OGps6IuzAiE80MzHSF4Y9AEowdO0=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 938->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8MxqUHJI4NoOvDph8ux4CgcZlDyF3I6rGJEfILgz1utcSaw4DNXej+IsI/
2MIAmxm4wpYBhxy2MMLrFiz+xmUG1jBFci8co/mLmPhF109MusQV9hhhiA7w
mYEjPeACeN2Bzw40M8gC9jhobOqIsAMjPtHMxCqPYg8A7k51LA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 939->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDaDbhc1OuBwDgsZlDj77kfXiEiPkfwZ73GqJNYcBm7vQ/UVGeGKE
DYGwZcAhhy2M8LoFi7/R3YQ3TJHcC8do/iIqfaHpJxSXOMMSzU1Y0xyB+MeW
HnABvO7A5U4sYUQWsMdBY1NHhB0Y8YlmJlZ5FHsAJWh17Q==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 940->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixgh/zPY41ZLrDkM2NyF7i8ywhMjbLDY
gWEGNjdhCSO8bsHib3Q34Q1TJPfCMZq/iEpf6PoJxCXOsERzE9Y0RyD+saUH
XACvO3C5E0sYkQXscdDY1BFhB4o7sZiJEd8Y9gAAWnp2LA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 941->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixgx/selllhzsJmLET5khCdG2KD7HZsZ
WOSwhRFet2DxN7qb8Podyb1wjOYvotIXun4i4hJX2GOEITogEP/Y0gMugNcd
uNyJJYzIAvY4aGzqiLADIz7RzMQqj2IPAIWkdu0=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 942->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixgx/selllhzsJmLET5khCdG2KD7HZsZ
WOSwhRFet2DxN7qb8Podyb1wjOYvotIXepwSEZe4wh4jDNEBgfjHlh5wAbzu
IBDnKHZSAuzRaGzyRNiBEZ9oZmKVR7EHAAuddu8=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 943->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDcDlGfDrRVaDzxxizICbg0WMGP/jUkusOdjMxQgfMsITW9ig+BOb
GVjksOnF6xYs/kZ3E16/I/kZPU6whSfO8EDXT0Rc4gp79HjAAATiH1t6wAXw
uoNAnKPYSQmwR6OxyRNhB0Z8opmJVR7FHgBhzHbx
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 944->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8qZkBjYwNweQbC5sDU4DOHGDPg5mARI8b/uNQSaw42Pkb4EOEfbGGAVYyA
vdj8h64Xr1uw+BvdTfjCFNnP6HGCLTxxhgeWsCQUl1jDEs1NWNMcgfjH6gYc
AK87CMQ5ip2UAHs0Gps8EXZgxCeamVjlUewBALoFdbI=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 945->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDcDl8djNgKYGnzn47EfWi0uMGP/jUkusOdj4GOFDRnhiCxsUf+Kw
F5v/0PUS4w6cZjCgqsdlH7J70P1AVPrCE6f4/IEt7NHjAQPgMwNHuOACeN1B
IM6RzaAI2KPR2OSJsAMjPtHMxCqPYg8A7vZ1Mg==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 946->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDcDlGfDrRVaDzxxizICbg0WMGP/jso9Yc7DxMcKHjPDEFjYo/sRh
Lz5/kOIOnGYwoKrHZR+ye9D9QDB+cegnFJdYwxLNTVjTHD4zcIQLLoDXHQTi
HNkMioA9Go1Nngg7MOITzUys8ij2AAAgu3Xz
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 947->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDcDlGfDrRVaDzxxizICbg0WMGP/jUkusOdj4GOFDRnhiCxsUf+Kw
F10Om15i3IEeRshuwhemyH5GjxNs4YnTHXjiFJ8/sIU9ejxgAHxm4AgXXACv
OwjEObIZ2NxINLBHo8k0CyM+0fRilUexBwC6tXUy
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 948->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDcDlGfDrRVaDzxxizICbg0WMGP/jUkusOdjMxQgfMsITW9ig+BOb
GVjksOnF6xYs/kZ3E16/I/kZPU6whSfO8MATp/j8gS3sMfSjA3xm4EgPuABe
dxCIc2QzsLmRaGCPRpNpFkZ8ounFKo9iDwAj8Xay
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 949->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixgx/selllhzsJmLET5khCe2sEHxJzYz
sMhh04vPT9j8je4mvH5H8jM2fxCdvvDEKaH0hR72GPrRAT4zcKQHXACvOwjE
ObIZ2NxINLBHo8k0C1t8oocFXjPtAXbadjI=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 950->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wODAiYQ5QZDLjFiPE/LrXEmsOAzV3o/iIjPBtwieFxBzY5
bHrxugWLv9HdhC9Mkf2MzR9Epy88cUoofaGHPYZ+dIDPDBzpARfAGhZI5uCL
c2QzsLmRaGCPRmOTJ8I8bPGJHhYY8ij2AADFl3Zx
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 951->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wODAiYQ5QZDLjFiPE/LrVwQMAcBmzuQvcXGeHZgEsMjzuw
yWHTi9ctWMIP3U34whTZzyj+wBHWOMMDGaO5iVD6Qg979HjAAATiH6sbcACs
YYFkDr44RzYDmxuJBmhhjlWeCPOwxSd6WGDIo9gDAAnEdTA=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 952->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixgx/selllhzGLC5C91fZIQntrBBtwPD
DGxuwqIXr1uw+BvdTfjCFNnPKP7AEdY4wwMZo7mJUPpCD3v0eMAA+MzA5QYc
AGtYIJmDL86RzcDmRqIBWphjlSfCPGzxiR4WGPIo9gAAmfF2MA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 953->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixgx/selllhzGLC5C91fZIQntrBBtwPD
DGxuwqIXr1uw+BvdTfjCFNnP2PxBdPpCxmh6CaUv9LBHZmNNc/jMwOUGHABr
WCCZgy/Okc2gCNij0djMJ8IObPGJHhYY8ijuAAAnG3Yy
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 954->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixgh/zPY41YLBwTMYcDmLnR/kRGe2MIG
3Q4MM7C5CYtevG7BEn7obsIbpkh+RqFxxAvO8EDGaHoJpS/0sEdmY01zeMzA
xseVbtHdiOEOAnGOYiclADns8aQjQoBQfGKVR3EHABKidPE=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 955->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wOph6fOcSYATcHixgh/zPY41ZLrDkM2NyF7i8ywhNb2KDb
gWEGWtjiCiO8bsHib3Q34Q1TJD+j0DjCE6cbkPyErpdQ+kIPe2Q21jRHIP6x
ugEHwOsOAnGOYiclAD0MsZlPhB2E4hOrPIo7AKF0dPM=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 956->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JxgWIsYsByQxcZhG0H80duMSI8T8utcSaw4DNXej+IsI/2MIAqxged6CH
La4wIiZucYmhmI0vbdij0TjCE6cbkPyErpdQ+kIPe2Q21jRHIP6xugEHwOsO
AnGOYiclAEfYo5hPhB2E4hOrPIo7AC2pdPU=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 957->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JxgVw2cWAhQ1Tj88cnPajuQOXGDH+x6WWWHOw+g3dX3j8gFU9jrBBtwPD
zVj8hE0vvnDF5m90N+ELU2Q/o9A4whNn+kLyE7pefP7AFvbIbKxpDp8ZuNyA
A+B1B4E4RzaDIoAj7NHdQggQik+s8ij2AADAT3J1
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 958->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JxgVw2cWAhQ1Tj88cnPajuQOXGD7/o7sDXY5kc3DoBwMi/IMtDLCZgc0+
uBlY/IQtjIhxB7b4xjAbX9qwR6NxhCfO9IXkJ3S9+PyBLewxwhAd4DMDlxtw
ALzuIBDnyGZQBHCEPbpbCAFC8YlVHsUeACjpcrQ=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 959->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JxgWIsYsByQxcZhG0H80duMSI8T8utcSaw4BFHFk/GBDhH2xhgM0MbPbB
zcDiJ2xhRIw7sMU3Nn/iTBv2aDSO8MTpDmSMppdQ+kIPN4wwRAf4zMDlBhwA
rzsIxDmyGWQB9DDHZQ4B+7G6A4uZWOVR7AEA9l50cQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 960->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8uZoBhLIAYu2ByMPX4zCHGDLg5WMSI8T8utcSaw4BFHCN8iAlTLGGAzQxs
9iHHC7qfsIURofBA9zcpZiC7F4XGEZ443YAlrRGbvtDDDSMM0QE+M3C5AQfA
6w4CcY5sBlkAPcxxmUPAfqzuwGImVnkUewBq73Px
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 961->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wODAiYQ5QZDLjFiPE/LrXEmsOARRzDX2SEZwMOM7DZBzcD
i5+whRFet2BxLy4zsJmH7F4UGkd44nMDHKPpJZS+0MMNIwzRAT4zcLkBB8Dr
DgJxjmwGWQA9zHGZQ8B+rO7AYiZWeRR7AFQEdLA=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 962->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwRmMEe
lU8JBpmFDRBjF0wODAiYQ5QZDLjFiPE/LrXEmoPNXAx/kRGeDTjMQKdRzMDi
J2xhhNctWPyNywysfkdyLwqNIzxxugHJT+h6CaUv9HDDCEN0gM8MXG7AAfC6
g0CcI5tBFkCKe2Q+VnVE2EEoPrHKo9gDAJQcdXE=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 963->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ5QZDLjFsOnBEMehllhzsJmL4S8ywrMBhxnoNIoZWPyE
LYzwugWLv3GZgdXvSO5FoXGEJ043IPkJXS+h9IUebhhhiA7wmYHLDTgAXncQ
iHNkM8gC6GGOyxwC9mN1BxYzscqj2AMAijp1cQ==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 964->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOZi+IuM8GzAYQY6jWIG
Fj9hCyNiw5SQGVj9juReFBpHeOJ0A5Kf0PUSSl/o4YYRhugAnxm43IAD4HUH
gThHNoMigCPsMeQJAELxiVUexR4AIs51cw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 965->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOai+4uc8GxAF0MPP2xm
YPETtjAiNkwJmYHV70juRaGJDAuUtIHDTYTSF06A7kY0caxm4EgPuABOd2AJ
O3xmUARwhD2GPAFAKD6xyqPYAwAhKXY0
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 966->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGXj9R8AcbOai+4uc8GxAF0MPP2xm
YPETunmkhCm+cMbpdyT3otBEhgVK2kALG2LTF06A7kY0cVzxj9UNeMzH6g4s
YYcL4DSfWIAj7DHkCQBcYYVVHqtaAD9RdPU=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 967->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOai+4uc8GxAF0MPP2xm
YPETunmkhCm+cMbpdyT3otBEhgVK2sDhJkLpCydAdyOaOFYzcKQHXACnO7CE
HT4zKAI4wh5DngDAFVZY5bGqBQB6QHW2
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 968->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyphxnQ
2NgANrW4zAEDAuYQdBOSegYsYrjcj24GNrXEmoONj+4vYsIWWxigAPTww2Ev
up+Q9eOLF2xhii+ccYUpin3INJFhgZI2cMQFofSFE6C7EU0cqxm43IAD4HQH
lrDDZwZFAEfYY8gTALjCCqs8VrUAV8Rz9Q==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 969->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOai+4uc8GxAF0MPP2xm
YPETsn588YItTPGFM06/I9uHTBMZFihpA0dcEEpfOAG6G9HEccU/VjfgADjd
gSXs8JlBEcAR9hjyBACusMIqj1UtAJkAdXU=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 970->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfIXOwmYsePuSEJ0YYoYcfNjOw
+AlZP1FuweJmbOGM0+9Y7CMlLODqkfyErpdQ+sIJcKU9AvGP1Q04AE53YAk7
fGZQBOzRaFzyBACusMIqj1UtAAnSdXc=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 971->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfIXOwmYsePuSEJ0YYoYcfNjOw
+AlZP1FuweJmbOGM0+9Y7CMlLODqkfyErpdQ+sIJcKU9fGbgcD8ugNMdWMIO
nxkUAXs0Gps8EXbgCius8ljVAgA2l3T3
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 972->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6CfFHGQzsJqLw15sZuDzHy734zMXPXzICU+MMEIPP2xmYPET
sn5C4YkepvjCGaffke1DpokMiwZkfTjiglD6wglwpT18ZuBwPy6A0x1Ywg6f
GRQBHGGP7hZCAFdYYZXHqhYALSpztg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 973->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfIXOwmYsePuSEJ0YYEeEO5DBA
DyMGHG7FF6b4whmn35HtQ6aJDIsGZH044oJQ+sIJcKU9fGbgcD8ugNMdWMIO
nxkUARxhj+4WQgBXWGGVx6oWACh1dTY=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 974->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+nGYg08/illI9jJgEcNmLzYz8PmPkDnYzEX3Fznh2YAuRoQ7
kMMAXxgRG6aEzMDqdyT3otBEhgVK2sARF4TSF06A7kY8YYvhD3Q34AA43YEl
7PCZQQlACUNsgFA44XMHrrDBqhYAptR1dQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 975->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOai+4uc8ET2CwMR9iKr
QYkLLGFEbJiii6G7A6vfkdVioYmOVzxxSih94QTobkQTx2oGjrjEBXC6A0vY
4TODEoAShtgAoXDC5w5cYYNVLQB403Zz
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 976->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOai+4uc8GxAFyPCHchh
gC+MiA1TdDEGNDOw+h1ZLRaa6HjFE6eE0hdOgO5GPGGL4Q90N+AAON2BHnZ4
ACF5QgAlDLEBQuGEzx24wgarWgCU4nX1
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 977->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOai+4uc8GxAFyPCHchh
gC+MiA1TdDEGNDOw+h1ZLRaa6HjFE6eE0hdOgO5GPGGL4Q90N+AAON2BHnZ4
ACF5ggA97LHJE2EHrrDCysZqDwBKt3U2
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 978->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOai+4uc8GxAFyPCHchh
gC+MiA1TQmZg9TuSe1FoIsMCJW3gcBOh9IUPYIQrjrDF8Ae6G/CYj9Ud6GFH
qhtJATjCHt0thACusMLKxmoPAI2ddTg=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 979->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGXj9R8AcbOai+4uc8GxAcwMx7kAO
A3xhRGyYoouhuwOr35HVYqGJjlc8cUoofeEDDdjkCcQ/un6sZqCZg+EO9LAj
1Y2kAPSwxyZPhB24wgorG6s9AD+PdPU=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 980->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PUfAXOwmYsePuSEJ0YYEeEO5DDA
F0bEhim6GAOaGVj9jqwWC010vOKJU0LpCx/AmvYIxD+6fnzpF6c70MOOVDeS
AtDDHps8EXbgCiusbKz2AABcXHQ4
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 981->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfIXOwmYsePuSEJ0YYEeEO5DDA
F0bEhim6GAOaGVj9jqwWC010vOKJU0LpCx/AmvbwmYEjLvGZj9Ud6GFHqhvJ
AbjMIdJ8XGFFtDn2AMDZdDo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 982->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+nGYg08/illI9jJgEcNmLzYz8PmPkDnYzEX3Fznh2YAuRoQ7
kMMAXxgRG6boYgxoZmD1O7JaZJrIsEBJGzjcRCh94QMY4YojbDH8ge4GPOZj
dQd62JHqRnIALnOINB9XWBFtjj0AVN5zug==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 983->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+gmYQ9AdSOoZsIhhsxebGfj8R8gcbOai+4uc8GxAFyPCHchh
gC+MiA1TdDEGNDOw+h1ZLTJNZFigpA0ccYHPHFxpCme44ghbDH9gcQMu87G6
Az3scJiP04141JOslkgzcIUV0ebYAwBTTHP5
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 984->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfIXOwmYsePuSEJ0YYEeEO5DDA
F0bEhim6GAOaGVj9jqwWmSYyLBqQ9eGIC3zm4EqbOMMVR9hi+AOLG3CZj9Ud
6GFHqhtxuAcvwKWWSDNwhRVeeRS1ADl7c/s=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 985->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfMWFBKHzICU+MMCJgLwNaGOAL
I2LDlJAZWP2O5F4UmsiwaEDWhyMu8JmDK23iDFccYYvhDyxuwGU+Vneghx2p
biQH4DKHSPNxhRVeeRS1AL8GdLw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 986->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfMWGB4Tc0/xFyB7bwxAgjAv5h
QAsDfGFEbJgSMgOrX5Dci0ITGZ4NyPpwxAUhc/ABbPJ44wOH+/Gajy1O0cOO
RDeSBXCZQ6T5WN2Bnh7w2g8Areh0PA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 987->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfMWFBKHzICU+UMMJiDzY+chjg
CyNiwxRdDN0dWP2OrBYLTXS8IvkJ3U2EzMEHsMnjjQ8ccYnXfGxxih52JLqR
LIDLHCLNx+oO9DSF134Au+d1Og==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 988->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtg+nGYg08/illI9jJgEcNmLzYz8PmPmLAgFD7khCeyXxiw2ION
jxwG+MKI2DAlZAZWvyO7GZkmMixQ0gaOuCBkDj6ATR5vfOBwP17zscUpetiR
6EayAC5ziDQfqzvwhA2mWgBX+3S6
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 989->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4PMfMWFBKHzICU+UMMJiDzY+chjg
CyNiw5SQGVj9juxmZJrIsGhA1ocjLgiZgw9gk8cbHzjcj9d8bHGKHnYkupEs
QKE5WN2BJ2ww1QIALtR0vA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 990->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHl8ehtw6Ec3h6A7kNSjm4vLXmxm4DKXGLdgMxc9fMgJTxR3YLEHGx85
DPCFEbFhSsgMrH5HdjMyTWRYNCDrQwsbfHGGK/7whisONzFg8wcWN+A0H5s8
etiR6MaBAFjdgSdsMNUCAP/Fc/8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 991->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHmCZuABRLsDST0DFjF0N+MyA5/biAkLQv4jJzxRzMBiDzY+chjgCyNi
w5SQGdjMQ3EzMk1kWDQg60MLG3xxRkrawiaGMz5wuB+v+bjkKXDjQACs7sAT
NphqAT+2dMA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 992->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHmCZuABRLsDST0DFjF0N+MyA5/byA4jEszAFp4oZhARpshqUOICSxgR
G6aEzMBmHoqbkWkSwhPZzwxY3ETIHHwAmzze+MDhfrzm45KnwI0DAbC6A0/Y
YAIAIaR1gQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 993->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxpgxns
GbACZHmCZuABRLsDST0DFjF0N+MyA5/byA4jEs3AFgZwQESYIqtBiQssYURs
mBIyA5t5KG5GpkkNCyzpDF+ckZK2sIkRk77R3YDTfFzyFLhxIABWd2CLY5wA
ANMedYM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 994->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
uByZ+tHNIdYMZDtxmYHLTVjVkuEWSs3AFgYk6UcLA3xhRGyYEjIDm3lwYI9G
kxoW9rj1EjIHH8AV1hhhiUc/Pjvw6qfAjQMBsLoDWxzjBACgaXcD
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 995->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
uByZ+tHNIdYMGBtdDEUtHjPwuY0a4UNOeOLzC1b9SH5EiQtk80gMU0JmYDMP
DuzRaFLDwh63XkLm4AO4whojLPHox2cHsWmbVDcOBMDqDmxxjBMAAEIpdkY=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 996->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
uByZ+tHNIdYMGBtdDEUtHjPwuY0a4UNOeOLzC1b9SH5EiQtk80gMU0JmYDMP
DgikEYJusMc0A1+ckZK2CLmJkH58aijVT4wZ9AJY3UGS2wBrwXWJ
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 997->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
uByZ+tHNIdYMGBtdDEUtHjPwuY0a4UNOeOLzC1b9SH5EiQsKwpSQGdjClBAg
2g0wP2HRS8gcQvYTchMx7ifFfFL0E2MGvQBWd5DkNgA8pHZK
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 998->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
uByZ+tHNIdYMGBtdjFgz8LmNGuFDTniS6hcGpHBHiQsKwpSQGdjimRAg2g04
wgRXnJGStgi5iRj3k2I+KfqJMYNegHJ3AAB+IXZM
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 999->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
SvWTag6yemSaVDPwuY0a4UNOeJDlFyx+oiRMCZnBgEc/LkBJ2sAXZ6SkLUJu
Isb9pJhPin5izKAXoNwdAF7Tdw0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 1000->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxph7EB
SvWTag6yemSaVDPwuY0a4UNOeFDiF2Q9lIQpOWYQApSYgS/OSElbhNxEjPtJ
MZ8U/cSYQS9AuTsAziR3Tg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False]}, Dynamic[$CellContext`i23$$],
                Alignment->Automatic,
                BaseStyle->"ListAnimateCore",
                ImageSize->All,
                TransitionDirection->Horizontal,
                TransitionDuration->0.5,
                TransitionEffect->Automatic],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
        GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}}], If[
        And[
         CurrentValue["NotebookSelected"], 
         CurrentValue["SelectionOver"]], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i23$$, \
$CellContext`i23$39050069$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 1000, 1}, 1000, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{309., {82.884033203125, 88.615966796875}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.773597305899763*^9, 3.773597845820311*^9, 
  3.773597896065844*^9, 3.773598036135097*^9, 3.7735981852012663`*^9, 
  3.7736028544457293`*^9, 3.77360474063561*^9, 3.773605062239173*^9},
 CellLabel->
  "Out[278]=",ExpressionUUID->"cc96ea53-dfdd-4312-8911-d8aed4ff72d2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "should", " ", "recall", " ", "Franklin", " ", "if", " ", "it", " ", 
    "halts"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"WatchImageWalkSATCRN", "[", 
   RowBox[{"memcnf", ",", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pix17v17", "\[Rule]", "0"}], ",", 
      RowBox[{"pix17v16", "\[Rule]", "0"}], ",", 
      RowBox[{"pix16v17", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix17v10", "\[Rule]", "0"}], ",", 
      RowBox[{"pix17v9", "\[Rule]", "0"}], ",", 
      RowBox[{"pix17v8", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix17v1", "\[Rule]", "0"}], ",", 
      RowBox[{"pix17v2", "\[Rule]", "0"}], ",", 
      RowBox[{"pix16v1", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix8v1", "\[Rule]", "0"}], ",", 
      RowBox[{"pix9v1", "\[Rule]", "0"}], ",", 
      RowBox[{"pix10v1", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix1v1", "\[Rule]", "0"}], ",", 
      RowBox[{"pix1v2", "\[Rule]", "0"}], ",", 
      RowBox[{"pix2v1", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix1v8", "\[Rule]", "0"}], ",", 
      RowBox[{"pix1v9", "\[Rule]", "0"}], ",", 
      RowBox[{"pix1v10", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix1v17", "\[Rule]", "1"}], ",", 
      RowBox[{"pix1v16", "\[Rule]", "1"}], ",", 
      RowBox[{"pix2v17", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{"pix8v17", "\[Rule]", "1"}], ",", 
      RowBox[{"pix9v17", "\[Rule]", "1"}], ",", 
      RowBox[{"pix10v17", "\[Rule]", "1"}]}], "}"}], ",", "1000", ",", 
    "5000.0"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.773597391852283*^9, 3.773597395140417*^9}, 
   3.773603873645281*^9, {3.773603904151799*^9, 3.773603928360194*^9}, {
   3.7736040384519157`*^9, 3.773604115308587*^9}, {3.773604382285151*^9, 
   3.773604536052544*^9}, {3.7736051474615383`*^9, 3.773605155318701*^9}, 
   3.773606768495427*^9},ExpressionUUID->"d3aff378-15a6-4ee3-814a-\
42317477d0d5"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i24$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i24$$ = 1}, 
     "\"max\"" :> {$CellContext`i24$$ = 1000}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i24$$], 1, ""}, 1, 1000, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i24$39649335$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            TagBox[
             StyleBox[GridBox[{
                {"\<\"\"\>", 
                 AnimatorBox[Dynamic[$CellContext`i24$$], {1, 1000, 1},
                  AnimationRate->Automatic,
                  AnimationRepetitions->1,
                  AnimationRunTime->0.,
                  AnimationRunning->False,
                  AnimationTimeIndex->5.,
                  
                  AppearanceElements->{
                   "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons",
                     "DirectionButton"},
                  AutoAction->False,
                  DisplayAllSteps->True]}
               },
               AutoDelete->False,
               
               GridBoxAlignment->{
                "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "ListAnimateLabel",
              StripOnInput->False],
             {"ControlArea", Top}],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4ACZ
jQzQxUF8dIxLHJs6ZLWE+Ljch08/NhqfGD6349ODL0wIhR2xfiDkVmzuwOVW
XP7CBXCZgYtNTHjh4uNKR/jcRSxGtwefe3G5E5eb8bkPm1txhQE+N+DTh00t
MfYTGz743IPP38T4HcIGAMLNddA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 2->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZIMAe
iQ3lM0D5KOJQPjrGKY5FHbJaQnx0MQz19pj6sdH4xHC5HUUPFvfgChMGHG7G
5hZcYUB02GAxHwzsUdkY+rC4DZefsJqPz41o4YZLPzIfVzrCAFjSFCGMbg82
+/D5DR0QCj98eQJXGOBzAz592NQSYz+x4YPPPfj8TYzfIWwAfy50yA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 3->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBSD
2TAAE2dAE4fy0TE2cWRzUcQYUNkw+5DtQTcb3R247EA2G91dyGZgM7sBm3sZ
MMVRABa/M+BwMza3YHUDWvjgUocRhsj22aOyMfQxYMqjA2z+JRgfaPbhdB8D
qhpc6QgDYIkjQhjZXkJpAtkOXABDPRZ5nHkCRxhgk8PpPgb8aomxn9jwwece
fP4mxu8QNgDiT3R/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 4->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfXQhbnsEr6AHKF6hniCCrgpCXYi7Hr2tpDJ5fTPtwITM/71k
TvdX+6wAvI/T0abPte/T93aYjUfqLuduDtZZgaGZjqy/+yKLH+TPNiscH/tt
T56nbK5hDKqfxSNjYj7z4PoCjxXqZzGtOAksEgMEb5HH/uKNmvK+qoPgQqL4
Ml6Zy7idGpuj3kXic/YqUjt3ayeKGY7IfIpHu7O1E96cPX+heO/1RX0iHH9x
9jnmNwJNlnK8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 5->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgjAQnHAwXnmCX9AHEL+AL6iJnEhM8GC48XTBlLhMZ1eaFNhpd3dm
Wk73Z9tVAF7H+dGm93UY0ng7LMEj9ZdzvyzWeQJTMz/y/H6vY8VBeI55wsEY
tzW5n4o5hzkU9fhNvRS2J3/Dxw6qZzn90+RygNAt9jG+8YjOoMiD0EJD6WW+
ci/zdnLsHuYlvSZd6h56/kbnX/ghfFUesF7LL7o7ygO1JvkF/ttaKnax4P+I
+Hi9WZfq88v7AFrRdfM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 6->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAQHboo3XoEr9AeIPQKeoIIdiUU7KK4y9GrksT48iaNMGE+vjcz
j2mHd/e6iMjntj6d/T7n2S79dQtGOz3u01ZsvIk4sz7edj98IS+Q93FqKb6U
zzihH/Y/4XAOUnPmnHdYE55j+AxjckzUScjeFTuxGZg+qBXthRyK5mwv5Mg0
QX7Fj3GBn/KRuRhf8Es3p+lbexOxH9Ok5v+K22EasBqdr6B/ysViNcf6a/ep
zI97/Otz4H7JjHSs
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 7->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgyAQ3PTQeO0T+oX2AcQv6AtoUk8mTeyh8cbT1UTKOjsgm6zIssMM
A/fXpxsuIvJt1k/nf+00+bm/bpO3H5+PcVu87bmGSxmcpIh1gXqc7/0B8KFQ
N3sCH/IfcKgD+nXvYdRrwmsMb3idxfx9EstdcyamgfmDXhmPheyBiTiyrz6P
8YjcAfUv9pI7R4zWgLoYd/wvvbmcv7VvQus3UdNf4DU45QFbo/qYlwXvjC+s
xvhz7zOjH89xxpNwCx0icqo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 8->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9oH4ZXRaCNQ5X9JKTmPH55zP
OVwf3X0DYNxNSxef52GIr8t2dm6xPx37+XCfDUhhWrJ99lh8ZP8fBwpMCh6f
GnFX09YNdA/jmAfl29xE+WklpvAFP47bj/phXKsnxUHpw1o5jSFqsDFO1LX9
OI3EDKR+v1wxc8bYHOal7i4wKHHq7dXmznz5z5xZm2Z+RWP1Pq0mrmaFs9Ry
RTt3b0UrVbPFR+mh3kSt9+/+DfmScWk=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 9->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IW5/OBhU0jtNK7ZJs8RzX
h+t9GDcAHrvlGPLzPM/5ddmuyS1Pp+O0vtzXDZS0HHV/Yvxz1PxXB0xPSb6/
BHWJ2eImqjEO80g2V3O0T1UD9UvOgJvPLMYTMzBnpx/PIGL+jrVROijNnRY8
D2EZT6DPl/0T3jvpwVowT+kT2D7lvR7/0BMNf7cCf6k7Z42ZV7sUF8VLeZY1
Udq5/wZaKcwen56mzEXN/o3fYc1vpg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 10->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8MjothOKczyVSotiJ7buz
d+dbd10BuG/Go8uP4zDk52k9GZfcH/b99LitGyhpPOp+3/GzUe3ZDzQxJfn4
Ivxu27rflVqfy8M4kreZR6Fc7JvrB1zse/PHLqUZ5WXMTj+jq8IX/XMaYkF3
jmMNBKemruhBiPFf30kP1oJxyjlBGxfNXgnqhzOB9r/TRcSpnjuNiatdCovl
HfWLdbC53NuCbhEnN2OKN7SmjEVx/9xfJrxtog==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 11->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8MjotKmCfz0Akp3US23f2
bY6X7rwAcF2NW1dv+2Go98Nyck6132376XI9G9DKuM32/MfHx+y/zwEX04yx
b/MGs3Vfq9AZ52EcJfrMw37VWVpLYHFv7FI9o7ySo8gXcP54FzCauNB/5sk9
EJxcXTEDno3UzzctCe0Efqa2iyE+mfZaUj/VBPz70BcR91ePiavNr7BY3tm8
uA82V7hLMEouzCPTgPAznTruDv8DuAdsIA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 12->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzydtgrgjMeApVR14mU8
nt352vUrALfN9Ony/TiO+XFaz84lD4f9MD9u6wFKmj71LP/4+Kj++x5ockry
+UXcu2P7vozeXX3GQbEgHDa+BHdhr+TfmxhrAQZb18aGPdBiULxyHYcROl/O
yRzwLMSb2gHvRurnm5ZoXt4X925yaJ5Ie8zDT01Y/GyBvv7iWO3W8Bjp0uFj
/okTxV3DgeDNzSLmUHiUz/rgnTT1FnsClC5p3Q==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 13->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMFH2UfDtCV2gHCFkhmcCF5hUopI+Sn0dPUlx6Pp2IwHYsyTnp
dNfHqx9PZvZutq1Pn26e0zKc98szTffbtAcvZZnldtvK+n7b/+78xTL4+X0W
frcQ92cUr7DxjcoP6sVT+RCL6+Z41S9awBn+F3Md3xCX+AqXOYY61HvVp+OA
eyHe1Ax4NpF+3Nwhx2nJaBZYF3JI/UTaYx4ONYH1swX64nzJcaStKB/6jual
8BV3Siuc57g+0hgYY3FfTteVrYW6als=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 14->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS6kW4/gFfQAxSvUE4xgVwWhLsTdHN1WRkxeXtKB+SWZvJc3
Od4ew7gTkWe3LEN5Xea5vK/79XIv0/k0rc5DmyK1X5Y2v2f53529jars+L4S
u5sa9zfAb7C1jcUHfPXObDov8na4vc1jeCR8K3B2eis/xWe4iTbsPavTaSBw
Bt1MfqyFxW78DdaAvBi2wYV6ot5DHVhPsNpQC8c5iacaB3+b/knWswE+085o
QnRzuZJ3JjaqFXyur834ADxzatc=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 15->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+ItT7eVoJnJTjGwTbOZzs7O
9nC998MGwGM3P/r0PE9Tel22y+GWxtNxXC73JYDczY8Sn3f8zk2+rGzwWUJ5
vlHXBXMg4KRchDd66z3K1byquanbMQ/pcHoh+LUaYA2KUx7FqK/RnXKFM6hW
U1N2q/GP2WgPqqvhUw+lH/fvqQ9u/tSv+gLOE2eADz02s7Uz0ZmqZqM38o48
CXxruFa+I6zrVe50Jrze9Mdnlg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 16->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1UksKwlAMHFyIW4/gFfQA4hXqCZ6gq4JQF+KuR7eVhySTmUDep0mTmck7
3J7DYwPgtVuWob0v09Q+1+16ubfxdBzX4L47MJ+XpfvvjH6H+N7t/w9qXnQ4
R8ihGrI34+J8yp1DD+6V9lCPMZe+zCvicHhROdoehIHzHB6lq4ulWkKDdOa4
2CXGgM/OSHBgXKUea0h83NtjHSR3ehtJs2iqpsiXGpvZ8nztTAVmhVdpx5qw
boW74qp0clwpVvon+wIn/mhT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 17->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1UksKwlAQCy7ErUfwCnoA8Qr1BE/QVUGoC3Hn0W3lUWYySWHep5M3yXwO
t+fw2AB47eZlaO/LNLXPdbtc7m08HcfFue8GfM/z0u1/Rr9D/O/f+gYVFw3O
EDDQ/sTNutSbgE07caU9xGPNhZfzMjpU3Ii1HKSBcRGrMNaHvMu68zlqVzNh
crH9dDNG+XK/yjyixuD3XEOukew/zYaqhdOs8GXezHyq/tqeCs2KX9XO1aHw
Isd3c7RiXa7kK/zp+wGl82nP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 18->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsOgjAQnPBh+PUIXkEPQLwCnqAm+kVCAh/Gvx4dMA1uZ2dpstB2Zx8z
28tz7N8NgLldP3363KcpfR+n7fBKw+06bM5zMSB366fYb49yhrgva4+Bx1lD
ZNCYKm90RzVVfPW3teAxlpPTQvQScVcc93oGG9agHhhnsQojfbZHUC7UcW6P
QHvK5Xo80kRgsojPKh9rCB0fzlG8CcmXtbAreF9q5q5OMFuebzhT0bOqr7Tj
98N6uVyCq/MdcSWf4vRfC6t9aI4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 19->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkOwjAQs3pAXHkCX4AHVHyhvCBIcKpUqRwQtzy9LQow8XgSKevYiceZ
420aHh2A534dhvS6zHN6X3fb5p7G82ncgofSgdyvQ+mfNcoe4rw0ywHxbVeY
790Kk008PEMdj3RY3ZnW7l6hJ9LCvJaO33sGG75BGiQuyqEVQz1bL8AYwisP
+C7nTeSJ5ZCnzHc+Kw+h+eE/ipqQ+bIX3ER9MV7Vm+MFGsM/FZrV+5UHBqe4
rt7Yi0YdNXOlmMrp3xZp82fL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 20->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAFSuUCYIEr0pI7QPxy+i0KIBzPgdLTuwkts8X
7y/34bYBMHfLMqTHaZrS87xdnWsaj4dxvdwVBXK/LEXfNooPcV7ExoDirao3
n9zqTTb34RkaeSkmm1ogu8pLeHIDC8c1sYC46wXfDQzuXdTDv/7M/q2BOs7Z
0BxwLseN4oQ4dD7FS/6ZQ+onmj05Y6o3BLxYCeZL/YGrE/wtz1X4pwKzwltx
QBypOZC9QOCB2OFrqTvV009eI41pCA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 21->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRT8uxK1H8Ap6APEK9QQV7Kog1IW4m6PbSoXM70stzDQzmST/
/+RwezTdRtJzN25N+7oMQ/u+bqfDve1Px35y7ucllfO4zetraz7L7sNdjJHF
x0Vvfnn8TYE6VDv6vLbbJdSS2VVew7OGxeNSjo4ZtFvDkHFDbf7xs94Vy4N2
5k/mAPNmmIFDjEf9XUPjk82e56GZqLRz3vFL5ot6QFwWvYG5SnsKmAlvpYFp
RHOAXAR4BH8ta5FvwanS9gOs72kG
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 22->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kksKwjAYhAcX0q1H8Ap6APEK9QQRdFUQ2oW4y9FtJWo6+ZLCX/KczOPf
Xx/9fSNp6uZfH57ncQyvy3aZ3MJwPAzL5i6VFE/zL9VnrDTXf/1Xys5BRSs6
88XxM6u5VHJq8QKs/G60d+VvGZ8WF79X1ei+gXc1Du5ddCxab+mz7KLh4Liy
n3uK+ZEncJ+yQmz/DMN7jni5/tynXC/6Ym9Tf1EGpKXIBvqqmilwJr4rD8wj
6gPUQjhS4Zdrdd8oj9LbN7xwagg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 23->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHQFxhnKBI7GsS0vhA/OXobFOB1I27Sqn6suM4
PdweXb8B8NxNU5del3FM7+t23tzTcDoO8+U+B2DnacqxrJH3+J//Au5dEEYR
vVE8BQaoNSldgstjPa/Rm+8wwiktjOOcst6GTtbAXMZcKqeqj3wy4gnX4t57
amu8rX4Gvaq4vXfsIeVVf499iP5E4R3XTbk9NqwXupaqN4FO2dNAc6S38MDd
RdhKGxo8KPGeV/m22o9lfADkyGlJ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 24->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMHFyIW4/gFfQA4hXqCZ5gVwWhLsRdjm4rtcZ5M/VBHu+TTCaT
7C63pl0BuG+GrSmPU9+X53k9Xq6lO+y78XM7GRDHYZvsfcZ0x/d9NiQ/YUGm
fBzOTwxQc3K8DFaOzbhBPp/FnCsu7JM5uVjhm/M7DhwfjLWQR+YmnYJw5Nn8
K00trpkRVUMQttQZNQbP3L8+Ov7zG9edl5ohrhe+liq34Gl7KjhH5ui0W9BB
cWMclYN5O91UP2ptXyiqZ4o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 25->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPwQfz2CV9ADiFeoJ6hgvwpC/RD/cnRbXTWdndFAls1uMpk8
NqdL0y0AXFfj0bS3wzC09+NyMs5tv9v20+e6KBD78Sj6vKPY+L5/FMlPaJAq
H4cziwFqTo6XwcqxGTfI5y3MueLCPpmTixW+OX+QT8VN2SZnrkP1J+cPwpF3
8597Gv9wzY6oGkJhm9mrvG73eI5qJ37WnUXNieuFr6XKLXiq+TnOkTm63pk+
8A7OagH1EnMezFvuE2OIXX3JAwskZss=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 26->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEQCx7Eq0/wC/oA8QvrC1bQ04KwHsTbPN1dKTpNE7cwpc20mcmQ
3eXe3VYAHptp6/rnaRz713k9X679cNgPc3JbAojjtJX4nFHu+OHfKCsYT/9z
qDeZm2sH5aEw7stwZT2ZIxQv2p5V3aZH1ac6p7e5fjUj+By/szg0xnMK4pFn
k88zjSVe4xGlIRT3Hw1cd9F79Nf6inVzfdQ9N3rhtTS1nWeVL0TP7K0Kd14h
TGoBzTLrJr3WT0q7miveIwhmjA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 27->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAQs3ggvozACjBAxQplgiDRVyWk8kD8MjotCnB17LbSVcldcmc7
PlzvbbcB8NiNvzY9z8OQXpfttLml/nTsp+K+BJCb8Vfis0bZ45//Rfky58P9
b6j6rE9Tz85Uh8oxLtMr8ok9suqLGruaW2EUOJl/prPunMRmsCrOkQfnWKfZ
O7u1qUdN5fvFe8Yji7pxb8OB+XCszbe+Yt48H/ROzBe1FtaPzrPKFwIze4vn
VdiE9pILSMvIm3paP0H0V7riDZyyZYw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 28->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPwQfz2CV9ADFK9QTxDBfhWE+iH+7dFtS6Kb6WyhgQ1J9pGZ
3Tndn223A/A6jFub3tdhSJ/bfro8Un8595PzmA2wZtyyzWfkO/7vP0Pw7vKL
RTG+Nv9t5K8wCVxGtayp6xa/r8sxZTH2BRYIjIxF8K96uhInsQVYVf88Dzkv
7hMoTvBVft9TOT+Vv6UfXDvgwHzYIu0pTShtqhmXxfrifO5FqEcx44UPMWZj
jPSfx6bmrjTIHPwfim+oJ9T1pS7n9QWJJ2bL
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 29->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPoh/noEr6AHKF6hniCCfhUK9UP8y9HbSoKbyWyggQ3JZh8z
kz0/puHVAXgf120In9s8h+/9sF2eYbxexu3xlAyI/bol+52R7vj70fJTfjYv
xtbg3pF7WUyif6RasS/r5ndbl2PyYuwVFgiMjEXwLzRtxElsDlaln+VR/Zmj
UytO+khT+X8qf48eSmc1N8SHzePH/T2cSu+8eL44h7Vw51H8scJe5bEOEH7B
W2kv5wWkpeVNfFVdGy95FWsBHTxmyQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 30->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBi19YX1DBPS0I60G85enuStV0MkELKU3SJJNJ
dudrP6wA3Dbz1Zf7cZrK47RelEsZD/txcW6rANbNV5XXG1XH195IZq/xb8n+
+BzmdCM9YBK4jHKZtzs/1+Havr70ZxgZi+i/4TT75zCgi/wpLOEf5QizYp6E
T9WQnCd9/rM/P/lQPKu9oX5Y1L6p+hnOZsb+iP3iGOYi3UcxY4U9xDEPiHbF
c2oTszeOge433Se0+cNufM4TaCVnCg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 31->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKAjEMRYMLcesRvIIeYPAK4wkq6GpAGBfiLkfXwQrp6w9iIYWkyc/P
b3bn23hdmdl9877G8jjOc3me1otzKdNhPy2P22r1DB/zIfgh3lgWr/Vfy3Ii
hgff4XecBC8Hlsc45wl92Dv2l+8ZR3IR85ODzAscUoxffwOMLo86ibe0B/lT
C+B2+P/ooXRWe4N5aGrfsp1QPJs/jkftCGqoMfdR1aWYJuqog/VxpXMaE3/v
rDHUY7ZGx5DP2XtdX/IwZYw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 32->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRYML6dYjeAU9QPEK9QQj2FVBqAtxl6NrdZTpn5dCAymTdCbz
8jP7y63rN2Z2b96fLj1O45ie5+0UXNNwPAzTz132bO3XvS3iIj/zKJ/P/zza
U9bwInaJKybgcqnlknfZ/8/pXVazVyzEKCzUvzI47C8ZtJeIBTXVnkE3ByZc
2/I8iDHUfYUeVW1go7mT/ovvieoHms6M6ssZ1RjfJelCNQ3OqQ5W50nnMBfM
Ht8n3IVzMpiFCfPHXuiUZ08=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 33->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kk0KwkAMhYMLcesRvIIeYPAK9QQj2FVBqAtxl6NrtUjm9UsDGZifvLz3
Jofrves3ZvbYfZauPs/jWF+X7bS51eF0HKbL/ZxzlF96sTYKpIW3kh4Sa0uL
7eHMZY+csjvp6wGz0aG1AVu5L7gQR8Ej/crB4X3koFpM36km0EFeL3xKfMEe
yl+9ENwFPvkR+FA9zcLav5P/KUamPZvVGIQvNeoxziVpIkyDOmvx/hrEk6ht
9Qz+Pp1P6IWeGvyFCedvvAE6SmaQ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 34->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1UkEKAkEMCx7Eq0/wC/qAwS+sLxhBTwvCehBvfbouDtKmaaELM91mkrSH
62O6bwA8d9/P1F/nZenvy3Y93Pp8Os5rcT9yRPulNcRoLulsjerjzopawAFh
gHoqTlWN3jWP6Xlzr8Nm7sY9IG3CO6WfOZj433NgLeD/xCxYh/I6+VT4It9g
/uyFmqXiKOaZNDO2wFHeVN4FD6p9q1KF2hHBj3cz7WWhKdUg+hDx/vrcvdq7
8k7MvtxP8lLOCREjaQ/xAf6zZc0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 35->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwkAMRT8uxK1H8Ap6gMEr1BOMYFcFoS7EXY6uxQHTP/8bSOk0zZ/k
JYfrfRg3AB67z2Ooz/M819dluxxudTodpyW4b96sfD0K1laS0zkKxdu3MLGV
DkgDlONq+hPL90bWzHVTrspfaeQcukOxU/1zDSH+zzXAaATV4rh27Cmn03Lv
EAyIbden4654AJKH5Kw0zM51+wehoTgpV6Z2RNSXGci9ND2p+bk8ZpnZqb2z
38zsw9whZwHSQT+X3MvP3hB6Zww=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 36->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhYMLcdsjeAU9wOAV6glG0FWhUBfSXY6uxUrTl/dsIJ3OT/6+
5Hjr28fOzJ6Hz6etr8sw1PG6nzb32p1P3XTZzDpL+S5ebC0lKOw9ntty5vGO
KbxfxSaxHGzUXYzr0WfMG2pl9qkGZoM5KduSc3DyPuZgwodDLoprYg82ydef
94kBsE11Ku6MhxnlQTkLhmzm0vxFUfO2Navgw0keWGNkQOeScWE+TdshS8lO
9J2yAj+pl/FfxPoJ9iXWssgbO21mEA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 37->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRYML6dYjeAU9wOAV6glGsKuCUBfiLkfXYgfjz//2Q9pOJ8kk
b7K/3PphY2b37v3o6+M0TfV53s6Lax2Ph3He3C22qHxeXuxXJRisma8HM2Xg
3+TiLIcYtRfPbf8d64ZeWXzqgcVgTSq25Bqc+CMDlsOhFsU1sYeYlOuPf2IA
bFOfiruaG8KDchYM2cyl+YvC2VgzJpwz0WNkQOeScWE5TcchS8mO8JWsIE+6
y/gtzmrCe4m9fPUCQiRmkg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 38->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS7ErUfwCnqAwSvUE4ygq4JQF+IuR9diC8lLnnmQ6cw0v/cm
h+tjuG9E5Ln7LkN/naepvy/b+XDr4+k4zj/3iy1ov4828WjG4Ox8zd1qwszE
qLlT8FFWB+qtsHXV5hDwbeAP8YFDFlNwD/z/+GEPkuRwfoWuqCPqVuYCvkzz
rMcwR0l+fM/AOdM564HMXNDfAmejsgw4Z4RjmL2iNs0pPA61pNol+lKtIE94
S7tnGkjsxdV2+AAZn2hP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 39->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHgwXH2CX9AHbPwCvmBN5ERiAgfjbZ+uBNQ6nS42KbCl7c5M
u7/c2m4DYGxejzbfT8OQH+ftdLjm/njop5+7xRdL86sk/Fqa/RNPIkZ5b0fk
pqaYWBFneY/CRfXF9gA8B5tP9Y6Dqlnh7vhX8hgDOC7Oth/rWkQMtV4RVggN
ksAoMNfmz/NUnCP9GYPaOae/tT8xytoAc8TR7d7K3WFPxHWsZahdMB+pFfVx
u2K/BV6LiediuXztCSomak8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 40->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEOwjAMBFccUK88gS/AAyy+UF4QJHqqhNQeEDc/HUoLStabRHKjbGt7
us7x9uiHHYC5+zz69LxMU3pd98vhnsbzaVxeHrbYlq2bG8pla/x1Exp99wvU
IsvxTHNxln0UF+UXvNCaV/LDP6g6gknmcg3RgxnAujjn9dhXFxrzq3kGVggP
TDCSHhioBs/TK/k1/yH68uylB9S/eUdVbouZQs0v9EbMkTVRZ2Yvgx9Cz+tI
r2gGgRXl3mJywVMwf9cbgvBokg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 41->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMDB7Eq0/wC/qA4BfqC1bQU0FoD8Vbnq61tWQnkw2kZdOdSTLT
0/3VPXciMh6+j65M12Eo79t+PjxKfzn388fjmmvo8jKVOnTJra6kBvf+KVk6
jLmawTntk3zzeHOcVS/YleHDDtC3qhM+un9DI5wh9FCYlXghhIPNKMif+aPA
RbC4J3qZ8aKfgU8a+gMm0zNoQPo3NUD9fKB3JNEv+l8SDPN+u09wqGXQg9Q9
T0urjIfqmcxkOA/O/IsPub1oEA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 42->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDD2UXvuEfqF9wOIX7Au20J6Egh7EW56uVgvZyWQNxGWzJjOZ
5Pb6tp+TiAyX5dPmsen7PD3P6+Wdu8e9Wx+vu++WtkOTlJY2L+IHsb9L5CZH
TUzhHuKYN1vP5qupWWBBr0ryXQ+Aq4CLb7T/QCPGwWHgf0wDUiPiKIxfhWsU
wz5xlpQjmaerJxX9IYdp7vSH/inG0a5aI3vGenS7h3vJdAn6VjgjLZ0eJG7x
a1pFdaiewXwV+SDnn82ALWeS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 43->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD2I1z7BL+gDpF+wL9iCnoSCHkpveXqrrBDHmdpAlE02k8lk
q8ezGy5mNpffT5det2lK73uxHPo0NvW4JK/Zs7XBo+WYt//HNjflocZjjJxp
H8YX+m41jtgBwwEbuR+4MI4kR+fHefBu4KB0Qf5KVycxxUHuR2lA+Mu7jCPZ
5wHPADviQA3WM17Ih/b4pUU01pPMifui75LpInR0+Cst6bsS+p5ppXB2epJZ
HHIOfXacV/sA0GVlTw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 44->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDF2I2x7BK+gBileoJ3iCrgpCXUh3OXotVsibzFQDacl/Mi+H
66O/N2b23L8/fXmdx7FMl91i3MpwOg5LsF11le6j3lktzP/D91VTGmo8+Bxs
OSfEoh3rPfSsZoUeDr0Re8JCMLMY3R/3wdyAgc3GvMQB6aEwJi7+wLqFX+aK
/vieqZ/pW8AaxnniHzhjM+S9ohAO2J4OMXxrNm/r7hz+ikt6V4JfyRXwk3YM
OWwXhxh7n1pmfOdnEg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 45->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCexBveboWqySTyTaQlk2ymclk
j7dHP+xEZO4+n74+L9NUX9f9crjX8Xwal+Rh9dXK17WINxbfiP1cMjd31MQU
ztkdmgNcNT0dlumhxc9guVMuhDPL0flRN6w1HAIGqQsakB4t3Tb3k/Bg/NNa
afQ0vEI/aehPZkTNg/6gGcNI9UAjGrg5ySxs1wwv2/2/XiIeaknfVaZLphXo
EzDsn8yikGP78fYGPV5mFA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 46->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDV2I2x7BK+gBileoJxhBVwWhLsRdjt5WW3jz5mUaSKeTz+Tl
Jaf7q382ZvY+zp8+fa7jmL63w3J5pOFyHhZnu+oq3V+9s1yUfce2qUUKOQ42
55ggp/BRbcTmEI//mw97QOxO2IzfCTBluYiTeVOxFvPHcTVeCx4Fb7vz4bgK
/jCW+0f++E49hvxTDvMo+TORSzVCPlgEB1mfal5i1qpegQX6djqN65NN7mBt
r4Kacu/wFL04+Xgm2Xs/mQDD62aS
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 47->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQXPwQfz2CV9ADFK9QTxDBfhWE+iH+7dG12MJ0drIJbJPua2Yn
Od2f/bAzs9fh9+nL+zpN5XPbzz+PMl7O4xw8Lras7m/e2XYpf8O3mtUMahx8
zjmVmhAjbOTmkI/nNYYzIHcnbsZ9Ek7OWCIetBIcGFPprTQKOlY4pveT5DH/
kCvwkAfPEfpZoj/VsI6s3waL8ENe9lZRR9WfavgN8F23dFX9cDfGJ5/CV72l
VjRDwMBdzOIUa96JfQFUu2eS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 48->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQXPwQfz2CV9ADFK9QTxDBfhWE+iH+7dG1WGU6O5sEtmn2NTuT
HK73ftiY2WP3+fTleZ6m8rps58OtjKfjOAf3iy2r+5p3tl7K3/D9zDKDGgef
0zmrCTHCxtkc8vH/H4PeOHttFq7jHGcsEQ9aiRmwjvNqurrwyRkafVZcBX/m
GfRi/pgnMLBf0MB0DevI+jnXJxjpexXYPHPQ0bQ2zK+mq+qHe6alfFeV3lIr
4hAwcBdcnGLNO7E38SVmlg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 49->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAQC36Ivx7BK+gBFq9QT7CCfhWE+iH+5ehabGWazXYXpu3OI5NJ
53B9dPcNgOfu++jy6zwM+X3Zjpdb7k/HfgzuJ5tO+hkTlmfyO5/LZTDUTPJn
H+VeqyligQ+FG0N+/P7HAnbkvsZF6zSH2svEC60MB9WF2rOiK43PcmjgLGpW
+Ftd3PzwvQs8oMSDwTA6qn61HZ11YirxrBZRE4cvNW4WSm+3v5YLpM5pKdxq
Wiq21aq1d/FtZqHEmv8EH81sZRg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 50->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwjAQXDxIrz7BL+gDgl+oL4hgTwWhPYi3fboWU9hMZhLYQDbZ2dnJ
nB+vcTqY2Tr8tjG/b8uSP/fjdnjm+XqZt8tTibLSPzxZvUqe5dhbD2Eq4P2e
czirGnoHfT1gVr0ChgN25N7jgnX4xrEXuW+0IhxQF8eeQlcnOcqhh9PJIX85
N85vvHeDZ3WezcD60r8THt118tTiUd9FDsRnyo/It/IlhORiUMe0BG5KS8RG
HaPO0newpAeM/4k3GF9wD2RX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 51->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB6kV5/gF/QBi1+oL1jBngqFehBveboWV0gmkzWQwqbJZDLJ
8baM005EHsPnM9bnZV3r67rfHvc6n0/z9vPQvFn5uhbx1uLBklw1LpkjRosp
vLMayhf6qsEMfBFffP8wA3DRDidXiz1KxHG5wnuzvJ6uqME/3Xr7Yfwtvt1z
mBvnNxp18cTH2QysL91dcqM/nbREPKoFw8h0JHPSuyT3QLkI1DEtQc9MS8RG
Ha3O6d2BpTcgfCcaMN74U2Qa
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 52->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYMLcesRvIIeoHiF8QQVdDUgjAtx16PrYB3S5Es1kCmTn5fk
JbvzbbiuROS+eX+G/DhOU36e1vPPJY+H/Tg7t1WrpI+W+lq7k2+sKH+1LRiR
WoxqK7Z+kOP6hdpFYfb61dgleaVekCPTQ6EayeM0scK1Ke4Xr0LxNu9PHOQc
do1zRzvv4UlrpxmoLvXVcGDqu7geF4QRzQtz4l3CPSCmmDziUsXTDUbzWR4X
HAEc5dMS3oDBCHciL1/HYpg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 53->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKAjEMRYMLcesRvIIeoHiF8QQjOKsBYVyIuxxdB4ukv681kBnSJD/p
7z9c78O0MbPH7vMZxud5WcbXZbsGt3E+Hec1uc+eLX3d81/PC4u1cu4Ro+XZ
XOZpTD2a8xDHfg+YMU8Yuo+n/i7IkezgNCPVOEWt8Wyq6/GK76M89PYjfMDV
t6Z7E1etGu3/xzPySBq0EoP2b2qWDHRGXNFdCl2CHhDTpI+4DPVNDXZmVnMN
cEIuWlMDglHd72dvDgFi2Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 54->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRQcX0q1H8Ap6gOAV6gki6KogtAtxl6NrNcjk5ScOpCHTP//P
/GR/uY+3jZktw/szxsdpnuPzvF0P1zgdD9P6c5dXjvBdKe/MFxHa+eQ5WitH
gh7PUsdhf/1S2+qdWDWb1+/1Ij1CD0lphJqnwBpyQeRMc3EOU3jvQ68/xe9y
CX1xngqLPloY1v/zWfrYe4PQZ03P0yJYR7/EnMQrvSanoU55CT/lG+xoVrom
eKjvc+oOwSFn+MQLeXpjWQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 55->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwjAQHDxIrz7BL+gDil+oL4hgTwWhHsRbnq7FIJvZ2V1ISzaTmWGy
x9tjmncAnsP3M5XXZV3L+7rfNveynE/Ldnhoq9X4W7X9ud+VxcKct96fI1qt
KunxXt2xWPZg71eLs9zkN/KTeZEZkYeqNIjDYUE9ge00k1yh8MajzDjrGw6X
KWeGvsdZhRjxnlnOUZbhDJK+m5ck067EnGU6jh9aL+RE71lmSXnKGUw0nS4E
D+vbnpoB6DfxHB8B3mVV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 56->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwjAQhQcX4tYjeAU9QPEK9QQRdFUQ2kVxN0fX4qDPlzfpQBo6efP3
JYfro79vzGzavT99mc/jWJ6X7fJzK8PpOCyH+1hh3Wd57Oz/M9QanIfvmyNb
YY45IB7zVfW7Xyz3gHUddVyL83M/PAfNLBnR/K5qEIdKa+Rr6Na4SpbMqZUn
85lgymyIF7NKNdl9Co4ZH8VPxlL/Uo99o3Ec8xJzOp1zvaoXE3rYqxqCZ3Om
FfbIh98nW/oGTN9JneMFmk1klA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 57->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS6kW4/gFfQAwSvUE4xgVwWhXYi7HF2Lg40vb9JAJkxm8nt5
x9ujH3YiMnefoy/PyzSV13W/XO5lPJ/G5fFQtYp+1apFP/OZurusPlOIQ61i
PoeL9/lobVn/mZJY5/eW9Uv7wTlgZtojiQ81AAfTiIFhjca/LVyb7xnGmd/h
FjBl3En4hNiwvTX7JDmsoen8QvaVYPon2Z6THpErjAst7hjYUIPgucWDDHuP
T6gBQnGENzrfT94fU2OS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 58->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBileoJxjBrgpCXYi7HF2LgyRv3swYSIfm+/KS
w/U+ThsAj93nM6bneVnS67Jdf25pPh3n1bnPmmX4quU3CNt8LJwv2341aprF
fA2IGJHDPqPebPevwst4fL4JLDV76KE44HlcLSMMNpS1mlw15lAYJP4OVs9b
wam6nZ7NzaH2VsUJHae0OT86++K788J5zFcFI9+KugVZExFzgQMx/q+ZREzo
C+IS0edF8ki+YidB3qQ0YhI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 59->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfbgQtx7BK+gBgleoJ4igq4LQLoq7OboWA87nTROYpvN/LzOn
+2t47gDMh+9nqMt1mur7tl+VRx0v53F1Hpu0U34i7TbH23Ss9jebFGujAhUL
7g86ok/nh774+0MvwkvnGx7o202PBIvnKMXhgs33/zrO8GM8SL/wTiymNw/2
pmx3ejbFI9TYwgkex2STPzrz8nun8MLn+fdKMIa9TPaN7Y64O/TIsHXmK6SH
1rO904didz5TJ9T4AM/vYdE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 60->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4eXSoyMM+24klN03s+O4c
n+7Pad4BeB1+n6m+r+taP7f9tnnU5XJetuCxebPyd2mrMX1WKBc2JrpGz6Fy
EcfdHj4mhB1hhFisC/a+0YHxucFIuLBGKcQL9j7/6zyjL9LR6V/If8CVe8B6
s7opVsQne0/A8eC8yDMNGf+0F9pIV9rr3mzC445mR2h1GBm3wftKgNGbz6gn
IXeKmTquxhcW42EQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 61->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwkAIJD0Yr32CX9AHbPxCfcGa2FMTk3owvfH02rgamGW6JLQssOww
cLo/h7ETkdfx8xny+zrPebkdtsMjT5fztAX7okXSVzVJLSXmbJtr/vrzt1Qa
uRKcpY4pvB294d4KarhcU1cDLMyPGCIs2KMmwCX+PtpuNgFmVyPqE3kKMFE/
cOA4xZ7ZfcSCeNg8WQ/GjpTtHsNPubACvSri28HIds3NO4j9fXs8MGyN+TLu
W3tnBXcVd7GqU9VYAbFUYA4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 62->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMizggrjyBL8ADKr4wXlAkdpqENA6IW58OE0Mkrt1WyrbEkee4
OVzvw7gxs8fu8xjy8zzP+XXZLsktT6fjtID7NdaTvlGSxZrDwrfvde/yq/fC
Or1GcqKptP5tf7wkrrfqTYTL+nWvwVAH0+y4vOeIqT6mOXCwOdEn9EB5LzxH
v6kv7P4grziwLmbAeTDUDEq/9IJoD/eM8wqNateCFsR8reWDw+QONnaR9bf2
zh/cVdzFiqfieAPtU2GO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 63->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4LQHoq3fboWqyazk20X0jaT7DCZ
5nB9tPcNgGH3frRpPPd9el62U3JL3enYTcX9HPNpPpEbeMzU3LftNe/8xZcC
C70QOWPUW/Dhr/FXi+YiPY6L/FG41QDWITgsVyYNIFz1MRfPEc7JXGu8V/pR
+i19WfE/Cw7Ggxl4Ho7ankj/ojtGq9uryMdAo7pv86xqFqv5YGpVbcEuKi/C
vaMj/aZasXPuvACvXmDN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 64->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNks0NwjAMhZ84IK6MwAowQMUKZYIgwakSUjkgbhkdKoqwnS8pltw09ot/
nr073/rrStJ98/706XEcx/Q8rafLJQ2H/TA5t7PO0n00d/I243P/FmvO/LUv
qQxW7C/uhGvl1i9+kSv2Jf/exQr8kN3WoFBH7LGaQ+AT42IsitGqscr7H/PA
uogXyE3zrHGFeyTGkTbfVmaDbxQwCnOm3lq9iO+ZfAt8Zlsj7Bf2BlhSx6XN
EQT5Dr5i55y8AOIOXw4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 65->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHooXn1Cv1AfIP2CfcEW6kkQ9FC85emtVCHJTthdiGsyMRkn
ub3mYbwAWJvfY0ifx7Kk7XndnXeauvu0g+1hx+n/Jj1sTGHmXeeqW854yUBq
ENz4LC/ofdbVN+Ora/vvhXCJ4kYTp4H/x7AHCAaeZ/QLakTzy7QoaV/Dn+lC
erN5RlrRPQLP8xbpW5oN7Yc8x+9ZDUeNM18YVtBTNMcabmSWVGevp+7hDq3h
sGznzPkCX/tgTQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 66->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qAxS/UF6ygp4JQD+ItT9diC5PpZNWFdJtMNpnM
7u58664rM7tv3p+uPo7DUJ+n9ehcan/Y9yO4nWxa5WNeLMYAC/+YC7vP8W9m
oobAg6/ykt5zXdwVX66N511wyeJBE9KAZ0x7mMBM5zFfVSO7v6CF0rQVUxx5
ZnVe1RMzoFbyHZnOy+yffk2elMPv7BeOiCvfFUbapz0Aa3ITJnVmHbEHrYXW
ZYk58wnrBWMgX4w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 67->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD2I1z7BL+gDFr9QX7CCPRWEepDe8nRdLJKdTtI2kIVkQjKZ
7On+7PpGRF7H79Pl93Uc83Q7lOCRh8t5KGA7+2zp55qkzhmsmJo6Rdzm11xg
noNXMeMEvSy/P18hfGGvig/uAfqwPJ2PmqaVGY6+rA75sh50T7ydp4d3D3F4
Bbq49yc7aOL56N+o43vnhTyhBv/ZFo4WZ7EyDLR3Zxgs5EZyVGfU0s4Ai/Re
3IT2+ABGi1/P
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 68->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe+nQtLpJMp1kMpJCkzUwm
PVzvw7gB8Nh9jiE/z/OcX5dtDW55Oh2nWtwvvlj6eknwOVOrVsy9wnWbX3MQ
XqfuYsWJell+P74QfGkux4fnIH1UXuKzpmkFo6Ov407mtBY9mjl5dz09Au0b
Xjwzv+/tHwi1kv8I+p7yf/EkJvxbtcNGO5DG3Bc6LqoW/Vm1x4hb8G/VjpyW
FoMs0rvZiezxBqjDYFM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 69->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRT8uxK1H8Ap6gOIV6glG0FVBaBfFXY6ugxUyP79pIG1nMv1J
XuZ0f/XPHYDp8H30Zb6OY3nf9nXxKMPlPNTgcfHFup9bh3bPxaqZO2cc9/uZ
O32lEfJmNbm1z/3X9e8mF/WV9oHtfXbjb8RY0FJ8mTVZw1poqBqDnuKRsA9M
ueeEy+odEDXLewR9Tnn678ZsQp3QGoExiI3qBXptKub1OY+aY1bbynwkK2bJ
DJxxr4pDmEljHxg2XxI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 70->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qA4hfqC1awp4JQD+ItT7cFdZPJZIuBdLdJdrIz
2cP13g8bEXns5k9fnudpKq/Ldvm5lfF0HJfk/uOzddW1Ex+DvZq6UGvjLZd6
DjGU9YUzNAe9v7h2db2QY4uHrMfRFfeEY8Bi+qLWYE7rLEbu5vBaMyd1TtsM
9983QLSi7yg5wzxgrPSjPa0RjMBXqjYpF9QO6ukdkhmFOSacKV7GmegaNDBG
5w45Zff62RvXbF/P
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 71->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kksOwjAMRC0WiC1H4ApwgIgrlBMECVaVkNpFxS5Hp5WAjCfjWEo//sTj
l5zur+G5M7P5sD6GvFynKb9v++3nkcfLedyCx+9aLdVVknkffRfIa3LR31tW
6zi3qL5UgzHUgL1/fnw7vTxjbw7FSGkMODKnhiFoUDGnnczxi3w9xhGPDnvH
VjGLuHAP5CPq5T0SsZICXrxHUIu6mp5oYo9mXqtswlmM6ihfagjOyN2Lzszh
OUScmSszAJPnTrGidP3tA1onXtE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 72->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDH6Ivx7BK+gBileoJ1jBfhWE+iH+5ei2IOzsZLIGto9ksslM
cro/x2lnZq/D+hjL+7os5XPbbz+PMl/O8xY8/s5qQz0+WOujb4d3wA7g7x2r
eYx1VZdyMIY9YG2neLiXOfZ4KI1Uj4mOrJNnNUBX5uKAQWv0y3w9jRUH9hEu
aKr6zObe2QHOl7tEOYhTujb9JLmBm+Ke3BH4WtUm7ABguC/EZ5xDHd6LbK/+
zDfUU7qyBmBy7hQLs2zsC+/tYBA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 73->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMHFxItx7BK+gBHl6hnuAJuioI7ULc5ei2oDRvMqmB9JPPZDLv
HW/P/rEDMHXzo6+vyzjW93W//NzrcD4NS/Lw9dnK6lbQxujb3NtK2/vrV/HG
kWOYmrvByfP1eEb5gMt4QoeMS8pR6YioqWUznCa8i8fz1uhHsXCWir/agWNU
FzRVPFUNIDHlntldoh5fp3RlPqqXd1OaZhhBY6x78y6+RumU6cqzAw+0ua27
q2JhntKVNXAWzv3PfY4YH8d3YhA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 74->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDH5Ifz2CV9ADLF6hnmAF/SoI7Yf4l6PbgsVkdqYupI/NZjKZ
2ePt2T92ZjZ186Ovr8s41vd1v/zc63A+DUvy8I15lV94sbwH3x7eXnLtWs/2
U5jGcNZ3g1PkG/Ec8g0u4hEdFBfJUZxBTV31CJrgLB7OxJX0gzkaLxUe8+cf
rvBOzaruANXDWg2Qm5O+TNfER9QiX6qpwGg0tsyf9VzzERNnp35gH+Fj0iPW
CH+VRw1O5BEW7QW5TV3tA2X7ZAw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 75->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEOwjAMBCMOiCtP4AvwgIgvlBcECU6VkMoBcfPTaSUozmYcS27apF7v
rnO4Pob7JqX03M2PobzO01Tel+3ycSvj6Tguh/tvzpH/aTnVe/JubrVc1/7q
ab/JAMOob4eT5+vxPM919bWKBz5ENSHHjs6GM/VwnqgWc//4MOkVeYPaQDd6
RLgwawt64n1wmKRTPVBu1Jd4VXyCWtWGnooXiA9zpJ7ES7V356G4qT5r7lWE
15uP+goeRFrJB9S0xgcs92KO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 76->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkl0KwjAMx4MPsleP4BX0AMUrzBNUcE8DYT6Ibz26G0hNk1/cAmnTfDX5
J8fbox92IvLs5qPPr8s05fd1vzzueTyfxsV4+PJM6cclSaszclF3Sd7P6SOm
HPot3p/kEvyt66y3jrX5AAeKQf2GPm3Nhf4QtlUZyM2AsIl6AxtiRHlh1k3e
wIdqpT4dPrBnhCfuwUrs33o1mTlRvLbb3bQzsDvidjWah80rrW11R40uqq3B
FTCIeiUcsKdKH6JYZI4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 77->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMjDggrjyBL8ADIr5QXhAkeqqEVA6Im59OK7HYk5m0ltw6XsYT
O4frves3KaXHbvp05Xkex/K6bOfDrQyn4zAH9x+dJP/Vcoo+sM39Ldd5lV8p
wyB4ikfg62zzfuAbahEP+2VeY8y/ZmaEJ8NisZ9NpNoBzobcrcJTs0eBueD+
Aq7IYVwZXrNO9FU4S7VNvnh/wlnxM9FTnb/5CtPzDLhkP/iuKF6DSzVXnIET
2svF6C6DvAHEsmPJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 78->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRYMLcesRvIIeYPAK9QQj6Kog1IW4y9FtQTD586YG0k7Tyc/P
Tw7Xx3DfmNlzNz+G+jpPU31ftsvHrY6n47j83H99tvJzL5Zjcvbw9tLea+Lk
1sEAvB6PxDecPcaFb8pVPK1XOMcpvnaGHl2cNNFePNyJ1syAdJOeG7ye9mrS
j84v4XbuEK81vH85qifuAexoqmF9DtS/cibtVAvaAdqJyAXnQb3AfFxzCW+F
S6NrrCGGtcI/3IFkH34HYss=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 79->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMHFyIW4/gFfQAD69QT/AEXRWEdlHcvaPbgmIymbSB9JOQyWSS
0/3VPXcAxsP86Op0HYb6vu2Xn0ftL+d+SR6/Plv5eyvwsSTfft9UY+OpI2KE
WoiaLLfCyb1tLeMJzFZID+YMn2MuTjOBq7BUzvEgc9hqDsEx4Kn9qH40T7o/
iFhyA1t4WzWsJ+MEfVQP5BzU/MxZacdaqBvIbi3DdBwsrthP41qFt8Il6Gp7
kMleJidvwNkHVtlkjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 80->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT8upFuP4BX0AMEr1BNE0FVBaBfibo5uC5Zmfv5EA1PSTub1
z88cb8/+sQMwdfOjz6/LOOb3db+83PNwPg1L8vCNeaUtLMF/C/K27tcz2PKW
fE0VEAyug6iJckKT6wOk9R9e2QtxVN/MC/squIqlck4HrcqzQocFGiueuh/1
P+pH3R/PTzgPBbPF+1XDfjInmlH2KNKg+mfNyjv2Qs2AnLUG02koueJ+jGsV
r6FFckB7eO8qfRBzLr39ADUtY0s=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 81->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCexBvebotCGYnk+3CdrebZDKZ
5Px4DeMBwNKtn6G8b/NcPvfj9vMs0/UybcbTb6+r/2/rUb/R3dxpwqd6zzYE
BsdBx0ib4FTVAcE1q5H4KBzb44RGXQ5XYSlbxYNyBs0cD0s4BjzVH87HuKLX
Qa/WPDjMXbxGDOvJcapXoTfIOaj6mXNlUxonMyD9lV4Qp8clfibyS7zGfAYt
fA5aXIv34d7IGcAXcaxjjg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 82->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwlAMHFxItx7BK+gBileoJ3iCrgpCXYi7HN0W1OZNJpUG0s9L3mQy
yf5y724bAI9mfHTleRqG8jpvp59r6Y+HfgruPj5aO7u1CGc/xxy3by7lV+eZ
Q2DwPeYAd6b4EV7VBwQnJN/ER+HYAicT9bi2kStNuBfz9bK+fEzN0nE0kR/0
YKN+WJ9V+4B4T+1D1p/KUzhqVmE2yDmo/nmWfzVOdkDmK70g3h4XdcxEfYm3
sJ9BC6rhTc3dx+QOVPYGKTJjDg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 83->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMfbgo3XqEXqE9gPQK9gRTqCuhYBfF3RxdhVbzeRkNxNG8+PKS
zOX5brsKwOc8P9r0vQ9DGh+n5eOV+tu1X8D657M1m+cGLrY6Njz/c02+ikcO
wmH/sxogYkyf4VN9gGhC8G70MJ68pwmFvgQv42KY0mFqupkJHW6XCPiC/Tgz
/YT7K2kgWkt8UX8sj/G4XYFohj5pTdbD0RkHd4DeNYKt/PKUvNBYJvUpX0GL
m6upIY3tXWJupo5jApzMYhA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 84->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbnq7Fislksu1C2m5nMplk
93C9d/1GRB67z6Orz/M41tdlO21udTgdhwnczzGv8g0tfu9C/rj+uCXmK8sF
naDBOCSHYuafGh+WH+pI8m1CEx1d8gT1sLZCsJlYzPmAmk7bYuwszYyU8INO
0l/whX22PBCvLb2sP8ZjOiw/eBb/pjVZD2tnnNwBetcIFs4A5yAeU1Kf6jW8
hPlDDbssB/l4NvyOvQGMU2FP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 85->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2I1z7BL+gDFr9QX7CCngpCPYi3PL0tVphOJqUL6ZJNdiYz
3dP91T0bM3sfp09XP9dhqN/bYU4etb+c+7nYLrGs8gsvkMP5P3fYvcS+1XkW
JjBUT3amajg/45rgMaFXYLEfQbeaSfEJXIXFNec5iJN14hxBG2h20R9wEn3o
MfJn72GTYw/exh32k3GUP4HD1rv0VGnY67HQonI5M70/6YPFHuZnvMzz9H8w
BywXuFgLegLGCBAmYc0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 86->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMDV2I2x7BK+gBBq9QTzCCrgpCXUh3OXotVnl9eSk4kA6ZybxP
msP10d0bM3vu35+uvs7DUMfLbk5utT8d+/myXWJZ5RNeIIfzb+6we4l1q/Ms
TGAgv+Le0iXC6V3QZMKvwOB+BN9Kk+ITuAqL75x1ECf7RB3BG3h2UR9wEn8O
O/Jn87DJ8Q+e0MD9ZBz+f+rtr48mZpL7oObMqF7MDs+Dyj25C/65dxZrmF/i
iZ5nmgIHLKzh+hR/tSaqL2DN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 87->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAihXKBEGir0pI5YH4eXQaCahzOYdactPkHPt8
zuF674cNgMdu/vTpeZ6m9Lps8+aWxtNxzOD+47N1i1uH5YywbOZWI+x7vzhX
jiCH33PtFi/hzM0YQ/2vcrAeBWeUWFSPcSOPNKnivKk6HlO9uZ5NxEudRX/M
rzW7UF+Xe3U+wYF14jw8P3X3pyOCdx3ptFbjf+9TcY7mobRDHdOsTzpW9RSG
UidvPkbFy/yFvQGJqWEM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 88->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvebpbcNlJOmkNZEs720ky
09P9OYw7EXkdls+Q39d5zp/bvmweebqcpwIef7lE2lKTbGcOK6GwqsPW++ac
pQQcuPe1W32RVFzF1sEZNeBTSKwbzW04hGgAuHr+QJPqPwyvV+pgzKNIRyF8
hNdrwbwL6wD333xBv17LnkfsLTTvOl2rd0awnsbeG99/6Afx2exhxqb20bxB
T2tU71C474hRfhNfSIphhg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 89->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQGzxIrz7BL+gDFr9QX7CCngpCexBv83S7oHbIJNWBLXQzzUyS
7i/3/rYxs6mbH319nMaxPs/b9nKtw/EwNHD3PnOV5Xix5Q6wVh76HDB6XwS/
8V4HPpyvMMXzmedsB9QLPWkXtjPbyYgHAXc4Xxz4U18spjtwUP+DZqU7aRLe
sKxZdnJO4P6bT+zLvlvLiP0LagfmefJCeLSmHTPC3GUeLBfLPb/mS6+Ujzgj
FMs9YpQ/VnkB3YphhA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 90->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDgl+oL1hBT4VCPYi3PN0uCA3JJBrYlm6SmUmm
x9s8PnYAnsP6GNvrsiztfd33j3ubzqepJw/fs4ZsRwXbncv1UFOnLkfvJcEH
r1WH5/lLXYg4avOuViX22f6ghWlmmkB24LQp43D4oc4G4wG5qzwic8PzJLth
XjPvUh6D/Tdeopf1VR4FPuQaqj1U85U7RvTI+07/Hfu2syDW/OJPd5Xt0XOY
YL7bHMW3IR/JgGHJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 91->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPoh/noEr6AHWLxCPcEK+lUo1A/xL0dvF4TNJpO1gRaax8xk
0vNjHl8DgPdxe435c1uW/L0fysczT9fLVIqn37NFqo8k1JyplRDVJ6ZG8ynA
B+8Vg2f5u7pAcIxu3SvJz+n5RgtqH9u7wQDxwGiTgEPnXJ/R4XhAcr0bkb3d
voE37NbsdiGPwhY7H+F19FgdzBfGp/+FPbPMg66mYHe2a+RDsz/zDr7nH3/o
FdFEOVSwu+saxW9iBXsFYE0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 92->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCPYi3PN0WFrudTLYN7JbNJJlk
0vPj1fUHAO9murr0uY1j+t6P8+OZhutlmMFTPpO1y7EWi4+wP56/VmII/Co/
m4o1qgfB4TBU6jBOsRZwGfeCuLbrSfTD+RZwlD4XR304HghfbUdi7tW8zLfx
D4S7UzxFbeP82t6DnpVuch4Vh/25SoNIo1Bj+Fm5/3B+pR18zBa/4q1p6jgK
k3svMFl/ZT/ZfF+I
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 93->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA/HIErgAHmLjCOEGR2NckpPGB+MvR2SQeqeu0i5SpnVPH
Tnu43vthA+Cxmz99ep6nKb0u22VzS+PpOC7g/pNzdP+0Dnk4bAlzdUaY/E/p
+VWtER/3lxgqPIyLWtXLWAsQchccjR5G6XuY0PCrIx1qDrJ35E34zvwGOGts
3l0wo+/eBFd4vqLJxFr5KTRj/Vn2Gs2xOmOUXll/dX7sBTlWvJkVb7E1U+7h
Q967wyR/Fm82tF1J
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 94->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbnm4XBJNJNq6BlG6yyUxm
c7jex2kD4LFbP2N5npelvC7beriV+XSca3L/8dWGr8sAaypXTdQ9oRw4Frju
73roM2PrWMLL9eF8cDfCEuYCNHv/iyHkGkOIg+FCPCIdeuYz/aJ3YpxE2/A/
4sVxhfFrZ0x9g5fW0u0VbK3jjP5aft+WjqnG8DMz/1Q/ngU2Jx34EW5rhghD
m353swNI+ht7AzXQXQo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 95->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKAjEMDH6Ivx7BK+gBildYT1DB/VoQ1g/xL0d3Cz6SyTRoIF22E2Ym
SXfn6zCuROS2WY6h3o/zXB+ndfu51Omwnxq4feUS5ZtaxIfBWqipU8DoPaTl
Z7UKfKhPMUl4ECe1TEvRi0iX+18NhbQaCh6cF/DB5vDhSOocH9uT1cFv4R7T
3REOq9F7L4EP+yc94Vzd3IjeGw+zRp/gPfD33g/zK7Hn4DmbH/YiHtMf9Jlu
NlPUsGH35HYmCb+LJx2sXk0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 96->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMfbgQtx7BK+gBBq8wnqCCsxoQxoW4y9GdQan5vIwNpKRN+t5L
m8P13g8bAI/dvPTleZ6m8rpsl82tjKfjuCT3X5+t+7l0sKZydY9PnZBcOHeu
8VmteK6En54zHKU3xH90Gi3IsRlHql1hMw6mrdZpHU5TwAAod8sf0btJ/zRm
uhgeIsbqLLCekzcVjQF7N2iGrQ//63lB8Nf+jLyv7zloTmaMvh1sThr4W2Yh
4Hh+uF5crLVQDdXeXSZcjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 97->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFA/TICK8AAFSuUCYJEX5WQ2gfil9FpBSoX+5IGS45kOz6f
LzneHl2/AzA189GF52Ucw+u6X4J7GM6nYSkevj5b+/PYIjWqrTE+96Koubxx
xld3o52lPMdL4dg6KvgpLtjAxgZ308/OMxS39R7zMJwchtlZ4tXoC5+TGpXe
LoeHP/EyPRxbXRPdcvPg+62mdgeHX3ozoa/in2Bm/pjN8X68S+380l9wOMyD
LApcrkn8xN5hC14K
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 98->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwkAMDS7ErUfwCnqAoVdoTzCCrgpCXUh3OXpbUCbz8jKigXQ6n7y8
vOR0ffT3nYg8D+unz69umvI87LfNLY+X87hdHt++WiquSYolcCmrft7CnTsH
t/jVW4xn+ZFHtA+4We5NfvgPelBs8bVEHBXc5tCAh+sLcHIYUDPW2NKAxgb1
h3p90/8fPFMz1YfoWukWxFpOThuIxV47rVnPiL6ov+MczBiesbnQH/K3ZsHh
WB5MT4GeSQO/sgWtVV/J
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 99->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/oF/QBi1+oL9iCPRWEehBvebottGx2MlkNpEs3yWQy
m2549uNBRF6n5dPn922e8+d+XH8eebpepjV43nyxVFyTFEvgUk7dcyHm7sEt
PstVmxPhYIzkMm6We4jNMEAPeg89WpwV3GIp9kBNRCgnh9Hg8+uNaC2ZH3E0
6Id4yI9iRHjS0IfoWukGtVZXe7rdMbW4Q05r9mZEX9TfcWb6RToIn+Gf/tEu
aCI4lgfRs5rLcKK7VtkXdAhhCA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 100->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qA4BfqC1bQU0GoB/GWp9uCutnJZNGFtN0mmcwk
2Z1vw3UlIvfN/BjK4zhN5XlaL5dLGQ/7cXFu3zYfrWYq9SiY1Ld9YsFnSnwJ
fhMH+bQ+8iC8mjpJbuojXL53hu3/S8zPOJuSPrmeMP5hLsApYHT49OaTaiH6
EQdn2avP8NJvwgfjkJNhfYm5ftcyTZjLehD0AvYvO4gaaP9IH9jc7Y/62S6Y
EhzPg/Sz0eU4UV3NeQFJ4GDH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 101->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEWCVyWk8kD8MjqtBI1zPodGcpPUztm+
8+H66O4bAM/d9On613kc+/dlO19u/XA6DrNz/7VppWI5oaxEhrLnXyz5chK+
AL+Kg4gJMELfGgyUnGGdppflztj8H/59qzbHk+EEVNcSx/k4j8Vo1NPSJ+xF
9M84Sssov8ILz6IexY/k1XJFby2v4UzQW8WB65c1a8yg0sRpIzRwZ9S9rM0f
zYLj0nIQ8Fn1ZWr6qwk+OgRixw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 102->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKg0AMRUMXpdseoVdoDxC8gj3BCHYlFOyiuMvRq1CZMfO/MRBlnJj/
52Vu3bt9nUTkc5kfbfo245im53lZ9Gl43Idl8/rPOTSnqeRQl5Lftta6PVOw
h/pIUeP0TLdr6gP42u3hdG2vTgN//rvU/zPPpoAT8ObrK73gfMzPoflEbEEf
I3pIH/I80k84H8i1ZAUYr17YmTYBvDGO9G45PTQTOj/AoZq7OAaBPrsLFcuS
gWNioG/pKZ7JDxdeYQo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 103->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMDH6Ivx7BK+gBFq+wnqCCfi0I64f4l6O7C1bT6cx2A+kjKdPJ
JIfro79vzOy5m5Y+vc7jmN6X7Xy5peF0HObk/uuTdfbbPZ9zPHp46/ktuHc6
V+CYvnsHefJ/K04x7M89clV4vsQP4wZxxR00QqyKG/I0o5wYhtJnVX9a2hIc
Vj/TF2MUQ+DFGpSeVX1gTFdVU2GEm9JRzhbOiuj3Uv/o2cpa1v6vZqHSMmoA
mjjBjZzaPfkAkZBhjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 104->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVoABKlZoJwgSvCohlQfi59HbSgRc+9zEktvETs6X
s0+3Z/9oALyOy6dP7+s0pc9wWDf3NF7O45psv75Yh99f8jrHtauzks8aj+IO
B/FeOpMn9UtxioE/9w1XVku/g/GzcVRyV3WFYDlulidAOTGMSJ9ijxDfBePF
dGF9CDSiGDU6k7lzuur7Rh+ta/QmZ0SDaHb2ZiHiTzFJD9wa27fU1o9mwWm5
Y0Jwda7ckxn7zF+Q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 105->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAngFON8DY
MHFkjKS2AaYWDeMSxzCHATe/wR5NHov9hMSxmsGAcDsDsjux2YUuj242ujgD
kW5HCqMGLGY1oKlBYaPbR8B/BMMHX/wQoRc9rpH9ghLGBMIIqxnEhDOWdIce
rhj2YwtjbGLodiO7Ad18HGkHX1pA14/NLfjiAIPNgKofwx947MemDsMMPABb
vCPLYXUPCgAAfb9fzw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 106->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADFK9QTzCCXRWEuhB3ObotOBJfPtNA2kwm8/Ly
Od4ew7gD8OyWz1Bel3ku7+t+PdzLdD5N6+Xhq4v0+P2l2tWvVcVKjSWN/AYH
8Vl6unfyZ7xCDKgYtHlKxo/92Mhd9UgcLKGYP5vzZfU1+pbWDhhM7y3PWtfi
ziHokYvBHIkH8+eehvnh9zWqyYjTg2h3sl3g9x6XbH7GVjFmtxr5vTiDkQjP
Xe+qNxOL9wF982AQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 107->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwkAIJB5Mrz7BL+gDNn6hvmBN9NTEpD0YbzzdNnENHQbqJrQsDDAL
HG/P/rETkambP319Xcaxvq/75XKvw/k0LM7DV+ZT5PfXpje7FYPVhi0+XjGO
5ZH4rgX8WH+DV5hDDEY8f+StGT+0C/gS7griuBGMmwtwYjlYf9wbNriuDsTi
rJXEK6kf9jnRkQfLwfrq6pMeUxurG/SA9VCxdrBr7r3y3/ycbjBut5IaGW7l
S47F4K6ymfh8H7b8YM8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 108->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMDS7ErUfwCnqA4hXGE1RwVgPCuBB3ObodVIwvL7GBtGk+L81n
d74O40pEbpt2DPV+nOf6OK2Xx6VOh/20GLdvblTke39k+y7g00jLi9Hm9BEn
+RTtLCbQaweGmltRXzwW/R/qWU+SP1q2WBr4KMlHc5A6WEw6IxGHyWKxXiXx
SjDCPidyDwbr688eBD2muqh+yM9qRux/O4i96pmfk42P260kR+bH9pOR9cFd
ZTPxeE9Fq2GO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 109->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbiQbj2CV9ADFK9QTzCCXRWEdiHucnRbrDC8vGQGMp9k8vLy
OT9ew3gAsHTrNpT3bZ7L537cHs8yXS/TZjztsq6e5L+Ufj+t/wnbnD4SIIxn
bFc+DX2GYdVpVXzmbRk/1jNewtFIIDjwn5on8+E6uvoDkkNYU8BhKl/udYhJ
GGGdkzvnoDBUXY19IfgrXZQ/xY9ybs0Cx3W2Rv/cvXq72eKaZvlGGMmq//Cs
qp54vC+gHV/P
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 110->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQXDxIrz7BL+gDgl+oL4hgTwWhPYi3PN0WlG5mZ5rAlia7mezM
7Pnx6oeDmc3d8unz+zZN+XM/rptnHq+XcU2efrGstEVJtq1kdd6dlX8t5MK5
CsR1+4J5UiOx9jBc7xUHc+eIofojOpXGu/6+DyM9YE3li9JC8PA9Bo8avbL3
sEeqC/POoA7vkf+AaXzGqF7oB+jjdVWcAn/goDi3ZiHcJznln/SIaIFvN/kq
jJ3la3BWmScR7ws5UmGQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 111->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3PN0WlKaTmWID2+5uwuzM
JMfbo+12ZvZsxk9bX5dhqO/rfjrca38+9VPy8F1jlHl5sTmKLfPhzn+1kEv3
aiFuOHt4Q9VILNRBaiN+1Iu8fY0f8cn/eTd45AQLaxZ7DOYD0RE5ph4pHPwT
/dhriQmcpc9kn7w2PmPoaeSIOpivShNyRw1K85ZZUDnZD+QB/NJsob9reomf
yQcIB+6RE+tJxvsACYJiEg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 112->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qA4BfqC1bQU0GoB/GWp9tCS3cnmaiBdLub7Oxk
ksP10d03IvLcjZ+uvM7DUN6X7bS5lf507KfgfvbRdHVTWU2Jy5xX7Zd8U4gl
GNH9hgN5I8X64XzBN23rRd6W8cNzxEs0q1fEimLIk9YWYDS5Qt5lutVrUD/2
mvZdWgyqc/Dv5ozMmAXuZolpTHSPuGMNTMd/ZyGK0X4gD+CHGjitRTzPL3pm
ZsC9zo964nSVD/EPYgw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 113->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylUkEKwjAQXDxIrz7BL+gDgl+oL4hgTwWhHsTbPt0WlG4mMwHpwjZNdncy
O5vj7dEPOzN7dvOnz6/LNOX3db9s7nk8n8YlePj6bGl1T7Za0u5xH/I9eKu+
wFccWjUbzn/4nsp+kTPGq97jOeIRLg71TrBYjPJQ+iieYa3uVbrFleDinOXc
rcRgOqv/6p2Je5w47YdpbJoDcscelI7/vgUWk/NguIQfmwVyauUVWjYsaoD5
EV/qah9SbmGI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 114->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylUkEKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvebq7oOwknbQsG0hL22Q6
meR0f3b9TkReh2np8vs6jvlz28+HRx4u52F+PP58srS4Jlksxa54hngFr+Ub
/IhDLWfD/R9fk63X81bEkca9xyNcFPILncTGeL5FXyJ9Ip6wF/9GuuFOcJle
tH6xGL7GJp7jxebLa8ry/P/Il/adcGecmY5rZiF6C/sRadzQSAinWpzRsmKo
gY9H/FBX+QIf9WHH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 115->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT7cFodvZnVUD2zTZ3clk
Jofrves3AB676dPV53kc6+uynRe3OpyOw5zcf2IaZYlWsIyio9m1qW+cU31Y
/4ccuF9x+nPf4tv7MvcVP4h9uk/GvZl+GyAOEV/ni9In40kcUhyeA9xUr4gX
qO4HPPfOxBtjTaM+Pl/55XqhayK/MuzQB8Q56YfS+ItG0XlZneMohvW9Ub3D
iXTFGyWlYIY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 116->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHigfhmBFWAAixXKBEGCVyWk9oH4eXRaCVHnfA61lKZJzpfL
2cfbs3/sRGTq5k9fXpdxLO/rflncy3A+Dcvh4Tvm0HWYyhqaD/Nrhzc8y/Kk
/vf3/TRgfqYJc//gPb9/L2pn+gz34T0t7aY1R+AS7p0pqUvmD/PC5Vh2xnzz
M+Ft+sV0CeA28LF6sh5DT0Oei3CfRK7MU6Y567GtvVBhhHAKzOAFwzCPAl8D
5/er3iPh32qADzy0Jh90FWGI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 117->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUkEKg0AMDD2I1z6hX7APWPyCvmAL7UkQ9CC95elVEBxnkxQMRNndyewk
s4/X2H1uIjLX66fLSztN+dtX2+Kdh2czbIf3PddIR2qSI5KfimvAK595dWLX
nzRwvaeJa//gkR/7Ze1q6FPeJ3ykXQlncSnfzbwifm8S7BsaQh7+A477iLw9
6aYeI75iPoFP7kx5LlAf+WXdybOxfLr6Fpjf1O9wFTMHfZ425PFw7EUU2Cu/
1YLH9OQHtnxhxw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 118->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBwS/UF6xgT4VCPYi3PN0WhM3OTtYNpNttkulM
kvNjGaeDiLyG7TGm921d0+d+3C/PNF8v8x48/XwzzW4q2TR283eXbxiL6oTX
Fxyw/g+n3nyP7/UidyP8DL+7d9M2d9MSg2EZ/lsBVyTW1hGv8CMcPF0e6mjN
tuANGlt4dI8ka2AYVU+xL66+6ivTQbQzjGjHeneh6IsE/NnJeu6wIm5Yz/Jw
Fi3zWnFXw7kU9gULiGFJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 119->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6ygp4LQHoq3PN0WhE1mJ6GBdHebZDYz
m8vzM7wPIjKf1s9Ql/s01e/juB1edbxdxy14/vtqpbkWaVZiV3s2+YqxqE54
vesB64XUZvcEeTZm+WLfSvpT/G/2mt1r8BVcsB/Q0OFmGuyId/gRDq4mD3lk
b+v6Bo4ZHtVZGgeG0WmKupj6TlfGg3BnGJHOe2fB6SJB/2yNNIp0SGYRc/At
MrNccVbDd3H2A7yNYQw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 120->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCexBvebotCBsnk7CBdLvZZJJM
cn68xukgIuuwfcb6vi1L/dyP++VZ5+tl3h9PP92kNNUiTUqsau/yb9eeOIF4
wKD5hcQGviGGedOS96ukPkW7+dcsr7Q4BbVYirkLqdMK8iCkBsObww9qdafx
wz6y2bq6yX4wPMqz6Y9hOE5xfpYf5JX1wXaDYESz7t0F5IXWz86Io4iHZBfR
x9kTsb3irvbN5QtECmDN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 121->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQXPyQ/noEr6AHCF6hniCCfhWE+iH+zdFtQcl0MxvtwjbNYycz
s9lf7v1tY2aPbvr0+Xkax/w6b+fJNQ/HwzBv7j45RSqJZCVSnOC5LdfxT525
eoch7zdRG5wNMWgPqa0Xgh/8Ov2jda+VOrhkLOVdxTPg+42KA/nGHCLv+HzY
H9FrhQmB5zUqPOkz6VMYlTbfP/ZH8K90KM8FhvJwzVvwvkj+aow8amgLef5a
b4TXym8VaZm6L2+YOl9L
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 122->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDxIrz7BL+gDgl+oL1hBTwWhPYi3PN0WtBuykxQDKWyTmWRm
93h79o8dgKmbP315XcaxvK/75XAvw/k0LMXDN+eQmiqoIXFq0Lv+T3AQx084
6HwQbNAbcphapIHuCochGjSbi4pTl5aLedfsacP7ALID0Oyb3rPtJ7O8jhDv
/Qg0Mj7qs9HHOFQ4v4+t/TXBMg7m4T9vwftC98/uMfCY3g3Bp29uw4eflkaH
q9E5a3wAa2RdUQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 123->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbotCptOJgmksE1mNjOb
0/05jDsAr8PyGer7Os/1c9uvh0edLudpLR7/uUTp2Qp6lCDx69v0ouNbhLM1
bPnsuXGdMVwTvSGHqTkN2awgjNDQsnvRcY3ScrF3mz4V7APEDMI3pzvqF3ex
DjWDfIdEI/NJn42+yCfFz+HugOeKsIqD8Rm32gX2Rc6fvWPgseMRexv1uf9J
sFa7W3Z/Y74vOZRcVw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 124->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kk0KwkAMhYMLcesRvIIeYPAK9QQj6Kog1IW4m6PbgtTx5UsC6dC85OX3
cH0M942ZPXfzZ6iv8zTV92W7/NzqeDqOC7j/6izlp63YvxTWFviu9iTOinBL
rqa4xigGviFHh7keslpNYqAHtAPeQPv56Yuzppq7GrU2rcv1HflDLq0t5Azy
630QH87ZAAtio/2t84HZu71HMxcO12/CTbeQ5qf9GfgCh+MB38jP2RPBGxYs
5/sAksBdVQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 125->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsEJwzAMFH2UfjtCV2gHMFkhmcCF9hUoJI+Qn0ZPAoHKp5MESmyfJJ9P
erx//fciIvNt//R16aaprsP12Hzq+HqOB3g/fbfydy3SWiH4+WexamJSF1ib
vSKOOYhFPFkNg7k3BG+1pnhu1vSc4Erc6sd0dlozzoYjckNe7t1RPLnLzQDT
K+kbzgerR3UWggW5Uf+QG5uTpnZgmuQ3fIhujmN2P+sfq0lquDokNotzPUi0
cDMMmLunsQ17+l1T
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 126->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDB5Krz7BL7QPWPoFfcEKehIK9lB6y9NVENydTNJA1N1JJsmY
bnz3cyMin/v+6PP3ta75N9yOw5SX52M5wPb03dLlmqS2RPDzzWK1iAld4Ls4
K+KYgxjeS8BR8JsZgE+xP4H5IIfeE1yJY003Bg11YLOjPmxuL57UMjsA97Qv
pmvAZ3SWOp9xKOGL5vB2reJ2zNTw+iG6mfyoPvt/DqenB9vFf3GKWGDYQ7lb
Zocp3wbzZFzX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 127->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMFHmUfjtCV2gHMF0hncCF9hUIpI/Sn0ZPAoHIp5MiUBz75LNO
0vU19p9ORL7n5dPX32Oa6v95WjfvOtxvwwpeNl+s7K5FWisE31YWqyYmdYF/
s1fE8Q5ieC47B8vFYlaDAp9ifgL6QAM9J7gSxzfDGDSsg5D6YX2QL4snb7kZ
gHOaF2o84HN1lvY+41DCx3S4nCHfZmYCc2+QGYt0uvuBjmy+wz5mPKQ/UZwi
lhj23ebkZpjyzaZ3Xho=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 128->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfELU9nk4ZIHadEytouqWu7
PVwfw30D4LmbP0N9naepvi/bZXGr4+k4LsX9mnOUX1pBG0XU11H1muvpJmju
1l/cgAOx1/cirhUXX/MajM4x5gfSxxrUnDk6j3yyf2kPB/vDXiS+NXi9fnFW
eAP0X/JiX//gBZ/R7lcYJvCUjsCZ+DZvRoU6Q7yxTKfn0NPBvoVR3WNyN/I+
On2muCShdPlawAp4H3JLXxo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 129->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwkAMDS6kW4/gFfQAg1eoJxjBrgpCuxB3ObpTGEr68pJAms5MPi8v
ub4+43QSkXVon7F+H8tSf8/zdnjX+X6bt8dL1yalaxPtdpdyVDWW+arxSdX4
Yy21WCBGy9GX3kuSA/IrYonOAjGII/pHjIYjq8ifrUO5Bs4sTseRiMPleI/8
SS2HC+4pLjbzJJ/bIyPIGYuN5rfzgzywPhLOXQ2yY1GfFkPWB/LmLJtjxB+b
R+KHO5gJ68u+uVwu3x+yWV+a
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 130->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHigfhmBFWCAihXKBEGCVyWk9oH4eXRSKaou50uw5CZNLvb5
7PPjPb0OZrYO+TOlz21Z0vd+3H6eab5e5u3yVDzbWDybl3W3sXaHtcIKTNcN
sBTDkQu9kbH53DoxKL4DF8mN9HA+/7cXHJ2cc/Jd0BqNeZuoySzwamIYL3IF
Xtx3xUv1vBOPY6OpvvHbVv92fVo6dPKiDiGHmLFWncihVwfrxhyq94AJsyVm
UeYT/FsaonFdyCnMs6rFfunOX1k=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 131->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe8nS7UCSdTGsgG7adTGdC
TvfnNO8AvA7lM+X3dV3z57bffh55uZyX7fJYs0SqWcJq/UVq06gqnKXYFxKC
x/dD8KgzdY4BB/Ebvd3VBurhPnTOxb1R8pt81+iE41e6ITwJfBfDeH5T6VI7
IebpPf7jY272pzjUfJWPoJn08i6pOZjCEkfPp9fAeyr3y1elAy0m+FdzHM1Z
7eEg2JfHS57A9wXYnWFX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 132->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMfbiQ2XoEr6AHGLzCeIIKuhoQxoW4y9HtQNH25aUayLSdJC8v
n/3lPt02AB5D/kzpeVqW9Dpv18c1zcfDvBp3RbOMRbNYdW9sRY3ejUQ+SkG+
HA+dS2Lzf3QwFD7XqbjhGyPjenhkN1LOybbPXYmYhXU4OLygFjfbyu548dwV
L+7rDzzG5j4qDNVftaOOc4Aje0AYkmPQ45qPUX5ZN8SpeKD1cfUHe/AP/+7u
oeWudlXiOLw3mZ9hlA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 133->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD2I1z6hX7APkH7BvmALehIKeii97dOroDVOJtFAZNdJZpNJ
bq93011EZCynT5M+j2FI32cxX9rU36t+Bq+LT1ZvntfzarWDY5wEMcyFvKfz
Zc/D/iGXvkfxBiN9Ui2WHJp3xKfwDI56IPY/MyOzyEENhs/pxcxW4aYupheb
j/Peab6gfqYXmx/uZ8RDNQAOuo9BjWwX8O717dYh+xjTv7MHVAtvRwPDvnQ8
5TF8P1PTYRQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 134->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHgwXH2CX9AHEL+AL1gTOZGYwMF426cLicjudNrQpFBod2bb
zvnx6voDgKmZH11638Yxfe7H5eOZhutlWJKnn8/Wbp7XeLXWyXMdtrypUQ5Y
vpIDmktiw74ZI8QSfcpZgPorzxFexJfJeR6c+8fKxC4y323HzGXscJl7qXlF
+1H73oMHXcf/5GxRn2etlTuqsJURl6cd3oPSB+s06tu9B+oa07+jAzkLT6OB
cV9lvcQxeF+D7WBV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 135->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUlsKwkAMHPwQfz2CV9ADFK9QT7CCfhWE+iH+7dFtwbrZSWYVA+lum+lk
8tidb/11BeC+mR59ehzHMT1P6/nlkobDfpiD27dP1hXPy32xTsQZhxJ3mMgB
n8/mQIlZTMgNf0qOgP9rrcay0Mx8UZ+sFuvcD4597mxiFpm1tepq3UU+p6vF
q7T8w4cYx9/C3qL+n3fBzqjijoxyqR7zHKL9cLvYqFvqQI1x9f/Qe6Vf7p4x
rsviQx7H9wL8q2FT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 136->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydklEKwjAMhoMPsleP4BX0AMUrzBNUcE+DwXwQ33J0O6iQJv9fhoFs7Zp+
yZ/l/FjG6SAir6E8xvy+rWv+3I/b5pnn62XeDk/Vi6XqxdSsm7PqmiTcsbGa
DAN4wwd7m0OTY0pkN/WYN2Iwfler06ikZn8/9ADoQSx0ZvX7fvscVvvef0DX
JF+oq8dlvfmHJzjOf4O9lfY+m5/ARuZysR4znb88cBY7umkd0sYE/WhOdtZP
Z8+Y12XjISfwvuVAYpQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 137->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlEKwzAIlX2U/e4Iu0J7gNArdCfIYP0KFLqP0T+PvhSyYvQZOsFao3n6
ovfnMs0XInpf82eKn3Fd4/boducV09CnPXgrmiUUzcLFHhJqPeIB5/Lv3FEW
tZCva1SYZLGrc8+qngwWNbAVR0bnLZ76bQUfg+XEJH/93rqG5H52Bu6/U8/0
1cIFPprvP3hox+B7gfl5uyBn5N4FGGbOaGaAD6v6Td7Soj6ozjG7hfbkZP/u
7gnRvGQ+xDF4XxIrY5Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 138->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksENwjAMRS0OqFdGYAUYIGKFMkGQ6KkSUjkgbhmdVArF/v5GrSU3SZ38
PMc+3h79sBORZ1c/fX5dpim/r/t5cc/j+TTOwUPzaql5tdLGxZL1Jf6dJ7u3
6P/EzRlYF3KH0ZRAWyCOIzA5LWRhrPI7w/LGt3KcwKIdGTCm8zdG7tC5r61B
OA/uc1x/dBmLyWWjXtRj9L1I/aJe0DUKzwbM0RuHdRDf65RdyMg4xO5xvcX6
ZCV/2HvKNC/upzpO7wPJvmQU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 139->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHRHyhvCBIcKqE1B4QtzydVIogGc+EWnKdehlP
Yh9vz/GxM7NlyJ8xvi7zHN/X/fpzj9P5NK3BQ9EsoWiWVGzjr/QbD5Bb+RKp
a+oRo+4NPRpME9gGcWUBX3JhXO1X4/yqB+NY3cdhBZ+D93cCPeo7b52BPIte
jKPCZVxwxzbjGc+T70Xmh7NJgN+tFZzVG8s5mK+n3I1YxsPaHLdb/+bT4d/d
PXgLxoniOLwPcEhj1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 140->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAihXKBEGCVyWk8kD8PDqpFKjj3LVYcp04rn0+
+3B99PcNgOcuf/r0Oo9jel+20+WWhtNxmB73RbN0RbNYsZXf6e+947H29Qs1
VyvejdRQMQrXomWxoZbEivmfxh9zMJyhP6+MD2NnLwy3w6h6YjNYPaP2MYwq
L8MS9+bvfOBxki/BG9sFP6MqN5OYX3As54AWH+UAxDIcqGOa3VqbzwJ+unuC
i6pXtFgi17N8ABioYtM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 141->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMDS5kth7BK+gBilcYT1BBVwPCzELc5eh2oGL68tIxkKZNk8fL
53h7jo+diCxDOcb8usxzfl/36+Oep/NpWj8PVYukqkW02sbP/hOP1a8/UDVY
+NYEuCSnh235UQv4yKXLVX45zo8YjCfUZ5X1Q9ndCuNtOEY1sRls3qX1MY4R
LuOCe/MXHsRjf2m/gr6xXbAzarCZIH5QYzgH8fm0B0Is4yFtjNutjfm4XWU7
GklvnyTAcXgf5F5iVQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 142->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhR8uxK1H8Ap6gOAV6gki6Kog1IW4m6ObQsTJy5vWgWnSSfP1
zc/h+hjuGwDPXXkM+XWepvy+bOeXWx5Px3E+3FcvlqoXs7o2cXWe9Lf2jQdu
jsXvlogr7kg20OmTK/FDLUorfne6OOmVOik/70qDqb03/qc75/qt9WB1jzam
NEZcpYXn5i8eMVWvotpxDmoWfI8aNucvNKteGLMXZiGsAcSqcoFjuhxUjWR/
ghlpOJEtzRMCTsf7AJpLYxQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 143->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMDS5kth7BK+gBBq8wnqCCrgaEmYW4y9HtQNHk5cUG0k/Svry+
5nh7To+diKxDHabyuixLeV/32+Ze5vNp3pKH5tXG5tW0zS7O8iZm99o83DV5
MRiK2GOsoSaG2O6swDmc4U7KhXGV350QJ5oEDeB91hkHZWtrWNPkUZPeH3TX
4mOMY4Yb+gXf0sFj/ch6jOmlWB/qZf3jsPH9hDPTOdT+0wu9nnAz8LH6qMHO
NKL/Q5xqyIzgIqf0L772AWSPZZQ=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 144->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfwCnqAwSvUE1Swq4JQF+IuR3cKs3h9eRkNpOnk8/Im
k9P9OUw7M3sd6mcY39dlGT+3/Xp4jPPlPK/BY9MqpWkVb3bjV3Hw4dmbhlqI
G2A4Y5fYQ+WYygV+mcUaL9HvGVejGjWHDk++n3M/0zmbfxTuyRhZzp/8w/uC
T3HMcNU+sa+Hl9XLPUhmx7MInCEesPn+grOaM+9Wbxe6O8GW+IT5mMD59T5C
A59MBC7mS5yA9wWPW2QW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 145->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbnm4XiqSTSTTQliaT6TTM
4fqY7hsRee7aNtXXeVnq+7JdL7c6n47zWtz31aL01UL7OeSxDjmL1UIwZax/
++CuFiO8h3KLOP0a5C2/Fp/XSKtAD2hk3NHsFJZ9I8Io6HDvIwfDWI1BLePF
uaTz+tVvchkf8yPzGO1DL+H//6gPQTDRn9FbmRfCGQg5QQ97w3kr0ep8Gnk0
CeS1eMrj+D7pc2MU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 146->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4BfWF1RwTwvCehBvebpdKGs7mWwNZMtOJukk
zen+HMadiLwO+TOk93We0+e2X34eabqcpyV4LJ5Ni2ezcjY4xgGruaaEo218
zQu4pr6mAOY0gH4L8Lq+qcct0iqQg3pI7Wh2Bl7fEXEMdKxG3gJ7pxrx7Qhv
64278+rlV9hWPbaPbMdoHu4S9v9HvDHCYfqc9s4u0BlIy3daah3B3eGMhGCE
S3cv0OFmI78+XR1X4wtRPGFV
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 147->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Ea5/gF/QBwS/UF6ygp0KhHqS3PF2LraaTyUIX0qWTZDLJ
5njr28dORJ6Hz6ctr8swlPG6n37upTufusnZzDYf/V6mssa8LX7AfKwpidG1
/5eXxJpGTgEsaAD9luCe3zTiIc73KNCf1wN8bE4LZmC+BvoMdeEhb0FnUOsL
NSe8+B741pvyHVbjY/vIdozmsbmxem4GYSchl3GgPspd2YWqJtTHeklqpzMS
gpFYunuJjjAb+fcZeALHG2RHYxg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 148->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMDC7ErUfwCnqA4BXqCZ5gVwWhLsRdjq7FqslkUh+kj05+8ybZ
na9dvxKR2+b16dr9OI7tcVpPP5c2HPbD5NzONh99X6YSMW8fP2A+1pTEaPR/
84pY01xTAEscgL8VOPZE3OeHvlLgoE3oX2hnYL4H4ga80qlmgRpU+mE8i4Ne
yO3vnFi+w5bqsX1kO0bzmG6sn9Mg7STkMg2Yrqk26GOsTpEX+LG3EG6LGjFO
BX86A8Ij6Se/d6Y6qcYT7YFjFA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 149->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfXQhbj2CV9ADBK9QTzCCrgqFuhB3c/S2UJz45mVoIJ1OkpfP
y5wfY//qALyPy6dPn9s0pe/9sF6eabhehtV52nQRK5oNRYwUm59sPjabiOH8
VjBhLGJM2Befwu/zca+/O8jnpLJTDVmfbJnU1/AxHCsl2gXNHPLnbE2eRZzi
T+Ih8M62Zx+MZ34lTvGm6jnOqjdJWMWB4qvK3XgLLQ7A/QWzqNohRxC2Ro4K
B/pXe0eZ8y+PnGUGOAVkig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 150->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPwQfz2CV9ADLF6hniCC/SoI9UP8y9FtoZDNZDbowjZ0H7OT
yZ7uz2HcAXgdls+Q3td5Tp/bfv15pOlyntbkcfPFrHg2FDNybHmK+dpsoobx
rfRkq/tBedUT8uJT5D0ec81W91dzEcRphpxPsUzuZ/gaxaux6C0gtOX6f3QW
dUo/2U98ecd+eQ++F+urtG04RfMcNmvP3BWG0qvB7uxCTwMwP6VlMDvSyHNS
/d0dDXg0745yzwpHYnwBrMRjjg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 151->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUkkKwzAMFDmUXPOEfqF9gOgX0he40J4CheRQcvPTk0DA8nhkQwWKiZbR
NtfXd/x0IrL0+2cMv8c8h/V5OX7eYbrfpsM5nLqLJo0qSRRUTj/YbGxUEoP4
mnKi5vkCfpbj9oUv8Vs81qvNz+qKY4catD7YIqitYWOKnTLxboHvv3smtej+
pHInwECOefco5m7djey1uKHnI/yg8zMMnBd7b3ChxcmsNtkFw67tiOaT+ShH
GQ8rvClwKMYGW4FhEg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 152->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksENwjAMRS0OiCsjsAIMELFCmSBIcKqEVA6Im0enlQpNfl4TEclNHTv/
O98+XB/dfWNmz9346eLrPAzxfdlOzi32p2M/BfezjSss5sGWFcRsjstZmusB
cir4P59w0ztreYpLdYrvya61epKf8drKuXA48cuZi6UcLjVmdepq9IJq/Ftn
4EP9rNInwcAZgH4U+rf6BroWuhHfF1vi+H7AKN5L2JVZaM1kxg1aEHZNI7wP
78MZrc2h/hvgIMYHEONhEA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 153->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKg1AMDF2UbnuEXqE9wMMr6AleoV0JBV2IuxxdBcF0MomB+HnGmUwy
j/ev/V5EZLytl7ZOzTDUubtuL5/av5799vG+5xrlSC1yRIGMzuT/f8WaBF8j
bMAM+RF3vytgKdbaXpFLQIcJdw4cyvjhTCEth0KPrk8zO6Y7myOdH2IxPMZJ
+k93aTAiD6B33PwTj7HZOi7C5/QiNupnGKgXdnbmBbZvuiPsJah13or0nsyA
ejTxhXsWgkMxFisQYBI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 154->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMDS7ErUeYK+gBxCt0TlDBWQ0IdSHucnRb6CJ9eamBTKfp5728
vuXxSttBRN6n+kn5cy8lf9djmzzzfr3sbfHcs8atZw3t41A367Rm6trT7TPr
9oySu5XNI3x2RoADzNWMFEugDxOuDhjK8KGmkBZDgaPjabRjfTuNJPiPdGc+
YJiEf/hOcEfkAfSO63viMdR00BHCaSzjiN4Z8Aln1y9w/+cF9t70jZBLsJf6
K/DtTAPq0Ykv3D/jQu/4AQDaYhQ=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 155->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBxS/UF6xgT4VCPYi3ebpbWCE7O2kNpNtssslk
kvNjHsaDmb26/BnS+7Ys6XM/rsYzTdfLtDpPRbP0RbOgnNW983tbxeJ3Hygo
F9tV3uBNmNes7cPblA9RLaM+nDT3xB1EPcYAUl8DhFHijLiy2qcwbnEKxsoS
8cc9RxiMMHu71/z9u2PMKbi+k4ZjhU+9FTG8P2pme7ug5h3yJ7jgmIiHvZlz
f3JHN/ai+VdYZI4vRFtilA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 156->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMDD2I1z7BL+gDln7BvmCFehIKeii95elVqOx2dkZsIGJ2ZyfJ
JM3w7MeLmS31+unj6zbP8X2vtuARp66dtsvr11cLyT1YsgB+Auv7uXAHLox/
eMUbyWsJR2P4d5XLoI/MinPgRT68z/OyHDlGaqq0Ag5W45GmhUZogMP65Zwg
xr1h83CBVTuGmqr5FdyoH9PaNEbO+49dYPOm+mEtogeqwYmZY39UR7EXRa8m
aqEcH0IUYxI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 157->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsEJwzAMPPIo+XaErtAOYLpCOoELzStQSB6lP42eBFpsn3VJK5BBtnw6
nXS6P7u+ATC1y9HF13Uc4/t2WINHHC7nYX08fnyxkNwCkgXyH3Ltey/cCIvj
Alf8kbhIeVsYlt25eaA+MqvuCZfx+D2v69Uw5utpqvokDI+jnB0cjdiIG/OX
c6KYa3vzMMVT7BdrquZXYbN+ntbQOWre/+yCN29XP+YierA93J3/mzsq9qLq
FSWXSo/CZpWkYhQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 158->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQXHqQXvsEv2AfEPyCfUGE9iQU7KF426dXQTGdnREDG0gymZ2d
3bp/d6+LmX2u89blbzuOeXpUy+GZh3szLI+3NeaV9vBk+0oQJ7C+3Yvwgsvh
HHjJH6Yj/LFjDi/uKI5ps2PNf2/CJ8zLcjjqZTqxTsHBNMreGfEIF2hD/dSX
E3PD+uFKp5gv9FT1L3ATX5mnCsP6rWYLZyXwqPrK3MqLAkM9INjgkaiPYkBL
qNWEFsrxA5p6Y1U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 159->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD2UXvsEv1AfsPQL+oIV9CQU7KH0lqdXQXGdzBQDkY2ZJLOz
qbpXM1zM7H2bP03+PKcpf9vrEvR5rB/jkryvPlva3ZPtlsBPYH37L9yLXg5x
6Is1gkeoMRHD2dUsxs3+cz7k7Jh3MZfNKDFBU+gbtIEejKPSmL1NMMAh/6AL
4cv2hr2HCyzdB6Kp0hfnMZ5MU4VhOqrdwl2hXNj9ytlKiwJD78+wJzQIGoq9
cKw1wYX2+AG1cWSS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 160->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDV0Utz1Cr9AeYPAKeoIp1JUg2EVxl6OrYOk0772hgXHM5Pfy
kutj6oaTmb2a7dPldzvPeenPu/LM4/027sbLcTZJ3+PJfqWwVX2LN08hLsYc
cR50yBtjlG+MMaGHf1e1DLF+JGKm/RR1rVIX+mfYGE7FTcjBMCiO2WxACOeK
C3qLvWF9wlxVz+Stxi/sDMHJOFU+jMfqbrG9FTaYm2Et1gPtn/n+wQFwKPbC
Y6wJLDTHCp44ZNE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 161->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYMLcesRvIIeIHiF8QQVdDUgjAtx16M7AyOmyZdioKVp8/Pe
aw7Xx3DfiMhzN29DeZ2nqbwv28W5lfF0HJfH/bpm09+qKq2Zt26suavq8nzO
mledH+r6nCzW50jiu3PVyMHmNdiEMSMf01c6fQN/FxM0tUbauBqEIdOY/iYY
aJ5pQf8VuMG9j/l3xkgv0reH48uBNLUx6dxlf5ZgRCzArektsU+PA9YlTMAP
NUzmoiqcBepgjQ+tsmYQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 162->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDggrjyBL8ADon6hvCCV4FQJqRxQb3k6LWqEPZ64ltw08XiZ
SS7Dq38eROR9Wj59/nTTlOf7cd088ni7jmvwvPli6e8liTUVC7HqrLoQL6pW
gb2rizkB1uS09vhPOOg8M5s6o7U0H9VXCLYkopN4DGpqjGkDNdgMLY3Z3TgD
XKQFuy/HjZwjJnpjdPYdfaM5KgemqcbQ+cg8GHPvrrEiN9NbfJ+IA+tZMa38
XQ3RgKu+M1cHufzsC5M+ZtE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 163->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwkAMDS7ErUfwCnqAwSvUE4ygq4LQLoq7ObqtOJi8vCSQDpl5+byX
nu6v4bkTkfmwfoa6XKepvm/7LXjU8XIet8fjz1crf29FrKm3FKvuugvxpmo1
iF1dzEmwJieLxdZDDjrPzKZykYPjo/oKwbZCdBKPQU2NYX+sEcwQacx24wxw
mRbsdNzIPWKyf4zNjtq6HSZzdA5M05QL6Oh2Fuw0OpGb6R3MEXFgPTsmytc1
qIZowLVldZDL1z6KIGWY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 164->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6ygp4JQD+ItT7cVxWQyCQbSdpvJbGZ2
d+fbcF2JyH0zP4b+OE5Tf57Wy+LSx8N+XIrbT87RfqlNfJjaP1g1KSTVcCms
Ay/2FFjXk63xGzU0UgONqTbhWlhdG/FJIkYA74JocRwGU/lWnU0IwOH8QT+8
gzbyHzF4PmHfZKbK3/Q+sTrqZ1rAR8dDfGNe0JmZn8kcmQa25xeT9VsO5mEI
0KoVD2p5xwvKg2WW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 165->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMFH2EfDtCV0gHMF0hncCB5BUIJI/Qn0ZvUgqVTydTgYzMyZLu
5Nuw9NNFRLb2OPq8P9Y1v57NeRnzfO/mE7x+/bD0c01SmsH+yVXjQlxNrShP
oZfLQUzgTXTHGDkkggHHGrdIJ+yriegkPKeIQWvkgpibxcSoMdtNUYNwwvkV
+8B7xT5wR85sP65vUKOmb/ifGG7N5Lr5yK4RY3+r+ieYnsEcEQdai+1CPB5p
6Ay4aq0OcvnYGwgNZJQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 166->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCngpCexBvebqtCGYnk2ogZbfJzs5M
dn+597cNgKmbP319nMaxPs/bZXOtw/EwLMXdJ+co37SCNlztn15zCZHmsIz2
AZfPrPQ2Z7I9r1lDEbVEo9KmuEPca0X4BN3TrIkHa+FamBnzQvsveMQhtEpf
FQfSpt4Ea1bzCfcKzF/+Bh6OZ8Bm/Uj4iVmnbyHRGTgrPxMemQaJhXUPPIby
MOXBa4XDWt7xAu7gYxY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 167->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYML6dYjeAU9wOAV6glGsKtCoS7EXY5uC4KZ5KUaSDuZn2Tm
/8zxNvXDTkQe3fLp6/Myz/V13a/BvY7n07iCh48vVr6uRVoz2D+5alzA1fTS
pLdS/CO3qcliOLfhUABzHFNutt5zc3taQCfhnGZtLdPQaBNmRpjZCxp5g1mi
rgJ/x43ehOdM8wnnbuiV6Yu6loj72Yc5w1sNfUC3UL91Z9DR3odySUfPJ+AS
8UzDVA+/pj7I5Q0912QY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 168->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwkAMRYMLcesRvIIeIHiFeoIR7Kog1IW4y9FtQTSTvBhIZzJJ/8z/
yeF6H8aNiDx2y2doz/M8t9dluwa3Np2O05rcf3wx/bmp9OZy31jqWnMu4Oaw
jLA9rvaY/2otvA9juLfjoJALHEtuQZNU485MQSfhmm7vrdLQaVOegY7Ym2jQ
S9RVYA3c6F7SNvaH/q/0It1KXTXnY+9Tn2FWE47U7yXuaSZAR/8eqo0caR5S
XnK+mtFSj7gnHOTyBgYMY9k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 169->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OqFdGYAUYIGKFMkGQ4FQJqT0gbhmdVkJg//9diOQ2iRPb
/8X7y72/bcxs6uZPXx+ncazP83ZZXOtwPAyLc/e2eZSvtWJxON9nbfnZ5szW
zOCMWzef60e85u8a71MuyBs0FOEDjWktyATqQX3EyfSZMAfWimHIme3hewq9
lE/EwPqRZfiDNpVXsaWYCX/FK7B1NUquwo9vT+8sepXiCG50f60nBEdfzz8a
VT+Q39if9WjKA+cqjtTyAuleYpg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 170->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENgzAMtPqo+HaErtAOgLoCnSBI9IWEBA/Un0cvSAXM+ZxECsFxcuc7
594OzeciIlO1fJo0v8Yxfd/XNehS/3z0a/L2n8uoj6m1nIfJ7bHEZ3XbL02B
cyZWy1XAVHuXrI4LeE4agMfe2UZYC3oCGhivMg6i2dXJdBGMcC/D6frMtLC+
iPcScRR5IGbeOszAf+YX04PncnnsveszeasOR+J6mfaoblcL1FHUCHpyHlgM
+kYjP/Cf4VAtP5zVYdk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 171->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhR8uxK1H8Ap6gMEr1BOMoKuCUBfiLke3Ba2Z5L12YEozP3nf
y+RwfXT3DYDnbvx09XUehvq+bKfgVvvTsZ829985jvKfVtAOtzfH0Gftt742
4c4FLSs5Nr9HeI3FjteIrpXgIeRPfFjwF2sSPDBdYxpBm55jNSQ55NqKZsPP
vJB3mVnYHWT/qWaid1JOUf/YI6pmtJccZ2LwQzCn2vg80Lzqnek7RJbAoTwk
bbRMSmuxRxVH/AfJQ718AMpKYlc=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 172->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfbgQtx7BK+gBgleoJ4hgVwWhLsTdHF2LFSZv3sSBafOZzPsk
h+t9GDcAHrvPZ6jP8zzX12W7TG51Oh2nZXO/5hrlm1bQRnGJ9q9q7bf+L+Hq
1HniZJ5fQeBrau74msBtsLwmxnKR6mNPSIPCtYRDWtPpyT5215K9gAEaC++D
r+oMov7gWfJ2VM+sTvnL3OVb6vVWwT3YG7T3qt4Lc+jeNfmoeGQaAjZaThlW
yqfnB48h+kgtb751Y5o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 173->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwkAInHgwXn2CX9AHbPxCfcGa2FMTk3ow3ni6NtYI7ECVhG5ZYBhg
d+dr168A3DavT1fvx3Gsj9N6Mi51OOyHybmddZbyVimwUpTCnixWPvdLChXH
8h0n0fwSLNE2Wr+PFVI/5IekPz8T14PBU7UZB+ZnMR6z8Ud3gc/0+0OuFDIv
uHx11+wQ1mazZZhRXKRRLuu3wWbiMfyMYGuz9+I5NJzZO0p4LPb4z84zPtk8
/D/yXXzlCc1IYl0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 174->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDF2I2x7BK+gBHl6hnuAJdlUQ6kLc5ehtsYV8ZqqB9NF8J8mc
7s+ub0TkdZw/XX1fx7F+bofl51GHy3lYnO2qq5SvahEvxaj4F8XqZv+lYmJR
fsCkFh+pZTG5GsYfY1F/lLMJnS/uJMwA+wIM0a4EZ8KI/MxGfG7eP3K1gH1J
yCezpZ0R7iSOxb57+wL3gFwi/nh7OxusT7iN+BIxIOxsjwgHmgFy1eTSm+/h
AeL4CficOJxqTXwOY54=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 175->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADKr4wXlAkOE1CGgfELU+HiQ0lrj2IlFVrnNR1
vTvfuuvKzO6b96erj+Mw1OdpPf5can/Y92NxO+UU5ZNeLEcJaXllWJ/3f6UF
LOsHTh75iVmRU5oR6ohl57OeOfB+CYPco37sXMIB913wbOZj3USPwpO74Dzm
hUYv1kPuxmYw7zQeM41r9CLvQf25VBdB5wtvM8+iFoy70vEbAit1+PfNl/gI
LRx6sYaYHC/li2Lh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 176->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPiPqF8oJUglMkpPZQccvToaKVvIwDltw08cQe
O3Men8PjAGDuPp8hL/005dftuG7uuVwvZQ2eNt8sfb0maEvCoVeGrfv5L4fA
RhzknvyDnFeRm+aAxtr6DNfqT2Esdzk/VpdwsOc14Ony2ziCOxGe9OKMaMHN
6w8OdGaBdpzGEOPcvMicqD5bcWZEbzaffDNWT92PuIOshofrATwX03L45i0+
xJQ+iZ6dhl2uN6rBYd0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 177->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKAjEMRYMLcesRvIIeoHiF8QQVdDUgjAtxl6Pr4Ahp8tIpZDpN0p/f
5B+uj+G+EZHn7vsZ6us8TfV92c6HWx1Px3EO7hdbVvmZFmlXMSbtTrn696+Z
mNyMgz3Dv4BfDfYaBtVXx08gjnx8T1x9i6cdDh5bE540jyZOPpgB9sjfJQyJ
dwJH8sEMqS89PWZ5oV/+PZk+e3FaoDePZ2dG9UivgbtI4Od5kBYIi7Sczhx6
mvYC3ur1HDQcsD7gmWFb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 178->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPyQ/noEr6AHCF6hniCCfhWE9kP8y9G1WGEfM9rANqTZnZ3s
zP5y728bAFP3/vT1cRrH+jxv58O1DsfDMF/ullhW+UQr8KuYgN9Zbvv+/xcw
uYqDPZsahtdC7RoM1p/2+vE+lxO52/mRvo1wiNgsR+nh7iFqop5iRu6eYSDM
gvUTHKKGSQ+FCZGnZrpCv6iTrCUcmFeZt1k/5tfEHUj8Ig/mBYbFvCw1V7MU
K741+jl5OGG9AGSrYl8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 179->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWEehBv+3QtVkgmGW0gLbubTCbJ
7C+3ftgAuHfvT18fp2mqz/N2PlzreDyM8+Nu8cXKx1uBt2Ic/p/Ftu/9P4eJ
hT83W8viIb5xTBNxFsPeZfVdLdtj0h/jurqWJzxHdsuB+XGM2od7h8jhff6a
EZvan6onOLA+wjxVPuDmwhhhXiv2JzXBuQmHwFdoO6uX6TVwBwI/5pFpIcPK
tCx3rmYpjHtlPQcNB6wX6PxiYQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 180->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWEehBveboWu7CdTNYG0qVtZjI7
yfH26IcdgGf3ffT5dZmm/L7u55d7Hs+ncf55WHKJ9EtLWEeqEutT1Vr5/i8F
h9V41iT6qyxYo3qlyYL+DtO4H2vjvhB8NUdLgyXhCXE6T/nOjInqI5/h62p+
59cGDTwL52eEh+gbeGWktXDK/YTncljywdVE3kD3q2fM2uQclB6lAdoHtcvh
zCMvG14Y9S4hd9hxfQB4rl+g
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 181->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhYcupFuP4BX0AMEr1BOkoKuC0C7E3Rxdi7Gm772RBqahyfy8
+SaH/t7dGjOb2veny4/zOObnZTf/XPNwOg7z5b5YWeljXnY8X86q3QM/TxCn
TOTw9LNQE9xFuR38lSYP6lNM1ePKR2jDuqRJxEcaPAkmkJOYYs8YE/lHnI39
6vzEa4MGnAXxVPHASPVDvAQ3nJ96V453ggP5RGxMzB3PQJucg9Ijata1icPW
mQcs/7HA2t8l3zDlegEt718e
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 182->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMDB7Eq0/wC/qA4BfWF1TQ04KwHsTbPF2XLVonk4KBbGmbmUwn
uzvfhuvKzO6b92coj+M0ledpPW8uZTzsx/lyW7OGL4m68vnnrFnheg8nnMoW
UwP+TamJdXS4fzhMa0LSP2AaL0B6pAfkE/OB+sM1P1QNcQZfuDdjsnrxlhDC
4+AXaVC6eRbBT4XP5iTmyR62/SWW+oHvhA+hJvPGSIs6I2/kHJKZhf/LOj78
MXPFkQW/FT0e6rPEC2CbYJw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 183->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3PF0Xi6aTzBrodps0k8mk
u/NtuK4A3Dfvz1Afx2mqz9N6PlzqeNiPc3DbVrPyWVZ+/97fnUF3m1mGoZbH
cPnmfQqPeSXxDgM5JxP1Q47TyIiPESeuGziVfv/Xb7hDmEEX7plz1P2kF8aT
+ql6goPUMNEv6ImYn2lljIe8Nvcb4mzZm2Rt0M+M5x58Shsg4hOP8L6woEPC
Vc0vw1DGvS7i+J6+9gKz5mIY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 184->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbnq7FUrMzyWIgpclmJ5PZ
HK73ftgAeOw+n748z9NUXpftHNzKeDqO8+F+8cW6r1v3+/f5KoardWYOo8KJ
3GPQPaPegsW8CGPl4vhGfKpezAf5OXMONWGepM+/80oNYYouzsI7UX0yi1im
H2uORq6lYaCf6Il8v4xcdjTbTepnfBZoIDUU+zfjd5dcpg2g+MRD9guxDhnX
7P1CjMR41iaOn2m1N/gsYlk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 185->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfoFfQAg1eoJ5iCXRWEuhB3c3QtLTXz8l5pIMPMJHl5
+TTds+0PZvY6/Y42v2/jmD/34/R45OF6GSbjedFF0qwl/e/+v3qb83VSHEaF
w9RjQFyB3AFL8XKxFYZxPlUuUpOy09owHnlCf/bWG3wAM3BwQmOUv89rxE4w
CsSEfIID9jDcsRfAR82A7d/u+SWBLXoQfDZ2C+dO/0RP2R4hF+y135lQK8Sp
+VEMIbjDmzi+plW+KuNg2Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 186->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDgl+oL4igp4LQHsRbnm4Lpe5OZqMLW5pkdzI7
mePt2T92AKZu/vT5dRnH/L7ul8U9D+fTsBwe1pwjfbOYfz7b1qC9NUryiVai
vs/1AppTi5fpdRjQfNxd8P12Hj6XfLhf6FQsxz/nrWoIU/Iw/GWdqk+iniPS
jzXnWcQez1jVq7WZK3pPxv/1fsonDjvQoMJveEv5hb0Qaap8xFy41npGelVp
D6+VxAiCPdzEsTNt8QG7pWEY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 187->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwkAMfbiQbj2CV9ADDF6hnmAEuyoI7ULc5eh2QGrm5RNIZzp5efme
H69xOgBYh+0z1vdtWernfmw/zzpfL3Mznn66SfmrqDvbmgi/K5HSKzKFjSf6
hH3P8gL5dhyI4+w49P66Hra7+Tj1cJ8kiJ/VazAI+GkWXc2M8/DFwbOQv5CP
ydF7c3po7twLyifaLzPXoG9hPI/bk2RXDQ+cXEH+SU+9PeJ6GCvME+1kMj/N
IV5sWGzXm4hH17TLFziyYBo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 188->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBBq9QTzCCXRWEuhB3ObotOJrPy2AgJTOZvLy8
9HC9D+MGwGO3fIb6PM9zfV226+FWp9NxWpP7jy9Wfi4t1qbupMS7ZlKso+dw
/VTsewQs5OdWazBg59J9vu9g6/U8Pk/5kHmodiX2D5o6TRiPVIdk5nQHjDtI
nmBIIbr+wcFrGGI2F9sL4ePxmW5pP4bNrPOvBhwQrnD1CXczd7IzppF4nA7X
bOcaQ1hvxLdGmx5OwHoDgvZfmg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 189->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADJr4wXlAkOE1CGgfELU9nk4CltlOIlK1bU8dO
vTvf+uvKzO6b6dGXx3Ecy/O0nj8uZTjsh3lz+84puiX9s44R/nl8Q513dVor
jft55BD6Epbl3w48ERv7fOusPh/14L7kg3qQJ+rDWaGmrCZoknNINP9zx1SP
kXBDb/zigDOkdabLFkzlL7pXNbdWP4WtQuHDmXhnyi/KC5knK3zgQV4LvbGv
4kr+M8aQfjGurWbTwiGsF9iZYB4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 190->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA0i/UF6ygp4JQD9Jbnt4Wt5JMJtVAWrKbzE4y
Od2e3WMnIq/D/OnKux2GMl73S3Av/eXcL5fH6tWaj2v9OzNnupGnjXcxjvGK
qxB/zyBWUsvitdZhiH9HERf429j1mPSG95QnmZ0iB8RlOaYnOgd7T/C2NA5a
oCXcXH/AIdNXGZ9sFmBUAzJXhycxL7zHsJkxfKixmrF9YbvAdvJvPaCHsIsJ
17B/4vn/nIVEDE1wcqwJaxBfHg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 191->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQXHoQr31Cv6APCH7BviBCPQlCPEhveXobKjbOzoYsxBhmMzvZ
nce0jvNNRLb2+xn9PoTg388mHV5+6bslgfdjHeF+W3T//wsGOMvLsRO3lhCe
nBvORT68ixz4LuQVkiMaN7UAznSx3kXUQN6mcrI3qTuIG/1SvUDtWANq0TkL
11jsO+qxegFh+YHpUppK9Rg3iwq9+cyYX5gXmCdr5oE5yFnSqvwnV/01vaAe
Jjw21wdHwV3b
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 192->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksOgjAQfWFh3HIEr6AHaLwCnqAmsiIxwYVx16MDEQO8eTM4SaFNZx7v
w+n+bNoKwOs4Ppr8vvZ9/twO0+GRu8u5my7rec2Vvq+Slv3mLtFe9P1mS1rh
eAtLL2MXcV5je1jgPk8X40L0wN6H2lgP+wWroTAHgWt6uFQWAZ70nLnD+Z7D
X87847vIVHpB5WWgeBlOapb4mgyFB3t8w1yh/4W9fEIupEHpVHwMT2z5h17A
wXBwfKwB8mJc2Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 193->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozACjCAxQplgiDBqxJS+6j4eXSoqIR9OSeR0qRxfLnz
+XR/Dc+diMyH72coy3Wayvu2X38eZbycxzV43OY29LeY/vchprBXOHe5pg7H
TcMchfd8rsQ8IxiYK3gv04W4Qu5IHWfaWJzWS2oNASuprRGeYRAfml6xN5G7
PydvZT5jLbxmzKc+Eu8Zj15/Vf2S8K98YthJDXp8WR/3eqHnT5MLaGA6GZ+K
p0T+zVpIgpHg5Fgfl7teGA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 194->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENgzAMtPqo+u0IXaEdIGIFOkEqtS+kSvBA/Dw6oFJwzpckkgmJ7fPZ
l9vr235OIjJclk8bx6bv4/Q8r4d37B73bnVeN9tW+G0ajv/EF9K4/c7E/nM1
GJycyRGLZ4UaFs/iOq4Yl+sLcYXEiPez3pjfzQs40DnhTKFGUscuokNRK1YT
udt7UiunM85i75nkUx2J9oxH7n0pGOXEcoGv05DMoMbXasbqsbdQ06fIBXpg
fTKuivcGuzoLg+WwAaOMNQMNW1xb
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 195->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IW54OE0NLHbcTk7qtje04
SQ/Xe9dvADx2n1eXn+dxzK/Ldtrc8nA6DlNwP6/5Sd+PpeW/iKUSB4H7cS05
ndrCguU9c/2Z1bh05nGhLtaFwCDGlT8VD/0iD7JPHityFHmgOTLGGJWTvUPk
czq1OXMvfM3MDzw1N3UX0b5fRvrBk+KS3zBD0YM1v35mKp+6C2vzaXqhGlSd
yqvxudP+pxdBmzTaWm8g611Z
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 196->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMDC6kW4/gFfQAD69QT/AEXRWEdiHucnRbqDidTJ6B9JOXTCaT
d7w9+8fOzKZufvT1dRnH+r7ul597Hc6nYTk8rD5b+bl/v9EwVkRsNQcMB8zg
gOuErWox5iWppRjmITfk7pjHOUbnyWye9Fc6bbgxlm3zQw+1E8RnjCyngefM
la3FX2iBM3O9nE/oHXha+3454QdOqpb4hh0KDf7xxbuj+qm7IPfD74wLzaDm
VFyd44DNWrb6h1kFRq7rB60UXdk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 197->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDC7ErUfwCnqAh1eoJ3iCXRWEuhB3ObotVJxOJk8Dr5+8ZDLJ
5HC9d/3GzB676dHV53kc6+uynX9udTgdh/lyv5zJyvf45xsNfUX4FnPAcMAM
B3Cxnie56POic9mHccgNuTvGccyvHK7DnMScVtwYy9bxoYbSBPEZI4tp4LEW
wVr8xSywZ+5f9se6KZ7W3hHeIYUXdpP4Bg2TObT44m6pemoXpD78TnhwD6rP
bBauaohZ/jMHjlWaRKw3x+JfGg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 198->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKg0AMDH6U/nqEXqE9gPQK9gRbqF9CwX4U/3J0FSydnZ2sCxE3m8fM
JJfnux8aM/uc10+fvvdpSvPjtF1eabxdx+2x3W093d/8948HfZ3wWZ7rWEcZ
5+zHg1yn2txPYXXCm8VyXeqP9zCH+zAm1suIA9dS+I9mAvFFjSimUg/9zu8C
25EWyJn5S348N4XT6jvCO1RgUrtJeIsZBjrU8OIuqX5qF+R8xB4pHMxB8Yy0
cNVDaCn7Q2zG1XId6roubJVd3w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 199->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMXHoQr32CX9AHFL9QX7CCPRWEehBv+/S2uMhkMlkMpEt3k8lM
ktP9OU5dSul13D5jfl+XJX9uh/3nkefLed4f++rVhq+XehrDu0HcJZtbEEc5
51QrQW4hbK6HZuLg3cQyLtVnLJnDfJgT90twM1gN/uFMgBf3NYxp4Dm9bC3+
ohc/PaQt1EfzdboAJ9oR3iHHSe0m8XUzJE2ul4Iv7pKqJ/dUzeePeSgNClvN
AnnyDnEvZX2INVqhjsNxWCvkNV3f
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 200->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Ea5/QL+gDFr/QvmAFPS0I9SC95em2tEicTIIL26XZZHYm
k/72HB4HEXmdls9Q39dpqvN4XH/utV3Obb3s9m1WEdGynRj/xgqJQa1aHLax
Zl8a1CpgZ1wx7+cE7hq8j1i0JtPD+oXcECvIST0xvJBHmJPgOb24Mv5BPe1n
VAf+Um3y34y4eSH8mU8OG/VDryhfiyP8vcxn6kPiB+050xn0guo1d3ReWD/E
5yrDcVgf5/ldng==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 201->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQXPwQfz2CV9ADBK9QTxDBfhWE+iH+7dG1WGQzOxMDaZN9zE5m
93C9D+PGzB67z2eoz/M819dlu1xudTodp8W5X3dYxczL94/2n60QG+R6xGEb
c9blItdDnBfIFVwd+DaxBDfWj3eZg3WQE+plrT4JS8R03xl4oa7JJ/Sk3IF3
g9vpM8un/fp3Vu8KGskZIWfFX81J6qG1MagB45tmlviVDrQPnX5QzYlGaUZI
D6Pf0c/qRz0sxzrDSVhvqfFeHg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 202->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD2I1z7BL+gDFr9QX7CCngpCPYi3PL0tiGQnk2wh3W6TTCaT
nO6v6TmIyPu4vab6uS5L/d4O++VR58t53p3jz8xTRLS09/9Zkn8m15pEFtSL
ctXEaYFciydtjuXbxBJcF9PLwTrICfUyeMqwgpi0T8MLdXW+QE/KHXg3uBH/
IJ/Oq/fd6SvbEWaI5/hn2Ni/eAzG1+0s8Uc60Dkk86CaE42cljBDBb+Cn9Zn
esA+OxyHtQKiRmDb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 203->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBwS/UF6xgTwWhHsRbnq4FkXQyWQvpNk0yO5nk
cL0P4wbAY/d5De15nuf2umwX59am03FagvuvhccAt7X/O63zL9RGQ2XFfVWt
hzw3qo14gZ+b8Im7i/tR+VwT/NSP0ivgSZ1EDvhb9FnpmmKFnpI78V7hWu5D
8hTn3zqjuam+0d8RZYyXeASeCZv7F70ovmlnBd9qzl0dmY/IVdhyR2gWTvFq
R0s9kHPTLCTWG/d4YN0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 204->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3PF0LCslkUgNpG5KZTNIc
rvdh3AB47D6PoT/P89xfl+0S3Pp0Ok5Lcv91Zw2wFuPgoHfLWO8JX2B+VmHN
1VkjrOdz+qyJmLSb6I+VGKwPeV9BOyD5jPuv1JRz+nmFzpQr9im1k27uJfVX
ePW//n1XczkedV98f1bwJf1OZ+Lm+ZE5lN50syJf7WF1j6xH1IbZRW+PNe7r
8olH9UfEqnuWeoK9AdEGX18=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 205->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOEGR2NckpPGB+OvRYRKPzLFZpa7KEqeO
69352vUrALfN69PV+3Ec6+O0noJLHQ77YUpu3zusArQyj2fb/QvYuFOtwXyW
w7ZQ1wphYz/84lj3jWkGxi/FYH7Ies24A7JfPNWdrIGcM84reKac0tNxJ958
l+Tv8EpPhyv0buZ9nb/Yf830S/wDz9Sb56dZHN/kWZF3OizpyFpwjfKQ9AjV
KS9Lr9CSs1Lur654AtCyYCA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 206->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB6kV5/gF/QBwS/UF6ygp4LQHsTbPl0LtqSTmXVhu5smk51M
crw9+8fOzKbu++nL6zKO5X3dz8a9DOfTMDsPvx2Wm1Xf2uuJ9/gvYJed4hqY
ZSl8DXHVARvzBc4xbrWhBsT/sw35WdZrw92M5osnexM1oHXGepVf9I29m95p
5KP8FZ7pqXAOfRP9VTNWneuH3BN/4aezBfOk+KaZJX6lg9RR8YFYqgHpN9OD
6dycP1Ur+Jq62gf7d16g
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 207->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKQjEMHFyIW4/gFfQAxSs8T1BBVw+E50Lc9ej6wCfT6TRioU3TZPKZ
Zne+DdcVgPvmfQz5cZym/DytZ+WSx8N+nI3bz6aVgJJq/Sv1zm+EXXbjF2CW
1cMXwpUkWI4H79f4ujf81qH1wfClfZp4LF1O5cD26XL2bKily2s5QuvTrf8P
fPXvLkbUVzBjJXn+nE91h7fb2eJ/D+rl2E0tije8hjwaPtkn5ECwyofjOZy/
Xq9iC3nFC+0PXSA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 208->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvfboWLI6TaRpoaZtMMpnm
cL1P88bMHrvPNuXneV3z67Ktl1teTselOvffBZbMSvqdLTrjG2DbcnEBplnD
Mb4ADvkVzmc6ztUWebF+7449ujom+jaT+UoSWkEMayj7xH57/sE/hXoI/hwX
8hzg5T/y/DFe8SfsaAbRxzxcH2q2hAbsq4a51VwUUcu9RTqImlxbakBY1kPp
HM5fr1fyOT5/9gYlU12e
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 209->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3PF0L1U0nk9DAlm2TyUym
Od4e/bATkWf3ffT1dZmm+r7u55d7Hc+ncU4elmOiiGhpd8nu9tsSWtpxdQxj
+aThEK8GZ/Up0cDqHDfpa/mj/m4+WesPuch8rBdyOD9YBP8izDFexpP0wzlS
PPHnjxPA4f4xHcmOUV+DGqbDzRF5IPBvAP/LK9Rins6+xUfwE2tSDwDr9szk
ox3FoLNCzulZxQc4cl1h
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 210->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfXQhbj2CV9ADDF6hnmCEdlUQ6kLc5ei1UJg0eQkNTJlO8vJ5
edfXux87AJ/z/9PX72Oe6+95Wn+GOt1v0+q8bEdZAaS0O7K7fttMSjsujmF0
PTScxYvC6f6E5GNx0QwWLyaG+SXqJ+ImmI/lsjUcH8yCXYQ+VpfVSfLZOXbv
MHjCj5Rgj1Z/rI9EY5RXMqPrHz5PyilirWo/y53h6b4P7MPGUA6IDiiXyh9p
1Jqe9Yiefa4FzZFcIg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 211->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3PF0XFpqdTKqFLu02M8lM
crg+hvsGwHP3/Qz1dZ6m+r5s58utjqfjOD/ul+1WAay0M3pn/29ZVtoOcQrj
86HhGG8OF+ojPhmXaDDCG8Wod6mP8ZxL6AtcIkcWE/T+8066WWvQy3yiH+yF
72Xog8oPysvz5/NiHa9mTHrW0c51BB8yT7HmUH3IuHv4lNP7wbWImHROe73o
+JzOH6LWX/Osff0Az3teHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 212->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbn64LFZLpTCyktGkyk0lz
uD6m+8bMnrvvNtXXeVnq+7JdL7c6n47z+rjvFlcr/VC6qbP3udyfDXEspxA+
kt9cHosPi8UJDQ186T3T594HP3lvhWARDhUTtIq+IjfqRq1Mv+JCHcGf1YB5
Brw4D56XYKB+2jOicahf6JM9t4jB/kFhZ/kSE/sIvcAYOafZXxCsv/NnMTbU
ZGMtuq8f5whbnA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 213->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS6kW4/gFfQAwSvUE4ygq4LQLsTdHF0LU8m8vMSB+eX7XpLj
7Tk+diKyDN9jLK/LPJf3db9+7mU6n6ZVeWi7X1XbQ9uO3lZmfLft7JiPknzG
H2+KDzBQu4BDBVn6z/iB3uUyetE+TpaD8Xdcg7pibuSNXBl/d5O+VJRnGNBP
IC/Og80bYEAZ7dE//EIwRDWX3p7h2PR0VjX2D2NiHaGeaBPWIesFiRXNKMPh
uJo6hT35rQ8Cm1zb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 214->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDH5Ifz2CV9ADLF6hnmAF+1UQ2g/xb4+uhRWyszPpQtp9JJmZ
JOfHa5wOZrYOv8+Y37dlyZ/7cTs883y9zNvjqVq7SqqbVE3t/Z2L/Rv6FRaT
CJ7zxT/lBxyon9BQ4C48R/pQD2K5eEttngiD6W90BjwQG3WjVqa/y0H64vWW
iAP4+f7QHDuzp2aM9kjEeh4dB1Zzp63rDcHDWe3mmGiX88W4CB9ZB9FLhadm
VNbDc7IdLs36AtlMXdk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 215->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD0Ur31Cv9A+QPyCvmAL9SQU7KF48+kq1GV2MgYDUXZ3kkwm
ub8+bX8xs2+1ftr0a8YxTd11O7zT8HwM2+Pt76XN9fpBNzorh9jdGTMLfL43
jeV/5sec0BTOyhyOk504w53USPVj5Tv247QCDL85Hty/4MG1ue8zergcYi6o
RRhPONTJ5VBxIofaMbmDQexeT/bB+oEObjaiHu+q22PB5XC/FJdgjmEugT3i
r3aULaoTziTbAu24X5Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 216->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3PN1dcCVNZoqBFNokM8k0
h+tjuG8APHfzMdTXeZrq+7JdLrc6no7jEtx/vTUr8+Ed4e7cSq5dneYqXORc
Y7VwnBEr4DV5aDEYLsuJcdYbi3tehm+FaEU4TPSZ5mc6gLwxfZUeHYw4x1/1
jB+hTuknMNiO0R3s1K58dI6oudMh/Q3hi7ua9pj0IveL9SI0lzqIv1R8ckeD
9Xi6f/KzDxDIXxQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 217->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRYMLcesRvIIeoHiF8QQVnNWAMC7EXY7uDKi06fvFQAppk/zk
9x+u92HcmNljtxxDfp7nOb8u2zW45el0nNbH/cdr87QcpVuIC/fU1n4dc1Vf
q+PYw4s8p5kgrvKs7kF9KSe+02z0XuJSf0/AFWC4mLPZl3g0uCN+FR+qB+zx
Vz3hW6hT/MGd0hhqEPAjntoJjf4G8KJWGx3DLFJfNIvgXPIAelA5XY0G6+F0
/+Rnb+yjX5Y=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 218->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKwkAMhoML6dYjeAU9QPEK9QQj6Kog1IW4y9FtYRzHzJfYQAby+POa
f3+5D7eNiDy6+RnS8zRN6XXeLsY1jcfDuAR3WX9F+/mpVYydVbNabPH/U/nW
KWJrV/YHozSTwVOemr6NT9ocG3dnM/HSQwTraw+3gh7qzNnsT3cQ8NF9oxtR
DdhjFd7jjndPizM+4hjeNeBw3c/bCYX+BvpFHCQ8zk7/AHPUOcgd4kjAs5Cj
RtyZvTpNrTfC7GAW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 219->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeoHiFeoIR7Kog1IW4y9Ftoa0zf16ogQxMJvk/
P5PT/dl2OzN7HcajTe/rMKTPbT9dHqm/nPvp8Th7ad6MR+6LSdxn19o1vuX2
w1EOxfCsxpsyF3uEPBfeKmZ1jr6Hvcn7ymGG+N7ArIDDgz4r/TQHg1j0d9GM
CAN0/FUf8Ufz1DrRTjuGc93whS/ShEZ/ozWqhfYYtGPv+TyoDytzcHdoR2jP
rMTAHRULe45wKqwvtSZfGg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 220->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozACjBAxAplgiDRVyWk8kD8MjpUROBe7hxLbhonPtuX
O1zvw7gxs8fu8xny8zzP+XXZLptbnk7HaTncV6+WvktJ9T/9Y79z56W6t+Lj
wovHRQzEFjlNP9ijOVyFgTHr72VvcN70CXgeI6oh7+D8jAcjMfV2PZ4Bl83R
zVf1Iz59HsSYxkpquWv4YXo0MQfWJfWjOpEGWb7s3fPI+rD1HaodppFAZ5RL
YZFW5Zus7A0xyV5b
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 221->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbn66LVWenkzSQ7TZpJpMh
u/NtuK7M7L55f4b8OE5Tfp7W8+WSx8N+nJPb6tXS5yip/qd/7JcnL5ivtV9X
7w1zJjDgTQlqGj7M0QDXw+CY9e8uN8o3PAkPMbwe6lyY0hdzfBJnT3dZS7hq
jm691z/SE+sopnaskEt9nB2Wc3Bf0T/qwzvY7KeYXXLv6YBaWUcHfBvsosRw
LNpnl8vCXjaiXdk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 222->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbnq6lxWZnZ7aBNOwmM5lN
c7o/u35nZq/D79Pl93Uc8+e2nw6PPFzOw5Q8Lr5YmoOn2S2td/88uMd8wDqp
LTBp5XTSAzkQU+lBjRZ4FQfe2fZZaoN8pRP4IofqwWJhmMM5YATNau4UC7zs
HZt41b81z4iDO7ZjDl7tn5gF6qQzFf1bfXAHq/0kb6faoz6mw8qa5hxibWMX
KYew+D+xVmop7Atzi12c
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 223->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMbDwYrz7BL+gDGr+AL1gTOZGY4MF469OVALGdnQJNysLSTqfT
nu7Ppt2JyOvwezTlfe378rnth49H6S7nbvh5nHwyHQ/T0UX/d6LcTSXYnGsY
494NcAMGiyM5FSfIn7kgJuZaUt/3g/iUG9ZBnkQfY7ygrzSG9YUYeII2me6M
N+J6XpvmRPryOlE9UQ+4C30DbrXDC7vM5kU1Teov1cHdqPaT9E65e36Mh8SY
VQ0cp2wXqZaJ+XlibDqTYF//I14c
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 224->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklEKgzAMhsMehq8eYVeYByi7gjtBB/NJEPRh+Najb6KO5O+faiANpU3y
52tvr6HtLiIyVb+ljZ/HOMb5eV0279g39345rDffLKwhhdXlhKcgxvbcpM6x
1n8vpIaThzn6rpD8XQvWxNzk9NfzYH2qDfugTsInYwQ9WDSGZzgHRmDjcc/4
FXqefifUAJwoT+hZnBv0uH/4QEeRKWjK3ob0YbUNXzI71a45Mh1i7xwyAI7s
n1GWnikdeNd9E2NfhnVfmA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 225->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkc0NwjAMhS0OqFdGYAUYIGKFMkGQ4FQJqT0gbh4doqbgPD8XLDltFP98
ft5f7v1tIyJT9z76/DiNY36et+VyzcPxMJTHXfVqaf5oml2q2390TdLYkqvm
XaHOp56QGiSP5dhYgfylnkKcq2H7QH87D6vv2LAPchJ9nEY4Q6QZ0YrpgL1t
TDS3QowzwvXXnmx/ohPVE5hX5wYe5BLgWttfqCkwuN1EfcjsxVh+yG51ZBwC
Mb80AB0bFvnyOZ7ITC7Ghjtp7AVTXWCa
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 226->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3PF2X7UI6nVQD2WzTJDOd
HK6P4b4B8Nx9P0N+nacpvy/b+XDL4+k4zpf74sXSEiwtjuL+n90SKlt7TfQ2
OYgZrkZycDWVU+/KpcmLHOP7c9UDSG4RPjiSPtbh0NUMda0xjwDb10SYjUYC
j3l198RRvVnNEJxDrmKu3NEvPPWOPzXo4kDfq/6Qu9eRuDR6uXzILdDRz5Ja
RuZ6uTbcSWUf75pfmA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 227->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDggrjyBL8ADLL5QXhAkeqqEVA6Im58OVVtIJjPBkuvG8TIZ
+3C9d/3GzB67z6dLz/M4ptdlOx1uaTgdh+lyv+giPpvwWc1/PnOu4VbImhv5
PfwH1C1qZDEsV2KB3BVL5Se+vD87G+Cr+FH5aIGfEBiQ30DsVsZWsxK98xjV
s+KI9MNZNueElr2Z1SCYJVbBF93hVj/2DsWB8R3Hfqz2v3y5X635I1+qTmvm
UItyqSTLxdjmTL7yBp65X1s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 228->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OqFdGYAUYwGKFMkGQ6KkSUjkgbhkdqqbg/HxbtZSmcWz/
FyfH26MfdiLy7L6fPr0u05Te1/28uKfxfBrnzUMZxXSZsi5D9O8T5SOrVLbm
ZrsP/xnqVjVMDK3jsUDuytL4ic/qs7UAX9MfLx5n6E92GFgPGg7gQQ6mbWMi
TZpr8xl7lE/urdJnNQhzeO6oZ4SD6rFzMO1i7I2jHqtt74Dlu+8r6oNlMn6X
zTB5vd/0/ggHxoZ38rMPbdlf3Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 229->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKAjEMRYMLcesRvIIeYPAK4wkq6GpAGBfiLkfXwSq/vz+xkBmSJs3L
b3fn23hdmdl98/6M5XGc5/I8rRfnUqbDflo2t9XqGj7m1b4+7rH5YM1yqnfO
xZhpHxmims44bsCWnPHrQfzoG/hSnyif/6SPBwzqHjoO4mEO1Zu1iXrKWqxX
7Ek93kOXm8WJOZ37DxdrIrVXc6jeBnMFHE0f0/tRffi+Mh2QCeIhGzBF96fe
aqiHmhWYmnPkLC9JZl+a
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 230->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEXRWEdiHucnQtjpB5+ejAa0kmnzd5
2V/u420DYBnen7E+TvNcn+ftalzrdDxM6+WuoZ3ygTR8bX3HkILuCOULx2of
nBoBB84xYD9U3aSGUH/PBvEz84ni+U/zYUQzEOaOPtZoFfTm2UQ93VydT1qm
OqHXwcRmfuLs6eDuY7bDP3iYd3gzh3pXwKPrA+e+xPnhfmX6a07KH3JTnCL9
/to/jwfFuntuar0ALdJfmg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 231->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsTbPl2LK6STGWkgLZtNMrOZ
HK73ftgAeOw+n748z9NUXpftfLiV8XQc58t982bd12vz3znesdcOC6tUXzk3
xiB6GA5ck5zjCH0Fl4QDcQbhcg7jcz7/aT7sbgYLPDallcHm2ThMWRvrScu/
OiHPN+2OixNnpcNaXvwOx0PuirG0z2L/VG/FVe6k01S9JXIKccctcnL6rdo/
xYNyZZ/U6w15BWAa
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 232->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDC7ErUfwCnqA4hXqCV5BV4VCXYi7d3QtvsI4mYQW0jbv5TOZ
yWmY+sfOzJ6H76svr+s8l/dtvzj3Ml7O43J5bNae7me12erjnTR4KuVjHXdm
4AcYohyJgfyaxfOs0B/9v75GOYKDEKfghy3jwOFgvAKn+xI3UU+XSzGspdIY
81EHF5udY89kli24eI4Ih5tDcW4wl9oFxXGwewpLiD3Tn2OiPc00J/027R/V
cv9RHVfrA9snXpg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 233->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYMLcesRvIIeQLzCeIIKzmpAGBfirkfXwQqvLy9hBjJt0ib9
8nO4PYZxY2bP3fc3lNdlnsv7ul2Ue5lOx2k53Ddp3/kntclfxzMp1q/oj3Gc
De5HDCpOygB6VXaSjkXwROeOR9x3NbQ+L5asBo6DeQWnW1fWXfpSjEqMmX/l
N/FuZsc3kYPzIV9Xs2BGFYfLg2suei1n06ivyewxi2Tn/MHm6gX2iA2Zov6t
mj+K5fZRHBfrA3ENX1M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 234->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBjG
R5bDihlQaWT9DVjUNyDpg6vF4QZ85mB1A5rZhNyO7BZk98MALnkM92BRjxGG
DKj+Qsf4wgDDHejuxeJOFJqBASOscNmJVS+yfrR4acAijtUN2NTiE8fiZkLp
EWuYkeEOrGGKFiZ40yYDWrziSXvobsHqdjS7kcUwwgtJHJfbkN2EK/6ISn9o
ZmGwcZmDYRYASOtfFA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 235->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozACjBAxQplgiDRVyWk8kD8MjpUBHTxXdxWcmM7Z/vs
+HC998PGzB67z69Pz/M0pddlOxu3NJ6O43y5L1K+7iu5yM/GOylWnxifBT5D
XHa2x0R5JAeXe4l7Vdvq+H8OwY34CDzNEPpV4jnQPWIAq+rQuwhdzYf6dbXU
++SFeKxD2MiPNYXe4k8za+xoxEPO1M2kiYW+ox2keAu4u9roo3mBn/a0sWfq
/Vbtn8tFeisP5XoDYFFe1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 236->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBxS/UF6ygp4JQD+Jtn67FVcfMJFpI2U0myewk
68N5OC3M7NI9fkO57qap3PbL+XIs43YzzsFVs/b1T6vNXneMmY9h3DifsOiz
35isjuQA96r8GRf7zn/XcHVInwBPGtonV5nnQHHEAFb1obmIc9RT5gLGz6UK
P+bjHAib+bGneJear9Qs2NGMh9TUaZLuprm5BnGvWcjd9UYf6QX+iBtyiub3
1/65WnSO6lCtO3dOXpY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 237->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwkAMHPoh/vYIXkEPIL1CPcEK9qsg1A/pX4+uxVXTySQLWXbzmAyT
HK73fmgAPPbvqy/PbprKfNmtn1sZT8dxDbbV6jl/bKn2/dsYOGbj8PUu1/pM
ftQjw3GG7Vvhplyo/odBOE6fIN9piH+tMuYgdeSjZgVsObPP1omespYwFsFR
YiKeg/WnGMmecY7TNKtNeEhNSZN0N0FzDeKsecideluf0jzcn2zmCZdw/wjL
vSMch/UCEFVdWQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 238->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHHoQr32CX9AHiF+oL9iCPRWEehBv+3QtbjFOJglkYZPNZHaS
w3gfpg7AY/85hvK8LEt5XXfr5Vbm03Fek33zZuev1+bb3eZAuWrz8PV/OByD
wKA3GY50w0XhplxAOPBcpT5BvdMGv1rl3FPqyKZmZXuqmK0j3u6/ol/EUWKy
DsHupBiKU7I3VfCStQkPqSlpku4maK5Bnv/ruAe9bUxpHu5PNnPqK7WMjHVO
dl7qijfUpF0c
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 239->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS6kW4/gFfQAg1eoJxhBVwWhXYi7HF2LI868vDcG0pJk8vLy
2V/u421jZsvw/oz5cZrn/DxvV+Oap+NhWoO7okXSR73o165jBjFP1grkNzjo
M4IBb3o4VO3399Ri/s2zaDOuYT6sDtav8JSyGYT+Udiu6prMV+eRmjQXMJxw
VPlqD7Vf3lSnL3VbuCN1oz0edKYwk+5tGuxVcEV+4b5E7dCLmE+3HxJzwl/y
QW7YK+lJztVePAVdHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 240->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwkAMfbgQtx7BK+gBBq9QTzCCXRWEuhB3c3Qtjti8vGQgnSaZ/N7L
4Xofxg2Ax+7zGerzPM/1ddkuyq1Op+O0OPdd+ilfaV1++toH8rUCeyje5GEb
RA56o+JTwf9uxeZUsxg7qLdAd/gEdRr1w/EsjIHEAf6d42pdU9kgcgbcuEOz
MRYqXvJQrD3cqWSuaDeYo2hHsz4kpoRJuqMgXoM+uT+3X1w7miXAJ51H+Ji/
tB+qJ/9pphBXvAHM1Fvb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 241->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDV2I2x7BK+gBileoJxhBVwWhLqS7OXotTiHz8t4YSGmSycvv
ne6v8dmZ2fv4/Yzpc53ntNwOm/FI0+U8bcG+aJHhp7nobvuYQSwPVgvkVzjo
M4IBb1i+VI9hDvdPnq+fAUvZoS+sg/VdvtJQU+3Bi4qR2viPd6A+FJgNucLy
1R28X3KKzczmBu4GDjZyWR+tfe/S5KjBXRXvyO2rnWJtNQv2x3bAONK4H9tl
EJyP9ElxAtYK+aNdHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 242->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD2I1z7BL+gDSr9QX7CCPRWEepDe+nQtbiGZzGhgSjfZJJPZ
nG6PYWzM7Hn8fIby6ue5LNfDdriX6XKetmBbUa37Yq3Yzz5mGOssGuSnu97n
7jMOmPcXFv9X9An4/oHbj7PUQPV3+Qqpp9LRm4opH/BA3ZIPDWbDXZE1kRP4
Uw2cj/BQuxU0ZfmqH5uD5O4mdwG1QS3Y2wI33LvAj82C/JgGYkfU+zEtk6F2
hCetk2q9Ab3CXRo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 243->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz6hX9AHlH6hvmALeioI9SC97dN1cQvZ2clqIC3ZJJNk
kn5+TPcDgGf3+UzhNa5r2K7HZNzCcjkvyXnKmmX4asy629YH8kXrR51f4PAb
CAMi5l+l/CRFbw219SPheXbV36/6Jt9TjoH4F7XQ8HlvooaNj6p/qmd9fCsu
JvekbkDsQ86s5vY4ZbxWPTWHyN3FvQXmhrlQu6Xe+O5cLhRfAqd1I97+FJeV
MHeiT4lTYb0Bl35eGg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 244->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwzAMHHoovfYJ/UL7gJAvpC9woT0FCskh5OanJ6YmlaVRYoNCZC0j
z+j2+nafE4Dxsn66MLXDEObnOTnv0D/ufQpes+XT/Cxm2+5IvPiXebLesS0G
1cPBqDJVn04x29E8EDUVvpmvBh9/bphJDI0TGRZ2Yt4dwZD5Uc1qjopprVlP
6rMdIHp4b2YaUE51vz089g6GDcGBt6tQupJcOl9jOT3iwvAFhwOnn9Hc2dVC
R80H01nwZPqY3VoABahd2Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 245->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+ItT9diCJvdGWNhSzabzExm
93C9j9MGwGP3+Y3peV6W9Lps1+SW5tNxXov7EuUbvpFL1D1Sb9b2nL0votbg
MAQHDZAcbc60ST3kfsUgedDX4zd7KiyH58mMC50axJ7jsBoz00/wsnuP6q3s
F5uBP/pBtbq5bTz1eL/42DsYt8OgswrXV3KW6huipz0vgl/QXjC80HOB0fSR
+MEwJE6YrTc9eV1d
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 246->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKgzAQXPwQfz1Cr2APIF7BniCF9isg2I/in0dvpWnYTGbXwAj7yMxk
18t9mZ+NiLy672cO72ldw3Zrj+AR4nWIR7FPSGf8YU/IOVL/x1Wfvm8g15AD
NTwIiaWMmTfTD7mfOUhc+TvTVzkLWgP5i5w+2Kt9COlnGsrjzvyDnq6hVzpL
b/7kDd4+qFdvpsjn6bFZM23goP+qwF4Nz+y9pr63f/DH5mDtotq5x6FnIIQP
OFwvxfkAtL1d3Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 247->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKg0AMRUMX0m2P0CvoAaRX0BOMoCuhYBeluxy9Fadj5vsnDkTIJP68
JHMfnt10EZHX9ffpwvuxLOHTV6szhrmp5zV4ixZPu5lGS3ck/vfVxmX/V9s9
Hy3FmAbkFHWE+JL7hx48HvO/9RX0i1xn9c1dyXCGyIgsGS/jEJLPahjGwx0e
6A1Z2S7d+ZMeqAb4rC6dKXmjiZ+8Z6bN+j99owJ7JbmUz6vv7R/42BxKu1Bg
djXsDHAuRMNlyc4XJs5e3w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 248->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKAjEMRYMLma1H8Ap6APEK4wkq6GpAmFmIux5dB8vQvv4kkNI2/cnP
T4/31/jcmdky/JYxva/znD63/Xp4pOl8mtbgoXixy99z8e1OxJt9ZbnGO77F
TOTAGzePiTPydT1EfFC/yVXF3f4EPrMu8HTWIEdy6TiSh4n3qkbFsbujQTNy
lVpG+ose3HmgZ2Kkpgpv7f/inEKs4Cz/qPm5uWe/bv1o/uDn6iBmkcE5zFFr
QF3UH4q4NPYF+EhgHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 249->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwzAMMz2MXveEfWF7wNgXuhek0J0Kg/YwdsvTu7JQHFlKwMWJY1lS
cxnfw6szs7X/fYb0eSxL+j5P+2ZK8+0678VzibLu/8gljjNSr3K3su8XcdSM
YEC/xDGyB7ygocUHNFZYri71kX7moe8PWHAHOeK9wBF5GL8fZjje4QwxwDPk
Sr1UZ8TnrDCIZpwrfcV+E/OY18I/5Mx0KWzMUa+cT3RQz63hA/DBf445faOC
B31DLS7V2gAqP2Bd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 250->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpA/XYEVoABKlYoEwQJXpWQygPxy+htRVS557uAJUdJ7HPO
Fx9vz+HRmNmrXZYhvS/TlD7Xw3q4p/F8GtdgV7xY//VcfLsj8d3eWfZ44VvM
SI0/8B67O0O9XMtXPTBuLi77I3jUBvGhFuQgR8zz+ZSHkXzHjfWNfxMMNEOu
VEt1R3RWvNj7iJG6VjQLs/4LKzizvljtMHekX/m++I+gF+uPaM7+HPd0Ritz
EWZI1Qk1ZuLdXt8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 251->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD0Ur31Cv1AfIP2CfcEW9CQIepDe9ulVsDZOJtFAZNdkspNJ
7u++bi8iMhbzp07TcxjS53VdLk3qyke3BG+rz1b9Pa++/Sfx3VlZ1njHt5iQ
GifwjBPif1y8HmivOkfXgjvlR/DmfdDH1IIcT3M0GiNvI4b1jf0ag7kjV4P3
9HF0DuehOGWCcXUNNDO7foR1OId9sb4RL3tMOFOx+UwfWovw0TPDM93RYC/M
Dnh1TI0v+Ple3Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 252->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhYMLcesRvIIeQHqF9gQj6Kog1IV0l6O3hdpmkvdiIKWTyc+X
ZC6Pd/s6iMjnNH/a8m2GoYzdcTk8S3+79svledVZ7rvqqpsd3Ff/RtTGE93u
bF7Zz//iEZOP/7GwHmCvngew0v5AfKjv5hNyJTNUVMv4Uw7gb2t4/7AbL27v
lJMxED81droPw6Qghs41mVlVz9tQLGFG/aLc4X2Afml9so8wL0nmAHgUMNEc
CQfcbcZSyQR6fGAe
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 253->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7EbY/gFewBBq9QTzCCXRUKdSHd5ei2MNZM8l51IKWTyefl
vZzvY9cfROR5Wj5dfl2nKc+343p55KG9DOtjU2w56WtabPPbdylvJtYetfnE
NOG6n/uv/JAL8jecPs75qlk9HoBVk/OD/oL6A34CVzscKupl4ikOEF/luPig
jT9Od4qTYSBxlleqB8onXIYdIvNX/f7hm+0CmJfVrvYDzEuxEz2QZp6LoAXR
zP/DHd3Zi4CH1Qk13koZXV0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 254->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDC7ErUfwCnqA4hXqCZ5gVwWhLsTdO7otPGyczEQDKS//ziSH
670fNmb22M2fvjzP01Rel+1i3Mp4Oo5LcN90lm7V2vTj93FrMZfrpXq/0Nrx
vt7O6qka6YczyNwvrKQe/1XiI/WBQ1vnoaocygcIjSkfwwl8BP4s5nmMFWzK
O6sXvGb7YHwwLpE/FDrvH77VLWTcCNyh3vWVO0URO5O3k2G1+KY3+uMusnvW
O3kDLPVZ2w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 255->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDS6KW4/QK7QHkF7BnmAK7Uoo6KK4y9FVGGzm5aXTwJOZTH6+
l/PjPbwaEZnb7TOkz22a0nI/7ZdnGq+XcX/sMjbrv9CMw2/fJb+ZWGtq/QG0
53Xt/Z86BYTUwx6kr1bycVY1qPV3HEqZ72qRGKcJ8H30ieZAH+ZAvNMGDeri
XFTbaC7Cc7F74uMYH4xLpxEY7cd2FHODmX9yE/y3yzd1Q03RAs1wdxjnTHM8
0x2t7EW0z46rwlaVFVsc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 256->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbotLG12MrEupHQ3mWQy
yen+7PodgNdh+nT5fR3H/Lnt58sjD5fzMDuP1aaTVivVlnfrR/WZ2OWk1Wdj
2ErSee39nzyNQeTjGqJu+YWH51qMbdV3GqLFu1xUk3WWXEFcmIeId31Felh/
kJd5ydlGvEhXt3uI8UVg1JvDU/9NPbWjjBUxCt9oE/Tt8EaLcKZ8gpmFOmzM
nP+jHVU85A7Bz0X38gX6l1rd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 257->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBileoJxjBrgpCXYi7HN0Wap28eZk2kNIkk997
Od2fbbcD8DqMnza9r8OQPrf9ZDxSfzn3U/A46yjNX23WxZ/HxdtFfnZeQ6ip
WvC28ds1hagn5mWf1fJRzmpNsJvILzCEzy9qUc885jiBr2u1Odin9orw4H6i
Ls8vuY14IFzlnpU5OUfixfm0v+unblRhrm60ho3aHSI/wyLklCXgTN7XBs75
P7pRNYe8IZS86F2+hHFb3Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 258->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoEboBgu
jiyPRS0cwPjIZmDBDUhmIbORzW5AV0sIo+nH6nYCbsFmHrp8gz0Ov2GxHyVs
kMzDhrHZiSyHEifIduFwN04xbP5CUo8RHugA3Vxs8YlHLdZ4w+dPLHxcYYM1
vND9ie5/ZPOxpQs8YdCARz/MDqxyyGGFw79Y7cfhFmxxhjV9ERHn6GxcaRRX
mGC4hwEzXrCHKwBL/Vtd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 259->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHDyUXn1Cv9A+QPoF+4It1JNQsIfiLU9XQTQmk2Aguptskskk
t/e37SoAv+v8acv/OQxlfF2Wy6f0j3u/OOtVZ2l2lVU3u/YjeIfddvARFZVL
n21uJDmcmvgtN4K3BIu7W3yqL4crq69EGq6spvY5rgHXC8VhbayvhA8nZ+YZ
YWAxZN50pwhOUTUtl25GOP7F1s7wBRxIEq9xUd5A4hU2Wj/AwmZG9+vEzO05
2tGIE1bHzoXzOgF9vF1b
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 260->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbgQtx7BK+gBpFdoTzCCrgpCXUh3OXpbKDbz5mWoA+lM8315
yeXxbl8HAJ/T/GnTtxmGNHbH5eeZ+tu1X4znVeZz38RW+em9HYEfNl1mE2Iu
l3/7HMa+e4Rw/t0D52J8zr/ABcqh6iOPL3JRTeYh49qfGg7Wqb6IDwjcMq/A
z/sgZ1PZiXCnBE5zNZnLYkbIb+PahK+IFRxYJd7jkr1DxDtssn6ARc1M7teO
mfM72tGIE1WH56J5nQC4Yl3b
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 261->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMDD2I1z7BL9gHSL+gL1ihPS0U9FB626dXQSSZTJY2EF03yWQy
pptf4/MiImu7Pcb0vi9L+kzN/vFI+dbnPXg9fLNBznc5HO/xbPJUrYkRLwpL
n13/H91gIPY/MwyQg/xUvuMngMH6i683WNCT5jGr8cA7NhfoIYS3wwj4Uy0j
XqBrdacIz6J6VnUle6BjjLOrRQ2gl5tNYBYyt6tX3Gj/gAv7Z0yTmpbIKcSI
DOcjO++0MvYFPhFc3w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 262->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDC6kW4/gFfQAxSvUEzxBVwWhXYi7d3RbqJJMZh4G0r6+NDOT
z/H2HB47M5u75TGU12Wayvu6Xz/uZTyfxjV42Hyx3n7vujne4zn853JDjHh1
WP6c+P/0gIHYZpyL1dDHfJZTlT4DDML/vfP5AQs4PUfqtbeWDrxjdUE/jOhO
GEI/7aXSBX1t7hTRiTnM094CX4o35qJ6pfZH7hbso69PajeTWtjMVB+YnjS/
FoYyrI/UlPiDfQB4VV5d
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 263->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwkAMi3pAXPsEvgAPiPhC+4JBoqdKSOWAuM3T24pSMo4zREqXWWzH
yen26IZGRJ7H5dGl13Wa0rs/rD/3NF7O47rZbrmEyh5ZP1msK3zjuW096+/9
/cbMWmIIwYju/sMTxAa9eM7VCnpYfVSfAAbht55RnywncDivbdR04Bpw4J7z
iHEZfNRPvUQcW5+UtYYzRe7iHZbIg3xurit9ofor8xPOFnht66PzZXmJFtYz
5kOk1fWvhhEF1kdqor3YYwYxvF4i
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 264->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOgzAMtHqoeu0T+oX2ARFfgBekUntCqgQHxC1PB1RKzXhsLJmEeJvM
5Pb81O+TiPSX+VPnoeq6PDbn5eeV28e9XYLX1WdLsllJX9+dJ9hj3npe0n/9
7V0XlQM9DmuVF8SmewNezGN3QC4YNoOP1BsOZV9veumZMMPg1BbhwDPAgbHC
8OMscXTGOx/hUrmmn0AM6lGDiFf2lql+jO+Ac9ofuIj4MPVisXv6MRxsNuOJ
3dXT33ujDIeneajFZhPtuF6i
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 265->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYML6dYjeAU9QPEK9QQj2FVBqAtxN0e3hVIy37ymBqZlksl7
Lz/nx6vrD2b2bqZPlz63cUzf+3G+PNNwvQxz8LScyVpb/3k59Bt8xTuXW2BE
J8DI/2L4N1ZjUy/fKX5z90gba9nj9/XKGj0nOCqd3iId9EEHY1npJxc0ypy9
/mDHKjxDDPmcQdRXtctyfgKr0I4+SPyN3VZ8Kl/ul6890KG4VZ+otZpfhLFl
1KB2Tc1itR+IWGIg
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 266->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytkkEKwkAMRYMLcesRvIIeQLxCPcEIdlUQ6kLc5ei2UIb0zZ/RhYG0ZCaT
/3+Sw+3R9Rsze+6mT5del3FM7+t2Du5pOB2H+XK/+GRny39fnOcrN+Thbb5r
+T9qxBwra0cNKk/hW4hb3KhFaaNRmwsOHrgVmJEnOf9yBh688y/8mbfqhaHn
rflgx4p61IGYM1C9coFDPDW/YsbKavUru63w1Hu5X1F7g4fCln0CV9XHao2a
kYPaNTWLbB9G4WQc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 267->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytUksKwjAQfbiQbj2CV9ADBK9QTxBBVwWhXYi7Obot1JK8eRNcOJC2+fT9
Jsfbs3/sAEzd/Ojz6zKO+X3dL5N7Hs6nYdk8rGOuhO1t60Cq10Fr2zn4fx2G
Gv/AKM/AY7M3/lb8KOYtbexFeav44b2Z0GCFNscJj+l0tNZIB++Z0o/4XJUF
dL+k7lTn4/DYB825ByorU/zE17oTxtwBhtH/3yq9KD7uc3i/OLsfvKgcZC+C
HEOMqETfXQ6cVVUfQGNjXQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 268->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB7Eq0/wC/qAxS/UF6ygp4LQHoq3fbot1JKdzHQD6bJpMslM
9vL8dO+DmY2n+dPl6T4M+fs4LpdX7m/Xfvl5Xn22ZNtZVrdUxw1iW57F2oDB
nGBgfRPD5xiJAzc/a8UV4n4exQ+5MG7Yl/ErrGeqTzon5Ad+ZH6cg+azWpGH
87N9KRyvT8Dz/fb2tqNVUf0b+1N7URgF6v/muYQ3AxrK3mJ/LS70fQltmY4S
QxnZe9ABtarsB9yvZF8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 269->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3PN0WasnOTrYupGG3k2Qm
c7o/u34H4HWYPl1+X8cxf277+fLIw+U8zD+PS0wnYc22BFL5Dnpbcahrqx4q
RA+uD3s4ThHGPM5nqmUNID6RviYfiPmBPlMzU5klT8JX+gR/5iHx7DliHPNX
Xhj3AL0LrcW8lm+NXVk0/w//lC9RD6P637GkNaodhrMD/7a0SH+C3ao9ev6b
u/DaBW/pRdXrC+uaY54=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 270->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDxIrj7BL+gDxC/EF4ygp4CQHMRbP90EYuyprg4Z6ITpvarm
eH+1zx2AoRk/bXlf+758bvvp8ijd+dRNwcNs47n8zWZbfBT/+ao81LWhhzLf
A/Xd3C5ZLThH4Fh8/k+1Jvx+Hx9LsTFHEPMR+QkcImK3bE/KD/jE/ryHzGc8
4vBuoV7p4GeRPqEf5SrNjWckvKr5a/plumQ9jOrl2+aZxCHztabpFixSH+JC
zWctN3HB2MV7llxV5wsRdGNb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 271->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeQLxCPcEIdlUQ6kLc5ei2UNvpy5/RgRSaSX7+
/5nD7dG0GzN77oZPk16Xvk/v63b8uafudOzGy/0Uwzkv4VPMOdx/c3OdLTWO
CH0/MNgbMMwCJ+ddhh3qLfZSg4FPSZ/kVeIp9AWsfCY8kDxRH/QJ/uQh64WX
K2yL3EI/3tPqMC+0spY8uAPllVfm1/ZX2ksJw9Ev3zZnwkP6VdtpUQv8UVi5
F2o+d/mXF9Qu3jO9CjuxD48pYl8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 272->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKg1AMHFyUbj1Cr9AeoPQKeoJXqCuhYBeluxxdBavPmeT5IILJ5DOT
XJ7vpqsAfM7Tp0nfxzCkX3uaf16pv137OVgvNr37ZrbY6qP437fisGGMTPIO
anCu1ABkJuNYVlvw0FzmkOO9mMstx0f9ofoYzw/lbtGchBd+Hmeag2ORlrs6
0Nkkn+5p99jvcGUsz8E78LSyQv/wrgp7iWoY5bu3zT1Jw7B3sD+XC+lTvNVC
f57/UAvm7vRhrWQnGAHJC2Ke
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 273->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDil+oL4hgTwWhHsRbnm4LFdOZ2djANqTZ2Zmd
7PH26PodgGczfbr0uoxjel/38+GehvNpmC8PS0yr/UVeArVAkfddBfYvPqjB
eKkD2sscQGpLPhTLPYD0hBjWhbUW4af+xCuqkYlPtDCnu69gXL3IS95Zm+Bp
nlaL/5tew94CHudVrvDLfJEu9y7VGqVfbrZ5ZmA0OO7g/ZwO58+WWWX+8n6T
F9y74WGv5E3wAW0dYl8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 274->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbn24XqmYnk3UD6dLdJDOZ
5HC998MGwGO3fPr0PE9Tel22+eeWxtNxzI/71Rfrfj6vjj/+jfuYuWvJz8Y1
ON/VAZ02BnC17QniGvWg4mQO80LJReHa/pxWVGMmPMeTMdV7JUfVi7SUmgot
1NwLHIh70avrLeJZ0UrqUsNTenNuUKPQS+224MNaSuxgfoqH0qdlV938zHuT
FhAYatc66rmwN4SBY54=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 275->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAQszggrjyBL8ADIr5QXhAkeqqEVA6IW59OI7Uw8ThJI023eDy2
09P92fU7AK/DfOni+zqO8XPbp5dHHC7nIW0el5pX+Ne0FBr1w63LfNvSnxZz
NPth8Bu4HR55r/KgcLIneLzlU3OtP+fVYBDyu9RJeKdbeRY67V6mhZ9B3kQW
6mxkvoR1fOytpLOSlcylNk/lzb0FDva2alQeS1nK2YXzUzpUPq1/lXVx9tUc
kWNRmcNZTY7rC+YgY10=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 276->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qA4hfqC1awp4JQD+Jtn24Xat1MJlkaSGGbSTIz
u6f7sx92IvI6zJ8+va/TlD63fTk80ng5j6V4XHKO7p95SWnkivvFxv4SOCO3
+qXCkxrDKbzHFf7Tc6RP7Dy2t+41WiuMeDjhMylvphl5QC2DHtUvoI14we6G
+gtYMw+1EZ5mL3jl+uLta9yLCpiB2hRHwKPXqCPkHvBg/rhvlXiBdxVygTA7
gje/4lV8ASeBYxw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 277->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMtHggvozACjBAxQplgiDRVyWk8kD8MjqNVIpzPjvqSW6VxDnf
2Tndn/2wE5HXYf706X2dpvS57cvikcbLeSyHxyVmdP/IS0gj1rwfNt4vQI7c
ui8qn5yJ4sO/RFphn649fwqZ1Nc5+q7xqnLEyxPg9LQEnlGnzqu0OP5Qo64f
zgb2M/HA3gPzRetCr9y+ePUac6kAHMazWG7Ug3OmtdlMmQ6nP4Yr6AVyhVoA
pkbw5tf8Cl95ImLd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 278->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFA/TICK8AAESuUCYJEX5WQygPx8+g0UoHkfElVS26SOj6f
fTneHv2wA/Ds5k8fX5dpiu/rPh3ucTyfxhQ8LD5b+LstjhX/3fvaxvxkjGEZ
RiuHOTMvdy9fqY7qQZ5Vf2yt+ihzrYLFM7AaT8DPSsRVLzU8C3pfcIOYH81e
6cb/TfRQew+Kp3ojFvxcC4zKbDnW1Fhwdv3BY7NO6q272krTfN/QUWIJrlI/
rHAhU1owTo5vDusDaJtinA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 279->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDgl+oL4hgTwWhHsTbPt0WKiazs5EubEmaZHZ2
Zo+3Rz/sADy7+dPn12Wa8vu6Xzb3PJ5P43J4WHOO9EtbE61Ece8bW94HGFZg
tN4wZ+bv7kFgpLiHik+rPw6uL/C4NmOxBhbxBLxW4lz1FuFZ0uuKG4R+pL3y
jf+b6CGaB45oxix5XSuMQFs+a3osOLv+4LHZJzXrrrbytFw3fJRYf+aZtQ+5
UCgvGKfEN4f1Aa43Y10=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 280->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8uxK1H8Ap6gMEr1BOMYFcFoS7EXY5uCwWn//8UAyltM/lJ
XuZ0f3b9DsDrMD26+r6OY/3c9vPHow6X8zAHj4tPVn4ei2PL0Zxr7d/8RCOa
HrZyuGeuL+cA1ShmBtJzsdV8bFzf6HFt1mIGkfUJKCsTd7NlelHMu+Fh+WUs
k3+SZ+bMOGd3LIpyXWkkbDm2uWPTs8zHPMye3F2X2m6nrg864zhkuxBWUA3J
JXO7YJ1WP0TrC39UYaI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 281->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbnm4LBbOTSd1AFpYkk5nZ
Pd2f/bAD8DrMR1/e12kqn9t+uTzKeDmPS/G45hzdL21NbCVcn4/W+QTDHIet
GebM+0MfqJf0+nkwH6pV+jh4v8AzwmEs9qDq81yA6JWoK20VHnv7hz9zNObS
wkHNCZ2Zz9kfsy76WmEIb1lv9i5VMAbrYz+yf0w6wu4GP5XnygeJp7xCxAiz
FOotGMfjW8D6AqknYGE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 282->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeQLxCPcEIuioIdSHucnRbaMc0+VIbSKH5eXkv
k8Pt2Tw2IvLa9Z+mvC9dVz7X7fBzL+3p2A7J/ei9nX+uo9eYy0+xWmdMqT9z
wjAclnooPvWrrROJGkCvn2/1EDf1c7P5gKcOx2PZfKizXETiriBP2mZ4tNsF
/p6jei5rOFAf6Mz2TDem4Nn7hhsCTekbA+egz+/jzzzSsPZNaee0h+z+gxbA
CFychRkLN1/rZ/YFVZZgIA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 283->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKg0AMRYML6dYj9Ap6gNIr2BOMUFeCYBeluxy9WtRmfn40EMFM5s9/
mbl2Y9sXIvK6zJ82ve/TlD6Pcvl5pqGph2WxWnOO2z91zb0G61st65O8ptjP
0mpsYTwc7WH1TEOMLjIQXjzf8jBvyG17lPk0ego6bIYS9QGjmxXxw9gyPTZb
4YzIhjqRR+eB7SOc0ZzZG1OSkSf3hghTeMfEs+PDeZycxxjcnQbzjPioVuDH
eZETLxDujIM37xh+8QXvuV5j
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 284->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKg0AMDV1Itz2CV7AHkF7BnmAEXQkFuyjdzdGrxc/k5WXQQATzeXkv
k7J9Nf1FRN7X6dOEz2Mcw/dZzD9dGO7VMCdvi09W7x4X32KQX2OqTnQsYj3z
FGO1hEOuh8UVhiS4qIHoxfkGQ/RuULfpR56wnxxWmjd1oNGbo3Q63Bie4kIw
I9QpHI+js1/TR3R6e2Y3Fol7nMwNEU3uGxPOqM3sA+8a5uG7nHlTTx/FYlxR
yxEuYGZG5uaNhr/9ADCXXqI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 285->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB6KV5/QL7QPWPoF+4IttCehoIfibZ+ugrXZyWS3gQgmm2Rm
kvPj3b8aEZna9dPHz20c43w/bT/POFwvw5bsdl8t/DztfsQg/40d75SlkLup
q/VQGEo1LJ71EItNcI6oWTCf9mDc0DycAnwLvXTevCNc2Jxsbw62ou7wXvNH
jCnYfBUDqyM8PZ3ZfeHtJZzDeJJ9VXdMMNN7BI6or6kXMvsPPZnmTAfEZnZB
9HCxgLkaiLML02sBpQVeYw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 286->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHooXn1Cv1AfIP2CfcEW6kkQ9FC87dOrYG12drIYiOAmmUwm
ub3Grr8AmKv104XPY5rC8rxuP+8wNPdhC9a7r9b+Pe5+vFH893bkGYtt6lmd
xVMYhoNXK2MgDOTcwH1gelF/iaFmY/N4Ip1X6oS0TuaJWVQf1llxK+pO+XZ+
xZHjtrenb1Yn5vR0Vvfl6XrqvqBx5I4FZ+9Oo4PNGrq9T+zU01xi8W4LehS5
kJXuRu4iw/oCSFJgJA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 287->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfwCnqAwSvUE4ygq4JQF+Jujm4LZZy8vFcmkDJN8l6+
p/treO7M7H2YP0P+XKcpf2/75eeRx8t5XJzHVWdJfy2rVhv4Q1wjJXlluMpn
hKMDS33mOWocsbs34lUuqA3tAY91mu+Xzsk8jsaRXlientpCD8LW4kuDDzcg
agy2BLFJ8FmcTWvHO1BzZfnDDRnnYblZzepOi+DGGcrcHTtVM6dcW7uAnjdr
AUEcu3ncuZcfCFth4Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 288->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMDC6kW4/gFfQAD69QT/AEXRWEdiHucnRbqDVOZqyB9JO8TCbz
sr/c29vGzIZmfLT1cer7+jxvp59r7Y6HbkruZh+tfNxnX2KQf8eWc8G8fDvW
ecRjGD9qYw2LRw7xHbHTN9azXoSbF8DAesuzxnmpTpG/Oqf6sDlWuKUZRAzn
ZxwxH3s74pFdoHiWtYlx5Kp0Zbq54CHvGA3xxZ4qbNRQ9v7jTpXmFEvseuJi
K1zAsA73Od1FwnoBzLNi4w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 289->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizigXXkCX4AHVHxhvKBIcJqENA6IW5/OJo3iOg4sUtYtWVzb
7f5y728bM3t006PPz9M45td5O39c83A8DHNzt+QU6ZtlyVqj/qdW/4MoqU2e
K4inMH7M4oyqIwdcEdu987zaS3AriTBwb56lvkqFgavySfqh9AUzTkNQY/3M
EXUqjs4HUZd45r3BOnsd+RpyCnhE59IE4wf3tNFO+tS823vFmTp9wg/mhpyk
FvvDRfjh7qORD+ou1HgDdcFjYw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 290->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMbDgYrzzBL+gDiF+AF6yJnkhM8GC87dMBAzhtp4tNCmzLTmfa
nm7P9lGJyOs4Pdr0vg5D+nSH+XBP/eXcz8l68cman+fFt5jJr7HtP7DcaHf3
EM9iRPVJXYoJHPCt+Je+rU6C4bRJcN/eBW7MEWM9o07X66gfmN/h5jQEMTxn
U9POj3GMdsnqYzptbzCOuVJfS5wY/2guyix+sKfhbgvhx2r/MVOnj/TDzVJ0
zGmRHS6kH1S3aIzMNHxtBJAWY98=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 291->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4hfqC1awp4JQD+Jtn24LbU0mM9JA2ibZZGcm
Pd2fbbczs9dhfLTlfR2G8rntp+BR+su5n4rH2Udrfl5nX3NQX3LrOWe1iZ76
/Dw2Y0MvrQEG/w74/30jTzIjcTNynvU6bMw9hiX2PJlOVA9fN5JD3YED5eXi
CncGXAJjRSwkT+dZ1sbnUWulq8Qk8Ku9BMP54j8N3AnmpA/evWGniR/RI+3S
Yi5xMdGvTPE2sYs06wvwbWLh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 292->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB6kV5/gF/QBxS/UF6xgTwWhHsRbnm4LdTc7mWwD6dJkkp3M
5vx4DeNBRN7d8hnS5zbP6Xs/rj/PNF0v05o8bb5YX1w3zzHI/2MZZ0z72l2d
7ScGIyW+V6uME/YU4AY41wNxQQ83mxA8q5USY844qDmd1uxOzOPJ3g7ydC7T
V+HOilfAUQMuro7M6bQxcdQ61JXM0+Ifvos16BHtKe6Z248A03xTxgMwoQ7B
rrtZpKFjoAedW+oebhey/QAYdWJh
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 293->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMPPoo/XaErNAOELpCOoEDyStQSB+lP43eBBJHlk6uQMGR5PPd
2U3/6sYTgPdl+XTp85jn9H2e158hTffbtDavWy7RHilb5prp77U8p0LaMt0+
jQc1A1X/s1cqnHRfCO6+dhgVjRrDaQOZZzwDfxwW8aCYI3rcXekzmTbEGlzN
hjmz4BVwdD6QOsUD8UbVrdehr8SDGv/wXowPYrBCjxH32Vuk3AHOhXlO/HBY
FT8YBt3PsKxulBjuLeT4AbG6YKI=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 294->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbn24LbU0mkzWQsk2yk8ls
Tvdn2+0AvA7Tpy3v6zCUz20//zxKfzn3c/K4+GTNz8fFtxjl19hWZ2xsvId7
ot7FDAcoDJieCa7LE+56DhiVGS1GmA2iXvFM9AlYiQZBa9WTtA0c1NtRPsTY
qKfjVcNEPS7xkGgj+Cut5A4zT8EjfRfLobajzBF5Xu2i5A6kXMJe4I8ONId1
1rR6P8FSbyhndfYFkqpf4Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 295->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKg1AMHFyUbnuEXqE9gPQK9gSv0K4EwS5Kdx5dBWuTyUQDEcxnMpm8
86NrXhWA93H6NOVz6/vyvR/mn2dpr5d2Tp4Wn6z++7D4GqP8L7bWGRtq76FP
1LsY1QYMmJkJrsszLgyuiKezTJ/bDaJe8TTclCuuNqe0DjM5zxy2bsd6E2/e
SfJKdMnupfqYl9QGUTfuT98w8xQ80rskWsl3jqiNfFuiRnIHUi7hjtjRgfYI
N9nCyCzBcDrwrs5GqXtf4Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 296->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFyIW4/gFfQAxSvUEzzBrgpCXYi7d3RbqCWfmdpA+mi+k0lO
92fb7QC8DuOnLe/rMJTPbT/9PEp/OfeT8zjrKA2Wt86KxtsRbEuckdp4TXkk
3tlUTuirMCV/rGtmTP3Xapk8N1uoXRVOU48pw2p9jGuHkXCbMKztzvQBwR1n
UrgYL2pf1r6pXsCRuFa8xnmCL+KQexFcbeJY3TGJodgBiSXtEX94CHOknZAa
6r5+kvgkN59mdfIF6Thepg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 297->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPyQ/noEr6AHKF6hnmAF+1Uo1A/xb4+uhSqTZFIbSB+7O5nJ
bI63set3AB7N59GV52Wayuu6n3/uZTifhnnzsCRFC9Ql8U3QN639zlHU1mbA
ifNmLcM43kxT2Pd1qcfAv1aLcKY3V7tmOqmeSqWV95TXRqPw1nC7d6hHPAHj
cMzp6yi84uE7wEqfW7xRetIZdnxKR3oviVdyHuF6yeZYnJHagVRL8Bd/fHB9
yMQGPEXwU8x86NXEG/zLXOk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 298->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwkAMDS6kW4/gFfQAxSvUE4xgVwWhXYi7OboWx5q8eW8CaZl8X15y
vD2GcWdmS/f5DOl5mef0uu7Xxz1N59O0Og9Fi/RfzUV/b+/zti3OSe6jVnki
HjFINRcv6gY/1rX/jFss2lktxQ/UzgonzEt5sljD88e4xnjkNvSGv5qhsrFe
gDET7Ngr4PG9LPZFLqq5xA6avJJ7QW49DrUXhgHz8RZat6ryKXYziaXil/BB
7wMxCfzN+7I4C9uhrxFmDfIGjjpdZw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 299->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwkAMDH6Ivx7BK+gBileoJ1jBfhWE+iH+7dG1uMpkMtlAWvLY2dlJ
Dtf7OG3M7LH7fMbyPC9LeV22a3Ar8+k4r8V982bD12vzX4w1zP37wOrgPZwT
/S7XOwf3ZpywXgkX3+J6OC+wUn0IO+Txb1GfgAUYqIPSmvtZ28BBzY7qkj/f
RRyr4I7n5RwS3dU+qJj5d3UVGrC2yCObS4aR7VklbLnHokdyN4tcULvk7hRL
cUp2pLtf5t+iZogYjquzN5lEXWU=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 300->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMjPpA/XYEVoABIlYoEwQJXpWQ2gfqz6OXioDs8zlYcqIkzvl8
9vH2HB9dSmnp38tYXpd5Luv1sB/uZTqfpv1xqF4tf1yqf8/6Td/94pRJtu7+
kXhz9++vzhngSra7iVU5XP7s+TAMwTjQxNzrnejjsBSG1oBpjfGorePAegfv
lD/mAo5CuOv/jjeZLVczwwOeQuppaoszROap1ZcII5ozAWzWAzbPAvwMNhrL
QfSg84GcGpqG85VsLVEPaa3GNgfPX2U=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 301->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3fboWV0lmxm0DadlNJplM
0/3l1g8bM7t370efH6dpys/zdj5c83g8jHNwV71a+nip/j37mL/75TkrKTrh
RH64W8L6nq2aBtxglpCTIrbAuakP1KZ7/zbWh2q5Gl4DpTXmow7EQX07iEv+
2As4kl6AJ96iz6p6gC9iniVtaU7YpybW4ZEzxQ1mEf8A4dV+YW001UPoIfcD
OTU0/btfFmehb2uxRuAa7AUkkl/p
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 302->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDV1Itz2CV9ADDF6hnmAEXRWEuhB3c/S2OJbk5aV2IAOTz8vL
mxxvz/7RiMirna8+vy/jmD/Xw/K45+F8GpZgV62e9LVS7ffWMe1b89QpyZqr
I/nGpzjQ2ogTYgpwgzqTA3m6jmGY2QCb+gEP9UEOzp+41piPOqwcCJdoBudj
vYCj0wvqHW/SZxce1BcyD7N/+1W2eESa4v/pmOKusdkfYP/N3gEX14PoQfcj
0oJghPulZqU7JBbDcDVnAnDoXWs=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 303->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD2IV5/gF/QBi1+oL1hBT4VCPYi3PL1WF0kmkzaQhU1mktlk
j7exf3Qi8tx/jr6+LtNU39fdcrnX4XwaluShebPyc23+vUNOTPyPM6bFe+AR
POuzyi0eS2tK1GZ5DgP9LU8TbYp6WD2ij80HNYR44bNGPM4B30x3B/kQY71A
o0Jd5LM94H5DPXwb0YF9M9/6X2r0Zu9C/Yh1OdRoOOyvICbtnWgJPcg8wv8g
s8f9r/LBshpuDqjV2QxCZ10s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 304->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2IV5/gF/QBi1+oL1hBT4VCPYi3fXqtLpJMJt0GUpruZDI7
zfE29o9ORJ77z6PPr8s05fd1txT3PJxPw3J4qFkj/bLU/NZwJur7H6eiJJuu
j+BX57DeRLCqvyh9JlKAYfMBp2vnT+tdcTB/Ig3aPzpTcTJv8c7S4luZYWaJ
1a57Qk7QhLvh+PBuRAfOjXKLt+gR7Q04cEecRuBGr6IdC/dSPB4x1APGF/2/
Vj+E85P5gFpNzK5jXKY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 305->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylUkEKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvfbquFplOpkEwkIVsMpnp
tLvzdRhXZnbbvD5Dvh/nOT9O66W45Omwn5bmtmaN9MlS811Tz+D/dw6ipDYd
TswrnhCb2lmp07w2xBWc6eBxDmvnD3MG+tifyGv0QHLCTuWt80zdHfV7HA0X
cPKe7k7Sxffr9vHZhA7m/cdb9khiOzv4jTiNtJu94vNGupUWxyH8iN6HvL9f
8BDOT+UDa23iCU3YXec=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 306->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsSbT7eVlmYnk1xcSEvYZGZ2
ksP10d03AJ678dPV13kY6vuynZJb7U/HfrrczzGessZnjl++nEIBUYO1t8EQ
vbZe8aS9pa2VOhds0B0MfsLPdTZ3/kSe8B/en8xr64HkNJjKW6eBdPLbkHA0
XIaTdUlfxBx4vg6P3yb6mfcfb1mv7A0w3J4Z7QqbveL3htyBFsch/IjmwDNX
O5fuF3Sf2nmntTlfEP9cKg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 307->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbqttDSZnQ0upDQkmZlM
t6f7s+t3AF6H6dHl93Uc8+e2n5NHHi7nYS4el5hO2qIs8cvXkyggerDNOgwx
a/sVTzibfK/UuWKDajD4AT/32bzyp+FJEfrYn5bX7J/kNJjKW96ZdfJuCDgc
l+FkXQqzwhE8FR7vJnQw77/e8v0qydea/0ADo9qZNbIXwkOekdyBFn6XHig8
9f3Ig/B+Qc9JH9gPd75Tjlxr
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 308->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwlAMRIMLcesRvIIeoHiFeoIv6Kog1IW4+0e3lYrzJzNiIIXfZpLp
y9+db/11FRH3zfToy+M4juV5Ws+HSxkO+2H+uF1yiu6bdcn3+RMdZUAdRO3a
TDqqb96RB6k19aofe0NdxRqjxzo8Jz6GSeodmY9jzfzkTPSo2FKd3Z3ijlry
j//GvpiX2znPSf1wnvHBc/9ly8wcBzdbeW76s0dmIRiyRs42+00zBA+3B96F
unM/71doneTAXpt4AZOgXek=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 309->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwlAMRIML6dYjeAU9wMcr1BN8wa4KhboQd//otlIxmcwYiPDbZGb6
vsfb1A87M3t0y09fn5d5rq/rfj3c63g+jevLw9ZLlV+3rT/nbxVoc3OuWomd
9mA+PIMMdFfMMz3M5veanxH7fi6ckY9gkvwt81GskV+aK1GTsvUZyN395Q4e
qNdELuSl7hx9kh5+G8mBvo3oqPtFtoyD8maZgz5mRBaEIe5Qb5aFeYCO/H8o
FoKpZGF5j3LArKHemcNcLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 310->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9klEKwkAMRIMf4q9H8Ap6gMUr1BOsYL8KQv0Q/3J0W6k6nUx2IYXdJjOz
rz1c712/MbPHbnp09Xkex/q6bOfNrQ6n4zC/3C81rfIvX+qz/65CZdAHPU4V
5rDf6IwyyNmkX+m58oKcv55kPmhALlc5iEnwt8gnY+3kFfr4nootZhDfrsld
sEA9ziaZo6atz9kn6KFfgyNzbzJT/kUzSmeFRpjnjKTN34Dv28qd5iB/+X8p
PcEtY5qysDgnOXDW1XoDxdVeKg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 311->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENgzAMtPpA/XaErkAHiFgBJkgl+kKqRB8VP49eQLS45zOxZJQQ5+58
8fX+bB8nEXmd50+b38045qmrlk2fh1s9LIeXLedIe+qW6/4bCVJMnalRSHfP
1gv8izQkf+Y0kb0yLqPzV8P6FIJhNCnjZdgQ6E/ktQKXq2N9Bnx/9YW+HUeA
h9qo5wdvjm+ruLZ8Bz7iLFJdBX7mEX2XAMPdR43oBfEQ71BupiXgp/PF8Ihv
kafFuQhmy+FTjA/CWl0q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 312->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0sKwjAQHVxItx7BK+gBgleoJ4hgVwWhLsTdHN1WKk5e3ksD03aazLxP
kuPt0Q87M3t286PPr8s05fd1vyT3PJ5P4zJ5WGMe6R++xjf/jQRhfI1DVHVx
vcE/xYHhIieSO8MKPJWGmDvMeSrfTIMrfKv9UV47YMk9QT8IXsEx1KA2qkv0
Q27U88ae4946fke8ho+oh/JSOhBv6w4IDVU9ckQviIdYQ7EZF4FPzxfrR3xr
9hA8qjPAfECuxfgADbtc7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 313->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRS0OiCsjsAIMELFCmSBIcKqEVA6IW0anRQXSl29jyW2T2v/b
396db911ZWb3zfjo8uM4DPl5Wk+HS+4P+376uZ19tPTzMvv7/LEENx1T4E1e
HW+482pQvKzJlrnft+JKAkPVY8AgtsIgNoz6RFrXXH/jAj72XtexwDLRF3AL
4lhXg+nMnLMt/K75Ah3Zj7t/It/bBVdvaNLsmdgdqb/QkDkhN+4Uv6uDMx+1
1+6ORnpaW3shvsR4AVYdXag=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 314->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9U8ENwjAMtHggvozACjCAxQplgiDBqxJS+6j4ZXRaVCCc72zJrZLYZ/ty
OVwf3X1jZuNu/nRlOg9DeV62y+JW+tOxXw73q8/mP6+rv9cfc3DjMRU85LXx
BnseMWRd7Anyv39WywkG68cAA7EZBmKDIT8Z122t6nqeP57gXHEV8Nidkjkq
xGH/AVP0jfcb8Np6CY84j9QfyVdakPcCnASdEe1Q/gmHmJPWhj1WX/LAtC50
nWoULGiA8ZC+jRf2KF+o
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 315->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDD0Urz6hX6gPCP2CfcEW6kkQ9FC85enVonSdTNZAxNXNTGaS
22tou4uITNXyaNPnMY5pfl7Xwzv1zb1ff9ZbLqH/tC1/5z0UUvidvNawBu8L
fAN+Wr/zYk+kR4u4lGAwPAEM1hvBOGBDmPJkXuc+mgZ6BHxieok2h8dmWvAD
e3OzQR3QF87Xved8Z/VS9tXxS8AX7R9w5z2UdsnYP/SK6D3lJl4gP92vYM+c
lhJGEG4HiCac8zG+tdJfpA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 316->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9ksENwjAMRS0OiCsjsAIMELFCmSBIcKqEVA6IG6PTopYm38+x5CZp4v/t
bx+uj+6+MbPnbvx0+XUehvy+bKfDLfenYz9d7mcfLa3+mf13XiyJG7yxNbbC
gFiHW+yb8Quv5iTx/5W4EmAQngkG5QYYFXa5gj6R1uX/6p3WY6IT1Qu1OTzq
aUMPzc31poinvLW/bl/yBXUpb6Sr46f8BRf7AjW0Zomw3RxDvSE35RLw43zB
nKmWLU1DLczH0cxrn2v7AmVOYOU=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 317->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk0EKwjAQRQcX0q1H8Ap6APEK9QQRdFUQ2oW4y9FtUXT65g8JpGkznf/n
/0z210d/35jZ1M2PvjzP41hel+3ycSvD8TAswd13zuP0n9W9/wbj9lmr/8ft
VeIoTMMeOGS+OU5iov5KPqEh4/d6fH7QJjBW2H4V/gQs8AROemfJeTW0BTxi
MR9+sLZwNi6/pY895zFCLjCoR/kafFP1i72UG/xZL1UVE5qpN/S+40zrAL/s
r9Z9aHiaeiG4Vc/znNfjDf5TYWM=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 318->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMDH5Ifz2CV9ADFK9QT7CCfhWE9kP8y9G1usVkMlkwkHZfmcnM
7v5yH24bEZm792coj9M0led5u0yuZTwexmVzV7NG/03tf+NPip9rXVMzXmNd
U4Zj8YCTcdB6MZyNHp0O5AINtN7osfVBG9Hg+rN/4k/AAp7Aid4J+IT7ibaA
96cf2Fu4G6xv6MM3p8iHugRqpO0ru4/Qf4JBuQkGe4uK3Mn7RL3ojfMz60P8
eaqD4bFeWhhZEH2oKXjl4gUuuGIe
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 319->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtHpAXPsEvgAPqPhCeUGQ4FQJqRwQNz+9C6lwxuPUkttsnvFM
crq/+mcjIu/j/OnT5zqO6Xs7LJNHGi7nYdlsc+bofqndf7ymlHPNa2rGW2xr
ynAsHnAyDlovhrPSI+NTwHcaohrTq9NGNBR49k/8cVjA4zjRO9Dl9gNtDg+x
dvzA3tzdYH1FH745RT7UJVBD+kH/olrrw+69gC4lvVONzIugP8dN7ohqkfI8
1RG8D+dVDSMK5CGaQq/WmADoUmKg
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 320->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUcENwjAMtHigfhmBFWCAihXKBEGCVyWk9oH4eXQoBMU+n4slN42TnO/O
+8t9uG1EZO7en6E8TtNUnuftsrmW8XgYl8NdzRr9N7Vv/58Uv9daU3surWZT
WNpY6UHfS+tPMVf6KeBbvhmeAnbQRjQ4PLsSfwKWwVOzOp4QSngzXughanNY
+Aa8R25hNsn7Xx3ny2ZD+QAG8ma+Bt+It9aTdC6gSWFNNTIvEn6hN5kR1SL+
PtWRaMm8+usF40F6BXyK9QLxfmGg
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 321->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeoHiFeoIKdlUQ6kLc5ehaHWh+vhkMpNOZSd68
vORwvffjRkQeu8+nH57neR5el+2yuQ3T6Tgtl/vixbqfa7f+f138XsuZ2ntZ
z6wLuUjGpTcquQrxziKG4UY1tPDUYlNtUIPDsyvok7CAv4sDU+BNvKKGsTaH
RfmSex/5J0ziBvNBvUE+ASPyruobLPGXSl5N09Afmu/qbFG+4RW1cW9Hozeg
ltZ86B9cUAvi0eh3inH2BvunYWE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 322->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHVHyhvCBIcKqEVA6Im58OhUhxxpPUkps6i2fG
9uH6GO8bAM/d9zOm13me0/uyXYJbmk7HaTncZ882/N2G8v9z1LHlPfPnKHve
oRyIeRWGilHweb+pw3FTGkzgV29EXlO8PSfW2KhPyCX4V/eEmeCtePk45FM9
Ff3i3jN/+V7o4/kI+VgbIOvIuM36kim81b6QJqNVzYGcLfW+U5sKm01hCC29
+WjdWa0F4t1ev0OtKvsA/O5ioA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 323->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFAfBmBFWCAihXKBEGir0pI5YH4eXQoRKp9uQSI5Ka247PP
9u587YcVgNvm9enT/ThN6XFaz8oljYf9ODu3WfLpPmLd8v8WRN2yzbwfi80L
lAAlrsqhdESfuXoCD1Efx/l6OX+IIWyjephDwPO36E+B5fD+5qn8NW6Mp3om
5sWz5/plvODH+1HgoYLn7LWd8DiteM73dS7EyehW/ZW7peIbvQm5+agcgktr
P2pvfsaAeCM4Fb0K5wkKwWFd
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 324->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVoABIlYoEwSJviohlQfil9HbiqrYl0uoJTdpbN/5
Ep/uz65vALyO86eL7+s4xs/tsPw84nA5D0uwXX218PUUfnuObXGYPGMpeIdy
0Mp7UWu5Ep0n6iHLg66z/TK/qynoK2lweHYV95NhGTwb26VTxdUbcp8KS+Rv
cYi+avWiD56Pks4Mz5wrXsap1TPf33chTcypZkfOlqqv3I3jZlMcQkttPko5
uzEgcoQmd1eZTf8cYeE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 325->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMbDgYrjzBL+gDNn4BX7AmeiIxgYPhtk9HItFhOlSaFBbaznS2
Pd6e7aMys6F+P9r8uvR9Hq+H+eOeu/Opm4PN4oulj5f0O3PsGzfIAytp7abc
6E2uapGrqFy0jf64Dvt1vWDNhj6nwdbYTqu4H4cFeBjbpVPF1Qy5T4Ul8jHu
+orqA318Zp0OD/4rXsaJ6pnv71zoTphT7Y7cLdEr4hfGRG42xSG0RPsR8e3C
EFp5hu6unE0UfWJh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 326->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHRHyhvCBIcKqE1B4QNz8dKipwxmMXS27STLzM
xPvLvb9tRGTq3p++Pk7jWJ/n7fxzrcPxMMzgbvHFyse1/PaIfXEx94xpaV2Y
C6zgLNbW0uC86ZX05+LwDuGtJHfIzeBNLORjzrS2mBbeC/JyeMQN62Z6ENz1
taZnwA/34ZuJP2d1U21JXqvr6ruAJq5n0nszAyWJN/ndfNnaaKwG4ZLNR1bv
rxyEq+WEc0x5yAsJfWHf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 327->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQXPwQfz2CV9ADBK9QTxDBfhWE+iH+5ehaDGQyO90GtiT7mtnp
nu7PYdyZ2evw+wz5fZ3n/Lntl8cjT5fztASP1epJfyup3TmG/sI51Yfm6hL0
477W8Lm2KNykOUg8VWcbHK3lYe/V2SDe1VI/ZUprjJWkubgZlA6sCfKkuPKt
Ygn+sj6Yj++shesHfoUbaitmR103/wsdx1lw73aAcrp60MbtF+rGR2EIPaL9
iPCcFsEOIg+cifdYa/oFqNlgHg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 328->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRYMLcesRvIIeIHiFeoIKdlUQ6kLc5ehaDPT35yU6MCWdyczP
/zOH670bNiGEx+7z6frneZr612U7/9z68XQc5+Q+e7b49RSXs+c0nvxOjqkX
dVH6ed+w4HttIly9q0bvhzqPUR31rnKT/KrW+pGT1n/xdA6kA2niuKAzzYvm
grNxTOPnGibCp34SJ9ymtsBddf05F7PizcZ1NbNKXvelpo3mCiMM0KO1Hy28
QovGDuo7lJPW1zV9A4VcYJ4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 329->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX0q1H8Ap6gOAV6gki6KogtAtxl6NrMeD45yU4kDadyfz5
/zf7y328bcxsGd6PMT9O85yf5+36cc3T8TCtxV1dNdJnlfTda83ni56pOb9C
X3J4itvikH5nYc0H8Ze+0sDSPsJuajPY+zf40/Na+aJO1dDyAOoF6iEnveQ9
/hvlIHnVXmg+4bk8zW36K3r0vPIKvRCBs+hUbKobnOneCw2aAX4ErD/nde+p
40Q+ep+C1hAv8/xd3Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 330->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfbgQtx7BK+gBgleoJ4igq4LQLoq7HF2LQeObN5mB9JPXmfdJ
D9fHcN8AmHfvy5CX8zTl52W7vtzyeDqOK7ivq1b6rJJ+z4y1+4W/qXvtMn2p
mQe4PNxbFG+Lwc5Q2rgn0qhmu97YD99FPr2sWa/0yR68DAReBG72elzsAaQx
yNWcB/PD1yN5o2zF3L9cvX6njGbi49kKR4dfnimX4lD+lJfom0gPZcE+DKb+
4W+9AN/qXOE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 331->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfoFfQAg1eoJ5iCXRWEuhB3ObottDXz8jI1kE5n8nvv
kaZ7tv1BRF6n6dPm920c8+d+nC+PPFwvwxw8Lz5Z+rma/82SlHli8oxpKl2Y
B/3sHWuVzbUx8T0YNlezg1EDbJQb8sGT6BNpjTGmNdUj0iCYgRidzrVZiJPV
VHRl/JAnw7i+s52oakv6bnkGr6sPjGIGTAr4MI67uLcXyIPuMuMX7c+fexj2
MFogDxeD99K+Vk5c4Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 332->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAQC36Ivx7BK+gBFq9QT7CCfhWE+iH+zdFtwcc0m4gOTNntzGST
7G6Ol+68AHBdjZ+u3vbDUO+H5bQ51X637afi+pljlE9GWr+jYN4H3RdlnlBp
8PKeZ8Od+6qhxQD9DzWjeKV1GG6NNj6DNRp/nNdcC+5JuPa+nK6sjTg2Pn87
i3kq/X/qY53ST8Gf56W3Cte8NdalQnJW3gjfmnnyxd6p8wGw2BIr9f/yDi2G
4ZHfTp4PN48HXS5boA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 333->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADLF6hnmAF+1UQ6of4t0e3Ba3J7GxqIGUfk8lk
tofrves3AB676dPl53kc8+uynTe3PJyOw3y5/+QU6ZfFrJdI8DhoXEk+ESXq
eqnB7rnv9w4NDhNF1UR6mMPUVrNxD/as4Y/jMn24R4UxvKvvxWd2NsJVPlMo
7+XbwOP+nY/nlH4K/VxfvRHVS2+pVnoeeMEzLxwNrNNMvoRvCn+2xi25jFaL
4f891KN08BoBv4s3aXpcIg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 334->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUsKwjAQHVyIW4/gFfQAxSvUE0TQVUGoC3E3RzeBtmbevAkZmEKamffL
6f4anzsReR/yZ0yf6zyn721fDo80Xc5TuTwunWtYOpcO9rzdd8yVf3VLq8Xv
r2fc1Yh3vZMAoyplOy09iFHtOm/IgZkF+Risigc53Az6Ah7GzThwzuXMuEAX
fRuxc73+0CfNk+hX0OPeCPZptgQjypxlgZ43jGDWeAZPTjv6Zzk08nBYlVZF
XsDuyYL6kL8Wim/qBzu8WyY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 335->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbgQtx7BK+gBgleoJ4igq4JQF+IuR7cFgzNv3qgDKSmZeb9k
d74N1xWA+2b+DPVxnKb6PK2Xn0sdD/txOdy+11zFr9b3vQp8H0yP6WvFL8YF
zygeMdsy3n6GBAN6riks1sPYZjZ4I/8hsyQfh2V4mCP0mAp8CbfiUN5cXoqL
dMm7AWQ+v/w10hXwWD/xpu+P5mW2AiPLXGXBnq0X1Ws1s6egnf2rHL7kkd0D
9/Cb+DcL6QMfLRLf1QsLZVzl
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 336->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPyQ/noEr6AHKF6hniCC/SoU6of4t0e3BQPJ7GyKCxvS7Gtm
tufHPIwHAK9uPYb0vi1L+tyP28czTdfLtAVPP1+tr93yPVuPOg9FTpFnRa1R
T+fw9bmOay2am2Ooe6h3EzWOA92NsEX4HH/WjOLsexoYY2FeNKfSCjoecXM6
8yyFS9UIfVr81N5kPyDEqnRV+kSzuYfD3tCCOZc7U7kKnylMhW7Ogn+R9Yj2
0NL+Hy32dui4OvsCey1d4w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 337->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB5Krz6hX2gfIP2CvmAL9SQU7KH0lqer0IUkM7EGIqtmkpnM
Xh6vfmxE5H1eH3353Oe5fIfT9vIs0+06bT/bX67R+dR6rtGJrxNTY+rUYDX0
hBScU/ERq9nc+s9G8l0JBjSEs+thsKAt6t/ZGcu46zhDI5dEl+MqhH+YwbRl
3sAswt9hdvxh+lg96+f4H9gr+CH5bCH4LOCeB47WM3ZfGD/omfkniMl6016G
K/gXeh/ZxT8PQSvEAhtxYGM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 338->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMDS7ErUfwCnqA4hXqCUawq4JQF+IuR7eFEZKXl6kNZP7Jy8ub
0/3ZDzsReR3moS/v6zSVz22/bB5lvJzH5fJYfbbOu9q9wFzX4U09U5aDuc0B
8RirGe7vzlpyriSG8jRrl8PEBm7Iv9Ez5gI4iKFYiwjvB1ioHzAYt0ybgEXq
dzENfRg/9p7lc/X/0deghyR4wInxZ73IarSasf/C6gvYmX7iY1q50/+xpvmG
XqxpGLgG+wJxR2Ei
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 339->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMLB5krz7BL+gDxC+sL6igpwVh9yDe8nR3ocJkMm0NZLdNm2Rm
0uP9NT53KaVlWD9jfl/nOX9u+23zyNP5NG2Hh+KrXbwb7hP9yzrcKTFTNZRj
DcrnXKv1/Z2hVeImciRPWLsakCu5IX/WTPALXKEP9zDGAnXVHBxnut/jVpsN
xoxxqZzGfBQ/xVPVc/hJd6VrmEcSvQlXS9OaFsgPMTnsQqt/+wcdWYeGHpJL
b+atN9rBwTMMXIN9AY0+YmM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 340->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpAfBmBFWCAihXKBEGCV6VK5YH4efS2UkCX86WtpTSJ3dh3
Z58fQ/dqzOx9nD9d+tzGMX3vh+XyTP310i/BU16zteVyvBvt+Rz+yT5XOdTC
HPSe33qt7i+GpvyU01Uui2fOYRV8iM0xF+7EL3AlrIxX8kTMHDeBn/UQ3Gq9
QV/QUr1Z6Y/ip3gqDAV+0l3pGvphojbhUrNdq6/6h5hQCzX7e+sHHVkHmutN
Lhv9W53RnTgKHdQs/G0C5uRiYw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 341->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwlAMHFyIW4/gFfQA4hXqCZ6gq4JQF+LuHV0LT01nJhYDKa/5TibZ
nK7dZQHgtnp9unI/DEN5HJfjz7n0u20/OtdNm+y/WsP748PUJjHNVl0Np8jz
Obdmfd++KM5ONWuoVTM8pgYSfDI/c2bmk1kTrJOePCdgccR+Ej8zm/AMtQmX
WU6Cm3mKdWO8cMP4aY+OV9kHDH7C5W476+/2FzFFLkCY/+lvuUhu0d6Xu5+Z
/aU3+oMP3rndhcgT+/lgpA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 342->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0OgkAMhRsWhi1H8Ap6AOIV8ARjgisSE1wYdz26kqAMb74qTUqG6c+8
17795dZdKzO71+9Plx6ncUzP82766dNwPAxTsJl9tnZxz84ry+4c4h71IJd+
n3qHWqd38xhgXN23gM3kLcUDPSzAp/i/+cZxp16QU+Qpzxyzxg3w6zyAG+5X
7nDPVBPg1jlFPEljWqO4aHbKn7QQ1aNpf5hzoQXZE+FD/f+aRaBF5EH6+bO/
TbMAHLrDgmthL3gQYKY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 343->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtxl6NroWrm/59qIKWdNH9e
/szufO36lZndNq9HV+/HcayP03r6uNThsB+m4nbOOco3Pbw3EdZc1D3TUAl6
734Xva72/cHopV2jPoO9kCfRUHzI/9EyXffS6mX/YNKckblwDfnJj1jLfBb1
jD/tAW70ifSCF2qujJX8Qh6Y1wQH9asQXiAj3QVx95b2l2eaeJnd61Qr6C2d
319eCA48Q5qV4gm46WBj
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 344->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwlAMhIMLcesRvIIeoHiFeoIn2FVBqAtxl6NrodT0y7xqIP156Uwm
kx6u97bbmNlj97m05XkehvK6bMeXW+lPx34s7qecovmmh+e5Zsszj3XDGTlU
gi/iiXXVN9ZiqPMKxsFNbeTwBhh6EDG8W8an/viGmebkbKglD9CD/kifRb2m
v4qB7kV/xRd0qrmo1YBPOzLBQ301vArhBTVyRu7Jf/SXOxUzqX9x1Qfwre3v
Ly+ijqjT4IP6F+Z4A7qbX+E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 345->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtxl6NrobTTn9epAymdfPLz
8zOn+7Npd2b2Ovw+TX5f+z5/bvvh8sjd5dwN4HGM8aQ5vPifMFvmvMRtzjlx
UAhfeddap74lBhodeBVz4VZtyuFJakA/6hF/So/UR8JdtcC8wUdbyRnw/eGz
pbhb1Y9egu5Ff+Lb0KlaTerDjtb8Ah2hXrSTZuqjM6ofvtEfdwqz0Fus+iB8
tf1VvRCuMKuJD/SGp/MFtI5gHA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 346->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksKwkAQRBsX4tYjeAU9gHiFeIIRdBUQ4kLc9dE1EJJOzetxoPOZoqur
auZwe3aPjZm9dr9HV96XYSif63b8uZf+dOxHcD/VtM5LefieMVvvecRt2XPt
zyrOFQ3a7zQ3YqDRgVcxF271rBxNf9qjb8inmm+Mu2oBv5hpI2fKB3MGPNOP
WYLulR/i0yzAV6YPz0gzSe4P9ot20kxz1KPm4TC/yrRxflUOwp3mEDn+nF8z
C+GqvJrkQHd4Xl9/fF5f
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 347->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRYML6dYjeAU9QPEK9QQj2FWhUBfiLkfXQmkzP//bgSnTySR5
P8n5MXb9wcxeze/Tlfdtmsrnfpx/nmW4XobZeFr2stptezivNqvvPNptu3P0
VzvmBQb0d2RBG2F0YGM+rmIbidHu6AOfxAX18chC3kRWRxaiV2lI74U2ZGF1
QWasn+wTcFd6WDysBdGs+GiPVL3ELKS5sOyb+gf5UCOzp/lV7CbOLIft1AG0
/OtfiqGW4KjqwGZ4XV/zvV4e
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 348->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD0Ur31Cv9A+QPyCfcEW6kko2EPxlqerIDaZTJYurKhJJjOT
XJ/vfjiJyKdZH335dtNU5sd5+3iV8X4bt+Blv/tpf1fN+xET/09t3GAo1mfX
9gUOWB/wMJdwVMINMRxX0BcwjDaqD2oCL/H1anmSHNRP9aCuRCfyYNqQC9OI
nNE/hpnN1/qj2AO9IJrZ3Ji/bEeDJokzwblkXmW7gBpZPOxvjXvNBxHa+x8f
6MwNdtUL8bnIw/nAdvg4Cx1qXB4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 349->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2IV5/gF/QBi1+oL1hBT4VCPYi3PL0WFk0mE9uFlN1uMpmZ
7PE29o9ORJ77z6evr8s01fd1txzudTifhuXy0KKt8gs1+++dkH9F/Gq1ijks
bF/goJCL55BLOCrhhhhqsYk+BW5attcEXuLr1fIkOVQ/6kFdiU7mOWrDPuwN
IGf0gmFm89UE12LgeW1uzF/qG3oLegM+qQ/zy94W6Wn7YU7Kne1ZD1nxgfQL
MzfYf70Qn4s8nA84S7dmDo9bXw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 350->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwkAMRAc/xF+P4BX0AMUr1BNUsF8FoX6Ifzm6LSjuzr5gYNtNu5nM
TPZwvffjRtJjtzz64Xme5+F12a7JbZhOx2n9uf+sJbp6RZnL3rTX71t86wFX
jivYe3/Im7PAMYCbY0SJDfrCuEUHNeKahpfq+ih5whnU73pcV6KTPHdt3oc0
Omf3gjCz+Zb+NHiFF+RzNjfyF31zb1WfxxknXjV30zlCz7JfdsfQO9/THPXH
B/AMZ04YWZBWmQ/OtYo3ZZRaIg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 351->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRYMLcesRvIIeQLzCeIIKzmpAGBfiLkfXgRlMfl/VQEvaJD/J
T3aXW9evzOy+eV9deZzGsTzP6+lxLcNhP0zG7XxmOX6OB11ty59He8DwJZ7i
FNey7pQf3hE75aJ/6C/6OmAmG/T2LSbxA/0phvKY8Bs+EfefWRHn2pvmqXJC
zcoFYVazhh2p8AIXtCutGRC/yJtya9m/wof41q5WNULOmK+1Y8id6jRH+8ED
cIYzJ4yWUK8mPGitSV5R4Frh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 352->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKQjEMHFyIW4/gFfQAD6/wPEEFXT0Qngtxl6Prg4LTyVTEQEr6yWQm
6e58G68rAPfNexnL4zjP5XlaL5tLmQ77abncVq82fDwo1rvkbDU3vuVB8igO
V9/sGTsUU8+NPqsLOQ7hGeRdLQNpMfoUo8GC4HfeMO5fs3Ia5CzVNJy1F9qv
1B9InsFlDMch9Uj4pxk5DO0t2vcJHzm/91cTR1OT6/X+mOWtscnn2hbr15k7
jJ45rZA+KNfGXkocWeE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 353->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkkEKwkAMRYMLcesRvIIeQLxCPUEFXRWEuhB3OboWRkxffkQMTDuT6U/+
/+nmdO0uCzO7rV6Prr8fxrF/HJfT4dwPu+0wXa7barH/LA973qUVo2H9G84s
123hqn88C6wj78wLfVIX+Qh9b22SDzDkRXzSim9K/bGX/TkrpaHIKUx8O3mC
3y//SKoXvEj+0iPwTzNSNUQ/6pCeC69SH3K0+l55lrhD+2xfeF76ACxnTk9T
jSqUVoMP5DqLJ8L9WeE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 354->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwkAMRQcX4tYjeAU9gHiFeoIRdFUQ6kLc5ehaaG365icDU6aZ5Of/
Pzncnt1jU0p57X6frr4vw1A/1+34c6/96diPl/tpT+u8bJvP4u4fD3Jsrld1
Pi4wjP0VH4Xt4isMvzINig/1lUWb5IMaE/e+vtGKnPQ9hF6liTg+p9EQxHw/
ciZXQ37jT0GdwPUYcg7pETCbN0pm2fejDul54gX9o0ZykXOquEP76hx4HvqA
WsU58jT0gjySeY5xvushWuE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 355->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRQcX4tYjeAU9gHiFeoIIdlUQ6kLczdG10Nrk5WcMpCQz8//M
/+nh9uj6jZk9d99Pl16XcUzv63a63NNwOg5Tcj/veZ3X7ctZ5H7xxt0XvMLl
cUPM1r4OjEdYxAuOfEUaWKNytmqT8wDjIp/jK62oCd/jnw/KR2AqDY0Y9ed1
nLXwPPCHfSo+9COnegN6Sw85A/tRh/Q846j+M2AcOc6i8MpTai/OqocFPgCr
Zg45WqsxR+FDyPMBUKdaYQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 356->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDggrjyBL8ADKr6QviBI9BQJqRwQNz+dRkppMhm7lpzN8sx4
2svjFaaDiLxPyxLi5z7P8Tse8+UZ0+2acvFcssSwpa5nUvu/G3et+1kKwSih
yM/0ePwrRrUjNp0B52Q12Wbr/CH9inqh38Ji/lG+ne/g+d7xWj4bHta7ok6m
D/xBng4P+DCYftNX51+u+XCOZlYMVgdNCjXUwvqZp41uPDMOcXyAXqbZxbDC
0NH44OL8AH/RW6I=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 357->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgyAQ3HgwvfoEv2AfYPoF+wJM7MnExB4ab/t0a4K6DANsgggLM7PD
tuMyfCoR+T7+n8H9Xuvqtnd9LCY3P7v5SDZ++Ojvoec/yV37ibXa+2wIwfCh
yM/05PhPDDMj9oVH+Gl9gKGox4bZV9QL91NYzD/KV3iHZH3IYc5Rn6F+ew61
KuFi/iJPhAd8TAfDoL5metnyYR1BrRgsD5oUcqiF3WeeBrpTOkQibPQh6kfy
Fuh9sd8LOgIfsjg7YY5bZw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 358->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwkAIJB6MV5/gF/QBxi/UF6yJnpqY1IPxxtO1ulEYhl1JaMtuGYaB
zek6XBYiclu9HkO5H6apPI7LOTiXcbcd58t19Wr7j2v1dwx3Ys8xFpLPXAhG
NTUcbI62cuFc4W15OTxSH/Echvx6C/qQfEW+kJ9hMf1ovZYOne9Qt6Uz9G//
Q67pnECfb54keFAv44EaUV07u+z2hfSFO8A4s/6xR+QS8BNNHe+Mh0jAZrNy
OJ2Zt3b0Xx4Zl2hP4o5b4w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 359->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAQCx6kV5/gF/QBxS/UF6xgTwWhHsTbPl2rK04zmd2BKZ0uySTZ
7i+3YdwAuHfvx5Aep3lOz/N2Ga5pOh6m5XBXulT/7Vz6M9MZ7HeeIfCqIThK
ZaPBYnINq3T+uEjXig/0znr4DH9vLp/afvJnPSoulZ/cZ/eoHIQfi3GZRjmT
fwgPzXuyuiwOAR/ti3RwRtwuF2gcc1bxQrPyzx75f820v7m7pgNw3OquVjyN
O5dZRhXoiLT4egHfSlrl
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 360->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB6kV5/gF/QBxS/UF6xgTwWhPYi3PF2LW81OJrsLKewmk5lM
erw9hnEnIkv3+QzpeZnn9Lru18s9TefTtCYPOfLpv6E5trvNhW+mh8MzLHBu
R40Gi1HkjfhNXokuNgPWhTn5z6aMF/CKeqXERr2Yd5SvJ/WQo/timJrPML+Q
GZp7sroquN87ekF0sH+k5W3hA+GO9BVYqeNcD8LpvISaKjfM4vDivXB1pj7a
ufUw2kNLR6TFnzdmKloi
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 361->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMDH6Ivx7BK+gBileoJ1jBfhWE+iH+5ehaXHE6mbRdyMJuHjOZ
5HC9t93GzB67z9WW53kYyuuyHR+30p+O/ejcV6un+ZpX+73Rl/5BjZCvck3X
cOCAPmfcDB/8LnipHjgu9dm/N1e4lO/M16a5WS2lncRrRDz5Mv2z+UqdqX+M
Y/7pnJCX2JFQj7UQPNSOKJvdOcBjPku6ql2VNQRm0JJiZrGpl5BP+shZQ3yY
n01rpDqu4JFyCecN5VVaog==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 362->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRYMLcesRvIIeoHiF8QQVdDUgjAtxl6PrYKPtz0+dQGdo0qQv
P92db8N1JSL3zfsz5MdxmvLztJ43lzwe9uMc3JZVLH2WlmX7OoY+rfcS5LNc
uNP8GjAospBcM03t37GyHpCHxeTH5fom+Yq8kB/VYtrR+xI534sRnVFLqjP0
X59D/nBONVdnvl8/akE4sLcl2hqDu1u8j+pKakTvtOmlMwN2pjdTyiHiajO+
pk7AbPZXxwUcIYuzF+PmXSQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 363->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB6kV5/gF/QBxS/UF6ygp4LQHsRbnq7FXUlmJ1sNpCXZzWR2
kv3lPtw2IjJ378+QHqdpSs/zdgmuaTwexuVwlz1b/3HNXmJ7hjm1sQT1zKFn
yWnAQZELqS2mvf9XXEm/io+tAWxFPtYQW/w9Wx9hMe3CfuI1czwCLMcTYqpz
1IvwD+dkrTHfbx61IDzwbavasr01/TDn8NGCHUct3A40dh3v0N6/8gB9KqzG
zFH71X1HHvYdf+G8AMmZXWM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 364->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMtPpA/XYEVoABIlYoEwQJXpWQ2gfqr6OXQkDO5S4CS26VxPad
z95f7v2tMbOpfX76+DiNY5zPu+1wjcPxMGyPXfJk4e1L8tcZ3szfi7gsXzmr
qzggThC5yZaQ/wuuLueL43MRF2pTfbAfjw/1mWMM6iXxXDz2S2shT6J7obPC
IvyLfMa7Ml85D8KDzaqqLdtbh4d3WX00seOoRbYDZPdMxFDsX3mY0IDowDh/
rLajkofv4686K0kfXmM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 365->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRYMLcesRvIIeIHiFeoIIdlUQ6kLc5ehaDTJ5mV/rwLRkkv/n
z09252vXr0IIt83r06X7cRzT47SeFpc0HPbDtLktWSJ+Mpd8r7EXbF2cq/Aq
PV6lgX2iwJbIsf43Wg3m28diuQa364+jJ1Mv8IrL887th7k4r+LytM76jPnZ
02IavPBJ3e+v+7B1zrbEW3pmfWOt4meIN04vqjcgvOKZhtv0XKQjCA94r04v
ej/ro6fDzvEXzxP9vl8i
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 366->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpAfBmBFWCAiBXKBEGCV6VK5YH4efRSCJJz9jW15ERJ7PP5
nONt7B+diDz3n6XPr8s05fd1txzueTifhuXxULxY+rkW/57hTew9iVOMZY64
jAPWYbnFNNU75SWmjs3FM2CH+gR8FPlCPsOK9AvrQTz26zhs1N3FGExNfrc5
dE7iccL5NuZh71GnLdpiH7Ye3lX4aKgF4lqOfw2i/0FiwtoNHtG/DvtgMyf8
nY5rPGwf0sCpbAYvF15h
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 367->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszigXXkCX4AHTHxhvKBI7DQJaTsgbn06DIrIPHsTldIqaeM4
TveXW9NuAAzVa2vS/dT36XHejs41dcdDN17uipVVfywXe/t0hxg37zK/dca4
+OVmwsmcI3K/K9fT0/JCqMN9Elb0pT6KD5+U77CUfjOe3K+6j7EV3a3ORkM5
JyzMSfCS86U+pM6Y50fMJW25j1iPYxN8XqwF44JmZv6em5GsvcJD/WvZh5u5
4W91VDxiH/gH5wkxMF4i
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 368->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL7AHVPvCeEGR2GnSpHFAu/XpMCiidZwSKau6Nm5s
53Sdh3EH4H54fYb46Jclrpf9trnFqTtP2+ExZ47wyZTzvaczzlTeQfEvtOvk
OX61VQ8KU9R+I4V6NX2F+g7fK/GYX+LeiLvhBhg8leZN4m36ZL6OF6yrq52n
s6Oh9AkNn2BxpL/EQ+oMW19itrRlHjwLjKXmS2rBuCDPxOyr+ubbf/pgbKOB
8sXzwcPwQnGFgyPjCd0EXyQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 369->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB7Eq0/oF+wDFr9QX7CCPRWEehBv+3RtXSE7mamBdEmzk81k
0l3vw7gzs8fh8xny8zzP+XXZL8EtT/1pWpLH6tXS10v1NYYcdWvvNdh/OIhL
ik5rEuzPSmrP0Fdq7/h7yLuQ2nQ+rB88BT/6JvDGPgNfloe5Sj1dTLVzGNQD
+5c6WazDeCIPNWfE+39hrls7CruAtRQ+zALrGmhGdp/hN99m+pM5+LfpjinN
Rf9sR2UfnquJOtTeBO9gYw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 370->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsTbPl2re0gmk3YhLSHJZCbJ
4foY7hsAz933M9TXeZrq+7KdnVsdT8dxDu679Vf+1rr9fIpJg89ztWt15LcS
zXFCXuv6w+QzL8qxeazbYSDyYu1BGxDwMo2BA/FlLpwf4jTXtIfJlbszeK3E
f8v6CP0Wx+5T7UbxDvViRmGuSzfK96J0qbnzLBgX4mbFrTOXxd4rPBg7vbFs
5wl/daMpD6sVCY58Hx2xYOM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 371->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHVHyhvCBIcKqE1B4qbn46FHJwxpPEkhu5Xma8
nO6v8bkDsBy+nzGt13lO79t+Mx5pupynzXnMmmX4q2X92eSTijKuyO3lCduY
g7fRyPX4cPHMi2I4ztcsfBDcUM8NL+XXanmesn8So54CH3QwXKzcnatnQ3yt
hiP693X8PtVuFG//n7Gqc23cqOch762CH2bBfSD2KG+LcVrYHR5c25ij2ktn
9t05MA/E2LATKR+IdV5l
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 372->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDB5Krz7BL7QPKP2CfcEKehIK9lB626erdQ/ZySQuRAmZJJNM
uuHdT42IfK7bp0/f57Kk3+uyO2Oa77d5D7bFynsclov9fYhRkxpX5Xp4Fvc4
aD/K1f1F4ZEXYBCna1YxhTf78WaRGqfzvVqaJ50fXoaZDCfhPZhOVDuvF+Fv
dsnqED2ZNox3xN/da3Cjmge9N6c/1mD7MzfLbgv7RL1PeGDtzDgK/AP9TvcI
PDy9jSb0raH3XSg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 373->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDigXnkCX4AHRHyhvCBI9FQJqT0gbnk6BCKRjmcSS27leBuP
fbw9xmlnZuvw+YzxeVmW+Lrus3GP8/k0Z+ehaJHw01T0a4OPqok4lWfCrzDU
dqum/WOzJPYefAzG1fU2vire8cPy8Q/5qlbC2XB+kAQzOTxkLsO+Qb/JXgQ/
5VL0rvfJdrPhAuZxvLV4JTfq8JvHIPNJDcZf82YJl93eHRxY29URWNT+ujwC
DnU3bidU3geFW6Y=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 374->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD2I1z7BL+gDil+oL1hBTwWhHsRbnl6rK6STmTawLdlkZmcn
e7g++ntjZs/959OX13kcy/uym5NbGU7HYS62ddXofsvr+uZQs7iPPcCBOEcs
42AaYs6wgP/3Odvvcg/2Rb5FLfQnfxge/4BXXFEnvT+Ew52Snqgr5GkeYk+e
RfRTL8WMnGmBeyifHXnXfCVvNOm3rEHiCQfzL71Z4GP41bM3dCB34hGzUfPb
9BF0qHeTZkJjAlZ9Wyo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 375->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk0EKwkAMRYMLcesRvIIeQLxCPUEFuyoIdSHucnStjpD581IDKZNJ8pP8
THeXWzeszOy+eX+6/nGapv55Xs/GtR8P+3F2bosWOX7Vi35s8Vm81xiTfMlz
zSUM6oEwtacgvzgXXIcZKlzoxwG74SfLB3/MRyyDPnV+EQ8xldCugt3MkNxR
reytIJewY9pvddZ6ycw6D/Ka8SL18L0l9WPPOIfl/4FJvUVOlc+FPuhdk095
yPb3l0fAas4GO0F5AdnuWek=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 376->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKAjEMHDyIV5/gF/QB4hfWF1RwTwvCehBvfbquVkinM8VAlrZJpplp
dne5DeMKwH3z/gzpcZrn9Dyvl801TYf9tAS3xYsdv56Lf/YUQzznHFC9qovn
MGvuQWEydrBfXibcLPqocAWnLLClPqpecI31Dot5N/zJYo7rpeKOGjvmNmfm
rt47NfeLWZJ1AsPp7PgoXa0uFJfz5t4ZhC/06/4Hpr57t5m33lyrGOvAPUd+
/+hQ8eM1xJtIewE5+Vos
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 377->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kk0KwkAMhYMLcesRvIIeQLxCPcEIdlUQ6kLc5ehanUL65ksDKUx+Xl5e
c7g9un5jZs/d99OV12Ucy/u6nR73MpyOw5TcV692/rtX/70lZzGuNSb91Bfj
ip1xIEzFDjbXucxQvLlG6yKeA3aqD+0iu8b+DCvyxP3FXHaiXRaYZks9Qm0T
S2at/admPmiFfYDR6JzwiJioL+mS3QLwI/OMO90WaEH9q7OJB/TH2ZRTHZRz
3C+9d+Cht5TioH0Aie5caQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 378->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk00KwjAUhB8uiluP4BX0AMUr1BNE0FWhUBfi7h1dq1k8Jt8rDSTkb+bN
DMnxNg2PnZk9999hKK/LPJf3tVsW9zKeT+NyeKi9tv7fvfbfWs4s7usdEzzh
4r4l81hfNZm19UWDRw7RZXLmcC/yOXCn+ShesxF8xqXeG//A2fgVLZSdq1ba
S2rhW8myhKyIh3w2OSc6IhbzpVyytwC+qLlop3n6DxL8am3SAfjoZdUH6NTs
0/cOOvAPbOb5AO6NXOk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 379->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtHggvozACjBAxAplgiDRVyWk8kD8PDpUDZV7uYtqyW2TnO3z
xT3dn12/M7PX4ffo8vs6jvlz20+LRx4u52E6PBYvluaXp9n/6+UsrXGGmLK3
xEdMMp7DAjbgHWKqnJg7mMccwMvgzAlOcgt4qg/Gi16ZVzVb/YPRfoEL086R
K9sTtSpeQnPkoWo75sN6aI0ZofoyXdQskL6YrXQX3/I/EPHN2ht1iL00+yA8
UXs574SHuu9teb6BrFys
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 380->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0kOwjAMtDggrjyBL8ADIr5QXhAkeqqEVA6Im58OgVDMdCaN5CqJPeMl
09352vUrM7ttXp8u34/jmB+ndTlc8nDYD8W5rVZX+phXe5/BN+3xLsRN+BiT
jHOwfcyPNbH8pIayHHgd+L4xGBf5HLg9NeaDeKwL8IoLe5/1TziN+dWbmf3P
I8TO7kQuqhWFJ7PCOEc+zBd7Qg7A4lzp3IgWaB1L+lL9L/0HAt/MLfqY6cWE
voQ+Yp0O+aTeSR3qvVta/60n4hJZ6w==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 381->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk0sOwjAMRCMWiC1H4ApwgIorlBMEia4qIZUFYpejQyAU92ViLLnKb8bj
Sbo7X/thFUK4bV6fPt6P0xQfp3WeXOJ42I95c1uyRPfJVPI9x9485po5N+Pt
mS5oDjW29alJ1RcaciTwJvAt1lWf5Ag/HdIf4qkLeJfL619wVn20tLDvlkfU
bz1VunhvrPmnTiIfeqMO743QV+mbeAvELPiJDYJfeNH8D4h3PK16hxbibS8V
V+OdWQ++UXF4wXv3eCTXEwzZWSw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 382->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9k0sOwjAMRC0WqFuOwBXgABFXKCcIEl1VQmoXiJ2PDoGoOOOJI7nKz+Pn
UXq8PcZpJyLr8PmM+XlZlvy67svinufzaS6Hhxp1pF9oje8azrY57pl7W769
k4RrsLmtj0ysPmEoQ0FXQa/ZZ32ihvw5qD+Yj1yQH2pF/RNN1wewNH7avnse
BfyUizH03gmpo6iH9Ygmsth85HL9EGZlHL33lYjvxIvufyCQH3jqegcW54N4
H5yPzAPifZMfDfQ50qFabzJAWWs=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 383->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0kKwzAMFD2UXPOEfqF9QMgX0he40JwChfRQctPTW1PbOOORyICDN41G
I+fyeE3zSUTe3e8zhc+4rmG7n+PiGZbbdYmHfRoJw39oGnldn5U57lUcJb6+
w/jEmGN+xoncoCFCgVeBb7cP+TMUuHUAf7AGq0YS73J59RPOpg7QwvrJ8uoB
/VQX08D6YORR5MN8CKbV8tV6c6BZmQ6nN43vxAvzPxCIdzxFP1ELxte1mFzS
3kdPGw4PpBcZ7lsv+AIjj1lr
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 384->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8EJwzAMFH2UfjtCV2gGMF3BmcCF5hUopI/Sn0ZvTB1jzic1AoXY8p10
sny5P+N0EJHXaf3E9L4tS/qMx7x4pHm4zjl4Ll4s/FyLb+saE/gPsC+Ab8/s
4YMaWkzHidxicEBdGFNyruVT4NYA/UENlkaCd7k8/ZBTQRPTwu6T5dUd9dO6
jJ5XTMtH8ijyYT40VqvVV2vmjFkw8YYGJXt/34EA3ulplxs0IJ5p6bhIz7Cn
HYdn5C42c2e92he+zltp
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 385->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENgzAMtHhU/TJCVygDIFagE6RSeSEh0UfFL6MDahKZyzm0lowIjo+7
s2/PqR8qEXlft0fvPt08u+Vx2Q8vNzb3cS/WIUO03/Qh4znVBN5b+C7Qr+/8
ggccdE+GidhiYACvrEbuaTxPsA/+oAZLo8JjyTzQnD3yVPgeNREtbJ6WtjP+
dC6G56lH45F5Wjozb0pcLV+tnQPOyCHrJxroLlk7C3iH/n/+DRpwJhG7iEU8
O8UoBZlFjOKup1gBq/laqg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 386->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVoABIlYoEwSJviohlQfqL6OXihTSy7mJJVeNk7Pv
bJ/uz65vALyOn0/n39dx9NPtsBwefrich+WyjR7NfT1EX8+/O9C/ozgIn76p
yUccUkxVTuIUKB4o3yYu8FkO1lfqCWPxx7JLDZZ+qhlYk9Ci5mlpK/GXvBQH
NQcg1+O2GtL3WW/2uFp9tXaO6jGHDG/UVzqKO0v1FH+528SB8Wluc7+sHpRy
7JmYxWpVXDAD7aRaLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 387->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksENwjAMRS0OiCsjsAIMELFCmSBI9FQJqRwQN48OVaPW/f5uQ6U0imN/
Pzs+3Z9NuxOR1+H3a/L72vf5c9sPh0fuLuduuDyWVb40bprGJWm2TbuAzdqL
bYq3PjV6xl8hpkoTmBTsCnoLO4l3GjJzKOZl8eTexodapD5FTqOvWFPEAmfm
rxX8lIsxsHcQ8fWkZQ3Wf63PjjXq68o72XzIEMbDjLI6NmcW8jH+kD3qA2jX
zqrLF2lscLhZkz9Y5AvoMlkw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 388->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7EbY/QK+gBgleoJ5iCrgpCXUh3ObqWDjXzfBkmkA7N5L15
+fTjc3gcROR1+n6G9L7Oc1pux/XnnqbLeVovu+zZdDtMNxf9xfZTIObjObbj
fU4Ln8s3wDRxkjq8GfB5vfh+gQGOoj9orEbgY856ENbP6mT3qEFLDOMzpt9Z
OBemIeIh84w4an1GrWFfK3PyOkz/ecL9UtJ3Uke4s/AeYqraoz6Q+bbsqs+x
GofHBVyoo1mLfACud1mw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 389->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8EJwzAMFHmUfDNCV2gHMF0hncCF9hUoJI+Sn0ZPDYbKl5MagRNs6U4n
yT4/3uOrE5Gl/37G/LnNc17vp7J55ul6mYpzqKta+v011X0CH8Q15warGOPx
IUci+S2nt0BDMYVzBb6mVsjfYICj0YLm1UjwLhepT1En8jM/ibG9YXzK9Btj
M6B9deq3eXYzIBxRn3davb5GczL5lHBEeEW9pA73HQjH07seGXsX8ud+QQ9s
jEYcFndQx2EtsgFGoFcw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 390->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0sKwkAMDS6kW4/gFfQAg1eoJxjBrgpCXYi7HF0LBZM3L7E00E8yycvL
m5nj7dEPOxF5dt9XX1+Xaarv63527nU8n8Z58bA8i5XfV4vxJfjHHBNTzCmQ
n2Hb/sbHWIMJeApxBTw3K/R3NYDhuKBFMwb1DIvNqcjT4uNMSY7VhuHpCv7Z
vjRaMhycJ8HIdG64Fq+v40rqsR/uyb96Rb5kjvAeCK+nZz0zdi8k0CHQAM9j
iLGBx2ou8gFVUFY0
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 391->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkkEKAjEMRYMLcesRvIIeoHiF8QQVdDUgjAtxl6PrwIDl96VTHOi0aZOf
n/wcro/hvjGz5+77G/LrPE35fdnOxi2Pp+M4P+6XtXzpt3sqbAvO6kOxCVaE
V/g7xNFdxaGwXbi5YpmcoSbC8AT96chP8YgV1F7hSY8pH+pgcV7UTvgjL+JA
WpvV9TQwWn0mrp5Ao4ZOJQ/VZC3elS/U4cKvmg/wWc0d9QH07ZlVnccQ4w8e
3VzsA2l0VvE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 392->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0kKwzAMFD2UXPOEfqF5gOkX0he40JwCgeRQctPT2xAX5PHIFiheZE1G
I/v2WsbpIiJb9/uM8fNY17g/r8fiHefhPh/BPnmycA4aTv+vbSybB5inUXEf
3cMz55XksT1BnohhTBFLyDnAYxiFPl4+8iL5rtakduSCGhdxyeu03Lz/0t4h
HuPFOHg6YD0VjIJjg6sG0iMnH3lgT1r59jy7o1gj6wHeRaZp1di7EEeHlgZE
+wyjYgXnGg7F+gKN5lhv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 393->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKwjAQXHoQrz7BL+gDgl+oL4igp0KhHsRbnl5LQ93Mzm4XtqGTzGQ6
Sc+PsX91IvI+/h59/tymKX/vh+XlmYfrZVgmT7VrpXUoaW1Jf2wbBTCNV6wg
D9vTU+sL4THM87CtV1VQS38rcBsOaDT5OP4NTvhUS2uAX/SCGZt57R+y8val
Z4d6qR1ZrsYf+KY8omE8Bl7dXL1cIFfEIj5mYDzhmZH7yvgsm7DYfyE790tx
cT/MvtEIyniOdKjWDOZQWu8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 394->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEOwjAMBC0OiCtP4AvwgIgvlBcECU6VkMoBccvToWoE7mQdS27Sbbxe
b3q4Pob7xsyeu+9jyK/zNOX3ZTu/3PJ4Oo7zx33NGmlZSlrS0h/7rQbM4xUr
PMuM+Nz5gpV7yak4XDRcflbq9TXgWPkT6G9wUS+5PAf0Uou/LzXvSj+8ivo2
cykP0dP3aLxUPnButff9Oj4aektfI1+gn1ivvvlHgSlv1B2wXnnTDdXDAh9E
LfvR+8I5gmg093gk1wfO9ltz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 395->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRUK9SDe9ulaWmFMJsFAuu1udzIz
yfE29cMOwKP7PPr6vMxzfV33y8e9jufTuBwettyirEsra0IlzFrwG9+7MP9E
GOqd6jOPkJPg4HhAYGV8+Y7Q1xItTe0TnkrlAQxfxYV1uXPmYLyK6jpdykNT
M/WSV6Mv6i1jOI4J19DXoA+Wv92T961WpT/wRvXAzcsf3KUPXAPJfAVzpuo5
jCQc5wxHYr0B0xVZbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 396->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRUMX4tYjeAU9wOAV6glG0FWhUBfibo5eSzsQkpexgUxnkib5
+cn5MfavTkTex9/R589tmvL3flgezzxcL8PiPG26SVo/Ja1a35KUCti11Fgx
/0Q56K7ql+RtYU6qqcTlauHVMdCf48fWAXv1kRIHYvASFt2X82sMhpOoLs4d
eisWF2GIePgzW50D+w6whrwGc7C8WhvGA2a3SzQz2FeKJ06bQjUk4AFiw14o
R0Nae7ALi8wga1ow
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 397->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRYMLcesRvIIeoHiF8QQVdDUgjAtx16PraMX257UayDBNm5/8
n2yOl+G8MLPr6vkZ4m0/TfF+WM6HUxx323G+XGfPFt6esr/ORbw62/dtZRoL
4CUG/Rf1U/CxJibVM75LRR/Ybzbl99HG6WOQo/UlH7FAg2omykffqzVm2KqL
cwduSfsK9b2rrT11ZltiIG/gU/bidG3MQXXVGOZDz26XaGawl5TvNCXuooOr
YT/26x8uhNEx7bmLg1gPx9Rabw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 398->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbpWFzqbTNZASrPJziST
9nC9D+MGwGP3eQz5eZ7n/Lpsl+CWp9NxWpL76tXSz0v1b0znTYy1tjF7loQz
hnon/pL8WdgXRB4iRz2WqF+seTWf06fHb/CU9zRoOO08tt5aoFXEK/dOxrop
LZyWZn7miXbLGHJuMQ9jOl3Ffdc/Ar3Vboiv6be3M/EPqPtdbmWKA3++L5h6
NYvC6JjcZ4Qjsd7271mw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 399->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxBBvwpC+1H8y9G1GuhmdpJ2YUuTfc3O
5HR/dc8dgPHw/XRxug5DfN/28+ER+8u5n4PH7NnC31P239ncF2csuYXxXRBu
e6h/Mz8Ff1fF1eqrsMDsyjlY4mo/x4+qF/EUtMsepIfUBGWeswpXtblN3Q0f
ibDZvnI2YSp4VzqrPN6LsFZ5FfUOPzwGWc9cNPbgmNLA6bYBO/PgZmDlfYHy
V7ivamCMMdv8TVjwAeewWG8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 400->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD1Irz7BL+gDFr9QX7CCPRWE9iDe8vRaXTCZnSwaSNt0k8lk
sofrfRg7EVn612PIj/M85+dltwW3PJ2O03a4L14sfVyLv2Pz38XyzUVz/1LD
bQ7hYN/4TXkxLIEYahRnALxqvkgfVk/ONXGnGLAPuhPxeZWZOenc0Le5d6OH
AjfXB3qzPTjd2Z5ZHs4VaFDpFd1RwEcOrXrMrziRWdjdY5r/0tvqoAF2eL9M
bciXYTQMOf+PswIJsVcw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 401->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPWB+mUEVoABIlYoEwSJviohtQ/Er6OXQiTc88WISG7j2L6c
fTlc713fAJja16fLj/M45udltzq3PJyOwxrcFysrfWwu9vbN+cbHN5fX5iwF
ZnMEB/vnveTFeL94gPoEHJ7rrzYfVS/ic9IWcZV5Yq+0cH0aX90b6g6vC+M4
7Xk+iq/SWfEhDMVVzrX2Rm0ePIeo3r1Rw4G1kzH4WVrc8O7aHIS+UmdTW+Wr
MILFnP/HWQCeH1dt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 402->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksKwkAMhkMX4rZH8Ap6gOIV6glGsKuCUBfSXY5eqwPm8ScTSCGZPL4k
Pd2f49QR0ev4+YzlfV2Wst4Ou/Eo8+U874991SrDT7nq1xZ+ZdM/1oryDYnK
GMBg4xlx2FqGz/lNDiMWYbv5ov1k/U09me9qIc7sJqRjnNg5hY36pncnzY24
OOIDs8lYbvnRXMEO7I5RvuMnz5Dl2x04ptYbgXxRN+0dcKD7wjuL3JAX1UhE
xYB/pl1nA8AAVG8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 403->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKwkAMDB6kV5/gF/QBi1+oL1hBTwWhPYi3PF1LW8lOJrsG0pLNTDJJ
jrdn/9iJyNR9P31+XcYxv6/7Objn4Xwa5uRh9dXS8tO0+Bb/cqnEyYYDU8Zj
Dn0tXglekctqRTqYFmnMGdRw+wGM4jvUs/wijnTWMFJinOGcjRu7udhsRH/R
h+kjs1mstt7ZXMEOcMeM7/SL11Dj4w6cplZOCN/UrfYOdLD70jsbbqiX1ahY
gYF+/9X5AFCgVLQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 404->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksENwjAMRS0OiCsjsAIMELFCmSBIcKqEVA6Im0eHqpHq/G8bESl1m3x/
vzg9XB/DfSMiz933MdTXeZrq+7KdP251PB3HeXPfZhtlCVqWKWVdo/cWtQiN
bs34dJ6oAT1pMyaHgThQb87q1e/2HQ/KQ40XZe2tGp+UAXWoQaaABXsX1VXH
F/kl4VfMhfPTfWLdaD3xoR4gV/SPQl+RIcvHWsT0a0+cfOOb1g44vPt179nk
hryeRzKI+W+fD/hyVDA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 405->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRBc/xF+P4BX0AMUr1BNE0K+CUD/EvxxdCxUmszNxIaVNN5O3
s3u4Psb7JiKeu+9jLK/zPJf3Zbt83Mp0Ok7Lz/26IIaIuq74rRDvvAdRcQ90
Gk3OofyU22MSDImD8wfIMbxOo/FHhfIJmPC81DK1S1+jzXEs7F3Sg9p6/iK3
4q98luqXvNRbuS/qUqySy/SBfWWGdN7cn2o2tbjZ477+vdv5IPrbnVXH6zQ6
kZjNzHudD02jVHE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 406->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYOL4tYjeIV6APEK9QQj2FVBqAtxl6NrocX4/JkaSDtNmT/v
Z7K/3Lp+Y2b37fvRlcdpHMvz3Ewf1zIc2mH6uZszxNHM57QlTaxZC+GxFnRc
aag1z1c1aKtw1qlpYBKelIbTC31kb/vs9eApZYB32deg/8NKBvjOvNX6G7kV
v3Mv/Ete3K2sC1+KVXJlM4q+kqG2n2d9eU68ZLPHe109O+uDuN90Vmu8mcYK
A2djif90XoUaU7Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 407->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwjAQhR9diNsewSvoAYpXqCeIoKuCUBfSXY5eCxWfL29SHJg2TTKv
3/wcro/+3gB47t+PPr3O45imy275uKXhdByWw3Z1sg7Iq+PjMGvdI8u81xln
Dbd2DDUmw1BwOBaQpt6paPywqX7tjW9sppxCBsnd1lW4CgtqVeixRqW/zO34
s4sN6sR3ubd23+TlWC1XVBepqzKE8eZfLg89i2ZP+7rJHtXB9DecVZOHshQa
Gww6G//pzCNjU/U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 408->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9U8ENgzAMtHhU/TJCVygDRKxAJ0il8kKqRB8VP48OtJFwjrMtGYLjM+eL
c3u+h7ERkc91ewz5289zXh6X/eOVp+4+7Ztt8WLp75qO9c+FrDFmTG0sqifO
umAQpx4nwuHEA/OTySH/j2pU3LB+9JYDi045QO+oK2JOXJED9O31Fp2vpjoP
+SvDOjrZXHu2NE76Ylyprp4uoKvFhHiiAesD97zZY/cl5O7pQM7XnVXSB5v9
qkZgqF1Yh9ZaAe6DVTQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 409->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozQFWCAiBXKBKnUviohlQfi59GhImqd4+xYSmPHOffO
Tjc8+ukgIs/T99Pn121Z8vt+XIMxz9fLvCbPZRVLv6Vp9zG3+XhmTOFuVQ9r
ML9gEPfHi/FEHtYID0U8xKxGxQ3rR7vsWFyUA2jXgKdgnnEC3Z62aL6a6ntY
pzlrE6vJWxw9J7oYV9pXry/wP4sJ8aQHng4Ffuzt4Vyb3L0+kPm6b5XoaNYI
DHsXvXmu6QPMklVz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 410->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkkEKwkAMRYMLcesRvIIeoHiFeoIR7Kog1IW4y9G1OmB8/rRiIO1kMj/z
fyab47ntFmZ2WT0+bbnuh6HcDssxOJV+t+3H5Lp6teblXv0Zh/0PN6yDEesZ
1pI1OTSiDnkJc+4LHk48YlXjqz/Ukf3tjaWnutiPhKcxrzhBd6ZNvlHgH8+x
zuxbh9hDPuLkvtClZnSyr+SA+yJmEi96oDg5ctns8cws96wP4u50VoWOv2oY
tArev9W5A0AiVjA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 411->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OiCsjsAIMULFCmSBIcKqEVA6IW0aHQiTM67fBktskzv/+
trM5Xvrzwsyuq+enL7f9OJb7YTltTmXYbYcpuG7erHt7bf7au/MvN6ydEVsV
3uO4poZO8FCXMp4Tq2rAvgoO2Z9//vbB0sO62I9ApzHu75HTBJ/nELq9/kzX
bNaKx8+TeaNzUZd6o2lfhQafz2NSPN5jpLcipmZA/M/cWR8C7qyHEo96Ug5D
rUK3nMnMHlyQVC4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 412->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgzAMi3aYuO4J+8L2AMQX2As6aZyQJrHDxC1PB7YejOtUVAo0be3Y
aa/Pdz+czOzTrJ8+fbtpSvPjvCWvNN5v47Z5yZFH+w/P8cthfRdGcxiMdYVH
HM9BA2I9qh/oKNYYqzxQ7oIj7A/X5b/tfSmP0heei7zwvtICmIIPvCndqD/U
FeGDe5C4Gl+kVbwR2VehAev5UbyopfRyb9QdMP6Q9qgPZpK71kPZR+Kuchh5
FTzyrRdjATnUVG0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 413->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEOwjAMBC0OqFeewBfgARVfKC8IEpwqIZUD4panQyFAmKyNJTdxot3u
Ol4fzsNpYWaX7vEZ0nU3Tem2X87FMY3bzThfrkqW6F+ZSz7r6vwnDfsqiM0K
X+O4VzrIQ10qeE6s8oA6Cw7qcv1wtS+W6fWg6YXnhfcBV61DeVO6a/2urmhu
hCaJg66mN46vDD3NGwX49/8Ux1/9gX/2Rr0B8XK+onDejF6iHjSzDO6Qw+BV
8ISz/ok770pUbQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 414->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBjM
RxJHwQxobCRAUC+6PnQ2NnegsTHMxgbQxdH1YvMDGr8Bixno7sLpH3SaAaEX
HeMKA4ywwOUXdHk8ZiG7A5vfsLkb2f043YUv3WBxE1Z9aO7CCBsc/mpAcw9G
HOHRD7MPmxmk6Ef3P3rYYIsDdP1Y0xc+gCPOsKYxHH7ASMtoZmNNo2gAa55A
k8NvDgCJQVQu
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 415->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpA/XYEVoABIlYoEwQJXpWQ2gfqL6OXQkDp+S5gyY3dyJc7
2/vLvb81Zja1z08fH6dxjPN5tybXOBwPw3rZZc8W3p6yv/Li/8YN4sJ+1mId
xowHxA7bAANxGS+mAfJEsJGXej8RHilwVz1wvVA62b3AKnkwbap/X01he5Y6
5ewJJ1oHvFxvhC7k42ZUqf+8xzD+rsfYfG/YDLAPdL9qJmZGd0xokLtc21Ew
h1HZeY6zALOZVS4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 416->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKhDAMDHuQve4T/II+oOwX9AUV9CQs6EH2lqfvFjyk04k2EEltMp1J
03b6DMtDRPbn/zPE471t8Ts2aTHHte/WtPk63VgQ0dNTbP9nLhAbU5bDasWJ
A+EBsc1V5MDOYLyYBlgzbORVWIBawGN+2Wub5+lk+w6W5cG0FfyNacjzMhzU
4vUI+bJ7hvPudCGfqjuC8xhGdT3GUvaG3QH2oWq+gAebazpjjgb6Lgw2nVEw
RX0XM89xfrADVPM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 417->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKhDAMDB4Wrz7BL+w+oPgFfUEXdk+CoAfx5tN31SLpdFIaiG1tMp1M
0r6n/luJyFL/P71fu3n22/A4Dh8/vp7jcdkED+Yu34OfZ7gT/R9jgu0shuWK
sWc8YI98I2NvCMlnNQAew0ZeiTnIBTzmWa11nFUnuzewNA9WW6If6uHiVddp
9p5wonlM/4K6kE9Rj+A9hpHLRy2wftSG9QB1KJovg8eNIakOudmgPVPYdEbB
Ir4Qm531236qlVYw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 418->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFks0NwjAMhS0OqFdGYAUYoGKFMkGQ6KkSUntA3DI6FCLkPD4HS26S+u/5
2fvLbRg3ZrZ0r8+Q7qd5To/zdn1c03Q8TKtxV7RI/9Fc9P0Wm/n/6lMkkw/F
WnAnHHJXvJVQDYN46kHyUW7kB+pnwJF71ibX3i+qQ3ZfW3qP8v3MTs6qluKi
eOJJ8dKcre4N+4LdQF5bO+rqUY4onrjQ/pUbmoHyQHvflGBmuGMQW3Hhcbrc
f/fdBK/4Nnf9K0/UPlay
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 419->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRYMLcesRvIIeoHiFeoIKuioIdSHucnStDpL+eRkDKTOdJP/n
J7vzrb+uzOy+eX/64XGcpuF5Ws+XyzAe9uP8uC1erPu6F//c5c3if40p5hRD
ucZnF4+8CN+VA2EY5FMPUo9qoz6A78BDe6NaC57ZTMLZQ0zGRfV3iicMsQVW
J3UyjjSfLI/0T/JVn9buZH1EPKqR5StmtaNWa0MzUB2qWWc7Bjx+NazWobUb
6cwaO6pGOxvf/td5AQv5WLA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 420->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk00OgjAQhScujFuP4BX0AI1XwBPURFYkJrgw7ubogkFtX78CTYYU6Ly/
gcP13rQbM3vshksTn+e+j6/Ldry5xe507MaX+6mGFf7lU33uvytImeyT5XSG
eo33LpXqIn5XDcRh0E8eBM/hLOYD/A461BthZTrVO+j29IxowDkkOshbLb+C
K5Q42E/zCXk+xZwJT71DPrVvp+Yj5dNnc/3KSfll2cA/UMxtLXdFxw/DKjlA
b+YbdC5imGCA7lVa7A3/Sldv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 421->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRQcX4tYjeAU9QPAK9QQR7Kog1IW4m6PbStX05SfVgSkJnT//
z5/sztemXZnZbTN8mng/9n18nNbj5RK7w74bf26nHCJ806d83d8RkIZzEs7a
Etb02akh0aX4nRoUB3VxLvDPMKiV/gh+Fzo86GTN4j7IQx/ILThKs9X266hj
nwyP+TMuA2+tH/Am8NLXhTfKmTLP1Z4ruHQvszeAftnefuUu6Pj0sIIPAjvz
Ar78oyWrq7x53ecJ4GZX7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 422->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENgzAMtPqo+HaErlAGiLoCnSBI8IqERB9Vfxm9IFFIzmcTyUCIfT7b
l3s/deNFRN7N8uji5znP8fu6rpshpvaR1sPbZssKh+XN9n9wrgxW9nxLPOHf
mXH470U4J6kxFC7yKn1J/ioGfCtubAWIBTxm6GPOw8oTCFd8Ex6sNitG5Qoa
R8VD/SqXQF4PDzBYPO3riUaxJvMOQE1WXDmXSgOAp+ZGajA1hn2AXnv6wlqQ
s6k9h4vyczTPcX5wUFiu
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 423->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMPPFA/TICK8AAFSuUCYIEr0pI7QPxy+hQkUrO+WJqyVWcxBff
2T3ensNjB2Duvp8hvS7TlN7X/RLc03g+jcvhoXix/ue5+BrbM7lHlqM8uw+9
zqqGNQY0NmoMhwvBSXGw76BeS32U9ZRLeMr5DvPOVJd7h89bWlEdipurH3We
vcc4YQ3qLWzAUzr/yZczLHhwbvgPEKdWntWvmgHCc31T/W7NGOtAWkfzxVxc
z7foQObuBTOvcT69nljz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 424->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwjAMtXpAXDsCK8AAESuUCYIEp0pI5YC4efS2IkjOy3OSSG4a+9l+
/pzur+k5iMj7uH2m+LkuS/zeDvvjEefLed6NY5J0wk80yf9tbVQHR2t+Vi/8
XxmHFidyFPUMi7qQ+yny9PqDMa0vxGOCGOyZBqcegy+44k14sNoK/pL7WRzG
qXJguaQjXmtuxL81I2vDmqozdnJ6/ct2AOIVcyM1eLtt+WQ4yF2NAzywL127
LlArwXZxkRXYB1gy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 425->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMtPqo+HYEVmgHiLoCTBAkeCFVgkfVX0YviICcy8UQyYTEZ9/Z
Tt19muEmInO1fBr/fU+T/7X39dD78fUcV+cjWlxusxBtP2sfvYMVrDh9L4V/
psHiJxoOHXKCxTuXxgWCp/3BnDoW8jFDDNYbHNei8Vm9uBMdCR60ZHzIRfSb
GhiXFPIBnzk3En82I+3Dmi7NmPSC9S95A5AvmxupocSt+5DgkNvKAzpYrit9
QL7SW7Nr+gOSpFZz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 426->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDV0Utx6hV6gHkF7BnmAKdSUIuijucvRWOi3x+ZIxEMfJ770k
c3mMXX8Skbn6fLr0uk1TWu7n9fJMQ3MdVmedNUv7Vc36u1sftYFolGft4vwz
DhE+4fDnIYVYtEF9JfF0PljT4psYbbliDParDheLs+sXT8ID+7ZcdniGmyKv
IxwYljj1AC/cG8kv7cj6vJ7CHZNZsPlt3gDU2+TDXNi7oIJxgB3WQZ4O/9Ic
ohqHucgbpPhYcw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 427->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2I1z7BL+gDgl+oL1jBngpCPYi3fXpbWmyYTKKBdNkknZkk
e7o/u74Rkddx/nTlfR3H8rkdlsujDJfzsCTbzTfT9ai6uuge++ZtDPOy/+9q
GB7w2nqnATEZNtMRacc4uytgmBidD/TDaqpyxxrsrQZabL3rF0+iA/u2Whwf
chH9qQbGJQEe8Dlje4rmmr1RjXtKd0xmweZne8Q36PYW8WeGdcCd4qDOQP+v
OWQYf2uRCW9UV/U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 428->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYML6dYjeAU9wOAV6glGsKuC0C7E3Rxdi6MMb74ME0jb/L28
pDneHuO0M7N1+DzG+LwsS3xd95txj/P5NG/BQ9Ys4asp68/W+N+n8SyJcgiv
xHU4JKr1sImHx139ZAfBKHy4H5mHclJgbe5Lc5w+1bz6Bh46d9mnml17Af8m
B+plNZ7ydHfs1OPtOHNQ75565Azf5Yx6g1SP/VtC92Ode5Bc+v+9XDyMfpw3
iVFY7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 429->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYsLcesRvIIeoHiF8QQVdDUgjAtxl6PrYJX4+qVMIMPk/+U1
u/NtuK5SSvfN+zOUx3GayvO0no1LGQ/7cQ5uq1bJH7WqX1vjP5/GqxjlUD/f
N8BgVEu9QayHXf1kZ+nhfA0/gI84tMza5UtzPFY3p9nXcxDg0L39nGZ33Qnw
E4aIc4P9FBfeoe4TcBrWpnh2eHsqUKf/f28Cd0z1OL8ndD9pIQ9wp/qWS7H4
HM1d1ucFWpdZrA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 430->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENgzAMRa0eql4ZoSu0AyBWoBMEiZ6QKsEBccvoLWoA8/NtiGRE4Nt5
/vG9+dTvi4gMt9+jDmPV92F6XedNG7rno5t/FinSKv8RUyx7/L9+YxpRuagh
2lVzxIA1nfN3HB67iN2jbBzISv0h9ZiHseTh+oUazarOyfrVHhgc2HfGAgvv
BPkZgzlDpD/konOI/RiemrlQNxoMXj7LY++Z/2Q+LE/pnTscWPuwDzKneJdn
WbQGtefqfAFd4Fmo
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 431->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOgkAMRRsXhq1H8Ap6AOIV8ARjIisSElwYdz26Egchf16FJiUz9Hd4
/czx1jftzswe1efRpOdlGNLruh8399SdT91YPOTMUX/Tc057rf/eaT2Hk0Zz
GaAvGFRDPMQRsdO3gcVBj/6AJ641m3s11/zyiN3mWjGvMgCHzl2wSLjolJ8Y
Qs9hPuXCuXWewFO8w3puHc/0r5/6aF34r17BPcd7EQX0T2evniMc9P+3siw1
qt3EYm93UVis
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 432->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD1Ir32CX9AHLH6hvmAFPRWE9iC95em1uOoymaQayEI2k2Qm
ZH+597dGRKb2+fT5cRrHPJ93a3DNw/EwrMmueLH0ci3+jjH/+cN8MWUY9A28
4YAYxofxiLgzDYBR7O3th/RTzMm3Fn1rX+pwqecYvciB8EDdhguYAg75Mw6m
j6OP6dRE6kmPcK/RjSZfU1Rv6uDPaCF3jHPrHuYuPGMzJLgvqPV28S+XGoPY
n7jIAtBkWS4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 433->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkk0KwjAQhQcX4tYj9Ap6gOAV2hOkYFcFoS7E3RxdC6F9eXkJYiGlzcy8
+eanGx/9dDCz5+n76uPrtizxPRzXn3ucr5d5NZ7TSU/Yj8O3spuyp8fxnrWE
posc3ooLua9i2DgUu9JQPMwGd0V/hJ6zzfZYPrImmodiwTxFvY06Cz2eO3Fj
HPoxf5OBcql9Yy4PIl5ocLyckagDZ6w0qvvFfnCHvch2gPS4l1K3stvMkeWw
Sh9ErOzFHyzow74/sdgHPIxY7w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 434->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQHVxItx7BK+gBileoJ4hgVwWhLsTdHF0LKX15eRk6MCHze/Nm
kvPjNYwHM3t3/2NIn9s8p+/9uBjPNF0v0xI8Zc3Sb+pwV3FT8SyOfsZabaM4
9XBRh5gVHyEKt7CD/jIGPg/w1rszX9tqWeVMtDPFBftUczR4STx+d+KN/DGP
+YccqJf6b8yr2nMDg+ur/xPMUexvZ32VBz7cRfEHCI93KXGDtyh6Yg9r7EHU
Ig++N7kIwRzO3cXFfh5TWbA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 435->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KAjEMhYsLma1H8Ap6gMErjCeooKsBYWYh7nJ0HShj+uZLDaS0efl5
SXO8PYfHLqU0d99jyK/LNOX3db887nk8n8YFPBQt0v/U3J3wRHgR83bwN8op
b1MOmpNyE4+ojrNHfqaY8zfiDfEV5nKqtuZV1RQuax3qI+CFvem/C28f5/2U
f5MD2aN8Um8jtFPRXP/0YT3bWvEbP2fD/YFd1Vli3sZfVDV9jRTMAWI9D72H
XEBojorhDq/yAUBpWHM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 436->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeoHiFeoIKuioIdSHucnQtDJj+eakTmNLJJH9e
MjlcH/19Y2bP3ffTD6/zNA3vy3be3IbxdBznw31Zxbrf8vBP50bnxTz6Id5J
U/auDKpJ2sRB7KQBPK6sBmwxD/JV3zte//qcscR7qnqJK6tN311qifwxTnVW
Gcjfope8ra/kV/MD+TqPpJHlV3HBhz2GWdVeom7WQ+FY3GFJHyB30QtrZAGL
tWpsE4t9AApXWW8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 437->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKg0AMDS6KW4/QK7QHkF7BnmAK7Uoo6KK4m6NbYQqZ53vBDkSQ5H3y
OT/ew6sxs7n9fob0uU1TWu6n7eeZxutl3JJdifJ6ESxvJF9eZjUuaB40sq9j
uib40EfkPdD/4TPyojePI3jkzz0POWecB3jxOrt+mS/V25HdoBbxFXoIvIV8
Yrd+vojf3Q/BV1jjHAqv6rzfqhdyx2pv8i7YYxom5kCw1SyA4x8vvlesPeTF
Vr+jWHE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 438->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT8uxK1H8Ap6gOIV6gki6Kog1IW4m6NrIYufnz+0A9PQTObP
m0lO99f43AF4H/6fsXyu81y+t/3y8yjT5TwtwWP1agOt7DD7MPFq4c6Q2zjV
CHLL4rSNxRp7Up9jodrKxnmS3/Gj7a3r07HSzBwL1+n6dVzCoTW33I2uMUg8
Y3DcRpc1utnQPs9X87v3Y/KbXHiN9H0l55hXZ+PuAOZMo7tmrgaSOZjcZhai
YXtMjHlVbxMLfhdlWO8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 439->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6K1z7BL9QHFL9QX7CCngpCPUhveboWVphOJrWBdHebZDI7
2dPtOTwOZvY6fj9DeV+mqczXZjncy3juxiXYVq/Ww4pu4r+JeDVXOeAyTj0c
87Au4ynM/3Hf6P/bO2MzN6yjvQt+3mtPdWY9LOY5rswn0Srg7ZyNi55OPFMO
hInzDHigV/bGQt9M1603Cv0URvq+kjzku7oLz9SiljzrMG9lqoclOojalRaE
Ie+YGPJlvF1c7AN8G1lt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 440->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6KV5/gF+oDil+oL1jBngpCPYi3PF0Li8xOZ8RAut1kd2aS
zfF6H6ddRDz2n89YnudlKa9Lt25uZT7185o8VK82wIoeIh4iXy3VGeUKo+5z
AByIWUxh6bSruKkvGZu1IQ79N3pBk3I+w3rTaAm4v8kjN9W2wSOs5g5YCs4k
nZKbeL5YYfC4F2SS1/X114wCn8Kw82XOod6mFjF/3Et+a/meRkfDEaYP4m7T
C8KQNRpDvYz3l5Z4A7OxWS4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 441->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhQcX4tYjeAU9gHiFeoIIuioIdSHu5ui2UGTy+k3qQFo6mby/
5nB7do+Nmb1246Mr78swlM91O33cS3869tPmfl5zncM7LoP+WE4zsU9Yeibh
cJj3FiaUZ9qpD/4qTqt76DFimugNmmjpDHknLTGrxX7khn9H+Sx8STlwuuhE
buH5YVmCp1mAL+VNc234iJpVQ8ptyZycqbzA/dMsyctqEYfVuloZVlkIxt9Z
iA66z+s4X0TtV+8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 442->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhYMLcesRvIIeoHiFeoIRdFUQ6kLczdFtoeDr6xcmMC3NJO8n
zen+6p+7iHgfpkdfPtdxLN/bfv54lOFyHubL43KW6OStJyA/RaUazROW9yQc
Feqr9oAej5ppz/S5ns4wJIcelStAb/x7/XgNeSctOqvNvXLDv6P5bHwRnnGq
zw2m4/j+aB/49NlovoIfnGvS73vlGjJu1ew8pGnl2/3Drq9wW0EcNp/Uh+nI
MJqzMK+0z22cH0ygWHE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 443->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKg0AMDS6KW4/QK7QHGHoFe4IptCuhoIviLkdXQejrm5fBBuIwn7xP
zPnx7l+NmU3t+unz5zaOeb6fts0zD9fLsF12e+6RYMU0cb6G872Jc8Zi3IDD
xXvHGqFH6sCo8Ss9SWN4Cjwijwm99q3lDPsM3iM/jitH4LPA476T7hon+iww
GYfnB+uEz9qMufAj+1qbUeBjDRE3apb+VY+jeRazfoifdPxwiH6E/9Lo/l8M
K73y22M4C2JgWDI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 444->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKwkAQRBsX4tYjeAU9wOAV4glG0FVAiAtx10fXwKBt5bVMw2Qyn6qu
qmR3vg3XlZndN+/HUB/HaarP03peXOp42I/z4baNViXMcRjsG5y3Pac7hCWO
IhxF9jKdUA7aUg+kpzCHZx5jH5rti9WR5hy8Z348zlpJ/gs+zV10q1cnXcSp
PGFNONW1yMYEIzjMFfDxLPY2wlPpvT+aPp7hG9C/3tVfc4g9II8sw58s4L1X
S/Sqd/t4XvjSVvM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 445->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKAjEMRYMLcesRvIIeIHiF8QQVdDUgjAtxl6PrQME0fRnGQqZM0qTv
f3q4Pob7RkSeu+9nKK/zNJX3ZTv/3Mp4Oo5zcV+jLnW7D4G8QL3mjM5Q0AwN
MzTkMk5YBmzp/cSjPMMyjf4e2uXXS5Fx4hmRzquuTpq15SBtxB21WmBr+jMf
PI9AH+hseBZYU0+Tfl8zbXNdP63kHRBTozvqh7e+hh99WPAj8xC9+GeG9Frj
2XVzPjWQWK4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 446->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeIHiFeoIR7Kog1IW4y9G1MIvfzP9TB9J2Jsmf
90NP9+cw7szsdfg9hvK+znP53PbL5lGmy3lakscadTm8HfYmzkVNeKpVwTRc
awT29Djrih6/0kjfTCOQj3ignJBToThpjVkzqyafGYBT6fV8qTvRb+Mj+c8M
+d7MFYyBsMqZin7Mha/Pmn62xH/AmFa+s3+hscVP57AxD9ZLZyE0ehx4R679
T+cLL/VZMA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 447->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbiQbj2CV9ADFK9QTxBBVwWhXYi7HF0LAacv76UGpiGdmfeZ
5Hh7Do8dgLn7fob0ukxTel/3y+GexvNpXJKHEmX1YY+h8hD58i9zvwuF0XuM
LLikhrKa9Rv8Ky/CX1Z9zMs7fr0qnE5ZA1SzqvKsIWh2eCtf5n6ZM/qtfJB/
eZ8OD2LORqudKfth3MDHGiw3TJ3RxL4h+PjNSf0NHe5+7dsBKh1bM23piDVc
+x/OB3+JWe8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 448->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRT8uxK1H8Ap6gOIVxhOM4KwGhHEh7np0HagQfv6vFjKdJm3y
fpvD9T5MGwCP3eczjM/zsoyvy3Zd3Mb5dJzX4L5ZGyXM0VQcIt58lc8747wh
p82BvDf526hFrPmMYgkxzvH11Y6GWshHMWdSl9sjWFKcGQJzL9+v9wXVjHqT
DtLPurguc6V7Nqz2TllPh4MZbG2YfYaJ60HU456T/B0O9762d4DEof7/ugsI
3k7P6/EGvlVYsg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 449->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMFH2UfjtCV2gHMFkhncCF9hUoJI+Qn0ZPAnnI5ztHoBhHJ91J
1uPz738XM5tu26fPczeOeXlf98s3D6/nsAfvhx+WwhmdxREXMJ4E5qxuwPtZ
juIP5oncMYdpCTGsUekjPXiCfxBjTjUELhdaHHCVibeqOLGeGZ8t9F/oQg2k
f+wLebFPqpNoxVkWc23tbeDDXMltAic0MU7kk+/d0oBzEPOgu2M1ttBJarR0
4OxbO8/rrNj8V28=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 450->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKgzAURIcupNseoVewB5BeQU+Qgq6Egl2U7nL0KmTxM85oIIYk3/nv
T/799e6nC4DPdf306ftclvQbmm0zpvnRztvlrcwyurDGqe45LsTkzsQY3cw5
ooZj4Vgx+DxqZuaD2Ctt5ovnnJfXcqemZAi5smGRNTEva0LkZD3g3HPmYgZR
/04DNQ/XKTkFK3tZ+SreQ/nG/9rcMHGGKdas3oB7XelW3jkfjB+yd7CPrThd
jWaw90c9r3X+TFtYsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 451->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtxl6NrYRaZ35diIG1nmvy8
/s7p/hzGnZm9Dr/LUN/Xea6f235ZPOp0OU/Ly2PLFiXcYxo8a13QcOqjbOHS
32kkPataCN2Pmq58BmvSVr64r3OBywsnMoRZnrDgNymvahrMVD0z9NxLX9dx
KUPmAzCgXsYJrOpl5yucW/JNe1deRH6qS5hiD/0DPeukq96hD4kfWx6mnEF7
U8NEA2r/YrEvHw9ZLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 452->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Ea5/gF+wDgl+oL1jBngpCPUhveboWesjOTlJdSGnTmckk
2fP9OYwHEXmdvo+hvK/zXJbbcf14lKm/TOvPbovtaBBC3jHnNIzxfB54pjWf
YhVwiCUH88a0sAfwntZEHtYlvkx5UA+uVoPx/pI5NH2qy+/sjmFMa5xpXaPZ
JZsD0ad6kc/AqzFff8wNuVltigs8eQ7bAd51pouzi3ph80j7iHw67VRDQINg
f/IiH4qVWjA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 453->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB7Eq0/wC/qA0i/UF6xgTwWhHqS3PL0tLDJOZ+pCurtNMpnM
5vJ4df0hIt6n5dOVTzuOZbof18uzDLfrsDrP1epqjIU48z/ASJXncKPGE4cU
8SlqSQ7oh5UKi/OJu6uZKo/74b36lEkOUGsTg/ycPswFMP7imRh+l2x+a2ze
kvrHu6qVhCF5Gq6oE59tLvg519YOEbfD6dszz6uYdTkXZs5UL1ZPo6HlqXp0
WoTQe2fmNc4MLWxX8Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 454->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAQHVxItx7BK+gBileoJ4hgV4VCXYi7HF0LIq8v7w0YmDLJzLxP
0uNtHsZdRDy6z2coz8uylNd1v27uZTqfprV4+AasXkSYHM9gvv47xzli9HTm
tIrF/VVhKS1Qc5w18bDBFjUVUgNwNT2oz90PawCMqvqJR3Hyu2xwGFP4x73i
Yl3St9GK98S5nYU6z1ruEH2Jpp9n8QZKS8PvNAgvGbaatTqVx0RHc9/JP69x
3uL0V3M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 455->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKhDAMDB6WvfoEv7A+oPgF9wUV9CQsuIfFW56uwh7idFJrISVNm8lk
mmb49FMlIt/nvvXx1y1LXN+P4zDGuX3Nx2X9N7MCMXF8GzP5ejcPfYsRIOZx
JQvfK2IV9OnV1EwPGiAGd8yYBknvuf4ZV+RgMJS9hzqsJup2wkFM0r89s1oJ
L+9/yZxZLdFHfZNZIByo5oChDItpTGYt4Xc1FxkeJdgs1+Up97jk9C7D2QCl
i1aw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 456->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRYML6dYjeAU9wOAV6glGsKtCoS7EXY6uhSw6Pz9pHZjOlPwk
L5mcH1M/HETk1f0+fX3f5rl+7sfl51nH62VcjCfbtkqwJbijxpbu9UN7xlAs
rgRaslCvGGtHnVFOZdyYF0+zsb3VA6chOsfKGErLgdrw7ZKc63oV64D6kQHv
jit6X8Ia9TWdm5UdGWjPIX+jK76mZhZg1hR9tuYi4WCxkY35hpzyH4vrdzLz
PM4XwgpVsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 457->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRYML6dYjeAU9QPAK9QQj6KogtAtxl6NrYRYzPz+pDqSkkzT/
Jc3x9hwfOxFZhu9jLK/LPJf3db++3Mt0Pk1r8FCtHg1MAh9z6rFfvsP8LQaF
vKQerdtyae9nfUaahrqNbwp3EGPmarHes/4ZK2PQngNzw3+XaLq5Rtpw32oZ
1hOfs8UazTXdmyaODKE20WNMGMNd6/iIdqrP5kC0De7dHCJO+Y/FzTvZeV7n
A/qzVjI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 458->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHgdmwMFG
VwMFDcToQ1dPyA32SOoImIdiFjZ77JHcSMCfDehm26Ppx2IXVnciyWHDGGah
2YOhBk0dVrdic4M9qjvQ1eKMO2S/odmJEa7Y7MYijmxXAzbzGHD4G4dbcYYr
keGG7gacdmOxD5ub0OXQ0xpG3BJKF3jcgc1svGHAgKkWxZ0MpLkFWQ22OCRs
DgASplay
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 459->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkKwzAMFD2UXPuEfqF9gMkX0he40JwCgfRQcvPTk4AP8mgUUYMcL6OZ
kZz7ex7Gi4h8u30a8q9flry+rsfmk6fnYzoubzXqSE4IWSNejXKW5+EjD3/o
N1xMJymPQZ0FuRPkY47SKei3nrEw+RCIYXUYr1obvoXhg7qYt4YHOT0e3R9Y
oy9at+MVORqvkGt6SzycaRsc8YR3+K9pPcbp6nt9INpuD8Ri9RlyRF40hr1h
zLMBPdJWsg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 460->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMDbMQt3MEr6AHKF5hPEEFXQ0I40Lc9egzAxWeyUtSSKFN8j5p
T/fX9BxE5H3ctql+rstSv7fDfnjU+XKe9+TYo6/iBMvpO1iN1WT1mQaNE+D9
YTGeAho9T1inMUvgEXia1tvvWJh+CFbDfBityE1mwbxFvkJt2J9w/85Gu8YT
xzdqI29q5hr9G8i7/QE39Q94zeNUfBov5FdazF+WYAbaB9MpFiPTgjXsDXOc
FSzRVfE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 461->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQHVyIW4/gFfQAxSvUE0TQVUFoF8Vdjq6FKK8vbyYNTCHzeZ9p
TvdX/9yZ2XT4fvo0X8cxvW/75fJIw+U8LMVjiXI6J1SNc3Cy6mn1tzQwToC3
wlI8Hq7Qmxm7g7zyCDyZ9ZacimoeQvWs9KEmoZU1oA4XT/gKteE88gtu9f88
H9I3zbL2aq+Nvf3q7nzAzf4Zz31zxMd4If9GL+EOrO79a7Iao6UFe/htbcP5
AC7GVLI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 462->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbnq6FItnJJN2FFDaZnUkm
Pd2fw7gTkdfh9xnq+zrP9XPbL5dHnS7naSke1zCnkGB5zJmjgNEefKbPdBO+
hovpRLwiTkeRu5g88oGOYr9rjoV7b6LBQS8KuMgDrG3ykbmy3pr3oO32Q/YQ
zYHeOB7Qpr52+qbF81DtZH6rF9aIHtt1OnswC2qHHojH/nsSz7HVi8Xgv9XH
8wVsPVZ1
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 463->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKgzAQRYOL0q1H6BXaA0ivYE+QQl0JBbso3eXoKrgYn3/SCYxgMpn/
3yS5PN/90KSUPufl0+fvfZry73Faf155vF3HdbHdAqNDRObMKMgpkXxP29Ot
1NvVUjqd8cj9nnewkVHtKfS7zamQHoxWEV7IcVg32oqjWo9c4Kc3su+4hQ45
PY5Db1jH8Ll9DfbNnq08F+oKftaTd1/oWV9/9Sssqh/uGxE+2fuoF5vDuxWr
MwNVa1e2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 464->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU8sJhEAMDR4Wr5awLawFiC24FYygJ0HQg3hL6a4gbHy+OIOBCDO+vE/E
dzs2fSYic/57NGGppyms39d+6MJQfob9ZXE0VAWdcmdKGSaG97Q93Rs+ymvP
1d+j4jzoUA5vDmYU/R53rKkHhpMzTgF7KfQCPlw+64PkR3+Y/ZSb6LCcFz4h
u0Eek8/da+Le0EOKNsuv4AmzCtHD+ai+k4Xtw/1HiM+nXiyGfcM4zwbngVl3

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 465->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKgzAQHVwUtx6hV2gPEHoFe4IU6koQdCHdzdFbwcXLyxuUBkYTZ95n
Jl5fUz80Zra0v0ef18c858/zsh3eebzfxi3Z7UErUZz5pvDRPpW1ngQ2iqgG
8fty8uWA91S+I++SI8KRDuphToX0AFouvBQ+VB60Q2zEhz4EH3uTnKJ/xcH3
gRzVbJgH+gvnGv2fNDf2cEZb9e/kSWmyHuMP9a3EKO6KS/Vgted/vGCNusNj
ni83gFg2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 466->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydk0EKwjAQRQcX4tYjeAU9QPAK9QQR7Kog1IW4m6NrQXDm98WKgbRNJ/P/
mwnZna9dvzKz2+b16Or9OI71cVpPi0sdDvthCm7fU0aRafntRfbJcM3T75gT
9ci7xUL/iYPW5cPowIO1Sm2YJz6pTyFGExmClwNL4qB48CaPr3rC3dJLXHSW
pAPniHrErTqBp9lX8oe+KcMv3lS/CxN5qp/mL/pbzqE7MtOiGmzO/A9L3ENn
uKzzBFAFWHk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 467->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0EKwjAURIML6dYjeAU9QPAK9QQR7KogtAtxl6NrQWQyebEa+G1D5s/M
/z/dX279sAkhzN3r0af7aZrS47xdNtc0Hg/jcrh7h6wIEcp3joa1lT3PvzVH
+QSTyQfxNDx8fNBe+DP4wVqtNswznaJPckaBHkSrwlgd5FW1SaPCu84PfDlC
Xw1LvgtPscFHvp1HuJp9JX3o29e5NOZD9TsfaWptlN+cOfSg+leAa22WdGf/
8aIYmuE6zxMR0lm2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 468->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1sKwkAMDH6Ivx7BK+gBFq9QT7CC/SoI9UP8y9G1KDI7O+m2C9lnZjJJ
2sP13vUbM3vsPlOXn+dxzK/Ldjrc8nA6DtPj/mcwkpmn7/o3K1fHu2TVcMbx
HjHIBz6VBoGT96xDnYHfI16lzRo4ilPUCd6UzeUmfSgPpRVjM96VP8dZwFfw
qF4qHtaUAj6hu+IBrrCuUR5Ut2ZfAiznz3yMUTVk/Gx80lL9K4Kr1Uv1za7R
gj6qh22eN+nsWfk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 469->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0sKgzAUfLgobj1Cr9AeIPQK9gQptCuhoIviLke30lbGeZMEGniGaOaT
N/F4e/aPxsym9v3o4+syjnG+HtbFPQ7n07B+7L4FI5il8Jm3sv0sv8NIjAv0
HjE/PtvvdxpKq+Bh01Nr4E/CjzurOJvDCTzqIV6V9AAl9ahP7BW1GZ8y+112
FT7mcVkqHnEfinyZfLnX2b6WcgK9ai4ZLN8r5mOM6iHji/rkxf0rgquWJXr+
xwvuURnWeRbekFj7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 470->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU1sKwjAQHPyQ/noEr6AHCF6hniCCfhWE9kP826Nr8cHuZNKIgW1I0pnZ
nU22p2t/WQGYuuenz7fDOOb7cT0vznnY74b5cPMONxJg6TV/A3H+nJs/d8MY
l2ifcOY5mLuCCdwih4LXr6kGpV/jb9Ve88zjVUDl4ELqkU9cr9dmfFE3xH8/
8AUe5aXiEfeh1o+qz0DwetHXpTqdXrMvQlvVz3whV/EeFL6pj4gp7ip52uql
z/mfXIz0uIcm9uN4APxuWPs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 471->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0kKwzAMFD2UXvuEfKF9QOgX0hc4kJwChfRQetPTm0AM8mhkQw1ysLXM
aOR042uYTyLyvmzbkD6PdU3f53k/TGm535bdeT2sXNpvmzUpv9mv1s/yc15f
qZvvpYx3sQwrurd+5NXqIeCOvUW9R5rZfGaUgzGKBzppxEc4hotHnEo9i+l0
tT2wOmTGyuox3qROjgt1DeaAujXnAtiKfOGMPnyvCvhYs4oPPNy/gHo23obl
/A8XG8Nm6LRy6we0JVf5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 472->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0EKg0AMDD0Ur31Cv9A+QPyCvmAL9SQU7KF4y9NV8JCdTNalC1lxN5mZ
TPT++vTjRUS+zbb16dfNc1qG6/7yTtPzMe2XtyPype222RB4HqH2HusF8qHW
1rF8p4Fxlc7Fnytysh6YXsQo9E75gZcF1VDrtc0JtGR+SpCPPAU8y6kMs4RD
ZqwMTyp8Nv2FvgZzQL7TuQC3ot4AL+sDNKNn1fygw/0L2N/Jt5Hp/EOLzWEz
dF65tQL32Fd7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 473->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylU0sKg0AMDS6KW4/gFeoBpFewJxhBV4JgF6W7HL0KLuLLi4oOZGY0v/de
tGzHps9E5JPPW5O+r2lKv/djeejSUD2HxVmstl1az5s1gXM1tX7MF4iHXJvH
4h0G1it6b/2Ml7k7DgwvqRFx3/QNuDKjGM5qbWMCLIpYWDz2wZNwU1sH7jQ/
wKSsnuzrjPMMdSU4qG5HcwEOinh39GD/lN7pDzjct3amTjSHC1hsDJuh08qt
P816Vvk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 474->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKhDAMDbOQ2c4RvIJzAPEKeoIKuhIGnIXMLkcfBYX09aVqIf0lL+8l
bdl/2vEhIt/nOrVhaeY5/LpiOwxhelfT5nztFg+t18mawJrzH3iBeIbNxCca
AJPkYwPuFTktT04v5FSGY7xOrcyoBmMen2KMo0VRi8OrEBOtpDa1vLCneMC6
e6yPDOvL9tX7o8h39i5EP6uf9SP5z+buNj9o8d7sUh2sF6S+My02JuqBXM3z
BzoHVvU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 475->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0sKgzAQHboQtz1Cr6AHCL2CPUGEugoIdlG6m6NXoYvJy5toDUyCzEze
Z8xtnIfpIiKvdt2G+L4vS/w8mu3jGVPfpS15/UW+NKybDYGT5bFfoJ71VuoL
DgyrwiHjTHAUcWp84U5lfQyX1GjwAzlYHA/P+qSMTyjrrA7UrlCTnWIwkKPt
R+3O3AruREfNZ5tzPf3HN68fVyhrsR/9YG9Kz+IDF29mh3QwL4i+PS74r+IM
9+/5Apx3WDg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 476->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHhU/TICK5QBIlYIEwSJviohtQ/Ez6NDpD7M+ZwmUtomtc93
Z18erzyfRGQbf49c3rd1LZ/7UA/Pslynpf4879usRLbAm30jBuIx7H0piVfG
A2tF94wH1FGsA/eOu8FUkkfrkhiF/L8z6MI4Vs/6pIxP8nGWB/bK6Rfx/jCO
Nh+1B31z3ImOQ59Bnybvca9vmBvWjnrX8MPNM3AOcSPthgud2V4dzIuWl8Fq
zWofzhdenlZ3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 477->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx6kV5/gF/QBi1+oL1jBngqFehBv83Rb8DDNZLYubEtnM0k2
nfNj6ocDgFe3PPr6vs1z/dyP68ezjtfLuB6eftutQtvXQfXlbR7DWIFX3Cbw
xlj2w3xqUd1Y0+tQPXh3nCb6pK7AGPVLLnGW6pUtPvOyyRO5brg/EPNRHn0/
3z35b8bemQ9/5Ez3sxIzVv1BG7F3T9vYbyOPMM/kmf/jrj75CDOX8fCcqSxa
WSZLzjSdtXm+rrNW9w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 478->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2I1z7BL+gDgl+oL1hBTwWhHsRbnt5WrYTZmWpgu9tNMjNJ
dne+ddfGzO7b6dOVx3EYyvO0mX8upT/s+9nZflYyNwt/76+V7r+7QyxYuI43
xEYMJxqYHsRjBveZZzkHq5NpT/5wksd4SUxAPsUiPjqTzCFmscRjvuKtZmd1
DNWY87F2oTlQO+IhDqsN6guve/yrZ/kt0HzBHaj3n34IzUzTKj/oqN6cwiGz
ZHOQvRRG3zT41nFGznZWtA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 479->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNks0NwjAMRiMOiCsjsAIMYLFCmSBIcKqEVA6Im0eHAkXWy9c0kdL82Z9f
be/Ot+66SindN+9Plx/HYcjP03o8XHJ/2Pfj4/Y3w7CU3L7rZ4b7/2qwxfB4
D/tEbWqYYFA81FMD9zHOtHf4u+KFplvpJ+MKGzc9i1zjTdYkxpipxWRPf1f2
ZKnoSZ1a3QWzk90E11Ke8X8yrws5i71QrQs0nLwzZ8ZUzIqpGh8cRc+16Ije
4L6Vhb0aa9im8wI+hlc4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 480->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbnq5VK+PsbLqBdNM0TSYz
7e587fqVmd02r0uX78dxzI/Terq55OGwH6aH26+DJTNPn/PtkP+dKgbzuUet
nnLOcxiDwsP9lFEe58wx7+oRNsh5y1xR40l7wTVxIDXBGQqrwgJ71nb7e6fS
z1WfSHeBWe1X4FrimXSTvC5wxruEuhAHav+QjwpmhSn8xgBToVlrH/EPcNyK
BWtYw7Y+T2UVVzY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 481->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQDB7Eq0/wC/qAxS/UF0TQU0FoD8XbPt0WDGwmM6ELSbNpdnd2
Jrk8P8P7kFKaT+s05OU+Tfn7OG7OK4+367j9PP9HbW7rVEYxC1+2hnjvnYc9
xzoGGBgezEfMTftl7RDvPWxhD+MaXBEfYFAD+4ocUE1iDYa1g6WpGfuNMSJf
5C9qLXUnmFl/igtqRLeGU8EZq0c1UW8gEe2EX/VhdTy767K+4KDRbG8efANE
k71Y4hnUUN7zyn52VVd7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 482->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKAjEMDS7ErUfwCnqA4hXGE1TQ1YAwLsRdju4MWEleXjoG2mnafN5L
MofrY7hvROS5m7ehvs7TVN+X7aLc6ng6jsvj/ru8aJm3tpoU82Vn8bbas4c7
xTwFMDA8GI+IllxvZwV/7WEzd+gXcCX+Cv5OB162BrQnxpZiBSzIM+PmfJJ4
iN/GDfkSzIxfVgsmFiurZ69mihgk+oYeA7fQu0R3PBLM2MfVGSNcMM9qHPwH
SE/+xcJmGt/ozP3kA1ScV3k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 483->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwjAUDC7ErUfwCnqA4hXqCSLYVUGoC3H3jm4rBiaTGe2DpHn/eZ8e
rvd+2KSUHrv56vPzPE35ddkuzC2Pp+O4KPffU1N081VOoQ6+6p1q2/hl72KD
TbCtyuXkWIfhyzvIPwgvxygy9mtwGf8g/4qnurAHciZk22AlLAqHqs35oIzx
Y1ybm/ZA1ed6oQixqn7anpE9xpD+qgdqdoav6jCYUfc3P2FpZrY2jvgHeCZr
saidZp3d0Q+9ATJYVj4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 484->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMLB7Eq0/wC/qA4hfWF1TQ04KwHsRbnu4uuJBMZ6KBdjftZJJM
erg+hvumlPLczdvQXudpau/LdnFubTwdx+Vy/13RrM7bular7sv+S8Rahlfc
DmOIZbnUue8D8VCfVXJOcNibJXmzeIP44ENfXgM6k9LzZLX4WIon/Ss+lbfr
g/Gg9kSPgM3mK+pBjVUscrB4qgGbnfBDH6Jmf/czP9TSzexfnmQOSktlnd7k
reU8HwEjVvs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 485->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMLB5krz7BL+gDgl9YX1BBTwvC7kG85enugoV0OlMNpN1tM5NJ
muPtOT52KaVlWJcxvy7znN/X/fZzz9P5NG2Xh6/X5rYuxYtZ2Nl3qmO9F48Y
zGOgoYfr8LnKE/S5tedO4rA2Z3k7eYq5aZc5sB/A1+gWWiKWxmNdhA/7hjxY
B+XB3tsPPtHneId47J/CIgfFo5Fc5VzOD5njRgPjVTMWtDRv9i9P5x1kL4XF
GIyVc17ZB++fWLw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 486->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU1sKwjAQXPyQ/noEr6AHCF6hniCCfhWE9kP826PbgpXJ7CR2IY8muzPT
6fZ4e/aPnZlN3Tz1+XUZx/y+7peHex7Op2G5PHxHGZ7maR1rJFjV3spcb+Vz
DfMk0tCqa+B5jQf0eYrnLvL43VzxNnhQkxrsQXHOfkB4sqi7ogVrQz7zmMZj
3xgnYOJK54ELNVjMkVoqeti/Wi1jNL8L6uc8s+AH30l/Ra9v4oc99/BWnPAP
iJ77qwWwlKd4J3vuFx8u/lp5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 487->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRQcX0q1H8Ap6gOAV6gki6KogtAtxl6Pbgim/f35MDCRpJ5M/
byZzvD37x87Mpm5e+vi6jGN8X/fLzz0O59OwHB6+cztSmJc88wiwq2+6n/7w
d3ECMSgeq9gNGEQOCX3Aj9mVRgr+Xi0OMqnJNZAcIma2J8VKLMU84RxZlB7X
jXWcJu5kd7GQwbxPy31Z11IeIt+f70IMGz+yod7KrOorer0aX/SKe+cGHcdJ
LM21KGnQmey5dXwAFjlavA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 488->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtHggvozACjCAxQplgiDRVyWk8kD8PDqtRJF7PqeJ5LSpnfPd
JT3dn12/E5HXYZq68r6OY/nc9vPiUYbLeZiTx1+sh+k0LbEMdU/2DvuN1FhS
H/oocGB8ZOO7OA5EgyWckDvDMK1oYX3AAxboAePBegYcifk/p0ynyxtwzfDM
1ZvGPPqwGsR771PAa90via+ZDqK3ei7AIfgOa/YfMM141zf7k7si0KcFJ/AE
Ls1eZBiQq+N8AacjXLw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 489->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtxl6Pbgi3pz/8tDmSmbZKX
30xO92fT7szsdRi2pr6vfV8/t/348qjd5dyNzuPPlsvLsE02LfaMMSHfSYyL
+MQugYGGeeq7BQ1EtwtNqJ0xFtrYwnzCj4zEKlwHq5l4lv2zJvWfwR9rrPGi
di/Zj31gZ6oVNViOQS7TyvqrZhT1Y+7WHae+C96sWfQX53yzPpkVgzqSQ+6H
zuI/vVAM8K1zviewXH0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 490->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKgzAQXHooXvuEfqF9QPAL+oIU6kko2EPxlqeroGUyO1Fc2IRsJrOz
m72/Pk13MbNvNS9N/NXDEMf2uhzesX8++uXytnpuKczL5pvhOYgY4NLqjEkK
b4AF/J+D3TyW4ynke4YHjUoTa1ccmTZlXLvgRw7HhfGjnMxHpv7B1ck5S/0z
3zfW5Th3dveO67ZyzVwT6uL+FmeO+sZvj/5Y5VF8qJXvuXbJK3KzDjVzsgfi
f+QsnulFiYPu9nkm3adceQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 491->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8EJwzAMFH2UfDtCV2gGMF0hmcCF5hUIpI/Sn0ZPAgmVLicnAtnIlu9O
sn1/DU13EZFPNQ9N/j7HMf/a6xK8c18/+mXztro3TfOw+WY2TmTNxLo65ijm
W74IA132ubiuyc8uX/74TFOk3WLQ/gQ8mKfJu8ODuhT00noQDyyqRZGXaCnh
KXBbnbQPZN5xYd1CemONaGX9Dd8c8OHZI27GowTPasV91EJxSxbcI/1DIh4P
dQa1nNFSes/ncCa5blr5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 492->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0EKwjAQRYMLcesRvIIeQHqF9gQRdFUQ6kK6m6O3hRa+LzNRA5OSZPL/
zM/v6fZsH7uU0uswT21+N8OQx26/LO65v5z75fC4xuew6zxtsQ1dcx85tgbv
GTGVL8JgpDKXNZjyMf9LTcb7EX7Qi8vj4Gt/hS66L5xuP8Sr1SLDyOvV4vBR
G7518ZaVr3KppooReYbaal3UN/Qc+Hg35JZeyUP/FP+B40/6/Cd+1OF6ztPA
eR/Xi/9oEWHgrI4zAUtuWXc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 493->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qA4hfqC1bQU0GoB/GWp9tCF2YnE6uBbNs0m5lM
crg++vvGzJ676ejL6zyO5X3Zzh+3MpyOw/xzv3hr3k1H9WodOcYpxxevsfru
fBfxshoZLnPiGNdFrpwDea74Un0Z/4Yj6mN/QZdEQ9kP11NcBFdnXMVF4LE2
2ayDDuKJWKgp1sh2punNWl6sb7pzhMd317AVDu8PaqPwTOT8hE88sjkGDcR8
5C7+o4XFvtd2PtoHj59adw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 494->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwkAMDS7ErUfwCnqAwSvUE4ygq4JQF+IuR7eFViZv3ps2kCmZNHkv
nzndX91zZ2bvw3h0+XMdhvy97SfjkfvLuZ+cx1mjeBqPRRdJoOW9RdtnLe2Q
g+EBzj+HwkVOeCe4YYxDfMk9cID6VC0Bl/znKao1MLCHLupx5RccaG2EC8Mr
e9OcNfZBfXEOkKPqDavN6plV+wPC8DB2DZvisP0x7WfvYxM+8FBzbOYhe459
2coF383aztfyA/ZvWbg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 495->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwkAMfbiQbj2CV9ADDF6hnmAEuyoIdSHucnRbaCXz5qVtIDPk+14y
7fnxarsDgHczHm3+3IYhf+/HyXjm/nrpp+Bp1lIsjceiiyR3K7+zbVZvy1qP
hzLn34MVda70B9y4xsQ85mIcr3gp4XlFve9TYPD8EDZ0bhUPOMjZBBeF53ej
eFVv6W/l53dQ/db2TFzVfsNvjvC4dgtb4qRgNwEegvpNfOIRvaMRJtf6uZnL
7l2gnDX6Z9b7/AAaZVl5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 496->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4hfqCyroqSDUg3jL022hhclkdtfAbunOTjKZ
zen+6p87M3sf5q0fPtdpGr63/fLzGMbLeVzA47pieDdv29qig686t4g73HfF
BZ5zvpUTdHBda5xXtCHHRT8OGONJlwruV/AxT6gBHPYw+GiWvEo+FjTI3oQW
Jw57k3Qxp/YOqK2Sr+izekfT/io+YiVumg2qr+rwu6bZL3jIeLM+6ajOBHsK
XOybtfzthcVe1Uy08/wAaf1a9Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 497->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWAAixXKBEGir0pI5YH4eXRaiSDnYjex5Li1c/bZ
8en+HMYdgNdhOYb0vs5z+tz2688jTZfztAaPPy1FZTmyZhFjPT/KuJr76mEN
TtkvxMHjg4Z/g5vFqNOPmliTmyfcL/VqFUENnpUKzZH4FPEGh67eUGMy7m+d
uiGHyDbyNffQ4uHPN+yDdpWxm7MI6vC7Vrsv/gw5XtWPJOAZ9kFYe5d3rysH
KAd9d3PBFzveWTI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 498->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBBq9QTzCCrgpCXYi7HN0WrCRv8moDmU9+7yUz
h+uju28APHfj0tXXeRjq+7KdLrfan4795Nx/NYqVcZl1luL27IxoMxdjKpfx
fIzSBCu1Q9gpxzg/407c0vkwhuBnJarC4DpGvJhP8KuenZjAbWxo8357ghs4
LL0D2VW9v//Q80E+X9kH/VXOXZyFwOF3bf5+yWfI/gZfieAp+6BcH8tcVtUA
1aDzai74APOzWHM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 499->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1hBTwWhPYi3PF0LFaaTSddAFjaTTCab
Pd6e/WNnZlP3Pfr6uoxjfV/38+Veh/NpmMHD4mCFHONGcc6BmEOOZ7WLOffZ
8kwrxy2JU42LOYN21p/1VTNSnpe1N3uAjtU7Qq4zLvQwpuaWWsh+PE69GQ86
lXGdmqP1D1GP4kn2hBjWqv3IGVSe2Gv4+0VrZTz0z0y9l5iltUul5R8O5Ap8
hG3zfABOj1a2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 500->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADFK9QTxDBfhWE+iH+5ehaiDidzNoEtnRnHzPZ
zeF674cNgMfu8+nT8zxN6XXZzs4tjafjOAf3xeh0YoxDcM0pWC7Gvq0tJyvP
P4u0Ko4VvCNux8/atS7iNfWa952NWshBOhZzFHwRN3o0VuVzXjQ//Goy5XOf
qmfQx83F9Vt9h6zH9Qn2xDGuDfdi9Fd54lc7M3xQna38okPn03IPvbdqaZqF
9pD/Vi3AGzprWDY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 501->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0kOwjAMHHFAvfIEvgAPiPhCeUGQ6KkSUntA3Px0KEtlJp42lVynjsce
T9L95dZ2GwBj83q1+X4ahvw4b6ePa+6Ph37a3H3NPQmw9PFvc/HZR2vC21q+
wxn3WTKIXI5zXTGDRXO6PMWtwAk88/tpwxZiiMefphQ35gqBJR7Mu+CCEjf7
oHZRU9SJdJH1lu4hnXWoq5rDzxxg5RkDhfZg/uo/SLGGvL/an3iwPjVzMA/m
UqUF9eN1LRfgCe7bWfc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 502->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU1sOgjAQnPhh+PUIXkEP0HgFPEFN5IvEBD6Mfz26okS209nCJkuh++jM
bDneHm23AzA2n0cbn5dhiK/rfvq4x/586qfgYfbZws9TWN6zGGifc7DUp7V8
1dvmMA7nLHcfBkOFQ4ZVYJQxi41N8RU9ErmsIRyZpk4vhUfFPN4FFpR1/1X0
Lnqq1fK0dV6/2j2kWUtdPR6Ws6h1ZwyUujN+7z8IWkOOr55POFifLTwYB2PZ
rAVyrmqG1Tv6tTexkFj3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 503->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk0EOgkAMRRsWhi1H8Ap6gMYr4AnGRFYkJrgw7np0QDF2Pn+KiZMUZpjp
7/udsL/c2q4SkXs9Pdr0OA1Dep538+Ka+uOhnzebJZah7zD9zl8h8GZzp2Ef
jei85jnIQDlIreJ3cQxYR/Mzxuo7LyEbDuaXaBhEqQeeg/pBHcKzuo/AtyE/
DHP5jIvmB1yYF+qhJtyj95X1teTDeya5xTt2/FjHr+l/oLyHuL9ZHziwP7/4
QI5/WEzXfcS9WGcE2H5ZNg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 504->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0EOgkAMRRsXhi1H8ApygIlXwBOMiaxISGBh2M3RFcX45/PLxEkKA53+
vrZwug1tdzCzqXpd2vi4jGOcr8fl4R775twvznq1dYWPpfDbv83orvagkb4a
e+dDHsMMkkPkct8bMHAe4MtYBaP0IZtaXK/QSGReD5BD1sM6Dgv7vLoT5eWF
fVNcMt7hUnG7eqSJPp5n1levDqxZxJZmvOk7xcn/IOgesr+Ynzi4P8Xvi85u
5v8nC9aqZljWeQKu0lh5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 505->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIb7BFs
MGZAo7GxkcxogJmBpqYBm3oGNDEkezHcgcUufOIN2MQZUOUa0NXZY1eH023Y
ALrfsZjRgIZxhQGyO7D6B90cHG5Bl8Pl7wY0e9EBcrhhcxdW/fjCiRTz0MzC
sAtXuOLyB1o6QXcDoTjGCHc0fVjzAQ770OUJ2o/mDvTwIZi+0NRixD+JbkH2
K7pavG6BAwDhP1b5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 506->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIb7BFs
MGZAo7GxkcxogJmBxAeBBmzqGdDEkOzFcAcWu/CJN2ATx+KmBmz2o6nD6TZs
AD18sJjRgIZxhQGyG7H6B90cHG5Bl8PlbxS3YDEPPS7RzcGqH184kWIeNreg
hTXWcMXlD7R0gi5GKI4xwh1NH7ocLvvQ1eBMFzjcgZ5mYWbjTV9oajHyDKE0
igYasPgLXQ6/OQDfa1b7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 507->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0sOgkAMbVwYtx7BK8gBJlwBTjAmsCIhwYVh16MriNh58zo0KTD09/ra
uT3Gpj+JyPPyeTTxVU9TnNvzcujiUN2HxXjddJPwVQ3/71UF3kHSGEnP+sth
zjSW5TB1EYeSWjRnyR8wKfoF7udiY4L9khwK6nFgMXr9u3aDBW1e3wkWks/y
5s6a7QwT6DHLBz60J+Ca8ur1AXuC/45mnPEOcWhjc2X3w92LAg7k+nC/wDe7
M4zLglgfrFfEsssbfPRWew==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 508->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvebquiiTTmV0LbWkynUmm
3Z2vXb8ys9vmtXT1fhzH+jitp8OlDof9MCW33xlGMfPy2d8zxH87i8N9L/lM
7zKOoJ3qiDwEy+IUD3U44krG0VysjQ3UIRwOU3kQa1T9y3yoBXNKM8UJn0c+
okvvz/m0wCffV2hRX1UfoBfx9F2ghsZ3wtf8fdEzYhb1oY6/fLCMaXwUvci/
FQb1EXLzPT0BQGtUQA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 509->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMLB7Eq0/wC/qA4BfWF1RwTwvCehBvebou9pBOJqGBbjdJM81M
ero/p3lXSnkdfp+pvq/rWj+3/eY86nI5L1vy2FYz+S8V4xf4lyBufAUMjWoZ
hpS+D/SxjmGOnG85xXMWL8ip7Y0Z8k0wKBbpMePT4YCp9LuNR9y6/gNuFtfi
0PpMJ8IxnAfrQXzM6UreK7vPnh+ZsdOd4Lm3n82VzTO6H/oY0gE0cDoGXKK3
ZY3qCLmc0xcd51V/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 510->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbn66Li0ynM9VAl22aTGaS
7M634bqKiPvm/Rny4zhN+Xlaz5dLHg/7cX7cLmex9DklwT3oPxk/3AthFJer
MFLUPPhwnvMH1OXYVMfIOOYObwW5CWv0djAkluDYcDFYjgu/Od0Vlz/wGEfm
mz45jXYe6FO1XF/Fvqp6mPNrxrLvDg919Oaq5unqEw/uNWtRPWj6aLS43UJj
3Vivu+tfewHIiVY+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 511->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozQFegAESuUCYJEX5UqlQfil9GhagXO5S6tpURxHJ/P
Fzf3sesPZvY8fbcuvq7TFN+34+w84tBehjl4XtdqYVkpON/gHMS98xNg0DPk
MA4p/P2irm3cG9QSWAk5eTwRy7gRy/RjejkMiiU4FtoRLMUFY6rvjMsOPMSh
+eJ/sMdiduAN5QI1qK5kXlk9n7P1x1R3hef7ED37N3IuKjx26QAaIA/kUmBU
DPv29apcfvYBNyBX/w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 512->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk00KwkAMhYML6dYjeAU9wOAV6glG0FVBaBfibo6uxYrhy0sNTJnMz8t7
b9L95d7fNmY2de9PXx+ncazP83ZOrnU4HoZ5c7eMJcpntOJyw7wk6y5vwJBz
3FEcWvnloa79WTfUAk7KyeMpvuRG/gb/Es4NQ3lAHooLsRjfNe6F896XRJfC
I468n7yP19ighbxUqFoBJ+lXVc+fl+8CDcF3gRd6IdHsz6R9AQ2+pvJhtb+E
F+q/UBpVSB+xt+7pC64zVr4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 513->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsEJwzAMFHmUfjNCV2gHMF0hncCF5hUopI+Sn0dPQ/NQTncS2NiWdNKd
fHm+h7Ezs8/5tw31e5/nujxO2+VVp9t12pz9vnYr/9WKuxuci3iHfI9BzwZ5
CgMX5ql3g1o+LutJxdnxrUGct4N+SX5jWIwXagpxTfldL+gL8X72ghfDQxya
n80HzqqvYEQj33/4P6K2r+fj6VygftCd4IW/IDgjh7Q+8GGaBwyiQZiD4BJ4
EKM6gi/XdAUOrlc8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 514->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk8ENwjAMRS0OiCsjsAIMULFCmSBI9FQJqRwQt4wOFRWYl+8ES64S2//H
/k1252s/rMzstnl9+nQ/TlN6nNbz5pLGw36ck9vFF+venju3N6y7IA6855Br
Ay7ioBMXxQPeZk9Rnf3GMurC8yv4rLjUXNQUdTnK2zfGXFHv/31lLvKRR+L/
0CdjFvZVmNDI9y91dabO8/ethZe64/2oXDQz8dXzoY/SvOCgpqL205OYLwND
IwfvRHMmewL8MlW+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 515->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvebouVoyTSWygyzbpTDNJ
ujtfh3ElIrfN6zPU+3Ge6+O0XjaXOh320xLcttWsvJeW7/9PTAI/7BU5Iixy
Qw6OA7GZXxqe5VlMLNNTgIPpw/xFcr0Gr4yL6bLn8B7kAfv4MObOY+8DXciH
+VN8R30UtGBezoLZSutqjN1n5+0fntadvB83Z4HmSEPPe2E1dxwJj6sB0afA
j4Yctod9PXkCCW9Vew==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 516->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk1EKwjAQRIMf4q9H8Ap6gOAV6gki2K+CUD/Evz26FiIMszPVhbTdJnmd
2WwP1/swbkopj93nMrTneZ7b67JdklubTsdpmdz30aPCvUKu5orPo4/E4Wdm
wxrJwHVrOnseTmeFuTU/lRjKnwrHpv3hWKJuYbQwj+P7jr+R1gNLnhHoYG4Q
l/dL3egT9jldKUxvrdYVQn0P++2fM0515xqqPjOenQfrnXSomqd/yHBSDYS/
ID4HM7gnfp/JG/rpVXs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 517->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0Kg0AMhYOL0q1H8Ar1AINX0BOMUFeCYBfF3RxdhRHSlxe1gSiTmXz5
rfqpHQoR+Ty3Txu/zTzHpXvsh3cc69e4X5ZZswT118ruxD+nrJSBPGZn/hgH
80S7ZIYTI92pJ3DGT31MPLZiotIcgvUxcZADctgwhnmPfRdxc0duAi7dGcxb
16n8vLwMJ5z7X82IxdM7d2fGpu9kd82eOTmj/z87xnpuGIxDZpiAe7ZbWmjv
1N01ZwUVxlT5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 518->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUssNgzAMtThUvTJCV4ABrK4AE6QSnJAq0UPVm0cH1BSC/ZyokUKI4+f3
/Lk9nt1YEdHrun668L7Pc/j0l+0yhKltpu2xjjsu/h7C8Z8P2+lkMpj0LpyJ
oeMhO8JrXirYf3k4HJLLB/kpbYJ4Fb+nTcCGGthiDI+O42jRHMYf+Tnadz+y
+iHe6Q8BHNSVmxlHT6lHiC+dORcPeqJnCeYC5jj10/h/ZgzV3MQozAbSYmqZ
WbB2yVs5zgJ9LlV5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 519->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMtHggvozACjCA1RXKBEGCVyWk8kD9efS2IlLN+ZJApDRNYp/v
Lj7dnv1jJyKvw/Lp07sbxzRd9+vmnobLeVgvj3nmoZ/FNP/rdva1qoQcvzet
YGA8nuuGISUczGPnXgepYTU9LA60WUmLq8+4mfJJOQAPw3oqkVOBC9YI8ei3
CPXVPJ5E/jT/h/cx0IK8Ag6rKw1fkYPX7PnU8smbYC9RLdjH2OOQ/0+PMc8D
RqM3GJfgZWVQ79xdG2cG0uJXdw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 520->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU8ENwjAMPPFA/TICK8AAFiuUCYIEr0pI5YH4eXSoCGp6vobWUprEsc/2
2d1f7u1tA+DRfD5tep76Pr3O2+FyTd3x0A2Pu7yy2Hdzy2cbdZPdEHzKu5vG
cPZVGDZiYAaHbaWe49HZa/UoO6pttpayHmHjppfMgfJwjmeIOZH8dBwj2DPf
gOR1goeYv/Rf0B+nWjivgKPi4g+vhZRzxRxV/UVPeJZkLZX/QfmvmTHFecBQ
OKKHJfeBy4own+tx3l/hWLo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 521->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksENwjAMRS0OiCsjsAIMYLFCmSBI9FQJqRwQN48OFQHc/20IldI0if/3
i+vN8dz1CxG5rB6vrlz341huh+W0OJVhtx2mw3Ud9dHnZFq/9bM3m1VI459J
b0G8oTbyUKfXhMXrsv0on2OK+Gjt44At9YY8yGYaj5ABOAy8XjGWnTsWzEHx
WG+8k+N4+wnzk77x/xjcBbmIB3rDMp+oJtKm/aYP6x70LvVZcmcf05qf6uD2
yeNHbxALeIS9JfNY5P/P5w5Bw1h7
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 522->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMDS7ErUfwCnqA4BXqCSrYVUGoC3GXo2txoG+Sl6kOtJlPXvLy
ksP13g0bEXnsPr+uf56nqX9dtvPh1o+n4zg/7stXln6NadnrcldZXSAGe7wz
4m8OS2Mo4DXhgnyVcMjyASfGL5yJBub4pTgWW2r8aiySN6ufvje4BH+vt0jg
jrqhxR4FfNY3qX3N1eJ5BT4sr6zoCivDNntMtPCz7mc3zFlSM/r8mj/oAPch
RmM2PGfUqDlbUvt6/v/FeQNQ/lo4
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 523->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMtHpAXPsEvgAPiPhCeUGQ6KkSUjmg3vz0UugydSZuseQszngb
53R/VnUhIq/jZ6ni+9q2sbsdhssjNpdzMzyWo44SfqphOX9VzB4WFzX3xAZn
hp3tUIOyGpivZ2f5WN0Mk+kVa6OxN7ia8jKlsUBnHOlfc+9OLQnezl6E8jr5
4K7B8Xfmhlg1vdC6ySxWsWSDV5CcrztjwsWKR/J38c3yoRnM3vwJD2DfxQOZ
If6JJIYjtuf/4/QelVm0
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 524->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIb7BFs
MGZAo+0RWhrQ+BhiSGxsauHiSG5owOYGbHrxiaOby4CmDpe5ONyO7jYMvxAR
VjA3YcN43YasDs0/GOagAzzxhh7uDOhuwWEfTD+KOdjimEC8YejDYh7WcGVA
02+PqR9ruCIBYvTi0481LeDgY4QFWlihqyHWfoxwQBInyh9Ywhw5TRBMW2hh
gTUNEW0OAM2UWXU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 525->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIb7BFs
MGZAo+0RWhrQ+Cj60dRjiCObgWY/hhvQ7WEgIM6ARxxdLzZxLH5Fdhs2fxMK
K5hfsWGcYYgeJgyY6hpwyeNxC4Z69LhnYMAafjA9yDSyHqz6cbgLQx8W87CG
K7p+e0z9WMMVCRCjF59+rGkBBx/FH1jCClf6x2s/tnBACiOi/IElzJHTBMG0
hc0NWOwjzhwANnpZdQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 526->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpAfBmBFWCAiBXKBEGCV6VK5YH4ZfRSKIp7PruN5Kaxc2fn
7OOtbx+NiDz3n0+bX5dhyO/rbjrcc3c+dVPwMNu80s9Kqv9fE9hThRQ4L/Bw
3/g1B+Q3NWAeWfFL4Cc5DWcQW9Tn4RheKhbN1VBZIe8xPLiCvhVSv9cjjP+x
WD/FI4/Yu5rXm59II6yH6qqWyUewER61R5/pGZlj1BLnK8zPdFAabXoH6yGZ
EXe2WA0k3zaeEeK+WTQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 527->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIb7BFs
MGZAo+0RWhrQ+Cj6kfnoatHNQNOP4QZ0exgIiDPgEUe2E4v7cfkVOXyw+ZtQ
WMHsxYaxmoWGG7D5B90cdL/iiTcM9VjiDpebkOMUWQ9O/ejmMGDXhxEeeNzT
gMc9WMMVCWDYh0UvPv1Ywx1L2sVIZzj8jKyGKPtxhAOy2QTNwRaHWNIIRloh
4AZ09cSZAwDcf1jz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 528->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfELU+HwQDjut0mZVWT2Emc
bo6X9rwAcF09f2267fs+3Q/L4XJK3W7bDcH1aPQ1QDTv82Xk/57kD85RPN+R
+y3HmP/Xg+sHE35U/FzTzWl651jojAZnufHDqlku4XFaQ3l01sreSrNZ/WQP
IbU/uUW88sDjMj0q/YT2gwldDTYq2CIe8LoLTmO6V87jnFn1Czow9xwdOLf0
RrK3UtEim3s2zwNHMVn1
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 529->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3PF2ronF2krqQLk0yyUw2
m+O56xcALqvHp6vX/TjW22E5/ZzqsNsOU3D9NncKYOV1P835P7fzm89hPOU3
flWjCA6KD2b8SPy+p9LpYhE3m8HJ2vhi2RpugoeaNbgOa03eLZ07oPVRHvOX
HATnH52I68m5grg6Ldlc/Wn6CWyGl3MnHMd4X424y/eM+gdz8LWNYwLrc6Od
k7tHJ9SNf+vcAe4iWPc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 530->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMRoML6dYjeAU9wOAV6glG0FVBaBfibo6uVZHP5M3YQDptJj8v
abana39ZmdnUPR99vh3GMd+P6/njnIf9bpgvNx8VSWYlvc+Xiv17ir2oj9rA
P9gpRwIG4rE/dmKjmtSn3NXYCsX5d2AriTWwAQf24/MQA7Cgv2dp9FRcbZw5
7IbaQxzNg/6vOVbppTVXlVAPYlvxYe7A/zNj2GP1U59F9Stz0NyejWLVt7Zz
uHtOqn3b0jwPr5tYew==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 531->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDV1Itz2CV9ADDF6hnmAKuioI7ULc5ehaLfJ88zI1kJlOPi8v
SffDrb82Zja3r6PP99M05cd5tzwueTwexsXZrQqSzDx97reC/XuD3TEGbSK+
sCuMJDgoPrZhV9xUTdUn+CJurvL4W3DzpLXgJnjIfhiHpbK36tyDnpziGKfA
VCL2E+HJ/RpxhZzaXFFUva29qPo/fCmPffy/OnGX+4zqB3NAbGefyMVY5lLM
oiJh3/YvzhOYeVhA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 532->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS6kW4/gFfQAQ69QTzCCXRWEdlHc5ehaFXm+eZl2IM00ycu8
fI7Xe9fvzGxqXp8uz+045sdlv/zc8nA+DYvz8BU4yczTR78F7D8NdscYtIn4
wq5yJMFB8TFhJ11wU2+qOsEXcXOF47vg7EmL5EA8VK+N8wi/4lLEr8wIcTgf
5q9yRpwKnKpDzd3+OeCcqn0N6oiwNbzsO+HYx3PlXvJ+Vd8P+oC5nX0Ci7HR
zoW7BSes27b29Ak7eFe+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 533->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeYPAK9QQj2FVBqAtxl6NrVeQ186U4kGaav3nJ
y+587fqVmd02r09X78dxrI/Tevq51OGwHybn9ityipmXj36L2H9a7K4xaqP4
eI+1JWaGgfAY2INusBFu6lN8nmBzyot3wOyFJebHGXrEAniIiyXemt4MuAvH
5U2aBdXMMDV51AfxbnMMytPiXJM+slzMB04cbE0vsMdxlshnNsNkDlrbow9y
NTbbkXS3rI0lDv/j5AmL5Vd9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 534->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sOgkAMbVwYtx6BK+gBGq+AJxgTWJGY4MK469EVVPJ480ZnklLoj/fa
TnO5tv3GzG6716NN99M4psd5O310aTgehsm5/wgcNwt/61nAvmiwB8agTcXz
O9eGmBUGhcf+2BU2Fz7FE3yhfE4cS3wEtnAtnM89XMWatqtZZFiAf8bNxOzo
fP2og+rKfwtMWV6Bo8LBexHES/a1kF/Klfm/ZkJ57JOYxa5X4Qc82V2p7QPv
AsVV95Jw8Azr6jwBn1NXuA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 535->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwzAMFD2UXPOEfqF5gOkX0he40JwCgeRQctPT27QNyCNNsECxY8/I
o+XymPrhJCJL8/n0+XWb57zez9vPM4/dddwu278bSyKafuvXzbnb71gwTSWG
7i1eAMNcCBbPMS68r5GmQCNq23PTiId7ok0DR37Rg1TyjmI5Qy02/0Cz6x25
V9QU1TyKQ95y8SyW5RXMxmFdCV8JN+TDbBR6gYd3rAfY6yr9Ro+bldo6ABZr
XV1L0IHYujhvHkhV9w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 536->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhR8upFuP4BX0AMEr1BNEsKuCUBfibo6u9QeSlzfTBqZJk/n5
8jL7y60fNgDu3fvT58dpmvLzvJ1/rnk8Hsb5cPezYiTA0nf+WLHfrP++NCzV
Pu669EftUzEoHizsc16qb4pJMDKbMR/VrNaOjiZMMpCZw2PqbIHFq9m8HXSc
MZPSXPGoWiofa+HkUPeSuga9Y05soxFp0uhOcXzmvQH3elhf6MDxsi+C3jCV
A+1dQpbAdxULXo9yVzA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 537->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwkAMRT8upFuP4BX0AMUr1BOMYFcFoS7EXY6uFdH052faQNrpTPjz
5me6v9y6fgPg3rwfXXmcxrE8z9vp41qG42GYFnffdNEC1v7Hfj6Mfa2Lz5zX
yMa+HvOanwYnYq2cZ13a3xSTYGQ2Yz4VrC00OCUDpSU8ptYUi3tne4beeR7E
88/4BZ8M0eOgx14kGuxx6itpKObFvpAnwXf65jXFqu56dX/hQ/hXaj6Is3AP
w/1fw1KpXcWCF61MVjQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 538->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU1sKwkAMHPwQfz2CV9ADLF6hnmAF/SoI9UP826NrRXCYzMYG0maT7HTy
6O58G64rAPfN+zHUx3Ga6vO0ng+XOh724xzcfpWkAK38bPYHm3NJPj7G6NkO
o5DPKWKu9cNwKyam94WjcmvKz4liGwxVx0F70Dp8mos5LvT++013V/MQ+YdZ
OjH1cV/dPmQ4Olfb12R3tJbuXBjH9V3OGnNcszmnO0Z8wr+S9cHUwjnas0X7
nmEs5YIXZDBV9w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 539->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBxS/UF6ygp4LQHsRbnq4VqcNkNm5gu9tsdjKZ
ZH+5D7eNmc3d+zOUx2mayvO8XX6uZTwexuVy911gvZn3vzP6wxljwT4+xFBn
lQ9iVgxeFmOlnzlTfq9xovqZmzM/ZYwtMHgFfYUGXuHj6k5xAfubs/YW4yzm
Db1UJvrqSY3NOJbomswO11LtC+Io3TNtKlzXXfQ5nTHg4/Q21UHUgjGsWdO8
ZxitXOwFjehUew==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 540->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD2I1z7BL+gDil+oL1hBTwWhHqS3PL1WRMfJbHcNZMlmk8kk
m9351l8bM7tvn0efHsdxTNNps1wuaTjsh+WxfStIZ+bd10Z/sDEW5OVDDGWr
ehDzwWC1GCv9zJnqe44T9c/cnPkpYWyBwYoxPzUAxzN8XL0pLiAKK/SV2wPI
ZZyAqUT8qxd6LOEwHzXXf3NL+WHua7MRe4xxzKdYn3iwXdUH8xT/X7Xvaxi1
XGwGgblVfw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 541->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD1Ir32CX9AHFL9QX7CCPRWEehBv+/S2IjpMJtt2ICWbJpNJ
do+3R9dXZvas50+XXpdxTO/rYTnc03A+DcvP5muA1iy3fx/jzsdcwCeGHMpX
/SDnx8FmPlfGWTP1z5Emmp+1ZdanwNyCg83tl+8BcwtcRS0AxeXmErWZtDGP
41TAO6C+0YwhT6BH7nVn7Vq923tpN+IdYx7rWe1POtjfNAfrFPdffFuAkGOr
FpsA1KdWAQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 542->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADKr4wXlAkdpqENA6IW54OQwg8x2GN1KnNUttx
ujtfu35lZrfN69PV+3Ec6+O0ng6XOhz2w/Rz+1kQxczLb4/5sMdaiHcOMdRe
8UHNF4OXxVqZZ83E74kmp/5Zm8Nq8SfoI4wUi+dQSFuCFSLxQmEZafk3W4ca
rAuYKsQMfKHHFCfRM/M182XhbpgL3Q++i7mFdyb8ddLSxE86ZhyZD8oDwW+k
P31bEMjDfG09PQHZa1aB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 543->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwjAQRYcuxG2P4BX0AMUr1BNE0FVBqAtxN0dvK4Ljn/9DAilp+jPz
5md6uD7Ge2dmz/36GMvrPM/lfdltL7cynY7T9rH/zjAGMx9+67if1lEbxmcv
xmBr1DMGNkEn95EZ8rtgcqjfoW4Ps8WfxAcxZCxkFboUR3kAXlA95KjdrQdN
1FEGwZR8FnUwjsjMeP58rfVo5Wzym8TAfsH/J/UZ8RdZWvPLHMoHcpZ6Afzp
TipesD5tq2kBFKFWQg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 544->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU1sKwjAQXPyQ/noEr6AHCF6hniCCfhWE9kP826NrpdJldsYY2JJO9jGz
2ewv9/62MbOpe3/6+jiNY32et/PPtQ7HwzAf7hYLq5h5WfcRT3vh+8Eizvyh
JuXADOMULvJ+MWf8FtwV37KeS41Yn5w5sRSPXP/MpXJgL5S/Y13LcbEvmCf1
JS7AU5+FDjozoBH50L4SHRgr75joSH6QL70Pca8svsU/cmGz3Jwv0MHuP3H5
sWIdNhNtTS89eVb7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 545->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sOgkAMnbgwbD2CV9ADTLwCnmBMZEViggvjrkcXEsTy+p5Dk8Lw+n3t
cLw92m6XUno246Mtr8swlPd1P33cS38+9ZPxMOsoOS1vc2ePL1KxG+IstxfE
ssuBinEKF3m/GOU446b6zT+75Aj1jdiMKPNZ9Zrr/aBN7g95Ov9QN8U43wfm
CXPxAnjgJXjQOwMcsR86V8IDY+WORY6VH+6I/Utkryx+S31ZozYHtQc4h17+
iK/D7kSd0wfS1Fg6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 546->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgkAMbDwYrj7BL+gDNn4BX7AmciIxwYPxtk8XEsRxOl1osiy0dGba
7h5vj7bbmdmzGR9tfl2GIb+v++njnvvzqZ+Ch3mNlmzZC7yjfzEVByucp7DR
2JcAgxfnRf4A9+uTNc7+EulNv3hYI/G7egnDYYm6sBc1PRxze1QnxAvzkhXS
wTiuL1S7wkLeSJczOhesR/a1xm1eQy1f/sczUndJzFXlr/KTjj+OtT7QfLDn
PD95toQhD/Ntm8kH+sFW+w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 547->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwjAQRQcX4tYjeAU9QPEK9QQRdFUQ6kLc5ei2EMP05SfthzTJZP7/
M216ur/6587M3ofp0YfPdRzD97afN48wXM7DfHhMY0JneY5u7eMZtXVCJE9p
ezDWOQ0O8mrxiu4/Jntkjaw37WPX6BH+saLPUfCV/ko9PCtmdy7zVV8E6qDO
pvfCXOfb1EM/Bd+EjupBeQtuiy/z+I3Uv8Q7WOGv+qOOhYdtuF9W5i7ei+rR
cwHvQ79mLRk/MSFWOA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 548->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAngFONyCx
kcXhABcbChrQ9WEzGxmgi9kjmYGEMfQiy5MizoDDj4TcC+U34HAfhn/s0cIC
ixkNONRghD22MMBmDhY3YHMjVvXobsEVV0h60c3Bqx+N34DuLyz+wAgbNHdg
cw+KOdj0YrMbi158+nGlBRT3Y8tL6GkQS1oiyn40d6DYwUBE+mLAVIsSLtj8
iAcg24MtDgn7CQB/7Fa4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 549->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB6kV5/gF/QBxS/UF6ygp4LQHsRbnm4LS5lkJ6kD291sk8kk
Tc+P9/A6iMjcLY+hfG7TVL7342o8y3i9jOvLU10Letl2hTPeb4jOFerjGLf3
R/TAAYv5Gf5/7yWocU9vtTXQZzhYPOEwXJH+JE/D4xHENv7YY98jwqfgo46X
zgyxsYcKe8iX1IV6DA+LZbnJXRYfzYLRz/4l318yS+FcBDoi7nS+pPU1PWA1
JsA87Bvu1/QD7rJV+Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 550->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Ea5/gF/QBi1+oL1hBTwWhHqS3PN0WljadnWQx0DbNZiaZ
bM6Pd/86iMjnNL/6/L2NY57ux+XnmYfrZVgOu/LMlmT7er40/GIacKiXb63k
rTzJwdrzf+K2JvBi7wpaFXtDjRLgCUfFxfpPJGbiOx40B1vl2xnjjAiXmpwK
w3aG/CvyER3VbBxdCvXpXKPaJBbh6S5g/+DjPdheUUuzPs4B/HC/LFb2OWz/
3d0yhhx4h21NP+RUVnk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 551->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvebq7IDidTLoD2XbTZjJJ
c7o/h3FnZq/D8hnq+zrP9XPbrz+POl3O03p4/NmCYv8121vcO/rB5wlHdr9B
AQ4wZw1olpwpvyX6bDunszbB0a2XOAKX0p/VWiJfQBIr34i09Pgc7qQxqv8A
F3m5jtCbpC7UE+ZHIOQWvl68nAXWn/TYhFauZTM/94H23fnCWGvv8Fx3ZwvA
HPyGkr/BF5ibVrg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 552->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD2I1z7BL+gDil+oL9hCPRWEehBveboteJjMTraBlHQ3mcxk
c5le47Mzs/d5+4zlc1/X8n2c9p+5LLfrsl/2f99sIDcRWx07nsOZJxhZfrAB
MMCdOTBfdafOLeEnuHNPZ26IzbHSC1qaWOodkhkEHDKeYaYz4POMBJ5DTlqj
tCfcnLRUOWzJblQ4qlb1tjiPo3q5C8w/mbEJrqzlsD/PgeLmfmGtxRwnvNZu
oTEGv6HED/YDzvpXug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 553->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB5krz7BL+gDil9YX1DBPS0srAfx1qfbBYXJOGkNdNtN0plk
0uNtGaedmT2G+hnz87Ku+XXdbz/3PJ9P8xY8fFa11FhG+/dcrcAZfUXl090Q
IwEGLJenasSYBf5EnKIfjClOVxtzEr/qDTEiLOfraOBwyFjDqE+HzxoJvAI5
4Z1oLqK2Qr3IOhlL6NLUtcVtXo/e/R/dVf2Bxk6r4J13+VkH4vhLBzFDfnet
t4WGOeEMmz29Abu0WHk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 554->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvh2BFWCAihXKBEGCV6VK5YH68+g0Ekj29ezUUprUce7O
l5wf0/A6iMj7tH6G8rnNc1nux/rzLOP1MtbN7jfW6JMhMJu8/vMmak6xHtdQ
76I3GGa4Opsj592MeQn0Ee0RJ+Ul/Js6wKBYzPuGB4p7tk/EI30yPzM8NTXh
mcR/1KbQC9WJWIQ39TXjFu/Hnjve8KD+wGOnOXjnTX7QwTiaOOQOXW3jbdmw
NdEd5j19AfedWLo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 555->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMRgcX0q1H8Ap6gOIV6glGsKtCoS7E3RzdFrvIvPlCDKTMTyZ5
zZfzYx7GQ0rp1a2fIb9vy5I/9+O2eebpepm2y9Puq/W72zXPeGfPjZX+525e
azYWZwUcVZxitHeKje8FE9lDNmV8L7gLXMWoPKoHVR7BqvokNSKLo63lIH/D
l/x9UXXxH01/nDkkT6SRqkfdI42bOtTB6XHF7Mx5WB8cqkaYR2jIXruzBbMx
jP9Pky8FOFc4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 556->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENgzAMjPqo+DICK5QBUFegEwQJXkhI8Kj4ZfSCyuO4nGNLRsROfGef
m2Hpp0cIYauOTx+/73WN++d5HsY4t6/5TNaXH9Zdjv8c4xzGwVL3d7MuGt6l
WCIet3uKI+YUt1I/BneXmzLnPdaQtTgG5xIfK6fmJDUSuLI3eMv8M40KlhQu
9ZHNx9hD5uNppPA45mmc4ZAO1owD4ak9d/GJh8Jw6wgN1d7J3SLjHVAalnv6
AQz1Vvk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 557->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD1Ir32CX7APkH7BvmAFe1oo2EPpzadXYZFkdmJcWFmT7Mxk
su34Hl4XEflc18+Qvo95Tr9ns/1MKd+7vCVvZa+rL1ufdUycHOZLzYJYeGa1
EFuAx9RFGsWJY07ziOI9q42t4L7GoFjYl+cB6Pe4mE/Yp8H3/AP9BsebETsr
DRUvYFT+sDeq4oe+HnGTWDTjiqe3vnoeC/Cxdx7ygw7GEeKQGaLXZ7XovOlb
LEb1Rvf1BzBXVTY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 558->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHoqBoMEe
iQ8VgwN0OXR5qJoGezT16GxsatHEYBimD0UdITcy4BBHk0OxA5lPhNuw+h3d
fhxuaMDmR2x+Q+Pjcg8uOVzh1ICuHtkM5HSAzW9IegnGER42hj4sZuAMa2xh
xEAgXJEANvvQxQjFMa40ihE26O5Fs68BTY4Y96O7A8UOXO7DohfFnehqSXAL
zjzEgGoG1jQFBgALIFY4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 559->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMNHmUfDNCV2gHMF0hncCF9hUoJI+Sn0ePUxSQTye3Aie2LJ10
Op8f7/HVhRCWvnzG9LnNc1rvp/3wTNP1Mu2Xg6xiUVaxHNVZfNWf3WuLggG4
XnxGn+Qf68ir4lo9aB7ojyQG/JntSW+Uu8L28pGfwWKzZzPQNRq12JwyxmsM
b34YhzjIBfFhb7QlPEyfjBtgunNVxuqhz80nGpo8MhvsudKNYDTfmOrF1FD+
nzxCHYP6/dsLvhumoavl1zbnUVY4
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 560->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHigfhmBFWCAiBXKBEGir0pI7QPx8+ikUh7O5a5gyW0S25c7
O+fHa5wOZrYO5TPm921Z8ud+3DbPPF8v8xY8VS+WqhfzFPb1rPmzuLVxx3xc
B3OC4cE7TMYDOQhc1ONYD9z3uDEtEVvVoz7GgfZNaPWAqWJY65ifIN8IHuYR
HEfeptfdbImOjifTBpiyr8HYfXj2a8bqjdLekDk0cyMYu/djH+Idih+pbXiS
+f/LRepmONS+WLpXOg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 561->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwzAIRHlU+WaErtAOYHWFdAJXal+RKiWPKj9Gj1P5QY7DLRIJBnxw
4PPjPb46EVn68hnz5zbPeb2f9sMzT9fLtAeHqkVS1SKazLn6Dn8Wl2NcMR9t
I0ow1KjDZH1gDwEu8lG8D71Hcecn9V3PhBvDcj6YQwuPxdicXH4Sz5fxg10g
Tnif2G63hAflhdwAM5qrFfau0Pdrx9EbpbMhe7CchWA06+McbA1jN3GwT8j9
d5bINdphuMuvbO7+WXk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 562->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwjAQHVxItx7BK+gBgleoJ4hgVwWhLsTdHN1UAj5fXpIOTNPM5735
tMfbY5x2ZvYc0mOMr8uyxPd1v17ucT6f5tV5yJokZE3iAe7Z9ncqv/38npVx
W/FVjA5X1W4al/txzle1C3+RJ/h7vXkFq7DxLBp4LHKXJuID8Zjp/jCOcbbk
gx1rczi9VSdgKK7WXFEKbmHr7bjgofrlfwCY2DPvusvPc0AOeG/icJ0Uq/qr
ifwOyFfd5Vc+UphW+w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 563->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHigfhmBFWCAiBXKBEGir0pI5YH4ZXRSKaL2+ZLUklvFvpzP
sc+P1zgdROQ95M8YP7dlid/7cT0843y9zGvyVDxbKJ4tBXUuMfNnednyqTjy
tvBVjk6t2v1/HwTvMMFiqHbZ8EYbGtRo9VbjcjF8C6hleMDoLIXg9VvizEl/
CWo7nbX7Kq61UT6mk/UGnN0ZCa+HenozdnUIn9slxak14Kx7+rUWuq97+xCL
ScHH6e6B0T2AXGuWIj+/8Vj5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 564->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQXDxIrz7BL+gDFr9QXxBBTwWhPYi3PN0WbNlMZqIDLel2drKz
mxxvz/6xM7Opm199el3GMb2v++XjnobzaVh+Hr7PDLcNeV17iKtYyFtjWXFa
fBLbdFznqvzCB/Arjpec6B81MtbG0MiP3pRWFcNegJ9CB1D1EPcgWr/mFXmF
DstnwN47Was6mTfQ/GdGrH6sQeazvgu96i7hPWvMv3nGQi3VHqRG6cNKTuQy
fwr0HBA/apZmH2eDVz4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 565->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sOg0AIJV00bj1Cr1APQHoFe4JpUlcmJrpo3HH0atIPMI8ZSTQjPOA9
GC+PqR9ORLQ026tPr9s8p/V+3j+eaeyu4x5sP89mTD+T75mV3/vYxekfF59X
qSdBDTnQK8o3Ohw+w7DFSIGbeG7IDmqLaonXi2ah9Jg6iEvQw+ARrjZz3xfl
I/OzZ3BWWKiLcK/SXFGu5u85hPlo7kG97F8Ce452U7xjiku2R+2v6SDbS2OR
vsjgPQB6ol0SvQGLiVa8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 566->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk8ENwjAMRS0OiCsjsAIMELFCmSBI9FQJqRwQt4xOK1XF+XkultI2sf39
/Z2e7s+u35nZ6zA9uvy+jmP+3Pbz5pGHy3mYncdlTZZstZKWfXLn/k1++/mL
5kW5vh5gNDwgbq2n5wGu9lMU1+MF2EV7VNN86ZVWqL/igJ4VDnEBfxPvtaTZ
BXEVDuWTqfYJvl0s9mVca0tXyvX8lcO/GdMdRT2sjiEO0R0J6wsP+scifJ/r
62lsw2ODS9i3wUzQvmmkVvk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 567->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENgzAMtPqo+u0IXaEdwGIFmCCV2hdSJXggfhkdkKA45zNYCsTJ+XI5
5/H+1d+LiPS3+VOnoeq6NDbXJfmk9vVsl837OuZQ+UfWNVezbv9sLvtajjCM
dzuPcDgdgRas33LGixwZ72D5CLfTxgLr4a5shP4jD/Gz4GFayL7DWy9P+mtx
BQ+rZ4HeK5kbrNMpUC875shXVmv1o4azHrM3Sv2QEsM0RG8kPB90uJ5pzI9+
5AB76CVEeG/GQ2MCEmZY9w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 568->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENgzAMtPqo+DJCVygDWF2BTpBK5YWEBI+Kn0cvVLRNzpfEUgh2zs7l
7Mtj6oeTiCzN9unD6zbPYb2fd+cZxu467oftsTZT+Znp4WsUj3f2L/+YAcYQ
D3mWqeF4ZLhg/tdndUUJRjmG1XbcmGE++Gxl9cc6hGtSh3Eh54mvKa7W3xiH
dVx+QR9j99Y4MJ3E95P2iOQavMXpVXgDm1GM0dknHDBevR94OL0K84V6UA2A
R40LnQPyHjqjH3sDjxRZ8w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 569->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRb84oF4ZgRVggIgVygRBoqdKSOWAuHl0WhRQ8vOd1lKqWLX9
n2Mfb49+2AF4dvOnj6/LNMX3db849zieT+Py85DObAF/s5B8PmjcMzOKMY6n
POMaKUdyAJU+5/98VRdBxAQdo2pXbMpUvxmbOiqm4nBYizqKpaVBnKzb0gTr
qvzG+5jSXWNQe4p6nnJGIjfnZ4a1GVfzc3zZBzF4O+LqE0fRo9oLbzdQxvCb
bmWReyD6kTv6tQ+Mslm0
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 570->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OiCsjsAIMELFCmSBI9FQJqRwQN49OKwWU/LwQLKWtm2/7
OfHheh/GjZk9dstjiM/zPMfXZbs6tzidjtO6uU9rsWBf85D8kP3P3/SdmYvG
VS9xrjlSTMXRYNH4j095LYAmsIZyV2xk1G/GRos0FUeDtchDLL9qCGeu69U0
rasMnfNxqgu9490b6yquBg/xK0Pvjqtzh7nF2QcGnc1ufeEoeqS5aM2GlRoX
vn9ZcJ5aedDeablYtg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 571->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMbDwYrj7BL+gDGr+AL1gTOZGY4MF469MFs5oynQKTLGzZ6XZa
5nh7tN1ORJ7N+GjL6zIM5X3dT8G99OdTPx0e6hqh8odpjdV992+2dzDgWJbr
+R41J+hItGD+L2b3ihKOzjnGtGfaGLBf6JUtxgkzJFoF72FalmqATqwbegQe
3mOojwFnr2QP9VLfEC+EuS7kev2oYe0fh7mTumzGTAN6c7U+6PAx9UXmDZlz
WC9btFA/wVnq0S8+Oc5Y9w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 572->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMRC0WqFuOwBXgABZXKCcIEqwqIbULxC5Hp+WnZPpcGMmN00zs
sePt6dpeVmY2NOOnTbdD36f7cT1tzqnb77rpcPO2EW5fZC/2tKoJZvcjv+SX
8Ne/HOWSeHr/s6e45sDxmpMd/EgbQWNLrWTYf9UBWk3jkJYgR1kn8qhG4Wmc
rPoI0J+ZL/koJmnFvi7MaKlfNfx846B+rCWYBXrbaC4iHdivhfmquFZzqJZ/
tGAf5Syc0Sce1axX+Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 573->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB7Eq0/wC/qA4BfqC1bQU0GoB/GWp9uCyGYyIw1s221mszOz
2cP1Mdw3ZvbczY+hvc7T1N6X7TK5tfF0HJfk/jvmcPtFeJ6nvIvvLgIwodb2
eNgrvKvjYi3+h3qsrjnBeMYE4664scDaoJUN6j/yIFwN6zAuYo9yLohT3np+
S7/W+gOaA3gWzSxHvKCeER2lF9aesdBPtYheKBjTfaF4FM9ZX6jesIxhWv75
2GtRd6qcCY0PEmxXfQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 574->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMtPqo+HaErtAOYLECTJBK5YVUiT4qfh4dqFrkXM6ApZAEXxzf
5a6PV9OdRORdzZ8mfephSGN7XjbP1N9v/ZK8/MYcKmuY5nvMr2uGw/Nba4+H
u0xdHQ3O4n+ox+qKEgxwMyXrqDcWG/2Z8lHoC3yN1PrvszqsF3JHgWe4SFvN
51CvHX38XZ6fQZ/Ue5gjWlDNCI/CC0ffOOBPuQReYB4LfRH0wd6x8EXkDckx
qP2ejoj1vFgd6tFvTOJAVQE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 575->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMNH2UfjtCV2gHMFkhmcCF9hUoJI+Qn0ZPUlxXPp+MBTIWlk53
km/PT/8+Oefmy370YemmKazD+QheYXzcx+PxGn0375KJz2N8T3eWF+uF5eCd
Ycc4YaCz/lD/6y1Mg//jpxzgorkzjIwbswo/8dyLeYBeIVhaizCuJAd5sLza
fgXycNcFpjUXwNf6kKf1V4TUV+dq6Cj+QuOOiz5GnGkl/HFvLfyRh46b56B0
My5Mn2V0jgSH/tGvbW+uVv8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 576->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk8ENwjAMRSMOiCsjsAIMELFCmaBI9FQJqRwQN49OK4Vgfl5DLKWKG/vn
f9s5XO/dsAkhPHbzp+uf52nqX5ft4tz68XQcl8N9WrPFkM3ir6/neU9xKd8o
RveEnfyMoSvAP8n/3G2kIX7xc4xw8dwVw5QbaSCekF/FEr0GWF6LAVeKUR4U
V+uvSZz2usAkA3yvT3mu1bnI+VdX0IGz0JBf1J3y6B0A/+YZq/DwfnMdnG7i
QvrWzM+B3tfWkzcEzFe8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 577->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk00KAjEMhYMLcesRvIIeoHiF8QQVnNWAMC7EXY7uDJSapl+1BjKT39eX
0B6u92HciMhjt3yG+DzPc3xdtqtzi9PpOK3JfdJFgmTRUPo+n22qS/1KNd4W
iCc/Y3gViDW4KsXDBz/XuNktd4+hnps7s7CJXygxmlhOlbAArxKYmeauzrG9
UvfZf3NfxMfGDb7+w9PngA/uFebAu9DRX+2d+ugdAP+vd+yX0M5792DmJi69
uywwpK7tw3kDvFxWvA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 578->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwjAQHVxItx7BK+gBgleoJ4igq4LQLsTdHN0WQkye75kMTDv/eTNJ
jrfn+NiZ2TKsnzG+LvMc39f9ptzjdD5Nm/OQeKVgmTzUOvqzzOJSvrMYlI3Y
k55rIBuxCazO7OFbP8fA7CV2rOGIDXpWsohzwmwfjnjFrFUdJDFLsyfOBHnl
X+6L4QFM1VnB2Uic6CN46F4Rg7oLnfk/fYSO/cr85h1rkdhX1x6KuRmW7l1a
jVe9qf91PmE3V30=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 579->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYMLcesRvIIeoHiF8QQVnNWAMC7EXY7uFETSrwntg8y0+c9L
T/fnNO9E5HXYPlN+X9c1f277cnnk5XJeivH4kw1J/tBU3yt7Cs4GJV57/jaO
eZLJQRFHF/Sq0Nt8mqCjj9R+nK3hyDsHfuqIywf79fhjHiKYJarJ+QmFH3et
zNn7cw8jfdLm9OPyauHVg64X39QJ7sxt4xsfGewffXCuIR5Qz+Pem9GDfQes
N7aTLz9bV7Y=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 580->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVklEKwjAMhosPsleP4BX0AMMrzBNUcE8DYXsQ33J0N+hK+JpgDGTr3yZ/
/qQ9P17DeEgpLd36GfL7Ns/5cz9u4Jmn62XaDk/FV+tTNekLVnt17e0rLMU1
bnLJAVw5lDc8lk5q5T64BPkCjQIOoTbWRH0rTgw350G91vzIQ3N68Wqyf5og
zrxrQ6P75z1EdPLM0GPOVduPdxXJb+o4mNw6v4lJQf3Qwb5Cc0C9fb1beJYW
x988XwPBV7Y=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 581->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkV0KwjAMx4MPsleP4BX0AMMrzBNUcE8DYXsQ33J0Nygl/TV1NZBtyfr/
aHJ+vIbxICJLtz6G8L7Nc/jcj1vxDNP1Mm0/TzHX6CWF9rE2vfRd65taY9o6
4yXO4UwcJtXDEEuv7INLgadHBYfSGzWh751TJ9150K83P/IwKnuraVZ3BJx9
e7sutHc82fup59PhUgf/c670QD309vCFTqUmN/1nZ6TRP3zwXk1zgF7yJHm/
xUvB8TfPF4W/Vro=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 582->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhYMLcesRvIIeoHiFeoIRdFUQ6kLc5ei24E/mmzejBlKaafLe
68tsjpf+vDCz62p69Om2H8d0Pyzn4pSG3XaYP66fOUX3SQ/v7+gs7+N5qP2F
Eeo5PM4SA7VTR8TknDqvaCOWY54ayenURk7wqz4XKf1QONhDgcOo7K3GWd0R
5qJ/atcF9xdN8f9c6RRYLualrzVfyIezwiPMKx5VE5v6sx5r3IuGDkM271f0
wPId0vtftRQYf+M8AFzNV/c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 583->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRQcX4tYjeAU9QPAK9QQR7Kog1IW4+0e3BW0nP39aDUzJTJP3
fzI5XO9NuzGzx274NPl57vv8umzH5Ja707Ebf+4/MYw0B5LNNaN5CuouBzG+
c/BezyDmxFC+eJ+qB96YVXnyudAEe3N1pa/4ECE9KA71oeLwCPoWaYI1aIDW
Rb2utFc8+fNB+RQsiP3yXoM3Gr6FqC+CwToqL84q/BdrbOFdLPhgjdU7EHqT
Jyvrv3ipGH9z3iLuWDg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 584->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKwkAMDB7Eq0/wC/qAxS/UF6ygp4LQHoq3PN0WRNPJzNJASpNNZibJ
6f7qnjszGw/zp6vTdRjq+7ZfgkftL+d+eTx+fbbydy+Wrdi6DvMh9ogR/h17
t2C0dMV3pVXUS00xJpyO2kKe8TN8J041MBy4Q8JBE3dTnI4cxvsc+Om8rTsI
XNw5nZvMgHroXgM/48Oc7DdLXLQPdqNusKqxDfrZLMDBtLHeyPfT1JpRWMIo
+a2N8wES0lc6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 585->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbnm5XFhknEzWQlu1mMjNJ
d+frMK7M7LZZHkO9H+e5Pk7rdrjU6bCf2uW25xKlp8EbA++K+A5n74nnFp5x
iJ7vWkgXXFJP5kP08h94F7q8RBzXBR9JD9Ur+OJ5QE3ow5HsLeNMd0Q4J37p
V+lhTayHfEjfwgPrkXMF/oAVGlK8WeCSOJpNtoOPGvtDv/JCHEqbwiIfziL1
mAT34B1+/Udf8QQW3lZ7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 586->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwkAMRYMLcesRvIIeYPAK9QQj6Kog1IW4y9FtpUhMXqYdSMs0yfyX
THq4Prr7RkSeu/HR1dd5GOr7sp02t9qfjv3k3M82rjKbmLfAt5L4zV5n8/Ha
0nD7X6wxBS3kIQ0Xr8QE+QpcWmKej2vxKRgyeA5fG53jV1JLpol3BHm2f5po
hP4DU+BZwwk+y5X21ZwRcoEhzRcJWphH/0Gjl5ZnUZ9qAY7gc7l/dUu8v7Us
dg78LC7O6Hd9AO0oVbo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 587->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeYPAK9QQj6KogtIviLke3lUFi8mbaQDqkk/z/
k8np/uqeOxEZD/Ony9N1GPL7tl+CR+4v5365PBafLRUXcwr8S5V7E2txn68t
Dhf/co0rcKEe4nD5pI/qFXRpir3YOGA3MAIW1fl5mJyA463SS40T34jqTK8B
13M3NBHuqk64U1NbnavBWHuvZr1I4MI62jPQ/5cjG/RTL5aDMAjLzW7zvoPZ
PaCdaO7o1z6qzVS6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 588->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0kOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQNz8dinJwJuO0ltLU23js
uqf7cxh3AF6H32PI7+s8589tvyiPPF3O0+I8llMkuTsJG/tA70W3ciQW4wWY
lpw9iRgE9qgGxUt+It+Ezzw/5osONup8U1iqL56H6MWYq8cSvUQ1ua/qRsuD
6zbzUrKC2+UJ7eN8OVdXv/u91vIBXSfQGZv5VzHYwF/1EvBv/iPK9TzUvm/l
4vdA7UR3R//yBatfUfs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 589->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtHigfhmBFWAAixXKBEGCVyWk9oH4eXSo8MO5nEMtpakd+3y2
k+PtOT52IrIM389YXpd5Lu/rflXuZTqfpvXw4MtFw67EhmcC/66bL4qFeAmm
abAr8ZHEnuUAf8qPxBs5s8gP+Yq09XYwGiwWh/0gtRhydTHEiPaEVzp7aXlg
3qZfTP7gdnkGDJq311eM1TY2nXGCUfklOmJjbZWPbOCf9QHeCnKh70FqP5zf
Vi7xHrA70bujP/kAHOBRew==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 590->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2xyKG
LseAxobyG6CYKHNxmNlgjyRuj0UNAwFxHG6DiTXg8w+SHIY/kP2Hro5IvyGb
gWEWNn+hhweaGhRz0EADDjdijSNc/kBSh+4OdHOwxjs6IGAuhnnYzMFhL95w
RdeLKy0Q0s/AgBnu2PTZYzcb3W8oahiIcD+ucEDLK+huwZVPkNWhxx+xbkFO
B9jSBGFzAE9HUf0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 591->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeoHiFeoIR7Kog1IW4y9G1MIv4+jNtIC3t/Pz8
P8np/uyHnZm9Dr9HX97XaSqf237+eJTxch7nw2NNRFfTkncHLGq95gKjeA3Y
wGEqlU72Ej145i0/4WzhI/ojTvVNNDiSNSk/dZMH4YlGOaOWj8jX4JFzZ2Q7
EDXwv+Cgn6hH3utKLe87rQeG2qUXsauuMLZBv/LCHkKL3EX7x3F+W7XEPVA7
sc7zBVWVUkA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 592->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkjEOwjAMRS0GxMoRuAIcIOIK5QRBgqkSUhkQm48OlTI4Lz+BSm7r2P7+
3/Hh+pjuGzN77r6vKb/Oy5Lfl+3q3PJ8Os5rcF8MTypmnW9Crqh1laNwDbkW
6pUpnuwlejDmIz0h1ugoZ/4rT/0LjAYr4hGf2lIda+YYdDri9IkluVvLo8IZ
zYEzQNyph+cCw8Ej8pFzVTqs5h+xR/W8Q7kbmA13rbk3oaHbn3MIfo+b3EWr
84j1L5e4B71dG+N8AA6TUYM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 593->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQbDyIV5/gF/QBwS/EF4ygp4AQD+Jtnq6BgNXV1TM2TDK91VQv
h+tjvG/M7Ln7fsbyOs9zeV+2i3Ir0+k4Lc79ekAGOJb8h194hTv6nV3ldjAq
8mhxIj6oZ9ycr5Ev61htVeX17gIjw6qKB/eA8kO9UGclP+tubmJGDo/6iDY5
d5ZsBwRG6A3x5Xn2+qpwwy5k+fR+eCfRFV/k4GKswb/Bw9WYcJO7aD6Osf7l
gvuU7VrYOScfcFNSwA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 594->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHigfhmBFWCAiBXKBEGir0pI5YH4eXRaFKnx+Zw2Ups4ti93
l5wfr344iMi7m399/tymKX/vxyV45vF6GZfkqXzzSLLOCWKWF9gXm1dWg71l
KMHQZOeQE+OTYlyXa/RTHWVPWd/WmmBEWMp4oAfQ7/QKwZBVf6TN+Sy2r84p
cKP33uBkcAmG86biyu5zy1eG695C1A8c3DlB7DgDh8jT5vnAw2gMuFEfxdYh
1i4udY3YNeqhb/Q/fqcxUf8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 595->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDggrjyBL8ADLL5QXhAkOFVCKgfEzU+HSjm44xmoJTdpkhmP
l8P1Mdw3ZvbcfT9De52nqb0v2/nn1sbTcZwv992TeXITK7sHfDicZSxYEI7w
5So1MU7XvEUf4iFOyaOfBcP92ydOdKoBdWANAF/yNcLRLfA91ptpN6ibgX7V
d7VPsRRHqU3GId5W1JXwlllQeNBQ4jjUlc0Z0YB9k/p/6FjkKLQxbI7HuFZp
gbxxtkpPqH0A+uZRwA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 596->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRQcX0q1H8Ap6gOIV6gki6KpQqAtx16NroYufP/8HHZgmJczP
+5M53qbhsYuIZ/f9DOV1mefyvu7Xn3sZz6dxPTxsCdFDhlnVOdQvW1aaWEux
GA1cLZPS7L1uoK5ionuSD/SnPLb2oMkpGZiDe0D1yW/UPvFcvhGzNPRwRTb5
7m5PPGp2Um+ANdXHD30VumkWXD0xpHuYX82Z8Yxh+RsclUfDpmrxPjcj//Si
0nM6Mj7Xg1PC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 597->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRSMOqFdGYAUYIGKFMkGQ4FQJqT0gbh4dKopkXr4bLKV2k/j7
f8f7y72/bVJKU/f+9OVxGsfyPG/nn2sZjodhPtwtC5ZF7H0W++6+LetrxlyY
BRjey5rcB2eFm4BrzEcdE2cW5bVih8klOZAHe6BwYBZoqe6rfqzgee+5VZhr
MWdE6YjeN+h/s6+o57VwPqp8cKjqkH/W2EpzpCGsDx4/GgNuKtfXi2bkHy5e
N++2ZvRjL/0GU4M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 598->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2I1z7BL+gDgl+oL1jBngpCPYi3fXpb7EKcTIIL6abd2XRm
ktP9OYydiLyO62Mo7+s8l8/tsL08ynQ5T9thvwcsJbndlXw3+LpHWy2vSvDy
i7U1hEXGBTizui0q7A5jecBZje4xPZk/WS3GAz0w99Fzx4X0JNIW9lbANwH+
rGaWo2dMR9Jf5pnzI+sRzon6OsyDhnX/Qf7KazPNll/IP+GBGlMfAmw0I/9w
Qd2oM5vR71oAxIlTgw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 599->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMjPpAfBmBFWAAixXKBEGCV6VK5YH4efRS0UjuxefUUhrXuZzP
ds6PsX91KaX38ffp8+c2Tfl7Pyw/zzxcL8NyeFoXmDi+3cWJG7yuq1jxVRx8
2mILt9o8LCfGQbOSuOWvNImDc7S591q+4dQWl6cDe2DuY8+LKamlwnv9YHyy
nanVVnGyPkAs5Ijm2+oH0WDPFDjoXEBDlQfnID43akAM1R/owBrDPhAseyN7
tGDdWGf0Rv82A1WtU0I=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 600->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4BfqC1awp4JQD+ItT9diC9nZSdrAdtNkMzuZ
7On+7PqdiLwOv09X3tdxLJ/bfvp5lOFyHqbkcV5gSny/K4m78zavxRbfgjoL
MIStjAtwZrjVnQqcPKbnATmL6tZ8wEixGA/UwNWj5lWfpJfmPNMjwtN6pp5b
gxnpALEUY0VDjFV6BBx8zhIMyluCczgHbbHDN0gw0/uBB/a4CYfMEHXZygX7
xj6zN/q3L7YVVAE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 601->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYcuxG2P4BX0AMUr1BOMoKuCUBfiLkdvCxXimy/TBqZ/k3x5
edPT/dU/m5TS+zhf+vy5jmP+3g7LyyMPl/OwbLbrkujg2d87+O7ybV2/MK2V
OgsYiVZNi2gm7l9P38fnOL7BnkV1NA9pcIyIZaRDPSCOhAWzFPnkR8Rztao/
nB1YdB6R51RX9N3ha7UfMMKgPloH7PAfBGahv6KDvNnkwBmqp3u16Nw657an
EyuwVQM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 602->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkUEKhDAMRYuLYbYewSuMBxi8gp6ggrMSBGcxuMvRtdBF+PnJGIha27yf
n3bzNn6alNL3eT3G/Bv2PR/ToyyWvPavtWy2NVW8a+o1vjGhXmpSBvLw29Ng
mkEPJcT5r/eE+VV840P7czxQ7w7DYwnrg3g3HKLFvNA7IroYos8l27/rnbDM
zIBtPECd0b0x11CPMNxgOlAnhM160GfC/oM+2Gz+cnCO5C5vzcLzCnsx5wTq
g1OB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 603->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMXDxIrz7BL+gDil+oL1jBngqFehBveboWqmQnM8FACptNJjNJ
93ibh3FXSnl0n89Qn5dlqa/rfj3c63Q+TevlYXOwPoZ+sZ445NnmshZ7EIyv
G+vHuBCugYM7m89ReUyH16c0JNoMMBSWMR5Ee8ApLY7SQndE+qJ5/g2OmrmY
A8a8vmxvTR32/WOuaT+IhXkCh9AH6kxgIwefk/IXPNi78vUSB98A2aX8t8Co
VrjLcd5b9FIB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 604->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EKg0AMDD0Ur31Cv9A+YPEL+oIt1JNQsIfiLU9XwZbsZLLFQITsJpOZ
ZL0+Xt1wEpF3s366/GmnKc/9eQueebzfxu3ysjtY8ke/s2Sc5a6x7s5qldUR
jK9rKmPXOwX1QjiYWG1OlMd0WH2Rhoo2BYwQi/Eg2h2OEByihe4IuZBdWf4F
TjTzYA4RbjRzWod9/83VGOUMHNw8gYPrA3UFBnmrOMsj/JEH7srWhzj4DwDH
6tsCo1rhrq5pAdyeUcI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 605->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKhDAMDHsQr/sEv6APKH5BX9CF9SQs6EH2lqevgkI6nVS2ELU2mcxM
2rw+w/QQkbXeH0Pc+mWJ37E6Nu84d+18HD7PgBXIt30H8t/k6xkMQ1kdwbhC
Q7rPegenXggHs1fEYHlMh9XnaShoU8BwsRgPoj3DEYJDtNAZIRcyK8s/wfE8
d3xAfhke03BXf+erWdZPRe6en9A76wN1CQa5q+jlP/yRB87K1rs44B3mFu8W
LKoVzsqafrn9UsI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 606->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYMLcesRvIIeoHiF8QQVnNWAMC7EXY6uAyPGN1+qgf6kaV7y
Xrs7X7t+ZWa3zWvq6v04jvVxWk/OpQ6H/TAFt/MQK7CPa4Hz2bx8BmE45QlG
rOHl21/ULkm+QQ/Bd8Wge8Qj8ss4NLi5YKRY0IfLGeIY4AAXfCOqIRb7Jxx8
97hPtFZdkINaIx91BR7K5Y2Lekrthe7iawz/YJL/q3/tQ/X9C0e0U6zm3xJD
rhJrc3oCKMpUAw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 607->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksEJwzAMRU0PodeOkBXSAUJWSCdwoT0FAukh9KbRm0DTiOdvNwIZW7K+
vr5d38f+eQohvM7L0se5m6b4vlXr4RGHazOsycvXYa3YM6bii1m7u8IwUWfA
+OFv971n7in+CQfVk/WYTWGY58UZS/uw1xlccgAPQ4x8sjqKWeQbqR4wz1/h
yHf3+4zW1IX9pBXqpa5iDs/Z/wmpJ3onuuPMnPyDmfp//MmD+h7CgXbESjAK
JmdFrjzTB2U8U4c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 608->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRQcX4tYjeAU9wOAV6gkq2FVBqAtxN0e3BbXT19exgZTMJPnz
f9LD9V41mxDCY9d/qvp57rr6ddkOh1vdno7tkNx/HBYl5l2UuLcURzeMJHiT
2hzTfKlO+M842JvshzbD+OkzjaU4jH0JrhzAI+GOfBbnKFp0R/YGLOdvOLr3
PGZtnMaKt2JX5KNzFR3s/eLqPHOzuePMnP6DC/3/+JMH57sKB7Mn1gyjYKoV
ubKmNwCNVAU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 609->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOgkAMRRsWxi1H8Ap6gIlXgBOMia5ITHBh3M3RgUR0+LwyNCnp0PbP
7++cbs/mUZnZ6zh+mvi+9n38tIfpcI/d5dxNyfrrYgFi/RcgHi2FvxNGArxF
bY5J7tUB/xUHulP7ZTbi9puPZsxj4Db3JXHkIDxQVy9XmGULC3cO/AkH957H
WhuWseqx4uPsSvmgrjCH9s64qGdupLucNYdv0Okv8Vcequ8uHNXYeSNFLWxj
7r1cbABB4VVG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 610->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwjAQRQcX0q1H8Ap6gOAV6gki2FVBaBfibo5uC1Xj75uSwLRJJvm8
P0mOt0fb7cxsbKZPm5+XYciv634e3HN/PvVz8rDE0pL8t+YS9Kfm6Rek4aD3
t7bUpIjW6bzqCpMH/OqN2L7+yGPZB7bPPpfQ/Q4cWNcoB17K8ZYWnjnwkw6e
uzKBR62Lzq/8yLiqruCjZHZhw3raek20T3P0VvRN1PIrh55ZlY5yQu3DuyUt
9F3LYm8W11eB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 611->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKg0AMRUMXxW2P0Cu0Bxh6BXuCEXQlCLqQ7uboVbBUf19KBqKZSebn
/2SuzVB3JzObquVT5/kxjvn1PK+bNvf3W78GL5ttK8n/4yfnTP1llfQ1wi1a
Q3O1ppqXp+ego2jNgDbldtBHGrU+3Ld0xCGsAjywr14MtNCcCAv7R3mAg3PX
+6BR+xLRQLG/fQUde86qCfu583/yZK8xmgG9yxB/4aEzC+EoT5iJ2wtZru4o
F3sDkkJWfw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 612->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX4tYjeAV7gNAr1BNEsKuCUBfSXY5uC4Lx502awJROJvnz
/59c7s9hPJjZ67R+hvju5zkut+OWPOLUXaeteP6GrAB5gHyNJLUUflHg5fu0
V8OvcEC+qkN67+I63P70kUbtX7lfw0rAA331aqCF5kRY6B+dAxycu94HjUm0
uBpIn7wX19dsFb2t1IR+Zv/FOcm1RjOgd9nCX3moR004yhNm4nohy9XdysU+
ynhYfw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 613->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRYMLcesRvIIeoHiF8QQVdDUgjAtx16M7A4L15TfTQgaStD8v
yRyuj+G+MbPnbv4M+XWepvy+bBfnlsfTcVyS+6/hJOEn4c9WkCvpZ06vjqtY
pB8wSF72gdqrug22v/5Uj6wfvG9pFXLxLnqNci0WuSOyUI/3hI7cu2JCrVLF
FJfU4w5X5lofV9t8T26eqO3uwWdO7UD9lz385OCMunTIKXbSNQsL+u5lsQ9J
TVhA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 614->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtxN0e3BcHpz5tYCylkkvk/
/2cO13vXb8zssZt+XX6exzG/Lts5ueXhdBzm4v4T8iXIE+RTFKmV9A2HV5/T
WYQfzIDzgo7yD25jtoU+0qj8MFuBCLVpr/RhDbTQngir5Z/rA5y195WriBbn
A+GBT+oJzmBt7lqT81O4XZ/whlqAF/cZzVBxqkfh+zLupZ2s8sKWPfQmfmt6
AyAtVzo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 615->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMDS6kW4/gFfQAg1eoJxjBrgpCXYi7HF0LhaYvL2k7kEIzmTfv
M+fHq+0OIvJu/p+2fm7DUL/34/jzrP310o+bp6nMKlNlvTKXwp6WuRbzYuaj
XoafcKB8xfd1D27AbaGPacT7CTclFWqzPJiviIM+BFxoRsgF8XCO4NDzG96O
gpbIB7tchoDtfGVnE03OT/DBzcG9qRYhmbI8VzhEmaXvS/gsy2QrF6uVvYl1
nB8IDld3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 616->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhQcX4tYjeAU9wOAV6glGsKuCUBfiLkfXQmsf6TexFtJhJi8v
Lz+H671pNymlx+7za8rz3PflddkOl1vpTsducO5Hky+PFr3l+TSHtTxbiA84
vvkmnxpgUG9avts/vGvqoxp9ftBmYKTBMscQbuGDWjRHxFXr3xSnOM+D8ZW5
KRb5/HyCeXrDvooGijXRgv0EDnNceg9rcTUrproXoKE2s3C/EmNpJmu1aK20
E7953qKlWXU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 617->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeoHiFeoIKuioIdSHucnQtjhK+ec1YSIfJvLy8
/OzOt/66MrP75v3rh8dxmobnaT1fLsN42I/z47ZY+LpihrMDppwe/fa5O/0K
n3D8fMqok37qhrYvvuInb0ObqziVP4n3jAu9auGqnotaYuzSjJwxC++O3JFX
7o/QFbGSj/OBnioX5lv1S8VyJyzpp+BwcMV7WgtqZl9S/Vbj2aN0v0xj1Uz+
1RJrVTvR5nkBG0NYdQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 618->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRYMLcesRvIIeYPAK4wkq6GpAGBfiLkfXwSrl9Td1IFOSJj+/
P9mdb+N1ZWb3zfs3psdxntPztF6cS5oO+2m53GYrviGb4RyQk08v4/bxnXGV
H2D8YsrIk3HyBrdvfoXP3h1urvio/kG9R1iYQ5QnNRdcyvvWjBx9W/eO3iVu
S3/FW+FW+jfepeqpSbeWO2EdPYHhwCp9voX74Ogr59nabeRT83C/TOcqrC6G
AcNq7f7iYi/dqFj3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 619->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbgo3XoEr1APULxCPcEIuioU2oW4y9G1WCS+vmQG0um8JC/f
020aHgcAS/v5DOV5mefyujbr417GczeuyuMm7vSb+H+P4V9vHsf3bYwr+4Tj
hylRuSoce9xzGt272JXclJ+Mn/hbxkVzyOxkz0UuXh/NyCguH+4b89T8fW3e
VvJxzWpOnDfzBDmEu4BKP4nDBFdUC+8Dx5XzjHab7LlH6X5B2yquKgc0h9q1
nOcN/O9adQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 620->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4eXSoyCNczo2J5EZ27bPv
4sP1PowbAI/d5zPk53me8+uyXZxbnk7Hafm5L1ZOqoz9hN+8clsdx9c3jjNe
B6PpmwJ5HEcbN8aq7rrWovwUR48v4bM19aTVWp7UXMxS13tvZNSXD+vGOL16
7z3/xhN8pB7ODO4uoKMnYZjAklzErnLf8Pxo81mj1f2CzlVY0Vlc3tFZ8Ab9
d1q2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 621->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRQjs5HF
GFDZDcjiUD4MY6hHNxtKo5sBF0PDeNWh+4EBU7wB3Sxs+pHtwWIniv9whAlW
/6KZj44x9KOFFT51WMMci1uQ9eOKowY0e9EBerihm0NIP674JNk8LP7BFra4
3IAzLTAQCE80MxqwmIXVL1jyEbq9RLsfyQ0YaRiLH/CFA7JaXGmEGLfg9DfR
5gAAQv1cuA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 622->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHgmj8+0Z
UNVBQQOyOJQPwxjq0c3BI9aAbje6mdjci80+NLehmIVsD7rd6Gxs/sMRJoT8
24AFY+jH4g586jDCHItbkPVjjSN0O7CYhx5u6OYQ0o8rPkk2D4t/sIUtLjdg
pAUGVJpgeKKrQw8/dDOwpNUGNPuJdj8uvyC5j9hwQFaLK40Q4xZ0M9DjkLA5
AF7tW3k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 623->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssJwzAMFT2UXDtCV2gHMFkhmcCF5mQoJIfQm0ZvAi4oT892BEosW3p6
+txfn2G6iMjSbZ8hrv08x+943Y13TM9H2h9vWbMEo2gHOfplUXuf7b86f8Sp
3CnmRkzGF/IxboilpDZFvlCvBh7nzoXeKVEXDzxafq7nhIuNpzPCHARPwU8J
T9oTyIO+FE8qfEg9ti7aLxaLuyCNfhpxeci5tUulOVf5l2qR4/9MH2wdpR05
wwUxcIZtnB8jvlq6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 624->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD2IV5/gF/QBi1+oL1hBT4VCPYi3PL0WtpCdnaQ2kLbpJpPJ
ZM+PsX91IvI+/h59/tymKX/vhyV45uF6GZbDU/FiyTjGSeq8Ymr/l3j1Jh+x
Cd4aK/ZGTMYX8JCDIpYzmyJfmFdtPZshqJdUY7hYwGMrr9GccLH1dEfYg+Ap
5CnhSTWBPphL8STgA9piPdXL1DZ3Qeq3q6expg/53rpL3p5D/t4sIpUeuCtW
G+Xu4RLdg/9wZoZ1Wbg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 625->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQDH6Ivx7BK+gBileoJ4igXwWh/Sj+7dG1EGGcnc0Gts1jMzM7
m9P9NT53pZTl8P2Mdb3Oc33f9tviUafLedoOjy3aGCCyvTYM99v6F5xviBPg
OU4I5pLamA/2kN8YnzF5ruqLauD7QgeH0mCDvxPlOc+FFq7f9Yg5Oj004lYc
ri/kCfJLvJLoEf1MfWWdwIf/0E8YjkfM0Rt+C0b8sp+JhshzvB/iJLldLwMv
/mqlsz7OBwN8WDg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 626->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMFHmUfjNCV2gHMF0hncCF9hUopI/Sn0ZPAg6I0x2JQHFkS6c7
2ZfnZ3h3ZvY9L5+h/u7TVP+P0xq86ni7juth37xZgXX7L2Svmcf9Fm9OcVUP
g5g49qLcAh5y8AJnShvjGzAcsKQege/EGQcvuUblpZkTLqg/3RH2IJoc8pzw
pPXICfpTPCOaAYPxknMNtfH+PWLYzjyDpT4Q42zwLaQ+7D53OKiZH51DzFVv
5AgXqpXo1DgzxD5Yew==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 627->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD0Ur31Cv1AfsPQL9gVbqKcFQQ/SW57eFRZJJxNxIequyWRm
svf3NIwXEVm6+hjy+pzn/H1dt80nl/5Rtp+3FnWlFmLe9hzP2Hdd2nKV5SBO
gLHXQyjJo5jJcGGYQvARk/FtGApYtC7iBxhHWJp8TZjH/AEuqN/NCHuQGaJv
Sni63oxTMA/k5TQDRlRP/TK1Chp2DIH6g+X6wB69wbvg+hANoYdMi8ifH2d8
sLnRHTnDhWolOmOcH8/BVzo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 628->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB7Eq0/wC/qA4BfqC1awp4JQD+ItT7eFQrOTybaFdMnuZjIz
aS/Pd9cfRORzml5d+d7Hsfwexzl5leF2HebD8xLTo0uIW/2+SrxHctM1qjus
Fs9dbr6vuj2sY5i6cqGYQvCZHqKj0teoS/kBRgvLNNa0vAr+ABfUH2aEPcgM
0TcjPENv5EO8N4YniWbEIfWpX4kXuAZ/EoyqD+Tozea/QjRQ/pkWMt8tH/zd
7BvZxSXB2I/zB7RkWLY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 629->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMXDxIrz7BL+gDgl+oL1jBngpCexBvebottphOJtsNpJAmmcxk
c3682u6QUhqb6dPm920Y8ud+nINn7q+Xfk6eFp9MwFfDf1F+MZWfuxrWi3kT
rxhq5iupo5jy52LN8gpxQSvmVAoarc6IH2CUsFR8z+6u0FCL0c90K+oATXZv
jhfDZHzIrVW9R4STtjsI92p63S0EGKGxORBvMMgtuDlsfokDaiHvu7cHW4u7
r8IgPLC2DucL/G1YtA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 630->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qA4BfqC1awp4JQD+ItT7dFxTA7ybaBlO1uMplM
crjeu34jIo/d9OnK8zyO5XXZzj+3MpyOw/y4//pkCv4zvGPvzkw/TmPwPsAQ
h2GuvpE4iql/Lsit4oK4EINvpo0e/TnQ04gzzU3rnKZWqAP24rRhfVcaQU9+
HkyPMB85gTbhnLOdIflU18beWIIRWlAHtfAzRC5VnUDT1LBPmG+Kg7uwZt8T
Hhi7iIu8AX6zV7Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 631->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD2I1z7BL+gDgl9oX7CCngpCPYi3PL0tKobZmaqBlO1uMslM
sjtdu0tjZrft/OnK/TiO5dFvlp9zGQ77YXlsXz6bg78N79h7svCn0xi8FxiW
MCLVDxJHMf3TC/aGvQTiQgy+hX/hmM9CzyDONA+vc5RWFQ/FJWnDeFcaASec
C3KQ+dgTaKPmTDkjjvF+ZK6RXIEhjdUhWuQZ4i5UdYSmqwb1cb6rOLgL/+w7
mNyBX3uxCRi4WbY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 632->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRQcXxa1H6BXqAcQrpCdIQVcFoS7E3RzdBlqY/vxvdSCFZOa/
zJ+mHR7pfjCz53H+pPy6TlN+903Z3PJ47saSPC1rjgusNfCM5UO4YjCtYJT9
yok8J3XfeFjvxIcjF2ow51Gj5qB4hMFYG++gUbOqfCgvYTaRv5lxPIfA/4J3
7+mrd4Y68EE9I8d4P1JrRCsYMtg9ZBZsxtEbq/mpf+iDzWOXg33+894hKobw
qTkf87hYug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 633->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEKg0AMDD2UXvsEv9A+QPoF+4IV7Eko6EF6m6dXQSHOTlYDu5BNZjKZ
rdpv87mY2XibryZNr2FIv/d1SbrUPx/9UryvZ46azhb8RnX43i1XHAKb1V0O
1qOwB3wgDRB7oN73cY/iAHPxDsq/gENxwWljTOQV75HNJjyI3/ux84gC1Mez
j/DRf4I18HuJx7SeEGu5FxFHGGqO8EJ57DWonjP6WYfyg/9KYWVvaccgSvPO
/ckfyi9Yug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 634->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkUEKwkAMRQcX4tYjeAU9wOAV6glGsKuCUBfiLke3BQvpn5epgSmk+fn5
Pzndn12/Sym9DtOnK+/rOJbPbT8njzJczsNcPP7eFFneEvpP6uaxS04c0FvV
XW6qh3ojXRm0eU6n0/IaZ8JDHCZclQfaX8ARcvnZEY40Sa3y4vyrN8XQrUxw
Onurf6WL9t66R4OD9IS9qd5FxBEGzYFd+BuSZ8L8o1910D70VtSL2MBjax/K
oTfc9vQFFW1Zug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 635->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKhDAMDHsQr/sEv+A+oOwX9AUV9FRY0MOytz59FVTCZNIWUpqmmUym
6abPsDxEZGv3bYjf97rG39gczhzTq09H8HnavgLYtfAO4lm/vXyGQXJNXPkZ
+QRby+UVCDeNqXhm1o9X8/QzySueAZ8Zy7lre+8YJ4gJYOj+sTejB/kr1A1r
1/IpN7F4eO/mk/90dSV93GcHo8Tf1CFa6D8szQLOXI0/8mB6VHGQZ2XeS3ow
HVjM7+kPi31aeQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 636->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksKwjAQhoMLcesRvIIeIHiFeoIIdlUQ6kLc5ei2UG3mmz/pwCSZzOuf
x+n+7PpdCOF1mI4uva/jmD63/Sw80nA5D7PyuPBEceUcw0rFv5EXMrY/GTY1
X6cvZBNH4VLxor1ZR47Q4c/gL31QXxZ+zTfiK1YYMnC4nNA1+yPqV3Nm/ST2
jbm3/CW24OPxX/nX5lmdkajj/8Yt+ynyGzvRi1LX2gXu+RZ+2Qcx32Yc4hQ7
4eJUiHVwhtwbT1/jlVq+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 637->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKg0AMHVyUbj1Cr9AeIPQKeoIptCuhYBeluxxdBYvJyzMGxpmY33tJ
Lo9392pKKZ/z/Onq9z6O9defFuVZh9t1WIztemaR7aiUTcx/p6/ifP86+OzF
BrvRXR6Gi+UTfyMPlWhTxkcgBvipxLj0DfnZYRgUcISaYEv7Q/izOSN/FAU/
xHUU73AlfcF6LAerm/WV8bA47U7QfpL6rg7GwTvjjHt+hJ/2gcw3zYO7QHZ6
by4oNgebIe5NlAk3/Vn9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 638->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMtHggvh2BFegAESuUCYJEX5UqlQfqz6PTSoXa50sQltI08dm+
s3O+j11/EJHnafl0+XWdpjzfjuvhkYf2MqzOZluLpX1pkt3MvTtv5rCfM2Bo
LOYAn7tjOQkXWs/cqcGr3RkXGwP6NEUc1Ut8Np7mMhwUeCDOzksJ12JPheBT
xLDeKuCQ1694x4voQ15Bs/iYULfSV6bj+w877Sepz/Tj3KhmrPMnf9qHQo5a
Dx1n8r7CnAumFSz6uKY3EHpaOA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 639->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRS0OiCsjsAIMELFCmSBIcKqEVA6IW0anlSjEzz+tJTdpHNv/
f+dwfXT3jZk9d+Ony6/zMOT3ZTv93HJ/OvZTcP/10dLfSzJvc4x7i3fLnF+f
q1zWwP1S4XHewsVz9DDiSro377T4hVqKr4jV+bJWhaEAh9SVdagDuTR4u9kr
/RQ2gWst3+ES/Mgj4DSfw75Luioevz1Wqafor/hzbpIz+8DX8EsdBI7FOsQs
3kSYc8PquJoh3020DzGhWLw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 640->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk00KwkAMhYMLcesRvIIeoHiFeoIR7Kog1IW4y9Ftweqbl5dxYErnJy9f
XtPD9d4PGzN77OZHX57naSqvy3ZZ3Mp4Oo7L4f4z59H9pndWj/WM3y3e9TUe
91Usn9PagaeaGRfvixwu8jPrlx9jRH2s5VxPwojxUguYmEP6yjrsAzNC3YE5
8Yjrx3vM9S++4qKeU3WEmkFD5c24mCeNtYafIr+qH3sXv2GrFzI/Ug+VD4Kj
qSOYuSeCn8lo/TdBX+q8Aah2Wjg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 641->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKwkAMDB7Eq0/wC/qAxS/UF6ygp4JQD+ItT7cFpdnJzBpI6XYzyUyS
Hq6P4b4xs+dufgz1dZ6m+r5sl8OtjqfjuFzuvz5bWd2Ltfa7w3fLsV5Wb/As
D8tvgQNzxQu/kxpO6jvR4wUwSp+K62iLeJorcEIeGBfnlXpOehHxdEaiR6g/
xiEvildzg51jOpLmkIPVVbyQh8Tan35C/aaOOCfNgQPG0zw9Y3gj/ezsRozB
nUj9FNb7b2T+xj7o9Fq4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 642->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKwkAMDB6kV5/gF/QBwS/UF6xgT4VCPYi3PF2LC2YnkzWQ0m0mmc6k
Pd6WcdqJyGP4XMbyvKxreV332+Fe5vNp3oqHmjX0m6bSRn0e7iViTX/Z9LM5
WHdnU4dXCbzsXSgfm+lqRvSYQk+mL8N1tPl+OktAu5uPOKyFvXl+qNMdAQeb
Z4DD92Iep3tzGfxAL4guxtvzNXhBer031E/gb3iSc9DstCGezukF65c/PoAf
HoPfRNhzEr3/Jp3fxBu1P1o8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 643->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0kOwjAMtDggrjyBL8ADLL5QXhAkOFVCag8VtzwdIgLYk3FqyU3ceJmZ
tIfrY7hvRGTevR9DWs7TlJ6XbQluaTwdx3K4r15NP0tW8ab/M7cnuSX+uqth
fYTsa/yrR49w4Xsyw2LKdgU+WaGGYEN+OeDT04dqJcA9mknwNFgtFjhv8lVC
jRC/zUNc4b0jJvBGD9SC8GJze7pSjZGTrOgJ892cIG44GwyYT/v0jNXLig6g
h83BbyK6F7TefxP2d/YCIv5a/Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 644->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtPpA/XYEVoABIlYoEwSJviohtQ/UX0YvEQXsyzklUppasc93
Z+V4e/RDIyJz+/r08XmZprhcDzm4x/F8GvNlt+1thfeRgtgVfnfmn+Tm+LNN
DanFvjr+1uP2eBE8ww04JX2CnhSghnBDfdhL43n11CvFSXvA8hie5wVyLLCw
J+jwuCEv6oM3N6IPdVCeWg/MseYr87jQJDt+KqyijxMXmhUHzN+dt8MD8as+
gB86h72Zf/yovQcX36wV52RZ/Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 645->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgjAQ3HgwXH2CX9AHNHwBX1ATOZGY4MFw69OBSHV3OlvcBOhSZnZ2
yp7vz64/iMirWW5dfLfjGKfbcU0ecbhehnXztF1bhM8jBbERfntmnb+F/PtO
YwgW6+rccCAf00X4TB/Bas1rV7/GEG0J+sNams/DJ8aF2ryaDp/nBWosuJgf
hA99w/P2fCg0Ef9oH0wn6QH1UL/+wObc9VNxFXUgx3+JzU4xL8zXWjC87PgA
fqBmr8eaH7V5cPlNzLjfWT4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 646->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKAjEMDB5krz7BL+gDil9YX1BBTwvC7kG85elaXNhkMqmB7jY0mUwm
7fH2HB87EVmG72esr8s81/d135x7nc6nqR0e1rVa+f20iLeynbk9iW2+FpJD
crGu9R0G4jFeBM9xs5iy7ZX0owVyCDeF/rCWxRPCAxfLQR4Bi+BlWiDHEA+6
YB9ZHM470yFgEP1oH0Q/2wPOuqertfQuyB89DY9QB3y8S+zthPfCdO0Z1BPS
Q4oDsWx+6VzAeu8hxXf2AegNWMI=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 647->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk0EKAjEMRYsLcesRvIIeIHiF8QQVdDUgjAtxl6Pr4MCk6UsMZKalyU/+
b3q4Pob7ppTy3H0/Q32dp6m+L9t5c6vj6TjOh/vFF5PfT6W0JuuZX1OsCuTY
XMKneuQU44142L7KutYI9w8/zeLMmvAVnHpQ6XNIqwbH6xD02MU7XTwPr6nV
z953pAP2BfzS+3CYVDfVNeCpCUZoVMftGwyYV8onnNQoP9Ih0cJr4DniWzDW
zQ3NWorxAaGVVro=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 648->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk00KAjEMhYsLcesRvIIeIHiF8QQVnNWAMC7EXY6ugwXT9EudQKaT9uXn
vdLD9T6Mm5TSY/f5DPl5nuf8umyX4Jan03FaDvfFi8nXVVJtZZ/+CasCOTaX
6lM/csIEpg6vBq/S7q3hp/Jz1MTxofoKHmGaONBbYdZqFnfe4J0unofnY1d7
31QTZwKdIy3+amv6dnUNeEacUE9Tp+njYn+HngvlU52uUY9Ih44WlQbAkd6C
td57WFfjDdihVvs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 649->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKAjEMRYsLcesRvIIeoHiF8QQVdDUgjAtxl6PrYMHM70s1kGHS/v4k
P+3ufBuuq5TSffP+DOVxnKbyPK3n4FLGw36cN7fVq+WPW05Lq+vdf4e1DDiP
J37KR06YwEzw5vCW2zXqT7Ww/PV/NCF+A48wWjvNxhQv+9RLgxddFmelf63H
z5s4sSbQOdKiiaUWn/eXrjSnqCfU03E1eSTWGdLd0PPE0zXKEekAd8djaX4N
T2Dhe+jxL+wFSjxW+Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 650->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKg0AMDD1Ir32CX7APCP2CvmAFPQkFeyi95emtIJidnY0NRFyTzGQn
sR2f/XwRkdf19+jT+7Gu6TM022FKy71btuBtd2cqYirFN9GTd6zHPJ/P8Bkf
eNgXM4iZyzePqVDj+kVO08P/0YThG/FaDnIyDaoxrwHEi3zQJauF++NMDM4F
d9ATvUNtHoDJeM90ZXPCXQj1dFgFD5wzDLL7rJ7qGhnjENIDwwLN2PzC3XNW
/R8i/My+Uh5V/Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 651->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk00KwjAQhR8uxK1H8Ap6gOAV6gki6Kog1IW4y9G1YCX98pL2Qcs0b+bN
TzqH66O7byQ9d99XF1/nYYjvy3b8uMX+dOxHcv97MgQpBRVnCgs2felHjjEt
jbCiLgdwefxkJ+qibuac/NOamdAPZ1ZLc445Xa2W4wxC2X+hJdMX8OcrPTjN
Vk3sd6Yv2NBMqCPvqzZXp5vHLs4z03I1007MZ+6AMxXPW3A5TC92V7gD5v6q
/x5Q3YeW/gwfyLxVfQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 652->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8sNgzAMtThUXBmhK7QDRF2BTpBK5YRUCQ4VN49OUX/m2S9gyZDEifM+
cLw92q4SkbF+Pdr8vAxDnq6HZXLP/fnUL8XmkyaSiKb326795qWxXduqwZ1u
HqSyfSygZs9/x8hVATfeqemfezSJtFTDx/WKzuFey4/VUIPk+bNezjfgj55Y
Dq4nwRJhW2lB/GFeWT93exSc3dTT4Igw41jJnYg1+tYd9wIO5Ihcwn8FNIv8
c3qSoFqX+q9iBgm2Vfk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 653->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENgzAMtHhU/TICK5QBoq5AJwhSeSEh0UfVn0dvUYGay9m1ZIhjxz5f
nKafuqESkcf58+ny8zrP+XU7LcY9j+1lXJz1qkaSiKbv3+7tdrS2e/98ULOw
iaoX5wn47Pltjb0q4Maamn5acISYnDglymIwj3cvhzwMD+mFxpO6KApx2APF
EGDyONl8Ls9C4iTglc0zOevyicLqEOxq65NZw/N4p+F8GxyHGqQX+lYQJ7m/
gk9HCq7ZrIU53nSnVns=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 654->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9ks0NwjAMhS0OiCsjsAIMELFCmSBIcKqEVA6IW0aHClKlz19sKY1d/z2/
+HB9DPeNmT1338+QX+dpyu/LdjZueTwdx9m5/59GkllJv7v9t9jk0ztBjvqk
p7OTYKk6xfVEfG1+1XXW0vaBntWPHCmmTlyBg3wnn0NxqzqEB2bBeO0B3BaJ
0xkQQ4Cpx0n1uZkBy6JbwGvAr+4C8gkzuD6Avd0l3VfK1zcN97vBseoR8QCz
RO/n6nTEcU27Ftb4AK2gVv0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 655->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwjAQRQcX4tYjeAU9QPAK9QQRdFUQ2kVxN0fXooXJn/8zkCZpZ17/
z+R0fw3PnZnNh+9jqMt1mur7tl83jzpezuP68fgfIYqZl9+87Y3tQ36aGYOx
kGE5z3Et8hKDcKMmL/ndVuOFrAPD0Z/SIvKcDMmCGpbXcNC78JJ4vb7FAJ/o
gWroaFKcpk9Mh+l+0nNldxBqu+dJPDDN+E9kRy/UM2hQ3qOeVK/OQfSj17/E
EcHuEvpM/CY+2/BW8w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 656->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3PN0WCs1OJhvIkjTJJJP0
8nwP4wHA57Q8Q/3e57n+HsfVedXpdp3W4HnTVqwsT9mc4hRkg767eMBQWIyB
mGdsJ3kBo4eLHcsEHyvCxp5vzC+bJckzoSkW1WR5JmZtdkDxgNe7G+OJvubr
uXfi823VPgJnVY/2nnKv6h+kWslJ8YfmrvbH2J5LOmd2byXU33NS8ykuvfsF
nEQUB+YZ8Bv5Ayb/Vfc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 657->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsEJwzAMFHmUfjNCV2gHEF0hncCF5hUopI+Sn0ZPAoHIp5MNMlasO+ly
vr2/w9iJyO+6bUP5P+e5LK/LnnzK9LhP+2V/RL1Mt02PRF0InAW+u/vAwbiQ
Q2Kd4Tmpa86E9XJyGcM6PPY0PaOFq/BQZyQol0ZMVmdkVjoL6EAu6hvykb7m
8dg7ydFbIzqCZoaX2k/6X9kbBCzVxPQL1x580MjttaRzZn6zBf29JjYf0+Jn
Rv8yX3ChF/StNTlWIJxWOg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 658->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMHboQtx7BK+gBgleoJxhBV4VCXYi7HL0tKGZeXmIHMtNpXt68
fI63sX90pZTnftn6+rpMU31fd+vlXofzaVidh4+1S2XZxPywd+bDU4ADY218
Ce7I8/0OcKkmkofaM8kV31T5WVojg0ecEqNc4mMYruHBFeTi8FnfkA/qaLU5
TqbFaGA5oE6qA3xK9PydQYjdVE+Ti3sH48Rz42xQnVG/Ex1ZX0IewDa1IDlm
9cBesFnLOWaoF1X/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 659->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKhDAMDHuQve4T/II+QPYL7gsq6ElY0IPsLU9fBYVpOomFVtMmk8kk
9fDtp4eIrM/96NP2Xpb0+1SHMaa5bebj8XXufGm3Hx1coM3epPRVG4OxLIZg
ZDjXP/OzGFGe807xG9RqcyqrL+DC/JTskP+NX4Zjl1NLhEU1tXGgH3JTi8m4
EKxCD48ni5e8n1RXNoPOLIR6Qi1FHscu8gJ/ytPrd8CD1eTOF8SiL2rBaoz0
sL2wPbzH+APcHVX/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 660->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRSMOqFdGYAUYwGKFMkGQ6KkSUjkgbh6dVqLg/PyfRnJaJ/bL
t5Pj7dEPu5TSs5unPr8u05Tf1/3i3PN4Po3L5uFr5XCbJ4NFC18j68F3A4bK
bTBWc/xXPKZJcdOfVdUKTAeGoy6Rh/ExzolRltU5LK7g4BC1tFiyf6m8j9WP
2hyZTAthVf1QOpFH7pP21YRBblWTGuwc4Vfnh9qUTnrfDR2sJvm+Qm6M/fWA
vLutfrA8VqdmfAANmlVA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 661->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUsOwjAMRC0WqFuOwBXgABZXKCcIEl1VQmoXiJ2PTivxccae1FKSJo2f
Z5zj7dEPOxGZu2Xqy/MyTeV13a+bexnPp3H9efiMOkyXSeFQ3arJudubAoPl
bjD8+vtmvEwT8yB/VvAKTANG0EXy8D56w5GyNOZk9yoOBvHSYtH+Sf0e373X
ZsgkWpAV+sF0Is+zpNFXrYeR3OCJRVYn6YVl9Z23UCfhNAPqZ+9COXC30pl4
bPUDe41vuKlF3pAoVkA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 662->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUsOwjAMRC0WiC1H4ApwAIsrlBMECVaVkNpFxc5Hh4qP4vE4sZQmTeI3
9uRwfQz3jYjMu/dnKMt5msrzsl1/bmU8Hcf1cP8dVaiI6WfG/f+sZB/yHSPL
7TBcLb91xiNcwzo1noVeQceAG+pifNQhfByUpTGH3XMcjKSXFqvraXUHewie
s0DvmR9ZncgBVuqr+mGYC3PqZ6UddIgXxvSr3oIO4TQD9Nm7pBy46+okPbb8
QK/xDbu1yAsfrld/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 663->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeYPAK9QQj2FVBqAtxl6NrUSR5eYkGptP5yZeX
ZHbn6zCuROS2eX2Gfj/Oc3+c1svi0qfDfloOt59hrIloe8+4/50b2Qd/x0Df
jE00qPHRjJeYos4Wz0KuEEeBH3SRHDT5t0wcgQX1q+45DlqSS8UKfTOmoM3p
Qg1Zb5LesjzoWwSOvfdvXVme9k2k9TSsEAfWjkHePo1DOKVBfOxLycEeimdU
fUHDemIPf2qRJ3SuVoE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 664->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeYPAK9QQj2FVBqAtxl6NrcYrJy8/4YDop03n5
kvRwvQ/jhogeu89jqM/zPNfXZbu83Op0Ok7L4b6tpvJd3Hal8kdMv/vKQ+49
b+GhWNbY8wvEyFnsmakV8jD4Gy6nBg5i6YnL3If+ed/JvrDDqriKwxV4mbkJ
IZviQoZkNl6f3TqyGQOH5Mn6FdbpePT4vfoZY8i9yuQJfFJBfq+G0AdnSNoj
nQsI+4n/WpeF3hHZVYM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 665->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADIr4wXjAkdpqENA6IW54Ogx481+mIlLXNEst2
e7jeu2FjZo/d59P1z/M09a/Ldj7c+vF0HOef+5Il/LeEWx3+x77MfudVj0O2
sAEjnGoKL4kgXDwHas36vPai4pVpUBwAk7OawVrSh76E4LrgovQ3fMea0o9v
Rd6R1bPMi32ODCPDIR7IR/rV0glr00/ir/QH75Er3UHWk/JPeDD+qg9C74KD
0Njyg/3kt7bKxd5AflSF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 666->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMDS7ErUfwCnqA4BXGE1TQ1YAwLsRdjq6jIySvLzHQT9okfe+l
u/NtuK5E5L55T0N7HKepPU/r2bm08bAf58vtMhbT72Iq3VlY2b3zLYtR6fOx
hsYapnBWYQFDHt43z5W8z3J8fMqx2ruaOCgG7XMyrYxgDe8z/oXuFIfEfvx8
2iPGnehA+RX9oFgk9jPVteKZ1PiHn/E33HvsgD+LoVoUOLA+1YFpIQkGwrHS
AzHgXyt78rEXaV5UPg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 667->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUcENwjAMtHigfhmBFWCAqCuUCYIEr0pI7aPi59GhJQLncjaRXCdxfL07
H6+P4b4Tkbl7f4a89NOUn5f9erjl8Xwa1+KhRFnpkzRJc7dlG1iXX696b1g/
YpS6Qv7uGZ6DgzrsWa1WvE+8x9ZdjdHeYGJQDqnt8bxSwrX6P9NP/EH96DFy
q3qI5+4ifY1u5BnUFPhQvwxGgyv1bF0/gT/TjzgVd+DvvWFeRDwQn/rAvBCH
A9EY+fFvTuFMtvUCj+9XOg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 668->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKg0AMDD2UXvuEfqF9wOIX9AVbaE9CQQ/iLU9Xi+BmdrJrIC6SZDKZ
7D7ev/Z7EZHxtn7aODXDEOfuuv18Yv969lvwvvtq4XANcliQLC4svpuexRAS
T3IUTlOHeA4OctAkX9MzyVPoo6X5TvLAWZU40wB5eHkGB82ZhWFlPci+cB+m
xts7M1Kn2K+kM9sn04PdNYYrdreunsCfzY84hjto6eVkWlR4IH71jkmeaziQ
GUt6lN5DlcffFmhtWDI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 669->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0sKwkAMhoMLcesRvIIeIHiFeoIRdFUQ6kLc5ei2UGya+TI0MB3a/zFJ
mjndX91zJyLvw/joyuc6DOV7208vj9Jfzv0EHuc1hi7LVJZQqXAhfA7b6iGA
O46FfaWLfq1cHGaOb37XoNGgCZ6mNS/NA2o1WNSDmEfGW/nESGohr7Qu0ilo
sv9OOYGumh3KRxgjr6pGOltqj2Y/w/lUP/Yj6aUlHAN+K4/ojzMGWs/13zZ7
OG52H5qz/o8fkUNYdQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 670->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKAjEMDB7Eq0/wC/qA4BfWF1RwTwvCehBvebq7IDJNJtFAt9t2ZjpJ
28P1PowbEXnsls/Qnud5bq/Ldh3c2nQ6Tuvi/tOW0KKxdYF5+DeF3mMyPhnb
Ly8ZF8J7MMAb9uo46jhO0zTiqpp0ob1G0EI9jZysVka8dvu79aAlRV6M5/bu
zi3LnfhmOuY9+3Mn3pgWy7HSNcbPgu1D8sBcWC0zjBF85YPVI9wxwkUszv2t
AdjsPZR3/RtvRqpX8w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 671->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB6kV5/gF/QBwS/UF6xgTwWhHsRbnu4WVKaTZNtA2u4mM5mE
9Hh79MNORJ5dffTldZmm8r7u58O9jOfTOAcPX6+m5JJ8V7ffnUBcIJblMD/X
gLOxHtaSYcFYg0G+4VsJo4QhTlOfl+ogvOiSw3Ehn3pMNisLtC7qUzzKT/uK
5kO1V3cj0MS4aHecHuq9xeXmBdiI1yJ8w1ydoA/DGsEso5xV/VkvNA+3YwEW
c/FuMwfkZv9Dc9f/9gFEiFj3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 672->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD2IV5/gF/QBi1+oL1hBT4VCPYi3PL1bqJKdTLYNpGyzmWSS
nfNj7F+diLyP5dPnz22a8vd+WH6eebhehuXytHqxBC7Bubj+YmLuV9NWDtbH
HiamyAe5MCzjwmoizwSYBBioqYhr8QhmQ6c7SR7D8qo6aMEsLH9zLvHvUmE2
tIFxxIXawXe38UCfdF8G6+aUun+4T2OuD5lDCT+KF18j5B/NAvp2GiNYm2tj
u2uY3Eg3Ta3/bQax2ld5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 673->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMHDyIV5/gF/QBi1+oL1hBTwWhPRRvebpbKOpOJt0GUrZNMp1J
sqf7q3vuAIyH8ujydB2G/L7t55dH7i/nfg4eFy+WyBGci5uKL2acA0iMKkYY
33rlEVdA4khM/PgZYRj9x4Q+Sz4v5BFoY5c9Sb6mhecs0KLym7rg51LVRHMP
OHFduDuprqu+B3zCfrEO5oNGPwmD9YN0uLsiZsA5W/j/98HdFfg+rO2G4yD4
tfqxtjfbZvIBORBWug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 674->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAHg3DgD0D
hnwDVKwBXS2SWAMBM1Dk0MyA68eG8bkVHaDZg+xenH5As6cBi/8a0MzCGWbo
bCQz0TFWN9hj6iFkHgbA4Rds6tHtIBi/6O7CFe843ISuD2fasUfVhyKOhvGG
KxZ/wNloNM7wRLIfwx5cYYPuXiQ3YFNDjPvR3YFuPtY0hkUvslpkMaLNQFKL
Kz8QFycAFsdX+w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 675->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD2I1z7BL9gHLH5BX7CF9iQU9CC97dOrYEucTFIHIqzJTmay
ae6v/nkRkbleP31eumnK76HaDo883tpxS173WJEgvkhi8gX/KRSscTgOOeD4
3WcRaUWwPknpVHqpHvSx1xdPX9QXvGFEWuVEXSFaD1ogb+pJD8aH76vvME4K
nH2yPMYj8gU7Qd/I8aF9oic6T9Xf2wU6D6LF9PH0R2C7CNz/dsNoIPrOcJi3
cHi4pw/EHFc4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 676->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBwS/UF6xgTwWhHsRbnm4L6u5OJtsupEubZDIz
zfH26IediDy7+dGn12Wa0vu6X17uaTyfxiV5+MZ8NIep5KM+/vnfN/H1DoNh
NTBM65v2sF7kwnRI5meIAXMM8E1zhDwivAITg9Ugj5BrmY88gF5XT2YwvOq/
SN3DMOlB79Xj4DzqMdkJ6mtDR6kTNa35Ge0C9YNwcXOIhuZ+FzzYfjsvAi2O
A+G3BWNt19qaPrPVWbQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 677->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylUkEKwkAMDD1Irz7BL+gDgl+oL1jBngpCexBveXpbUDc7ma2Cgeyym2SS
md3D9d71jYhM7bJ06XEex/S87NbDLQ2n47AG9y9fTLObSjaN/om/7yTmBwyG
tYFhWu60htU6q/JwMUMM4GeAb5q9OgfrC/jodAaNNRTbx9EqOod80oPhFe8i
ZQ3DpIbaa8TBflRjnPWbroSH54mcqJ6uP/sLVT0Ih9CHcNj6334OpkfQgtT6
XH/3DwbO/dubzEGeXDY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 678->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBwS/UF6ygp4LQHsRbnm4Lys4mk9pA2m6TmWSy
Od6e/WMnIlM3P/ryuoxjeV/3y+FehvNpWIKHr8+m1U2lmjoXiPtcyA8cCVcT
h7Np+24wGY+zVIckvF4T0WdafZOehN87xWjEZHlGem16cdiQT2rgHBCHc0EM
46RG7sDzMI3/ZsRmm/Xga6NeY1qIBrYL6TyIhlCHaFjbb+yD7XeYBcFiLv7b
zOFyf99rPFzTBwehWrY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 679->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKwkAMDB6kV5/gF/QBwS/UF6ygp4LQHsTbPt0WlM4mMzWQliWZ2UyS
Pd6e/WNnZlM3f/ryuoxjeV/3y+FehvNpWIKHr8/mq1e31Ty4QTzmQn7iEFxN
HM7V23+DUTzBpA4TvFET3g+cldWl9Aj+6BTjGaPyqpNZYC1CB6urwQg9Pyxi
GCc1MtvIkzSKOliPZF9JDVELaqL9BDzbBdkPsifpHte8/+pQ+72phcwwcqR+
CsP41pvRM/kAuBdaMg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 680->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3fbotqDudzew2kJYlyWQy
yfH26IedmT27+dPH12Wa4vu6Xx73OJ5P4xI8fH22kD0FyxbIDeKcC/kFhsBa
xeGdOBdrFA6bmsMcfO7NPCzXJcUPcoq+Tn2B5XEFPWt5/7jSQPDguVc9+G85
/qvFGg/TtcZ8Ur/GPpu6Cg44C2NJ8/o4c+At1W4Bc9wba/BQ912dxdlhS1Nl
GGfdt+3kA9J9WvE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 681->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHigfhmBFWCAiBXKBEGir0pI7QPxy+i0EqHO+ZzUkqvUds7n
i8+PVz8cRGTulk8f37dpip/7cf15xvF6Gdfk6eeLhc1TPkM8x5LK/c9S1hfx
ClaRlw0/YW2DEzPDYQ9GIPORPOVX6wuzoRs9gGurLgXyFiJ2Xs2xNpdAHu7l
XvqO4eC9DdEOcUwt4pGdbOrqcNCzIJZrrA+ZQ++St+emhu1YgwfT03BkGgjp
VdHUM51H3fdhfAEYRFlz
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 682->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvebq7YDWdTFoDWdpMdjIT
erjeh3EjIo/d8hny8zzP+XXZrpdbnk7HaQX3n1wi/VLLGeqlpgb7nqXur+oN
rgo3d8XejiYWkbaeFueP4FQfm0swlm4foDXqKzVNxK+I92s1tnyhD/hPTU+o
IdJDEnlcP/KRN9nda6DDekGuMNgc4sO+JdTi5qSYt6eD7TN8N3YHQmY1dhqF
xXHefxxvgsxZ8w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 683->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMFHmUfjNCV2gHCF0hncCF5hUopI+Sn0ZPAk0jn062QMGW5PPd
OZfnux8aEfmc10+fvvdpSvPjtG1eabxdx63Z/nKN7kjd11Dfa2p6/7UcPcV6
ASvrm73ibIUTC+TmNKBW1ET0idUX8HDaocfS+QF6ozmrw3EV8Z5ZjgTL1hle
5pvkZ8J3Rz4kEcfNR3qAR9HXgIfVglhhsHuIDkW+Jtw9XYxb48H8DP8b64GQ
84RfzQ/3fgUcHgsimls0
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 684->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHigfhmBFWCAihXKBEGCVyWk9oH4eXRaiVL3fI6xlDaxk8vd
xcfbs3vsRGRspk9XXpdhKO/rfl7cS38+9XPx8B1TtOvQZQ75Jaem9pvLWlPM
V7A2dbNW3JtwYoHcnAbUipqYDqvvHz1Qs/4oYuEZeJOQK/McuODZCMvmGR76
psHc+VDRxnDofoE/cE19DXiowUCsMNg9kR/2PhPunjbGzXhQTZkP2BuVnsj8
cO9Het697SY+gNBbMA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 685->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMqzggrjyBL8ADJr4wXlAkOE1CGgfELU9nkxhzHafFUqeuTRzH
zeH66O+blNJzN336/DqPY35ftvPPLQ+n4zBf7r9rQrcuW/Z0XpwliAVYt64f
alyJ9sDh4ls8BNaG8Qu/RdyqP8iR+lQ/dIf+GHNxDulwcUoTg/pFHVyTayg+
9s2CvfNB9UYzV3BXvFDnf/ka6DDgYK4Qqk7kB9YDqPyIt6VD9dT0gWejMhMt
P9z7iZl3b1vgAzvXWrA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 686->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfwCnqAwSvUE4xgVwWhLsRdjm4LisnLy4yB9JPve0kO
1/swbkTksVseQ32e57m+Ltv151an03FanfuPLlJ+qt9vsDsVE2tEC7FntdBv
aminL60DgthsvNo3YNGMn+FG8TE+4NPClebATkIcw4SS8Mx4Wzur5/YLOQFj
hqfDj80c+eDcs7nSmUC+uwX5I1c8Zm3wUMRrhOVndXs4sEfzvuwMJPbPOLbm
EfZHbj7s1skbGrlasg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 687->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngqFehBvebotVEwmE91AynaTzEyS
Pd6mftiJyKNbPn19Xua5vq779edex/NpXIOHzRcrX9fPGe6dC5w3U4shJo9h
YdxgaAsv4bd4irESY8q0GJ7QR/mhj/UDMS3caQ3oCHlME1rSJ+MMHATP7Rdq
Wuqz94Q4IR/6wRk1z5XoUNDr6hOjPNk8hPSFPATD3WeG+mHf6buRmMtmHfr8
Mw8hfOlunb0B6DZY8Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 688->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB6kV5/gF/QBi1+oL1hBTwWhPYi3PN0WKs7OTtYOpGw7zWSS
tMfbs3/szGzq5kufX5dxzO/rfrm55+F8GhbysMaM9Av/nul5EUbnFY4aBu8p
LeZBw7fUFfVRz5lLNefKC9Sp+kgNf6of4jzp4BzegXxPeWIEfUY1q90Tiv1S
zpb8aI+s0/LJueyrNdfKB9YDrXCe1qgTzQNyECqftcNvnLwUPYl5/P1PxOxl
nwHCvgWn8QGfEFpx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 689->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMizigXXkCX4AHTHxhvKBI7DRp0jggbnk6mwTCcZ1iqeva1I6T
9nibh3FnZo9u/QzleVmW8rrut8W9TOfTtAUPn7Gi/w3//tN+OgCOGgYaSovj
oOGtXI38lRcEnHec2QvkQQ2sTfpjvlg78YMWc8hH65z3ol6zWK+oBc9VOYRe
uN9/tWR+xD2yTssnc9kX97jiWrw/J7+Br5DlIZ6zdvLO+S3J/QxJjmYfqB+y
F1mdCeQ7SGIabzXuWrA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 690->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OFVdGYIUyQMUKZYIg0VMlpHJA3Dw6VATJefwEvpSmjuPv
b8f783WcNmZ2274+Y7oflyU9Tt1qXNJ86OfVucsrY3gvz3s8a64AjxyRV3HR
H2z/J+8PHhe8nztOTdQXdYjapD7yCdsRX3AxBjpa93wQ9ZqV9Ypa4r2vHNzR
A8ZU46lH9Js8LZ2MpS72WMGRO3IX8Qoil3oH/qv5VLMkz2ugflFDtQ/UxppV
PyuQc1DxaTwBLPZaLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 691->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgkAM3HAwXHmCX9AHEL+AL1gTPZGYwMFw69ORuMZhdtrYpCy7bafT
YTnensOjSSnN7fsx5NdlmvJyPWybex7Pp3ELdsWL9R+3suJZ6GDW/3yHq7A4
Dnv7p6/oz1wY95tvzIn5IQ/Ew/kUDzUbYSiXNcQjyqs0x5xU1yqsqgevpAHX
uPXMR+jNOBFP5MvzhbqCGfVGbHmHaQbvLmAdv4f/isDYnXvG/MUMrg7MTXy/
CscxpYOK+RgrzmtbLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 692->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk8ENwjAMRS0OqFdGYAUYIGKFMkGQ6KkSUntA3Dw6VATV/PwfNZLbpK6f
7Z/keHv0w87M5u7z6PPzMk35dd0vi3sez6dxcR6KlZG+L0/r3JIwg7mtsT9D
LmWYVQyZs1ULYbniRp/qtawdebG/Lf2AL+rjyGL9hzpa/1WaQy0Yy1hVDtJT
1ABjmvFMD1a/0BzrQB/WQPUyEhvzBZbU03T/uA+O7NZdIYy/72qIHJt0wLNB
9q/iiEHvBPFpxhutf1jx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 693->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwjAQRQcX0q1H8Ap6gOAV6gki2FWhUBfibo6uxUg/P39qBqZNmMyb
yU9yvE39sDOzR/f59Pl5mef8uu6XyT2P59O4BA/Fi6Xvz9M6thS40djW3J8z
VzLMKkZY8x+HWB5xMRZxy9yZh/tr2Q/FUB9nlto/9BGtk5pTL5yrzqiqIXhO
PMxpya/0FrWV5sowxj1IvVQu1gNWqCf0q+4C5jmzt96KYGz1X/VCNZp04Lsh
zq/iBCbfhIjFjDcPVVh3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 694->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB6kV5/gF/QBxS/UF6xgT4VCPYi3PF2LCybTmdpA2myTTCbJ
9ngbu35nZo/m8+jK8zJN5XXdz4d7Gc6nYXYeqlZpv+r1Hb8t1MCu4u1PUxzD
MvCbiFN1Sf14doUbfYxL8DniYX/YI7Ph7ERpTtC1uISDEvslvTBe//arZiH3
Tvgkm+BInshF8KHzYrlkl6vztJyDdyHmJYwt/wrbp+KAXKDGpjng3SD7W+AI
YX0wn8Z4A90VV/U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 695->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwkAMRYMLcesRvIIeYPAK9QQj6Kog1IW4m6NrcbTpnxdsIO20SX7+
T9rd+dZdV2Z237wvXX4chyE/T+vx4ZL7w74fg9vq1dLHS737d42bnKuVNPks
j7BM4hbkRX2hv3JBXB8jLi7mMb6aZvpUI53luYBTTUltTZRXEuj1XKSWsLRH
k2NTD5pFuPfIQJ/qIA7ETzngvFSHfO9eWzhPa2sUS3F+nP/9K7TPBTOkHovm
oHOE/UV7USMdFIsxXkOZWPc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 696->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDV1Itx7BK+gBhl6hnmAEuyoIdSHd5ei1ONX48jI0kE6myby8
fE63Rz80IvJs358+v7ppyvP1sF7uebycx9V5LFokfVTLaf85FbCLaPrpHy7D
Qr8EcVFekh+5UFzGKYixGFtfvvUxPGbDXYlKkMdiYJwkj+ckqJNhOS7BfC0X
DWzXBybQZ1aH4wl1bz7kQGdE6rB9tmfYT8OX7YImj2M5IwfHs7IXVS6Qo7Zf
9i3txY65oLA6mC/GWABUj1g2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 697->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMPPGo+DJCV2gHiLoCnSCVygupEjwqfhmdokIx5o7UkhNHSc7n
s8+PV90UAPrys9Txfeu6ONxP0+EZ2+ulnS6r2WcL3y2FNUYQDhdj/bu4x6UY
wA5D5szheFO4jJN4Y+tYdPnVx/BY7M6JOFyejYYmbw5LakByKKxcfy2XxGKm
g+KUqWPH0/Cyd54D7RGpw/bY7lJPooPH8jiWs8dgmqu5oCZyHM2X/Uu1+KMv
TI+N3mSecYgxAqerV/k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 698->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQXDxIrz7BL+gDgl+oL4hgT4VCPYi3fbot1JJMZhYXNjRsMzs7
k5wfUz8czOzVLUuf37d5zp/7cd0883i9jGvxtGUdnpYlbZskEmvF2V/uobCw
buI/1tesxcFQuAEGzu6kts/H8Mg3auEkQw2LvhSbaY5cRA/GK9LXgYtHHJQ3
xINGD+jHMMoacqAekTlKfxiGCnUXHPDQQ8RoeAb3goboEd2v8izV4g9flB5V
wpzNW6jiC+YxWHk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 699->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0sOwkAIJV2Ybj2CV9ADNF6hnmBM7KqJSbsw7jh6rb/AmwcloZ1hBh4P
mMP13g+NiMzt69OXx3mayvOyWze3Mp6O43q4/6oX7T76Fvu3ijbwVWNLYwjf
K95F3ADfCdqzGMEdBW5i+bF4ZI21UKJpDQ0ucqpyQgl4sh5VuWzgoU/Y9ywn
wMYYjLP1+Z1hDrRHhMd/bfjSGQ78EQf7hrExRpVnMhdUAoxsvqyvqwXpf9SX
qB5OgWf1FpwsyPVXug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 700->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk0sKg0AMhocuitseoVeoB5BewZ5gCnUlCHZRusvRfVRK/CaJgaiZSf78
eXh9Dm13Sim9q/nR5s99HPP3cV6MV+7rW79cXjbdizQ/XUW/tW5+2taxos4i
jB2O8hf6NsAhniU8jzAcHzF4Cvkxl1ULbKrVDwHHqE9Fz8nFmJ3Hy6zJ4oYY
d+4RJ+QmRlEz+Fq7WPQ1qOP/nZx4R7xd4L9DbGLQ3+QfiZMj2i8dq2spdiyY
S4TBWg8xVpkAOx1YeQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 701->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMjHggvozACjBAxQplgiDBqxJS+6j4eXQoBHS5nF1LbuXEvtzZ
yeH66O+blNK0e3/6PJ/HMT8v2yW45eF0HJbNfXGw7uvWQQzrf08lB+LfmmH9
Cka1D7FRrnEN4ylT+R4nxkQexQy4NNo9PaIXJpx7yDNQediXpueeTpidx0tq
Utyoxp274kL/ph90ntJlpCcRD3U/FW511x0eUR/U2RVHwGYMzpf8I3POiO4X
1qKW5p0Fc4kwWOsqxsdeLZhYOg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 702->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwkAMDS7ErUfwCnqAwSvUE4xgVwWhLsRdjq7VAZPXl7SBlIYkLy+f
OVzvXb8Rkcfu8+nq8zyO9XXZTsatDqfjMDn3TY2Un2rx9kylxRSfruWvDpNh
od/YCrGsFsVCf2QjJ8S0PJqo4aJYO+qHzEKJSlAHcyg2m3nUp9ldxIv2xLhB
Trj3jFMwE6yX3ojwmdKbQVzxc0YukUS34PLYOwIMjJ/VTzhkNVbNwfZP/rO9
hBhkX4sYX3kDXGVYvA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 703->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk00KAjEMhYMLma1H8Ap6gOIVxhNUcFYDA+NC3PXoOjhI++W1TiElofl5
eUmPt6kfdmb26D5XH5+XeY6v634x7nE8n8bl8bBKdsJXUihtJ7b6hDI8Md4y
nwCd75mdUM/VAhZ5RF7q1bw5Dit9E/G1+hFcJCFWqcMYlbvIU+NAzI4zdjVE
vgIbYhyG1myArdaH4xm9s58Wr6qPny54kHwinrtAXt0/Qo7WHFr4HQ+osYkH
8Qc4/6375fYGM/zP6Rt4t1i+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 704->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB6kV5/gF/QBi1+oL1jBngqFehBveboWKySTSd2FlC6bmczM
ssfb1A87EXl0n09fn5d5rq/rftnc63g+jcvhYS2zyre0+H0oWXuKhyvixfSQ
fndu9grzwizQwpYSXvxPea0O8b2K+hJuxmHxilxkDmIYt+PBxe5RoJ/5Qh9W
W5JF0LBxN6gt8xFyBu/oZyvX4MN6+en5l6fBhzmIY+8o4UjnN2SIbyXVR7A0
i4Z7YXlkb6qN4w2cNFnA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 705->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0EKwkAMDB7Eq0/wC/qA4BfqC1awp4JQD+ItT9fCgtnJpC4GUtjdZCaZ
NIfrfRg3IvLYfT5DeZ7nubwu2+VwK9PpOC2P++rV9Oum8a5xqTEqjRnmi4uB
/NTUYTu8gPkDy/CN1BR68GfgNKwFYjMerNuIS8KDOQy7wUFLtDeNMw4c2XxX
tKBzz4z01z1nqJVpyv7Ppg/fi+Na1dPlBx7MY3uUYKQ6/LEraX0kl2rRMxei
R7ZTff28AZ3cWb4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 706->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKg1AMDF0Utz1Cr9AeIHgFe4JXqCuhYBfFXY6ugqVx8nkGIprPZPLx
+nx3/YmIPs3y6Mq3HccyPc7rx6sM99uwOi+bbsJ/FbY29MnPpkQwn1SMxsmE
FbbCM5gVLEEf8vB64H2cxhDkArGmToDhKQV1NIbH1eCgBLMXtjs2NaL9JrNw
947v2gY4h/cMXNO5OrUx15uDO0+yMdi/AKddH8ABY7K7yLhE+01xnH8A91+9
L7J53j3X+5kBkMxceQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 707->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQHHoQrz7BL+gDFr9QXxBBT4VCPYi3Pr2Wim5mJ2kD25JkMzsz
mxxvfftoADz3n0+bXpdhSO/rbp7cU3c+dfPm4Rtu2BKj5fMQWHJ+efivgdct
3wOdCcMo10StNSzBDazJc2JcgTEyF8oNdQoYKlCo4zEU14AjfMh0qd4pXeyF
50Z/74Xqe+Dh16j25j4T16qvwhc+q3yQfiLmsP5wT7wO4sA5tXtR41LqbxVH
vAHu/+r9Ii0Bg3UWNU3KJF33
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 708->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKgzAQHHooXvuEfqE+IPgF+4IU6kkQ9CDe8vRWsHSdnUQXVkmymZ3d
2dxfQ9tdAEzV99PGuRnHuDyv6+Id+/rRr4e3zY0FIG3+W0sHxeG/B94P+zPQ
HWeBYpkT88oYcwPXZDkxruVh8KxzrMtzAmOHZXmTBioOCodN6Qitscsh+puC
/9teKN0dD7tHubmO0swkUU+pr6W7qg+yn8jwFXMq3xFx4Jiz/JlLTt8ijngD
rP/hfFEtDoPrzGJ8AJR+Xjw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 709->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKAjEMRYMLcesRvIIeoHiF8QQVnNWAMC7EXY+uA6OmL786gbS0SX5+
knZ3vnb9ysxum9fS5ftxHPPjtJ4Olzwc9sNk3M7qJJmVWd/nz+7V4GffO+N9
qm2GmCAJvuREPoituCgbajCF63k4PK8BR3AgR2JUWIgp4KH8Ag5Fzc/EjFUO
gVdS3H0vfvZBcUNu1tF8M+C6qK+sg7MTXKS08iBO9Zgc6LOUf+gDcizCEX+A
8//7vlBLwGCdTYwnI/5dPg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 710->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhQcX0q1H8Ap6gOAV6gki6KogtAtxl6NrqdbJl2dIYDqdZn7e
e9P95d7fNmY2de9HHx+ncYzP83YOrnE4Hob5cvcxd4JZCov/xqv3Zktelmu/
OLlvPp89shkKQxAx8aA2w6LuVF/Dncfh+nmjFpKP0EeZqknAofKKPjzkDByc
J3dved3qhRZVHRQ29CGPYu/gzl1VdSUP7k5gkeffHNQpjYmhtoca/kIHzGjS
Abvke9P/BS6Ka1uPF1m6XHk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 711->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0kOwjAMtDigXnkCX4AHWHyhvCBI9FQJqT0gbn46VIXijCdpI7mJGy8z
Y+V4e7TdTkTG5vNp0/MyDOl13U/OPfXnUz9dHr7mloqYzvvPX3ZvMsdlsfL3
zf3z8Vgj68EwKPERD+RmWNidw4f4sYdBPW+oBeVD6mOdEgbTmFOKMyV8C5w9
F1YnzF7yPD8P1KKqA+KCPMYjzN3lI9ZVXQmP5Ux0oHoWegUNhWuMGGpzqOEP
OkCPTTrgG9igaWkhj9V3E9Yb8g9dtg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 712->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKwjAQXDyIV5/gF/QBwS/UF0TQU0GoB/G2T9eikc3sjA2kIenMZHa2
3Z1vw3VlZvfN+zHUx3Ga6vO0njeXOh724/xy+51hFDMvn7Xtf2ucBjjrzzye
Ix55oNH4EZ/uYjqg5epd8Cd1AdewTrylu5Qe1Ja0gOMlcxTOC6lX1BxrYb5S
763nxX7QPqkc0BfwWB2YM/rF+hZzRV3rc17MM/DZtxB5nYb4VxhG+mdD3PE3
h8Dtsig5F9UXlUfyxLzQ8QJpYV06
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 713->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAQG/wQfz2CV9ADDF6hnmAF+1UQ6of4t0fX4oPsTGI7sC3dzWSS
bHfna9evzOy2eT26cj+OY3mc1tPHpQyH/TAdbj8Lys2qv99xv1m2AId7iBfn
UQPi0yzGw+aR/R8f8+Ac98VWoi3NUnzBW+IKPdVzj8JVJ36FZ/TCdGFPzLei
NnVPKoeoS/iLOuk9C62zuUZea3OezRP62b+AfQ2HyJJhpH5WYsbfHKCXZiE4
luSRfDMttJ5UAls8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 714->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHigfhmBFWCAiBXKBEGCV6VK7aPi59GhKlTO5ew2UtLGsS93
F58fffs6iMjYfJc2T7dhyO/7cd48c3e9dPPh6TfNSCKali/GiylLnjp5Nr7+
E4w1Tjio4VJxYjiAR7lZjRLgQt4/F3kxvS4e0aaBNk11jZdH38LRbLUwXrYG
/cX3QC9CH5CXo6/qHacfGddNXxFXSp83/TT17B5bV2A4Xnq9RPmz4dwR+mBq
0YsIY48fFae9XOQD975cOg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 715->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtHggvozACjCAxQplgiDRVyWk8kD8MjpUUORc79JYSprEztl3
Tg/Xe9dvzOyx+0xdep7HMb0u22lzS8PpOEzO/W8Ec7Ps3y+eF8N43HxW+Fxj
FH6oIbvAQyxhmXGIHBkH53FzLNZlDnE1PMItC24ZMFXcQiu0FS40p+Jiy36g
FohJ14jNeg35qu8x7Ku6Eh7/tcBQpvLEe9hDpqV6S2v1Rx1YjiYd2D9QwWjR
g3Ft68kb2JtbOg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 716->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPQNDgz2E
BmMkcQZ0cXQ1DAi9DejqSDADph/ZHQ343IMDNGAxF10Om7kN9ljYDAg3obsN
XQ9O8xhQ1WOYhc3/6HwCZmEAAn7BZhahuEFWhzWe0O3GxkazpwHNTGR34nMH
ulvxhis2/QyYcYc3PJHchc0eZH3ocYieH/ClJYLuR/IHNjuICgdseQBPeicm
PDD8SqxbGAAoWFm4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 717->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0sOwjAMREcsEFuOwBXgABFXKCcIEqwqIZUFYuejQwUFZzIO1FLa5uPx
s+NujpfuvABwXT0fXb7thyHfD8txcsr9btuPm+v3cJYAS6/3Z4DmvOZs8jU+
N0Nj8vccxudYR5gJXd5TupbEN75MzNbyUXOkQIvigDQj1kKH7UcuimvyqeK5
NaM8qjoA9X1RrCg/5ox6RPVRq66SAS6e0IgsiuP9Cg3xP7R6SfJzDkBZL8ER
6hAHs3ntOfWo7uVfFjwAGKlcNA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 718->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EOwjAMszggrjyBL8ADKr4wXlAkOE1C2g4TtzwdJhhKXbcdlbotS+zZ
aXa4Prr7BsC4e1+6OJ2HIT4v2zm4xf507Ofk/rvdCoCFz/23QTG/c2vBGtcp
blCeNPhaUxjxfR/bipziNdbrMCa01TAqRihwMYY4S3UJD6+GF8W1YLwnj/P6
2EPmtfRc8cc6i+csZrHV1wzPPlv9dLrULHhcwiH+h9osSf3sAUj7RZ6qPKQj
64Xj/qcf2bms1YIXgS1d8w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 719->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPyQ/noEr6AHKF6hnmAF+1UQ2g/xL0fX4oPs7GRbA9slTWYy
yWZ/uXX9BsDUvD5dup/GMT3O29m5puF4GObg7nOctYC17/t3QD7/c/bFGucp
blCcNPhcUxhR3/u2IqZ4jfUKXTyjJQzrNsXFGOKM8jIetkBXkS9q+J48zuvj
+vLdlaZKf6wzfGexi0tzLfCuT9VTZLIO4TIOMZfaLkn93AOQz4t6qvIIHdGO
/DOPYnfXasETZutgMg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 720->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB5krz7BL7gPKH5hfUEF91QQdg/iLU/XQoXsZNI10ELbzGQm
zfn+nOaDiKzDd5vy67os+X071sMjl/FS6uOpLYgEa+/OhLY7xbyIQ8Rx/PBq
cpXUYvXtWf94c7zJ4BJwGF0KXvYwqFkZF2KAk+U5TRiBLtZPrGE9oS4NfNB/
Z5o6/qjO6O9htlBXOGfEJ/MUBfUMuA1Hp99slqh+9CCy7Rd46vKIz2W9dzxR
kNmIePhcfAAfGFx1
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 721->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMFH2UfDtCV2gHMFkhncCB5GUoJI/Qn0ZvAynIp7NjgQyWpfOd
pPv4HuaLiKzd7xji1i9L/Lyu+2WK6flI++PtcLAAfhYzpkdMMc+8uTrA+Nfb
fCV/sf/tXRveHG4wdSHH0JC7ID/GCTBsvsPCGuDB8hDLWUULm52NMzycL+pg
c6ecKvooz9Lsoe/Iq7hnRCfTVLLSLti6DKPSb7ZLlD9qEMn7BZqqOOJzz/a9
pR9ud1u5yBc3aVz3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 722->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD2I1z7BL+gDFr9QX7CCngpCPYi3PL0tWAyTmW1gS5tNJjPT
nO6v4dmZ2fu4PIb6uU5T/d4O68ejjpfzuF72vwNR4OzlSK8XyCkMM4rhG0bE
E7NUztmdhTvBxQt5tz8n5Cb1EoxYn7CwB3iwOsRK0dCC3uEMhudhJtOBvGmQ
PXLATDzVf4bd2vM19QedTJMKrMX5W40DP8RQu0T5sxAzmj5ED6ztfcJp+IG7
oXC4phk7zFs4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 723->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOglAQQycujFuP4BX0AMQr4Am+iaxITHBh3PXoSiIR+tvBST6BT/+b
TuFwvbfdJiIeu8+lLc/zMJTXZTs+3Ep/Ovbjy/13UTW0QtzzHp2F0ENxIyQD
zVKPpJfbg3o34zsvYF38eBDeWGd5sdRXLD5DPpSOWVUls3B2zFC8aQ+qt/nu
0lMy35pPx/gn1+r82kymWMv9Jw3IHzPcvyT9qzI90hzmGUSefcVJ8uAcHUfP
9AZQh1p7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 724->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXPsEvkAfEPGF8oIg0VOlSuWAevPToSzCmY5TS2mSZjz2
2D5ex67fAbgfXp8uP87TlOfLfrnc8tCehuWx+S6yBFj67O8FcYbDkG/hr/DK
R8T3+Fqs6J9FcVhfKjHGOPz5TOTGuJAPJX7FxT6Uh8Ix18oqWrh2HEPxmX8T
GlTfZU6BPtYh+y44VD7hvEHrlJoCYyz34ofxsxTVW82S7LeyIEZ1vpxvkefG
vG/Vg+sY8WhNT/R1XPs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 725->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB7Ea5/gF/QBwS/UF2yhngpCPUhveboWKs3OTmIgbbdJJjPJ
nodn/ziIyOv0ffTlfZvnstyP62Es0/UyrcFu8810d3PfVUz2t/l/gGFZPquB
swGHrFeEZVHM4TW46uq0xjCtvZkX08NiGmBhDeGLeYjVWKIFZ4dcGJ75GNHA
9k6N6GM66N59fcInrBWuk2oKDHNxF78cf5cYRnSX/vH3c6h6QO8UB3mS/Ud7
ibT42TCdsaYPgWVcvA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 726->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OiCsjsAIMELFCmSBIcKqE1B4qbh4dKrWq/fOd1JLbuG6e
v51cnp/ufRCR8fR/dHm6D0P+Po5z8Mr97drPyfPii6XN1axdTra32m/AUPK/
IFMgb2JXH3moN2BplDO8gpvMvuQZmrzb+goMyjOaKYv1j3GDVVilF5wdamE8
tTnSBz13ZqQ/dyYVna6fhp5IA+uTMSKL7oLd5xjBLIu7tFN/MYe1BtSuclAn
mWnBacxjXdt6+xg/WBJcPg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 727->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMDD1Ir32CX7APEL+gL9hCPQkFe5De8vRWsOzsdFI0sJo1ZjKT
pL49+vFkZs/z59GnpZvn9Bqq9XJP07WZ1uBlO5u1+Tj4Rczy2/Gblbku/jfG
NIrDvajPeMw3wPIoJvB/arNvWZdzPteK8ICzxFL6FV/Uzjhs3EPQwr1jLgrP
MSZ0yLkrE/qUDjl30vWPT8QB+4maIh4qX+2CC7yoF3KXdvLHPhQ1Ai1yJmK/
eP5H+/H1sc4+jDcnuV15
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 728->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU1sKgzAQXPwo/nqEXqE9QOgV7AlSqF9CQT+kfzl6KwiOs7O2uBBJso/Z
mY3nx6vtKjMb6++nzdNtGPL7fpoPz9xfL/3sbJa1WFpXgf3GZ8GdrXkF81U8
5ihjfK7H/fKd2lMfXN9h89623FifEuEm4UtBLcWfztibquWMNSQuHCvnBsb4
zONXvusLcBUPOXfihXF7M3I8SBfJJbAIp4h6TguBF87z338FNRF6yJnsva+D
eiB2VEfbB5Y9W/k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 729->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1sKg0AMDP0o/vYIvUJ7gMUr2BNsoX4JBftR/MvRVRA2TiY+Aqvrxkxm
Jnp/f5v2IiK/aro0+V/3fR5e1/nhk7vno5uTt2UtkcpSs1/lpNzVnkmp0wQ5
xLA1LLB/VBedsT3wcPjYG/ey1ob+aNQ3kVwKsFAX4Wu5MSwXO1pshHODd6Le
R+otL/SZ6XDeWF3of8RlR4cajIgH4876KMFzXpB+4TyP/ivWE6KFzmTr+zrj
h3jdsoHDYwQwll04
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 730->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQHVyIW4/gFfQAwSvUE0Swq4JQF+Jujq6FSl5e5oUOpEkzmfeZ
5HR/DuPOzF6H32fI7+s8589tv/w88nQ5T0vyuI41UhkO6ypnZXbcs7LniXIw
RzVNMD9qonMNVhJrpYMxkIc40Rv3xxUv6wYvYa/Ql9JLZyocDtAXecGQ90Y4
irtbH+jiPkc+5HuJ+q+0BPXOtSa8iFA8WFdhiF42OjfyI1bFIbz07hTfV++9
b+nHf20dnDi+rZddew==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 731->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQXDyIV5/gF/QBxS/UF0TQU0FoD8Vbnq7FWGYns6EL2yZkZ3Zn
0p7ur/65M7Pp8H30ab6OY3rf9svmkYbLeVgOjyVLdL/MJf97PFvXBjUQmfHm
3wpTBdThHJlxiqsL1jRHldyb16SN/eE6yQe9JRfrUr4JDY6H9cJ8We0hwnsz
jwt7K608j/KlwRF+L8r/yFeBZy9Qf+gn4VUfxDmOwMtqzo39kcv1CLS07tRo
5kjjFj9WjtZ/I+MDu1Ndug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 732->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/oA6RfqC1bQU0GoB+ktT2+LW5idnawGUpruZjIz
6en+6p87M3sflkefPt04pum2X4tHGi7nYT085sxx/abn3Go8k98gHPsRlzEa
gfORh3PfLyzBTWohrngPZ6I29ofvSTyYLbFYF/MI9iE9N6v4uarJH+cZVr4X
PIQGuXdVC58VRuVNQ1/oq+hnL1B/6CdxV3Owr8AIvIz6m/MFF+WH/L/Ufojz
Fn/7YbVua+DomAHQDV37
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 733->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EKwkAMXDyIV5/gF/QBxS/UF6xgTwWhHsRbnq7FFWYnkxjY0jSbZGaS
Hq73cdqUUh67z2Osz/Oy1Ndluzq3Op+O8xrct9Ns+B5r5+djTH4DM8zHulwj
MeyPOIzzsloBNsmFsOI97IncjPLQZ+7Kz2opnbN5SM1Zg8Fj5PsOi5hzh0Nw
kHNXJnRWNZw2AT8TeJxmxJXnJecSWNSHeXQ7V/r3LF/uRaCB2+sIX4ADa2T7
HupBcfVv/Of0BkgfXvc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 734->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgjAQ3HAwXnmCX9AHEL+AL6iJnEhM8GC49elIrDi7nW3ZpISlO7Mz
23K6P/uhEZHX8fPow/s6TWG+HdbkEcbLeVw327RSdN8V0/rl256Qb52oiIhH
XqeeBfZHHdFia3xEm8IhP2CwDnuiN4vD3HpneYkL9SkONnvLY/0zDuH1mRZy
hkqH50UI3gaZszpz0OTy2JnX5mq82vMqeiH4rA/xoe6c6PcSvqYfubJ77elz
dCBH6b7vmcfGsfO/+ccCIAJefQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 735->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbnq7FbU2yM1sDWUiTTjKz
2cP13vUbEXnsPkeXn+dxzK/LdgpueTgdhym5L14sfV2Lz/GSE/AtiTM1GA6X
1ENLAYdhruGFeo1zWK6kzuY0eZeQm2OKZ+IWVsUN1QEOro9gDDuj00NID6lr
WG+kJTWgM9qdShvCT8k87F90X00ugRPsA3hEjRkG03P1vaC9FqAnmAPteWvf
oR6hdsH489387A32wV95
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 736->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHigfhmBFWCAiBXKBEGir0pI7QPxy+hQtRKX88W1lCZO3POd
7fPj1Q8HM5u736fP79s05c/9uDjPPF4v4/J42tZmad1KWpel/121q7PV/xa8
D+KlQX7k4TD38Ci+MI8GV4zDN9RWKDf6TTzwIyynTcUJDVUergFhqniZg3C4
L1IL51Ym6lxhAyeJI/QoPi0Osl+RFlEHl0foqGYuwFC9jPgjlptrE/UUPNyc
78y7rAfF8rlZK2dfdd5fug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 737->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk0EKwjAQRQcX4tYjeAU9QPAK9QQRdFUQ2kVxl6NradHJz0s6kDZNfv6f
+ZOe7q/uuTOz8fB9dHG6DkN83/bzxyP2l3M/bx7XsUZYXiksw8J/zYIMk7nl
Z5Nfb+AxnH5SXeVt8QnW51TwEw7OZPUB329e0bVQ8lAO6nOBcxj0XD0QTsKj
hvCob1iLalOAzxm3ywl5oB7Kp5YD9qtVC/hQ6EAdnrvFUdXf+l9UQ/vb6Glx
zzfuO/ohWJ0TD9f0AYCxXvs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 738->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUVsOwjAMs/hA/HIErgAHiLjCOEGR4GsS0vhA/PXoMG0TreuEVcrWh2Mn
zuH66O4bAM/d99Ol13kY0vuyHQ+31J+O/fi4n2NeNv2yTQH73cEoQHvUubm8
D/Bysb7SXsHHNZTnhT97nKZzqv4E3z9dUL7iUj5HOOl5iXH6YnyjIfh4LuxH
Zj1vEVZyQPRMvVeeWzwj2Qd0Ha6fRX6j4812qRf1vtGJ6vdqcTxv/AzqAGOd
Hl0/6J2x62byAUMUXPk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 739->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB6kV5/gF/QBi1+oL1jBngqFehBv+3Qt3UMyyQRcSLttZyaT
6Z4fyzgdROQ1/C5jfd/WtX7ux+3hWefrZd4+nnr1VfZbK3tJVgJ7sdym3yMe
OAbT92l/zYm0lBenCdzGNIvn6Nko78++qVaxGgwXZq4xbC7y7wxHPAZ1XC6Q
R+gJsLo3Zk7PC2YeeSEeGnKF8LGn4rs+wHN5gE6UGT0XSZZR5jSHwAf2Re30
fAHOzZ15MesLaTpb9Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 740->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMDB7Eq0/wC/qAsl9YX1BBTwvCepC95em7i12Ik0mrgRTaJDPJ
pKfbs3/sROR1WI4+v7txzNN1v17uebichzV4LF4sfVyLb3cbo2/G1NZbXMRg
MfOmyBfVAj/24jDJrBQz+Ro7W6jPn7za6kHaeVRzmxPNFeyO7sTkII6bBfSg
PUEu4ji+AONL8xTsiJhirfhap+cPf6GqB+A4HvI3av97q2GahzqQPkLOlh7i
8yx3VStnM47eXDI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 741->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA0i/UF6ygp4JQD9Jbnt4WFxxmJ9sNpGy7k8lk
0svjPbwOZvY5rY8hfftpSvP9uL0803i7jtvlOWeO7pee02ppdM7hWI+8iI/u
4Fu1P+mNgjUUmrAPc3ZlDc7mrAfOqk/U1ysaHLj3cIXniInmCnYndwIY5ilm
UXOzpsBbNbfkIf9Zg/RL1du/H9dKP01jm/yocLAvu/phDuV56AP/P8ghsE1+
0D1j23ayAJfDW/M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 742->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwkAMfbgQtx7BK+gBBq9QTzCCrgpCXYi7HF2LA+bzMm0gpW3ey+dl
5nB9DPcNgOfu+xjq6zxN9X3Zzh+3Op6O4xzcN29Wfi7N0XO492ai+Tov/rnB
YrD/WH3KZXzVS8hJZqU5S+To2Ux/rhdWJ6srnR5E5V7CBc01Jpsr2Z3hwOL8
3Jojrud0Nx1t2dzZGQmal2RHxMRzEblUT3BsdneMHp0cXpel/rUOTPNUB39+
NI9gV+nh4h67TtMPiW5b9Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 743->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwkAMfbiQbj2CV9ADFK9QTzCCXRWEdiHu5uhaHDGfl84E0jZN8pL3
hjneHsO4A7B0n8eQnpd5Tq/rfg3uaTqfpjV5KF6s/3ouji2H+S6WZb/ExR8b
LAf9j82nvaxf7BLGEabENTwkN7Wf4cHmqFyv3xGvLLBrdU5zWSMwfjHj7WZE
3AyO40J4u50CbRnvGo7ci54RMacFfC/VE7w2ujtKjw0Mq0ttf6kB07xJB9tH
zr9JD5O3tW2avgGfNVt7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 744->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EKwkAMDD2IV5/gF/QBi1+oL1hBT4VCPYi3PL0WV5zNTkIbSGmymUky
yx5vY//oROS5/3z6/LpMU35fd0twz8P5NCyHh+LF0te1+C/GM5oDU8Qjr/y5
hZ1JnVPbz8MyPMzixh4n8po9cDeqj9PHcmBfDfbSVHNEdY3mWBPMgdb08HaD
GmW7iMR3A1jWm+Y9HuRKzh0RU4uVFuv2JbXe26n0CDhwnzXzowZM81U6WBy5
/6162H86C7UZYDZbQA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 745->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0EKwjAQDB6kV5/gF/QBxS/UF0TQU0GoB/G2T9diIpvZGS0ubNskO7sz
Q7o9XYfLKqV0616PId8P05Qfx/W8OOdxvxvnw03JEv07rWRd+zO658I83u3V
ekMM4EOdS4pleJzL1qqn70t0NPrQCzEneNG3b6ULfVNcmedNry88fIQZpB/q
NqYFZwtOzFvlOQsDHugF9UthU8Squay26pJ+CC9DzUL+nyB4yu/H3WD/wz9+
4DflQuMJB/hcRA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 746->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMDH6Ivx7BK+gBgleoJ1jBfhWE+iH+7dG1tGIyO6O4sN1Hd5KZ
SXbna9evzOy2eX26cj+OY3mc1tPhUobDfph+bpe5DJ+X6vM0/9yZwzTYW8ZW
z3fv9xUxgI/vKuSkWIbHvOysYsa4REdl3EAH5mm88LwqXeib4so8T7G+8Iij
yUHisZpILYpP6DPMzXqH6gINyEH6ZZb8jzwQq/JKvsoP4QXDN/X80ePYJya0
yFpEHKnfv37gnnKh4wnniV3A
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 747->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0sKAjEMDS7ErUfwCnqA4BXGE1TQ1YAwLsRdjq7DjJrPSxQDbdo0yXt9
tJvjpTsviOi6ek5du+2Hod0Py3Fzav1u24+H63nMxpMTngbxJ2Y8WpOtFbax
V774Glev8wwH1zPD91zSve7p4pJg6rul+gCcoAVbX3KgIs+dBX00r4SHtoAB
+lX8f6nX8VJbzwmYxvIcUr2Igr6ifMYDYYe8TA9156zHO6d6Y8hAPeT35W3A
P/aHHn4NuUB7AAIyXgM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 748->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgkAMbDwYrz6BL+gDNn4BXrAkciIxwYPx1qcrAWI7O11ssixsO+10
6Db9ox0OIvI8fR9tft2mKb+74/xxz+P1Ms7O87pWS8umaVmSfmduZ+/isZr8
mYu3GMBvZwUHyGnjIkOfYl3CVaAu9qGMmwT9Eo5q82IuxkEqceCjWkAO5GGt
qEHy1fgzLakFmkWzE/1jyxU57GlSYAmH3dnCuJoegZZFDJuxmhE86yW6Zw4X
3IV/9UAdWZ9xjg+o6l6F
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 749->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtHggvozACjBAxAplgiDBqxJS+6j4eXSoCNR27lIipUkc3+l8
Tg/XR3ffiMi4e3+6PJ2HIT8v2/lwy/3p2M+X+zLLSJ9FU9mnJeZWtJcF+502
xvKrc4n9OMxUoEURnnC7XMQbOUEdirQJqZdwSPKrGh6HCTqqvHAHvWjUwnpX
9TzkMP2VhpV909uoCQyrNWqgfonXb32JWPq2WM0tP4iXVc4/+pEWg0e1MB8c
jvwLq36Iv2c9bHO8AFDCXQM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 750->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4BfqC1bQU0GoB/G2T9fSFpPZSWogTbuzmZ3M
9nB9dPeNiDx330dXXudhKO/Ldvy4lf507EdwP+ccOpWqU4r+1lzFNLH0VruO
vUIwWGs0WE71+zIe1OYw5CWcFrOzoT903oBD1NeqQQ/oaPYBVhGzWgIdNpoz
CF+mP7z34D31NtHJMNQQ+iVeP7vv1M9sX+ZH4GX0n6f62SzLGcaP1Vmwj3D9
5Yd4nN3hOscHeT5dfw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 751->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EKwkAMDB7Eq0/wC/qA4BfqC1awp4JQD+Jtn66lVZPZSdBAmm2mSScT
dne+dv1KRG6b16Mr9+M4lsdpPb1cynDYDxO4XXwxnUPV2UW/OReNVxVn71qX
x1oJMJNrONie6r9r6rG34eYwNgP0tJidDfWh8wY9RH2sGtQAD6prhCGXgIe1
hgvpl/EP9x6cU20TngxDDlRXVkv2neqZ8c30CLRkmv/C/2P4D6NH2gf3nNyF
f/TAM+VC7Ql5M13A
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 752->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0sKwkAMDS6kW4/gFfQAwSvUE4ygq4LQLsTdHF1Lq319+YiBNDPJJHl5
M91f7u1tIyJD8/605XHq+/I8b8fNtXTHQzcGd7POopOpOqno4ltZVpBPbkU/
50oQA5/BwDWFfBwTe95g8upSX4zhbMyPOy9jlCUPbdUgR9d7j1eDiYVqMA4U
gyXilPiJ+OKZeJ1yy5gcQazMp8trMAe+oZ98ZnipL8eyGuFdJxjw/LcH8JHW
4XtO/oV/+OC1i8WVFyKXXcA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 753->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk0EKAjEMRYMLcesRvIIeQLzCeIIKuhoQxoW4y9F1sGp4/amBDM0kv/n/
Qzen63BZmNlt9foM5X6YpvI4LufiXMbddpyb65o19u/0mp/62wszxn4Nj3hL
sCZ6+Odijwuskx+4pDW1JrtjL2qjP1IvOdoP59yfcIt3qLmGEwN3UEuMZkfm
KfzJ/Go04dz1tsOz4WKtn9KvRIfy+Z+fcg572VMcmhngM/6RD/GSn3p3xCVv
oesHtPAsuch4AsD7XX8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 754->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDD1Irz7BL+gDil+oL1hBT4VCexBveXotrhImk7SBLbudbGYm
u3u6j/2zEZG5/Xz68rpOU3nfDuviUYbLeVjBYx01uu/QOn7rP2ZyBPEaavdL
sFcAI/+U8GiUFwRiSjwwrRpwWm8KuqlfolGBl9Vy3Emeq4MBNdCLDeRg9fBc
8K5kfcB52ttEp9MiO/sa+GB93uonzQNexJgGl7NTv9Xj7jXTl7275Pw2+wFe
cE610FgAG6de/w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 755->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMizigXXkCX4AHTHxhvKBIcJqEtB0QtzwdJgpKPTtE6rQmqWu7
2V/uw21jZnP3/gzlcZqm8jxvl821jMfDuBR3ddXoP8vr+u5/NSO53prweD7i
in6Va+5nmLFPBHJwwoNxdbiXaUN/qF7C0UFPgxXPA1/Vt8LBAAzUwrCoJuCv
ZkX6QDil3iqeiAPvmL2R0sF8/ucn7YN7scY4rHqyuRAepHOtcGIOewE79QO0
4D/q1BgvM/Rfvg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 756->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylkkEKwkAMRYMLcesRvIIeoHiFeoIRdFUQ6kLczdG1OIX0zc8oOJDSmSQ/
Pz/ZnW/9dWVm983706fHcRzT87SeLpc0HPbD5NwWK6f7WC42371PvrmTfb7H
NYdp8Im3zHrEjHLBpcJknuIa1PS9UR/Vr8LPDrfCAocMjiquwuEJ+lQzYg2F
x7lQi1AHcPmqbcSTeN0yrjUj2YctdaamsuYvfOkLOFQxrb0Ah/lf7TV5yFlw
N/7YL++PNGnO0l6khl37
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 757->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylUksKg0AMDV2UbnsEr1APIF7BnmCEuhIEuyjucvRWOmL68qJCBzKQz7y8
vEnRDk13EpHn5XM16VWPY5ru59l5pL689XPymi2f6muabfFtDmNqfVnfqok5
DCE5iCn2I70cHmAhB2U8GFfsSWZDfnRegq+m3mEBBwWOrM7h4AnmZH/kehA8
NreCT3UALrvaRjwRr+Lv6Q6zOeRXZ9SU9jzCF3MBB1eztReBBmyvkQfFwd34
Y79sPtJk8y/lDecgXbo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 758->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMDS5kth7BK+gBilcYT1BBVwPCzELc5eg6WDF5eSkWUprfa16S
/eU+3jYisgzva6yP0zzX53m7Ktc6HQ/T6tw1aad8RJt8detDm1pdfrlqbAFD
iA9siv+RvwIeYGENAdPaEbNEn+WGWJQvwVcTH7BYreLjWRztOfYg4cKw3Lzw
EN4KOu0D6iXWxnhkvFwtEvPpDouPd2+D1+tn9l+oF33ZbDCmtxdJDzAf55Li
4G509vDffuDb6t1ZygvJGF13
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 759->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCexBveboWV0wmk3YhpdnsziQz
e7w9+mEnInP3+fT1eZmm+rrul+Rex/NpXIqHFm2Vb2iLX25ruKc2l/9dNXsB
Q0gN9hT5CFfAAyzsIWBmGMgJswUswhV4bU/F68TmUsBm5xDD9YAaME8Ip+NI
vEF9FHKqA+Yl9sbmyObCGVCjTFfnF3pHvMnWZr9Yy7zZ0mGlB3vHzUe0SL0U
OJO8w1QP0B//bb6u6RsiAlv5
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 760->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KAjEMhYMLcesRvIIeoHiF8QQVdDUgzCwGdz26DraSfk3KFFLIT19f
XnK6v4bnTkTmw/ca4nKdpvi+7VfnEcfLeVyTx2z5hJ+lbMXXOcaS9gXvNa7g
LXOIJf7Hvy08YJGDxiw5i78YdaU2hRbL+svjqN9rszTU2FadhcXzj1kz8eam
58WD/rkrrg70Q8vN6sPri/tAjTxdq3lxdhv0JC+XL3OGFtUueTp0OFQ40GQT
Dnejs4fdOUjbq6VJX9MPxIJb9w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 761->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKg0AMDD1Ir31Cv6APkH7BvmAFPQmCPZTe9umtdIXs7CRrIGrMZpJM
svdxHeaLiLyuv8cQ3o9tC59nsxtTWLp22Z23pEn6v8akh619+C9qWyBe40oZ
m721YH6WG/GIjTVozMPH6hdyDjGQH9qvVZPiKOOa1SD2OYZViDUrb26V2SAP
jFcaz7iE3NhHdZcMjlxeJfdFwHT5hLqi0UdxDwhWtksWrlODzsn2torDduPE
nXEx8Jv1ROUL9Dhacw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 762->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQXDyIV5/gF/QB4hfqCyLoqSDUg3jL07WYwmQyu+nCNmx3M5mZ
5HB7Do+Nmb12v8+Q3pdpSp/rdi7uaTwdx7m5L1ni/M9ccqmxx/8y1kb7Edfa
vdWKweersxlP1A0HyKWn+Ks51sb+SL0eJ8IJOZg/p7Ca8O4qurfO3SAWe+H6
wDXOKj9Ao6sr8Cj01eoe8uj6Sbyyo6PhLrAivZK/Cj5jzfuCvRVG502sel/I
w9Mk4wuAQ1o2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 763->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg1AMDF2UbnuEXqE9gHgFe4JXaFdCQRfi7h1dpY86Tj4aiBpf3mRm
yO31bT4nEekv86NJQ911aXyel+Kd2se9XQ6vJUtUv8wlJUpZe/+1rHcz/MP+
zTe+MfbmE181B7gwLmp0Maw+4KX84VkBxwy4CsviIH6fhaWCdQa61QwPr9Kz
Pb9MLkK9lh+gUflj6GGPQl/F5nzIT+K16aOazyIM14eAA95hTw7hWLsR7MTe
frEOS6fv6QR7UVq0
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 764->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgkAMnHgwXn2CX9AHEL+AL1gTOZGY4MF469OVuIEyO11oUmDZ7jAz
Laf7s+12AF6H36VN7+swpM9tPy4eqb+c+3HzmDNH80/LiVpirp3WmM8avfP4
0zOWZz0Pa5b34tuMJ8J4z2FITlQD0uG9MeLDdRFHr6vAUhwQ1ymsIlgn905o
W+sN98d7EfrAa+pB4YfTGOqqeFT1FZrzJj+JlwU6mLvCqp2X/FWoWd6Ko/6B
ykyszRfrUDpjT7/a6Fv3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 765->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENgzAMtPqo+DJCVygDoK5AJ0il8kJCgkfFz6O3tGkwZzvBkgkB+3x3
hMtj7PoTEc3V59KF122awnI/r5tnGJrrsL6sY8Zof8kxKZe01aY9bb0MzyR+
uqd9r+TB7X5VsyVnJ9iqlbjICWoIdEhvGPhgncIzdCksiwPMRa8VJ88D7M9o
K30bS4fnl+qFeTgbOShvgIesY48X6dXifMTPfyi+oEPWJOwMRskHN6yzfBTH
+gcy5930w9CK56CI8Y03uvJdNg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 766->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgkAMbDwYrz7BL+gDDF/AF6yJnEhM8GC49emArlCms8UmhV1oZ6bD
cro/62YnIq/DeKnTu+q61N/20+aR2su5nV4ec+a4flNzSpSy1M57WXoVnq3q
ZY1h+x1uxC+k14QSXDYD47deoC7nD3LhmvilDIvpBF702mkqeYD9wWx0JtCG
3CW/XC/wITfVEOiwdVrSJf7ONP/j5y+cXpjD1szYAcaWD8XAf4r4EXoIfewb
hX6QWfEcbGJ8YgAoVV02
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 767->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNks0NwjAMRi0OiCsjsAIMULFCmSBI9FQJqRwQt4wOFRENn5+jWnLT/Nif
/ZLD9d4PGzN77D6fPj3P05Rel+08uaXxdBznzX3xYt3Xc3FruS1nf3NbYnO1
5s7LWh3v8rb0DWIry5CXeiD9moXW5fiolv4LH82jDCPOxNrVFDGQeLoj1Qjz
dV474vVnoKfaWAPdcdAP1mV+pJrX8CQO1IfuRSyJX/guyESfeLQYahzd0Voe
7q1Bn3GON3+JXbY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 768->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDil+oL4hgTwWhHsRbnq7FYJPZ2aUL25JkdzIz
m+PtMYw7AM/u+xnS6zLP6X3dL4t7ms6naTk8lCzR/zKXRJRYa/9rrL252jP1
tFf3G9zofojeKrLAZQzmz3Wso9FHuiUnVUc4hoPjs1cnPWde1K9mxHe4eL3V
4fnVBPnP3JQfcj6BHskL9q84q9l4YfiSDtCZxHL8Mz4EPNhH5UfkYdMn3pfU
GfhhOG3lgg+SPF6y
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 769->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/YB0i/UF6xgT4VCPUhv+3QtrjaZzKYupJDdSTIz
6ek2dv1ORB6H96dLz3aa0nzdL8k9Dc15WB6PJcq5fCKXkChkxf5yWWuzunN4
uNP1usfmfPG12Mcc0gP5Iw51GH2gm85lOOjjOFR8ruGo5xqjemjdNW3GGzia
P/tXIu248wzcmB90P4GeDLmZSXQI1Gz6qeodDvgjn6gH22VVO/Phq5H4EXlo
6si+qM7AD8fpXy7yAlW9XvU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 770->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKAjEMRYMLcesRvIIeQLzCeIIKuhoQxoW469F1sDjtz8uMgRTSpr//
J+nucu9uKzN7bD5Ll56nYUiv83oMrqk/7PvxcFu82PHrubjNuU25v9imu7na
c/myV9+vMRbfN39XcRoDDMc14lvFDT94y2nXM8FBLKkV5Wm/nA7SEumGNwiv
4QazMqdde076kEOgi/RkiaP5IM7Um8gcX9HRcLC4llS/aC7Q9E9BPf6Zjehv
LWKIFscJuLCmN9FtYDg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 771->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk00KwjAQhYcuxG2P4BX0AMUr1BNE0FVBqAvpLkevxUAnb96LA9O/zM/7
kunp/hqfnZm9j9/LmD7XeU7L7bC9PNJ0OU/bYl+82PDzXNxabnust+zzfV2L
udWd1JB9vbFvrk6IBQ9aQRtyVHxuLYtn1J2hr6zle4s4ZAgcjGXYeyg2H4NW
aSOzQs+daFF8gbNx7hjnmeh+EQ6DnOZcQH7Yd6WB7YUR3j9zQQ17QG86G6hJ
/WOtGoIlaCJaONMKMDRc+w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 772->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMtHigfhmBFWCAihXKBEGir0pI7QPx8+hQEamXy7mx5LZp7POd
nZwfr2E8mNnS/R5Det/mOX3ux3XxTNP1Mq2bp+zZ+r97dosc4h3XtuU6xSF+
gUP5iLFbm7GFMTeFV3Elvqyj0Ad7Hnwzb6e6IRbWDuJYQ6VDaem3GpG21mwQ
i2cl5644Bfokh0AXx/kOr0gH8uB/sp+Qr7g64aHGJkbjXEhTd8XqXlTnht+q
V4pPox8FJ6Ez1vQFHdhbeQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 773->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMDD2IV5/gF/QBxS/UF6ygp0KhHsTbPr0WV0xmJ9kGUgibTGaS
9HibhkcnIs/95zOk12We0/u6W4N7Gs+ncX08FC/Wfz0XF89Vftax/Gsz5Gl8
gwP1GiPsjdjEkFvVl3EFvqjD6FNvOq60kzhvwNIzaOVRHUxLb2uZttZuxOPl
7Z1xcvTR23F0IVfNpbqhQMevH523Y3R3UGcwgjsP5xBwqOYA+23iwL/AbtXd
i6PFcCI6fYwFWntaug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 774->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtHggvozACjBAxAplgiDRVyWk8kD8PDpULcK93FlYchM3yfnO
Tg7Xe9dvzOyx+3y6+jyPY31dtlNwq8PpOEyL+8UXK7N7+c2ph/0eY5tjx/8l
jAwHLeNA9ipzwhe5NFyBL+pY6QtrkW+jncSeYLE+ZDlpzZWWomvT5CB42Bcn
PJvcbC700bsjdCHXyAV5ZTq++eh5YbR3cG6FITiw+sl7wYy9FfsTB94C1gox
snrQOgocbm/SxVq4
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 775->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKg0AMDV2UbnuEXqEeYOgV7AlG0JUg2EXpLkdvRYuZNy/BB1Hj5PPe
ZObWTe1wEpHX5fdo8/sxz/nzPC9On8fmPi6L1802pNU07d/UTLxaX1Zf8X8y
b1YHEXEgsR6U8EUuVQzwRR2FPrNm+Vbaia9BLeR2JK7ac08LzoJoK2IAOJci
x5s740Ty3LPj6EKulgvycnXI3o/mO6AzgbyiRqAh3Ifonth9+PeA3mEdzCNn
2p0LwNV9lIt8AVtfWTo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 776->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBpV+oL9iCngpCPUhv+3Rb7GIyO4kdSCHbnWQm
2fPw7B8HEXk1y6dP726a0nw7rsk9jdfLuP48bbGg/UVubV5FAeby5ZYw96CH
OUNEGpDD+EqLqxe9Qn+jA3RlwtN55Z3kOaiFnv/dozPXurQXpdHzFu0G92I4
3t4R5J1V88BZkBqoVWtBXaiH7YvyHdCdAM/UCDx4M6Vv05tD6QG9wzrII2/a
3QvA9b1Xi3wAzXpZ9w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 777->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwjAQhQcX0q1H8Ap6gOAV6gki2FVBqAtxl6NrMcX0y5t0YArTzM97
b+Z4e/TDzsye3ffTx9dlmuL7up+DexzPp3F+PGTPFn6espvnyC//pbK+zGN+
wJut8935rFH1BRb2JZZETsBLHit+4L3EFXcRp0Yv8t3Kk5pTg1Bj9Li1dsO9
8Fbk3mnUXulBLUQPYi2xVDfs8bD/PFnvmcKLmG+tHkpTeZueDssMgcXtwzpx
0+5eYC5v0UfbB4/6WPs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 778->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgjAQ3HgwXn2CX5AHNHwBX1ATOZGQ4MFw69OViDKdzlY3WULpznZm
tpyuY9fvzOx+eD26+GinKc6X/bK4xaE5D8vmcc01wjtT2N5lUj1+S2HLrI7r
A+1ZXu9yYIzCAxfJV2ml8zMexCsJHK4L7WKdKr1Y76866TnyQi3UU2mrzYbn
kmG8uXOIe1b4wV6IYK6IlX45WIXx/EReBV+Pw0dHpYfytMafe3zPEFzcPqif
/zETM/nDD8S5fWQ8AerPV30=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 779->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMjHggvozACjCAxQplgiDBqxJSeSB+Hh0KLXXOZ2PJVVP7nLtL
ujvfuuuqlHLfvB9dfRyHoT5P63Fxqf1h34/F7ZRTyDdVlnebn+825poJlSWb
PtvPajBXIx6IYXjDxfVKW3M9wBd1KHIjezntZK3JLNT7r496bnlZLTCTaaM6
UKd4THjuGOSeOT/QCxKNH4ClfgVYhon8tLwc34jDrCOZwTzN+OOM3x6ESzgH
/gX0Or2jCQ/0LjzbJl4RGFlA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 780->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sOgkAMnbgwbDmCV5ADNF4BTzAmsiIhgYVhx9EVBabz5rWxSaHM9LWv
Hy6Poe1OIYSp+jza+LqNY5zv5/XjGfvm2q+X9aabyE8XSbbW77mW/U7JIkn1
2fFGDMYMKRflgRiG13nRF7gg1yymQAyB+kiNaNN6IY7JU3H1/FjPCy6AL/xZ
Dise7ITZS2s2ZM+KfgAvJtZssvr+wDKM1U/klflZHPaaCQe25+a8HR5HDrDd
OPAv4K66O+rwwN6Zs83kDew7WsA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 781->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EOgkAMbDwYrj6BL+gDiF/AFyyJnkhM8GC87dMVWMk4na5NytLdbTsz
hXa497edmT2az6NPz/M0pddlPwfXNJ6O43x4KF6sWz0XN/JlD+17BpYxH/a2
lXO4ptUxuByVj335rsAieQEOjjPvm+bLPTHOlVrM12lB/JTm/7i4+wqLqMcz
wRxVUxrqHunBWghO0Wx++AUY1PwVnsgk3ghDoIWbv5pnBQP23HrQe/h9wer+
s4hjDUvEW9WR9gb0+Vp9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 782->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU1sKwkAQG/yQ/noEr6AHEK9QT7CCfhWE9kP869G1uEg2k9SB6bKPZDOZ
7f766O+biJi6z6cvz/M4ltdlu0xuZTgehmVzV7PG6ZtzzeDkEOsz4+vab2SM
4V3V8A8PWpxe5JbnQuwpf8RdCuM4FBfXm7zAe5iHg2thToikRfBxTxCTOF1v
0HfnB3shamKtiJW+mjoUxvoZ7dnmnNNgvEj9V/10bxPmzR1Ci3xfMKb/zNW4
4of00fHIeAP8FFn/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 783->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMDB7Eq0/wC/qAxS/UF6ygp4JQD+ItT9fiCtnJzAbSdptkdjLJ
4fqY7hsze+6+j6m+zstS35fterjV+XSc1+C+ebPyc29u6GjkvweMf8xLH6NY
gDvkUPpcZY4x5BS5Yp6RGOgTY+o79UswXORErkw7H/BJXMhMMD9xUXigHfLo
+mCGO8L0wPtG9Wbpfqqr6IPVKD1jfeKrOAgt0vzZPNVuhnN3B+FC9yu81cyH
Oyp6SX0zHGofSKdbQA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 784->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMHDyIV5/QL9gHFL9QX7CCPRWEehBv+3Qt3UN2MlkbSNlukslk
0nb35zgdALxOv8eY3tdlSZ/bcX15pLm/zGvwXLzYsHkuDnY2dc/1KGcIzMj+
cRjq3Miy4AbBReZBxEgfG4vOezCsVhVPwzXTnZ1B8XFcxE4433GJ8AJuDjPa
jdU90oP7teoB17+lCc/BNXIWmknyDThEWsj9t74LhcM99uDYfwB1nLVvchGz
uLkVjrQvuLRdQA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 785->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkjEOwjAMRb8YUFeOwBXgABVXKCcIEkyVkNoBseXoUJHBcZ5bLLlKY8d+
/snx9hweO0lz9/0M6XWZpvS+7pefexrPp3EJHooX63+ei8u7N9r351XWgpqR
bTH0dW5kGdgELJinNpZNfqYY9fX1oYbVquI0rNntbfF47WkWmrtiAW09h2WL
GBqzukd6+H5Qw7Pas6grzSE+g/pIzdxVXsQQaIH3v/YuqI7vEfGtvA3S4i+W
gIPuEN9oZR+Ga1vC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 786->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEOgjAQRScsDFuP4BX0AI1XwBPURFckJLAw7np0JDZk/PO/hJ8MFNqZ
vvnt6T50z8bMpvbz6PLrOo75fTssH4/cX879MnmsUZW+UWoYBor9x3yrYyM1
lRwHZUiwVqgQNqy9svpa7u1rYE6Yw3GKNdBj9Ao5fzhg3T8e9J71gv4EFuJt
gZ58DmVgZ0XON/gB+wUR1iK4mLbuJ/PH90B5FYPvHRiY5/JeMOEeik+dg/Bi
N4vqe4tl1QymF1x9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 787->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbnq6LZYmTmYoD2bJNm8xM
szvfhuvKzO6b92eoj+M01edpPf9c6njYj3Ny26KhfMJbGAaC7Dveb3vLCjkK
PIccCpwVcMyFOo5aY62wxhp4h2lMdQrJQY3kB9HLzlE+ygOiBXmlHsTvrze0
rINp7fqi/IB+CYSrE15qdnvzmeYC+jLdXQ5RO3Bgnsu5YMAeip96B+HF31yU
7l9cFrwAhR1eug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 788->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKhDAMDB7Eq0/YL+w+QPYL+oIurCdhQQ+ytzxdxR7idFJqIBbTZjKT
5PH59WMlIkuzf/qwvuc5/If6+PmG6fWcjss2erTudI0u6GgkrpgfY8nJ8AiP
Ig6OKd4ZHEWtFsucFwzIYRoTnAKMSz+IXvpOUg2JXqYFMO07V5NTE7kxzNze
2Pl6GO6ukL4p4eVxwNoslusn5etxMHnIgc3fmzflgjVKcIBTbo/vcKG6hfSK
4mxLcV55
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 789->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBjG
h8uhA3tM8QZ0/VAxZDMasOjDZi6KG3DpwWNOA7ockjsa0P2KTx0Wd6Hrw8q2
J84MlPDA4l+s6hgw/YDhDxx+RjYTWR3OeEMCyHaiuw2bmfjSDXL84jIDZ1rB
Em4NWNyFyw3odqO4l4jwxOpeXG5A0ofuBmzxjyu+sboFm/sJmYPmJpxxTqJb
sPqbAUtYYTUHAN8AXL4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 790->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX0q1H8Ap6gNIrxBNE0FVBaBfFXY6uxaQkf/6MHZjSJJOf
N/k531/heRCRuft+QlyGaYrv23EdPOJ4vYzr4ilnjv6XKWcZm0HWE+7Pc1u9
tGv1POMQTKx3+BLTlVZ7Y/XqCBfuo//9Po2EvUG/tE50D6oP6AU18R5N36qo
z0Q2xWC9H+KvpaE4gRe9Qi6LwXyf3ruA/YrXYijajgb6xPymgWcQFu8OCwf1
fI8G4WAe/tf5AJveWoE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 791->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtxN0fXYpXpy0+rA2kbMvnz
/qS787VpV2Z227weTb4f+z4/TushueTusO+G4naMcaV3lDE+ebhEvVQa3xre
hX08gxpkUdoRn8rTlLMs7RNc7JPf6TcNd1fwK/eZ9+B8wAs1OQPJgjWZr3kf
yqtkwnwjDccJXvojV8RQ99bzmv0vcLbjRc6aYojuTM17jqXuVYzhHEzcxT8a
AQdnuKzzBERqWH8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 792->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMbDwYrj7BL8gDiF/AF6yJnEhI8GC89elAXM0yM43bpEBpdzrT
7vk+9cPBzJ7N+ujT6zrP6X07bsEjje1l3JKn7Nm6j3v2bxyaqPEC4/cf3o64
2AMxsI/CjvipGLD9X53g5ZCT3wpfYNCsQK+sM9ZAOkALYuIOJBew3X6NdZBW
ZWK/EQbxBL6ozwEv4lDmyn2FWkRv2guc22EEs6SaSv40h/J8rRZxF3Cm0d2r
5mHBrMgWJXFYfQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 793->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMtPpAfDtCV4ABUFegE6QSvCIhwQP1l9Fb1LQ45zPCUoBw8fnO
zu059eNFRJb68+jDep/n8HpU22YIsW3iBl7zytF9V8rrt3eD4Elx/DH21nlY
AzlQC+MmkbCGytHcidUXgkF/NEa/GT/hKHqltXY7HzuHHowP8IKcWNPUIHw4
X/RhvLIg8/U4jE7gQH+oy9OgMT2vU168+UFeweH00pw5uhcsSH7x/8TdoL0g
Pg+1eDrE6ZWJNxfGV/0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 794->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpA/TICK8AAFSuUCYJEX5WQ2gfi59FLRYji85nWkpukts++
S073Zz80IjK3n0+fXtdpSu/bYT080ng5j2vwmD1b93XN/jsbq85K4lphlBis
ro71wBkQD7GJKfaoahw26V/yyFwKMbrfiUH1qP7RPOCA8xgs5C+8J+uBhveL
PBxXZuR+Iwz2xgwfpnWkK+FR9qDBFhd6f1BnMAItXc6/dxFogPWMS6hhpMVe
DMh1c4itj3EWUwhYew==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 795->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX4tYjeAU9QPAK9QQR7Kog1IW4y9G1GEvyZsZkIG3DJC//
//RwvQ/jRkQeu89jiM/zPMfXZbtMbnE6Haeluc8jV/iOlMdvXlUQtb6sVDDW
Ht6qRw4ZXGOxjUqe9uDopK8ABvIpe953D0NpgF9zHfKhHsuzUKOh07w38pCf
8sKzGwwzD08nGPRHXS0N6xnIwM2z0KXuBfsqhsFS51j/1x8NpWZ66uKU/plF
L6OlQ+r9PucNv01W/Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 796->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozACjCAxQplgiDBqxJS+6j4eXSoSMG5nFMsuUnq+Hy+
+HB9dPeNiIy796dL03kY0vOynQ+31J+O/RzcZ8+mH7fsy7kwleq+N3MY3xis
VQxxtOGMQ2AWcXd4FvXo4/DfFDSCWpizhsH0QGx2z7TGo33gXkjfERc04Gds
L418z4XxV6Jlg0ekW9VLlC+/evgmlZ7O6PtBXoFBsFg+9tCa7wW3qAHz0dTB
90/m+C+MNR5S5sc4LxrBVbo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 797->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbnq6LVafTSdFASkOayUzS
zfEynBdmdl09jyHf9tOU74flHJzyuNuOc3JdvFh6uRd/x5VB7CLvgPHJJchx
neqTOm7ibWAecQc8pQHfOfVyctbW9E0i18FRvKJ3uCNnrqiT7yZ0R1zYiJ+r
u3XqkYviH8xLYfTm1miJONi3H++kmSeY3B/VVRgCS9Xz3+j972oOpOknHNQv
/vFfXCIeVtfHOA8Salh7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 798->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDD1Irz7BL+gDFr9QX7CCPRWE9iDe8vRaXCU7mawG0m3IZjKT
7OF6H8ZORJb+9Rny4zzP+XnZbcEtT6fjtCX3xYult2vxT1yZiZXk1WB8c3C6
HOKkhgu5G5hG3A0e02DvKeGlCWZke0GNkhgxHAeCjTjVHZa3OvFf4p50b+Lr
UAflEO2G7NXNI+LJ9BtMxosZ211TC6l3+4O6CiOYJdZH7ys07AHvsIlj9eM7
/hfjFw/hGr2tcrRYPA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 799->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0sKAkEMRBsX4tYjeAU9gHiF8QQt6GpAGBfiLkfX0UbSLxWxoOdX6Uol
ndmcrsNlUUq5rV6Xod4P01Qfx+X8cq7jbjvO5Lqthv1nWVvvd8J9UzHmNL4c
7oGjDjUYw9gERk7kTGsojhe+2CMfx+fAQSN4ENrUYX8C7+tEzd4H65bnhhif
24SPLj/90EvWD+QLUF4zXwLq7EztTyDPD/s6jaSX3J/NVwrmwOz+1BGzoGbs
Ly/wIf8BzGCPJ8jwWP0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 800->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRSMOqFdGYAUYoGKFMkGQ6KkSUjkgbhkdqraS/fMMtZSmybd/
7G8fb4+u36WUns330+XXZRzz+7qfDvc8nE/DBB6WtVg7b6Wd13p2uLkjn/XO
YbJXmPIoh/qob2CF8pc3wzqTwSGvQhi8q34FOKocQD96r0gdWG+gM+Yf9c2Y
62+S/H9o4s7QV8tDehEXzZHqG82HxagW1FPiq/5JnOMItNT4ar4oB5oDo4G7
38BDWliOf1pSHvqvNdb2AZtoVvs=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 801->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMDB7Eq0/wC/qApV+oL1hBTwWhHqS3PL2tbiGZTBrY0t0ks7OT
uTze/esgIp/T8unrtxvHOt2P6+ZZh9t1WJPntlqU/9K2fnsbcMZq1GBsOd1q
CukrEnAFMbAGa5NQxl88dvpOW0d4KcuRe7FOCUbggGfJfVafkDd83b+ZQfY2
qjPh73DgPOsP8ySeY3oxHOYj1DfzB/Mncgh6Qn+YH/Q5jERL7A/+2vMn6kA8
k3rc4OzNL/UowVK8G94ZOLqYAZalWHk=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 802->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk00KAjEMhYMLcesRvIIeQLzCeIIKuhoQxoW469F1sAPpl9dOIdOfJG9e
XtPD7Tk8Nmb22v0+Q3pfpil9rtt5c0/j6TjOzn2xMs5/y8WWPf3LyPS7s8qH
OfiAYcQgF3JqjKxwrcZWNYQ4wSsrn/gv47LACBxwthqj+Di+1ZqYojaps+Af
uHU0CZxgHkfppXBUH1HfVn9QX9Ym9UR+uD/kVRgNLcNb6/WFq13qAD16/eXn
3v2tciEPrq3Ob+N8Ae1vWPk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 803->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKAjEMRYMLcesRvIIeYPAK4wkqOKsBYVyIuxxdByu2vy8NZDohze/P
Tw7X+zhtzOyx+3zG9DwvS3pdtmtwS/PpOK/JffZsw9c9+y/WfBjbv87LnJxN
TjBMMZSLcgjMCddqbI/eL+8BL6ccvKv3HDAaDqBf9w7xgV5KDYl/wwX0rnSz
dldQk2hniH+gF/Xl0o/ONaw1qDWeTWQ4P6mrMACL6pv3ezNVHWBnov0qz2h+
3R0FTj7Av9X1Mc4bnZRZeQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 804->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwjAQhQcXxa1H8Ar1AOIV6gki2FVBqAtxl6NrMcr8fFNwIJ2GmXl5
eS/7y20YNyJy374/Q3mc5rk8z92yuZbp0E9LcddWi+Nn1ba+e1MXCf06qsL4
1VwOtQTXcCA84uS5eFyx2DU7X/cBr0o1+Pd9FTACB9BvtYf4wF20huFc4gLZ
6OZxMk1AQ88p0wL9AU28n6irijAr0RPUU7iXfDAYgEXza1rou6MOiZ/0dnTO
/PtHDzOb4IT3YeIFDhxZ+Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 805->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8EJwzAMFHmUfjNCV2gHEF0hmcCF5BUopI+Sn0dPQt1gn04mAgc7kk6n
k317vbuxEZHPdft04fuc57D0l/0whOlxn3Znm1Yy/a2Y1vFPyD6Lzy1mGIIY
WsZ4GIIYCnE1TsiF8VWHJ2IqYIA+xkf2GBcJhuFA9GP1cn2Mn/RCebEamEPO
/1qR8KC1a5wqWtD5YP9i50l1FRuPuWYujtH5QZ77jgjGGS2wB6ODM092v6gW
5K6e1aPIdXDM/ShsBU9fWjg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 806->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EKAjEMDB5krz7BL+gDil9YX1DBPS0srAfx1qfrYpF0MlMwkKXdJNPJ
pD3elnHamdlj+HzG/Lysa35d99vmnufzad6Ch+rV0tdL9d8/I2uX7604DEOM
1OYoDEOMJPIYJ+TC+CbBEzETYIA+ISbWPq8QjMCB6MfO8/qEOOnFWziXcSG8
Gv0QR2nS0ZdpyvRiffkYzpPqCv2zWsWD1Yf5QZ18RwRDaUE17NwDOc/OXNT8
/tGjqRU44X409gYIAVj7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 807->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0EKwkAMDB6kV5/gF/QBi1+oL1hBTwWhPYi3PF2Li4yTSQsupEszu5Nh
kt1f7v1tY2ZT9/709XEax/o8b+efax2Oh2EGdy3aKp/wFpj7Bi6Rc+Aw5IA9
YAmvc20+Z0kOtajzJdHJnIU4yJ+Aifus2wVH0CD8U/XQn4ArLbBCXaVlrTfM
k3my4K/y1ElT1vdQt0R/s/lALOuJ9BPuZ3qDN8oD4si8WJ159U5Yi5gv3LP+
/ePHjybGFjlecLhZOg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 808->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgjAQ3HAwXHmCX9AHNH4BX1ATOZGY4MFw69ORgGacnRWaLGW77ezs
dHu8PdquMrNn/f60+XUZhjxeD7Nzz/351M/BZrV1pGUqabHvGpqJdRifs4X3
Er7DMvIT7AtyybPERe4HbMeF+Lo60kaN6h/8IjCkHrgW5EN9XFzUgsPlVVwi
bSBXETyinJJTpAfXKDBUXtY34oCx6E6knnA+4uu0CbRw96/6a6vn1TthLqq/
YHY6msfYq8cPJ479xZgACFVX/Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 809->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EOwjAMizigXXkCX4AHVHxhvKBI7DQJaRwQtz4dpg3kOg4blbKubeLY
Xre/3NpuY2b35v1o8+M0DPl53o6La+6Ph3483M0xjzRNJU3x3cMwsQ/jU1s4
l/AdltE6QV7QS9YSF5kP2I4L8XU60oJG9Q7rIjCkH7gX9EN/3LnQgsP1VVx+
eMM6Vtczp8gP1igw8Iy/p/SV9Lv7GPEI6iO+JdU5leYAI/Ji8c6r/4S5qPsF
M+tn7H/8cLqt5hFjvACZ+Vh9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 810->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtHggvozACjBAxAplgiDRVyWk8kD8PDpUjYpzuStYctM48dl3
dQ/Xe9dvzOyx+zy6/DyPY35dttPmlofTcZgO98WLpXnxNPsSQ8d4MC8xj/FU
r455gGERg9XGu8Jc3U/QJ6tvgkf66kM5svewd4LB9ED9Wb2oT3NOuGAfVV3W
y4o2yEPmMyMz1OiBHAkG8sdV5lp9xnSUeob85vtBXvMfrWAoLX7OvJplho35
gj/D+FePBVfMmsZ4AyvTWPk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 811->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMjHigfhmBFWCAiBXKBEGCVyWk9oH4eXSoGirncpdiKU1jx2ff
xcfbs3/sQghT9/306XUZx/S+7ufDPQ3n0zAHD3lli8tmcVmrDxf6nf1yzftj
uRvJKyzHTdXGuwLD1H2HTXtx/VY84gZH9u/ORjCqHoj+rJ7Xp4oTLthHUZf1
0tAGech8ZjgHTA/kSDBUvnwjZx53sw+RX72f0kNo0cqncwH6oQ7N92TzKfgz
jH/1WHHFrElO4QO6rFv3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 812->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMNHmUfjNCV2gHMF0hncCF5hUopI+Sn0ZPQ5win05OBI5jCZ1O
J12e765vQgif8+/Tpe99HNP0OC2PVxpu12EJtvlki+slcT1/Hx70K9tyRftj
eQvJKyzHpVYbsQmGsBhgUy6qjukj7vTI/tVbCIbhQPRn9bQ+Jk56QR5FXcaF
4G01sA8zMydf+xn/Kh5iOPl0d4CPxsUcOl+ig8fXaONoUcune4G9B8vbnSfb
T2cODOOoHkZzTytjMylDXDI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 813->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKAjEMRYMLcesRvIIeoHiF8QQVnNWAMC7EXY6ugxXT5HUayDQlk5/f
nxyu92HciMhj9/kM+Xme5/y6bJfLLU+n47Qk98WLpe+hqcQtF7jLv1bpX8Jv
WckjD4vnY4ehlHPYgYvro5BT48ijhSd13wrH1Wiq66mf1SfkPRfgQXgVl8Z8
6R1hZl4H4IT81/A8RmI9cXccH4vra3C+znB+wEGhN2HQbvXe/otxlzv7Zc+1
+QU+HT2C5i2tgr0BAwFcbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 814->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OqFdGYAUYIGKFMkGQ4FQJqT0gbh4dKlLJsV9aLLlN6vr/
nx8fb8/+sRORqfs++vy6jGN+X/fz5p6H82mYi4eSJdLvpamsWymwNxhK/3r8
tUiAQxpEIr8J5HHYSnhGr0JNTaKOFp7UvBWO69FU9xOf9SfUvRbQQXiVFvB7
6fHnCHfmfQBNqN9hBG8sRmI/cXacnsABZ1qbU7w/0KDATRg0W1tnX9Y4y//i
SOS334OeDT+CjpZXIT7bjFwy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 815->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYMLcesRvIIeYPAK9QQj6Kog1IW4y9G1OGCafBkamM6EpO+9
/Byuj+G+EZHn7vsZ6us8TfV92c7OrY6n4zgH9+00K79LS3tnR8A3GEq5Hr9n
BXBIg0jkN5byGGwlvOLyQJdSLHsbXwGjq0GW+VQDxr0W17sMb6HF3/L/h+oI
/ez032J4bvV8K+eIOhI9FrdbU2I4P9CgwE0YtFtp7bSj0PtVOBL5/Y7QXLJa
go6sV8E+13Natg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 816->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKAjEQRBsX4tYjeAU9wOAVxhNEcFYDwrgQd310HYzQqVQ1NuTfaV5V
crjex2ljZo/dpxvL87ws5XXZrotbmU/HeT3c11Zj+A4+1DlrMRf36r6zXBzx
HtRo6igGI+sQrs5CLcoaOJ2ceWidNjYPayc1UgZr85EDmahO0PzjQG1SE/IL
HZ2fmf8m+IXnqk7G0fwf5AEvpCYR9P0Ug/Aiu0//BfMk8f6vOtYz4z59F6Gl
41BedfEGfPZZ9Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 817->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkk0KwjAQhYcuxG2P4BX0AMUr1BNE0FVBqAvpbo5eixEmL+8FcSDNz0we
35vmcH2M987Mnvv3Z0yv8zyn5bLbNrc0nY7TluzzyDF8Jh/ymo1Yi2f53Fkt
zngPNAodxWBkH8JVLmhR1sDpJOdhVN7YOuydaDQZrKzHM2SiPsHzl4PpOdSg
H4854kH2BLmM8zOulk6Lo3g/jAF8Ui0R9P8pBtELdl++L2QXPfhHR/0/9PhL
P6o3oHpVxQpGE1p3
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 818->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMRCMWqFuOwBXgABFXKCcIEl1VQmoXiF2ODhUBueMZq5bSjxtP
3zg+3h79sEspzd3n0pfnZZrK67pfXu5lPJ/G5eOhrRb5e6u5PbNl92Ku5Svk
azY1tlbEr15ywP9CnUCfsa7+kUHD1FSsxX1MD7xRHVKjONGH84t8wIHekMWd
m8kxH45TnQ2ZM9cP1QvQiThW88MYwCfVEkF5FYPohTv/aL6QXfRgkw4wKWb0
uKUfbFbDWf/HGx1UW7g=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 819->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADKr4wXlAkOE1CGgfELU+HiQoy146w1K1rVsdO
sjvfhuvKzO6b92Ooj+M01edpPX9c6njYj3Nw21ZD+by8tH35nS32RuLh3OHc
IwfjQmB+pgc0M7iIRX+oFT07iXlYVJfiC7md8Yg7Sif66Pwm/ev+J1pY/TzG
iAfHnAyBQ9ZD1QJ4Mh2L/jAN4JNyCVC9JG83+4LD4A6di6hd1AB50vlM+sA8
/lMPNqvprH/xAhNOWXk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 820->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX4tYjeAU9QPAK9QQV7Kog1IW4m6Pbgsj48yZ2IEnTyf/5
fzKH670bNmb22M1T1z/P09S/Lttlc+vH03FckvvP+A0v8xSHrdhb43+BVXEZ
Bw09m4QnuejPW5xFOALGS1In1SQ5B45KA9SZzqiPyi+9V9Ch3lQL1c9LvUac
650UgsV6kAfQQvjKC+HBJ3IlgXrh3phrcZhgsC+i9vCd1f5ff+obKod6XFMP
6tVmr3/jDe45WHs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 821->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMXHoovfqEfqE+IPQL9gVbqCdBsIfiLU+vQoV0MiMGsms2mzEz
m+tz7PpTKeV9WZaufu7TVOfHeQ1edWhvw5psfv5vbsuy+WYqjmfq3MiOdQqD
Od4V5iIX+fkepgFGqHEDnRjfknNOMFIPMVZ9WuaR+BKc2Adyw16Yfm55j3WO
/2QGtVQPxoH0wuoTF8WDcElYwuj7iVhpoeZIzkXUJHxTzfc0EG+IWMjxiB5s
Vo9hfAGgvVg+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 822->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB5Krz6hX2gfIP2CfcEW6kko2EPxlqerUCGdzKiBbHZNZsyE
XJ7vtqvM7HOej7Z878NQxsdpebxKf7v2S7L++b95Mx+rr4bvvW+IxYg4xYHO
aoW5yEV9rjRYyENfHjxpAzz27YQj9YC8ogZ1UL1i5qme9ML4vMkx4uRMSE+I
c6ZjY1cUPmlROoiWxCWM9kv+G3NbHAYYuhdxJuFOZ763XyHSuRGNR+bBdvUY
xwTnwFfC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 823->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKg0AMDB5Krz6hX2gfsPQL9gVbqCehYA/FW56ugpR0MlMbiJJNMs7E
7On+7PrGzF7H5dHV93Uc63Q7rMGjDpfzsCbbzRcr9jEvWxzOUrx3hr34xj6F
gc5qhbnIRX2uNFjIAy8PnrTF7xLeTjCQQ8JlPEvWQfUKLqmecGF4HnNEg5oJ
44R9znT82pXyzYfhqV6mk2oSRv+fiNUsWL/cL9CdZkDumMSBWjo3onFvHmpX
/8OYAcA+WEA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 824->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKgzAQXPpR/O0ReoV6gNAr6AlSqF+CYD9K//boKoiN40ziQgz7Gndm
c38NTXcxs081f5r4fY5j/LXXxXnHvn70S/K2ntmCbeZh9ZPYwS/FsNdEjFnI
HFYrzEUu5eeKA9bavsexF3uQB+C5wjGiP5sTdNlw0HC+8P+HA16OE3JjPA5z
qt3gDEwP5ClwcJeIp3rTXJaTMLo/4UstSL18X9BHNTC4T+JQ3QjHkh47zvCe
i5xsAgwkVYE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 825->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0EKwkAMDB6kV5/gF/QBi1+oL1hBTwWhPYi3PN0WSkknM1UMbCGbyZCZ
bI+3Z/vYmdnQjJ+2vi59X9/X/ZTca3c+dVPxMJ8xii3hZc7DXcq/3WGvEayK
snEYVoSLWtTnSgNibd3j2Is9qAX4XPFY9p9h0JcFg4HzIWfAbWlCbUxH8lPt
huhKfqBOwUPnMOEZ6ohaLM+g3g/Dpj1EP5QXBC/fF/QxD1Y1No/gYXv4xw/1
T/3G8QHkLFYF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 826->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0EKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbnm4LRZPZJC0GtpDszGwm
3T1cH919A+C5Gz9dfZ2Hob4v2ym51f507KfN/bzGKPiGlDlXtSZfqjEXDjar
RSvj0754eFh/EnlgLCxHmMsc9kJ6EuloTvlxGGNqWoeD+2NNhcs8sZ7nA46m
G46vZh4am+i4fSCYK/egvaDtIbo/Hlb309wv5dnr37y37F4szMCcs0Yn+Q//
zCN6U+s0PnWAVcY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 827->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkkEKg0AMRUMX4rZH8ArtAQavYE8wQrsSCnZR3M3Rq6iY+f2JYiDCZJKX
/DhV+25eFxH5lOOnid+67+PwKKbDM3b3WzddXhcfLchmQTnG5GAMa1kPjDEG
Oss1zonlr3GPiww9a5hjqzMdCXUSXrI4uiZsNZiTxTQHDTUiU+V5mjKeoUMI
kxrR9bcPnN/geHPQvRJugnnoHGA0D/vCnTU/vkfzXezsIOtzhOP8hzP7yDST
t+ozfuxeVcI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 828->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkkEKwjAQRQcX0q1H8Ap6gOAV6gki2FVBqAtxl6PbQqHp658YOpBAZub/
zP/J+fFqu4OZvZtxa+PnNgzxez9Oh2fsr5d+Kp7mNUawJUK2mLPKHLHqDubA
kXIudZfCZ+ek+q2Clxz5rPNcKYhaAcNa8niItz894NsENQZwZn0lTSs+W7DU
QE4ZnEH5wfkdHoWXWjgPvKMW10/TvZt3oB+Ol+x3/5cX3pvV8BTeYY8fK83i
/5Y5ficKVoE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 829->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQioHAngEB7JEw
uhgDkWLoerHZgS6GzQx0jE0tDn4DNvUwcXzmopthj8puQMLY/IEhjkWuAZc5
6PoZCKhBMo9gWCK5E24mkjp8fkIxD09YENSPzQ3YwgPd/TjMweoOBuxhhhEn
yG5mwHQDrvSDTS0DmjvQzcbmBwx78KUvXABXmBNjDp54wGYGofDAlRaJMwMA
pNpWQA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 830->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKgzAQXPoh/e0RegV7gNAr6Aki6JdQsB+lfzl6FYSukxmThQ3JPiaz
k9yHVzddzOx9XZcufp7LEr99sx3GOD/aeUvedl8t2N+Cc4xZZQx72R0YYxjo
rFZYErlUwg1QC33JOZsjixcwkqjxZ1nj8IpaggYHfQgXqp/PkRmUJmcYVA/k
L3AoD+OaZW/iOVvOIZufvMnhHuyDPRrrl/9LmdK8Bge1Ms5f6gGzqL9Yh/ED
ngNVgw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 831->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKg0AMRUMXpdseoVdoDyBeQU8whXYlFHQh7nJ0FYYhzfwfJjBqMpNv
/tPH+zd8LyKy3I7LkNZ+ntM2Xs/kk6bXczo373kd0UkJ7XJualUe1BT1SkPN
66KFzpJQsvc3H/OV7wq4qFnIR6SPNDwvlIc1xNx6AfxKvznn3wP52T3ggTGJ
NCAPPz/RieaImFTspJ6h8g/4oe9Q+tyzD9RP/y8WjHmLjvPN5qc8nBf2L7Zp
7OXaWAE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 832->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg1AMDF2UbnuEXqE9gHgFPcErtCuhoAtxl6OrICUZJ9HA+5g3mTeZ
5+P9a74XERluy9SUse77MrXX9eNTutezWw/v2/Ch1TLZIbCXPKeYr2DFPQbe
j1oQG4QGeD3Tl8Vavi2njAdwjJ9xUDzUoKdYu/Pc9kLO/rUGl/Xk+BIvDusJ
B/Uj0Y6aIx2ZJ3i39WSngwR9P6Lf9ZJwCOEI9Ue9iF8PeaDvSP9ZP5yfwb8a
c8yxZ1eB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 833->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbnq6LFdvZmdhAmzTZTCfT
3Z1vw3VlZvfNexvy4zhN+Xlaz4dLHg/7cS5uyyqWPs5TidMv18QW5xzzCTzG
aHg/csFvhbmoec9cxdcY3z6vlpxN4DMMygd6nHCpexeaIxeoIZ4pLgwv0AIx
KQ75zxZ6BNyRs+IRaYJ315owvdHo+xH+zSwBhhEMyV/NYq3/h4NzK/69elAN
rBfjBRmiWIE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 834->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkMENwjAMRS0OqFdGYAUYIGKFMkGQ4FQJqT0gbh4dKgKtnf+DLaVJ7Prl
f+8v9/62EZGpe3/6/DiNY36et/PlmofjYZiLu7JKpM+mqZzTkjNnCeSSywnJ
ofDvR5kulNQ04gswvn26WtQb4SOGIm+u5/cfyoF6xQIeNdV36klsjs3CM2E0
GMYH0y5Lf0tHNVfv3WmmOhpvK2Ct9RsvDYYABtXPvIjd/3G8b6Y/Og84A4ky
XtS+WIM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 835->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1RwTwvCehBvebouVmynM90G2qYJmU4m
PVzvw7gxs8fusw3xeZ7n+Lpsl8stTqfjtCT3aSUL38ND8sM/VvgmYqwuw6Ux
ZojTiwnmIuc9fRGMX51ni9WgbmsYznojd8TJ51TxQSzIMf4VF6V3EFq0NEFO
prVweIvOKOOseFS6krqcs+RBjM6P8C96aWAYwZD8VS9Wnqs40Df69J829FB/
sQ/jDfYhV4E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 836->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpAfDsCK8AAFiuUCYJEX5WQygP159FLRQTp5WzFUhrHqS93
l5zuz2HsROR1/HyG9L7Oc1puh23xSNPlPG2bfR459DuZ5lz/tV0uDTWFmjg1
Fko4tGASHBYGuoxpKP+FPisGPSvAZxjGtJE14pQeVXyQF+wx/hUXD08dLyJP
CCfPCyvPZ3cPnL258pX0/XhIwMPpr+6P8N9pgWD9zNMwvDtrwQHdmFOdTkRv
sQ1jBafJVsQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 837->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHigfhmBFWCAiBXKBEGir0pI7QPx8+hQqIRzPqex5CZpfOez
4+Pt0Q87EZm7z6fPz8s05dd1vxzueTyfxuXysPpq6eea/vuvi1mtJfIfcRab
ICYypmGLM+BhplCXshpsLODUOM1l+DGOcSirDc4YU+CYHtQFd0y/01LhwzqK
2cHcjRyur9Hbg+ZodX0lONRDdQR4936Ac7WAMbybr9p8V2pp4iE6UXNTP6TM
w2Z+m+MNhfxXRA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 838->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOgyAQ3PTQeO0T/IJ9APEL9gU00ZNJEz2Y3vbprdboMgyEbrIisDM7
A9TPVzdcRGSuvp/OL+00+ffjuk56P96bcd287bmH+6W6839LMaMNR9YRZ7Fs
jQXTwHoV8LBQ8KXMg60FnJqkvQw/1jEORW9kjjUBjulBXbDH9EdaMnzoI3g7
2DvDkcqjLnfvLtSBY3Su4BV9JnWQoPcHuMhLhkMIR1J/gZciHqITNf97Huwt
lnF8AEF4Vwc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 839->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBjG
h8uhA3ss4uj6kPViE8MG0O3HZiaR5uAUR3JTAzY/QEEDOhspfBpw+QfJfHR1
2MxoQPcbFj66GvQ4wnAPurvQ5DDsxeYWPOah+wPZHRh24wDoYdCAyww8aa8B
D40Rrkh6sfkTq3uIdDu2eEAxA4tZ2PRjpC8CYYjLL0SZg8Wd6G4mNTzwpVX8
fgIAQc1WBw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 840->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKg0AMRYOL4tYj9ArtAaRXsCeYQl0Jgl2U7nJ0HZhF/PlxbGBkJpqf
l+9cX/MwNiLyabfHkL6PZUm/5yUf3mm636b8sivLRC+iZeW9zbvAb2yO1db0
gEHYYgwHOmHeMCmboYTi3vij0TxQU9OgXsMZGXd1jAdZjupND8xFejiH5XC9
g0APNNIIdFxNH3CRGdiclOckO/sPOw2i5fqw+1XxMJrllA7hRJ5//XA8Enjl
YgXI11UN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 841->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPQNDAxSD
2Mji6ABDDUwdMmbAQuMwD90NGGZh00PAHJziSG5qwOYHKGhAZyOFTwMu/6Cx
CZmBNazxmAEzBzmMMNyD7hZ8+pHsQBfDGr9Y/IHsDlzhgGEmjnDAMANPPKLo
scfhLjz6kO1AdwvW8GRA+B8j/tD0oZiBI/9gqMGXLgiEAb6wxZd38LmZ1PDA
CFsGHGGFAQAmoVXG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 842->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPQNDAxSD
2MjiKHxCYuh6GXCIobOR3IBMY7ULm15i5JDNgtmBQ18DOhspfDDksNmLTR2a
GQTDGosbUfRhcQ+GW/DpR7IDXQxr/CL5F5s7MOxGdwcWO5HNwTADTzyipxP0
8MWVZrD5E90tWMOTAdXf+OIBxQwsZmHTj5G+8KVvdL/gCVt8eQefm0kND4yw
ZcARVhgAAE0WVoU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 843->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBgF
QOWIFrNHE2PAIYbOZkB1QwOyeejqsOklRg7ZLFx+hYIGdDa627CoQ/cbITMa
0P2GxseQZ0DVh809GG7Box/ZnehiuMxrQKKR4whnOGDzG45wwDADTzyi6MES
JrjcgOFPLG7BGp4MqP7G5n+MsMERFrjSOM50QSAMUOwhxhws7kR3M6nhgeEe
BhxhhQEAYKtWyA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 844->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBgF
QOWIFrNHE2PAIYbOZkB1QwOyeejqsOklRg7ZLFx+gIIGdDa627CoQ/cbITMa
0N2AxseQZ8DUjzXOkN2CRmOox+YWXOYh6UXXgzMccLgJWzhgmIHHHBQ99pjh
i8sPGG4mNjwZUP2NnkaR9aGYgcUsXGkcZ7ogEAYo9hBjDpY4RHczqeGB4R4G
HGGFAQBqH1dI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 845->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozACjAAYoUyQZDoqxJSeSB+Hh0q8nDvzgmW3CZOfDmf
fbg9hnFjZs/d9zOU12Wey/u6XTb3Mp2O03K4r17t/HOvjnGLMevEMN+SmLLI
AV3cbeGk8cDJVQ3VHNeBG2mUrHsYjrXBnt4yzld3Vlzgr/gTlwaeIw7E03zg
gnpQP7K+i/yYK3UNRpz/0VP0BOfUFYdEC5VP89Wab9Bg9U4PB+qnPggMOV+m
MbpakX0ANBJWiQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 846->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYML6dYjeAU9gHiFeoIRdFUQ2oW4y9G1OEJIXmYMpJ1Jm5+f
n+yvj/G+EZFl+DzG8jzPc3ldtuvlVqbjYVo/7qpXO31dq/u42Jh0Yj5fkhjZ
rz45/NvCSeOGk1IP1dSfjT5Bo+Tcw1Dfm7uHWpLkt/Rxb+IfuDTwfB92d0Lt
BifCwd0jDMhXwy/oaixwhpn09oL0Rw6JFji/1l6QZTP7Bwe0Iv6pHtBL4AM4
3NMbYGFWxg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 847->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD2UXn2CX6gPEL9QX7CCPRWE9iDe8vRaXGGdzGwxkHY3u0lm
Jnu8PYaxMbOle3+G9LzMc3pd221zT9Opn7bDQ/Zs5497doxbGbOdGOabiDH7
9mdO7tbqyHiByRmHbI7rQp+gkVjv1XDkBvvQy0R+TR/4s54BC6nnkI/9pSYC
E6tD3x6rQfJLfIEj8hBc6HxJPtOfYhBa0PkxXWumZlZ7X/Z7F7VH/P/oEfCQ
OpzTChS4Vcg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 848->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBhd
nAFZjIGAGLp+Bhxi2ADMfmwYi1p85uAUR3JTAzY/QEEDOhspfDDksNmLTR2a
GQ3ofsPCR3cjVv34wgeNxhbHGG7BYl4Dkn4MPUToxxr2aOZgTXs4zMEVJ1jD
Fd0fOPyCLX7R7cYV/ljdgCMssMYfvnSBxy3Y4pmgOVjCCt3NRIUHFjPQ8xBh
PwEAMQJXBQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 849->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvh2BFegAESuUCYJEX5UqlQfqz6NDRR6n8yWtJTdO4rue
7Vyf8zCezOx9+X2G/LkvS14f523zylN/m7bLrnix9HcvjmeWLJo6V/mJVo4F
ryPPnoYGT/UcNLmqoZhzDP0Jd+q/Ko84nGsTe9bIeNYTtNAa8pUWweeAD5gD
eKwNsRyrfOZReBfcypx0qJnIfgI+zK+modILhQ+1tN439EHNeZenNQfBcaQf
QY9VehXsC45HWMY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 850->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbnq7FReJkpmxgu2namZ1M
9nC9D+PGzB67z2Ooz/M819dlu7zc6nQ6TsvHfVstynd5W1hPweqF1AvsmBNe
jzyMs5NH1oMmZz20cMyDPx54kl/YC5ztgifpExoRn2aGWmBnM05aCJ/HfhHT
gacaSs7//hU8DE91CayJXlb9hLNZ/9GjH4fwEvHqfslQnvfwrM2BcPT4kfSY
8CrFGy8+WAc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 851->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0sKg0AMDV0Utz1Cr1APULyCPcEUdCUUdCHdzdFb6VTGNy9vAnE0kvdJ
9Pp89ePJzJbme+nD2s1zeD/O28MQpvY2bS8vKVPcfxlTYt3ymlVq2G9OjcWf
n6WHw/A8DsCKzEOKCPeYVW/OLF0c1OdoZFoKH7kWONmOpaeMdz+Jh8IrC9RQ
wxA4Sgeda+5DeHHnCdwHHug7YDizxH6KqwI54LuWOGoPBEPNo9if+G+4pw+W
xVhE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 852->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0EOgkAMRRsWhi1H8Ap6AOIV8ARjoisSE1gYdj06EmdRf3+LNikzlPTx
+xmOt+fwaERkbt+Xobwu01SW62G7uZfxfBq3h13NGv0ntSbWxdYkrinWe1hx
j2EZmH9ywrphKZurhuLe+OM8QjbjEwb1K2OI73d6mC6zMv1OC+Gp6XdeRJ4E
mrAvZCScTIfzFeews0R6omDfD/q+GIGX2E+5WeA74FynnJ25fzpfwhn4D+3P
tALL1leH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 853->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB6kV5/gF/QBpV+oL1jBngpCPUhveXpbXCROJsEOpJtmd2aT
bM73Zz8cROTVrJ++vLtpKvPtuP08yni9jNvmqVpF+zGthnGxMYljivEWVvQR
VgNtp04YN1rK6qpQ9E1/XI8Cn/VSUYf1O9IQz3f5YC6wsvxpLgA1fMfJeoI5
ARd9PJtpuDf5oxa7Z2ty/Ajs/YD3o0G0GJ/qZsA7YK5THVK3kPzT+RKvgfel
s/7FAv58Voc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 854->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkj0OwjAMhS0GxMoRuAIcoOIK5QRBgqkSUhkQm48OFRnMZzuBJzl1nL7n
n2R3vo3XlYjcN+9lLI/jPJfnab1sLmU67KflcFutYviYVmNcbEzymDI+4Euf
sBq0P3XSuNHSqK8KpW/m42aU+NEslTrRvKmBWiILe5WczxyuFkChR84XvzN/
y6XPf1sa7k5+6MXVLAk/Q3R/5MGPaiA/1G2BOZC7qRP0Tb3u+xKv0XurcU8v
NQFWRg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 855->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMDD0Ur31Cv9A+QPyCvmAL9iQU9CC9+fQq3WIymSw2EInZzWQy
2evj1T5PIjJV66dNczOO6d2dt58+DffbsB1esmerv75kx7zonOx3aQ7rJcgx
0xjof+IwM/MFM+i7Jlb6OI2CmGm5IA7TGzGAC3NnWjNSjz0cF7BfDWohtT03
vQNOlH/09oJ56E4OzMI4H9JT8XD7wzqIGQesp7glwx7Qu4gDcxtNCUZJD7e/
wlvlM30AwnlYBw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 856->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBhd
nAFZjAG3WAO6uD0ajc5GB8huQMdY1OIzB5/5cDXY/AoFDehsJLdhhBEONraw
bEA3B48bsIUpun4M96C7hZCZuNyCBmB2oIcFgz2qPIrdONyE1f240h42M+xx
xAkRfsHmZqLCE8l+jPhD14eezrC4AVs6x5ku8LgDOUxwug+LXmR3oIQpFjPw
hQdG/OFJq9j9BADR2laH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 857->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EMw
CrBHyBMSa0AXt0ej0dloAGY/3BxkjA7wmINTDsl/WN2KxG9AZ9ujuQ+bXWhs
DHVoZhByA7YwRdePNc6Q3ULITFxuQQPo4YauB2eYYHETLj9gCy+sZtjjiBMi
/ILNzUSFJwN2tejxCnMjMhufGdjigVBcYLWDFHPQ/I3NPFLDg5i0it1PAKxf
V4s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 858->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboBgu
hiSHAnCINaCLE2MWEmhANgMdowM85uCUQ/IfVrci8RvQ2OgYq11obAx12MzB
4wZsYYrNLSj2oLuFkJm43IIG0MMNXQ/OMMHiJlx+wBZeWM1Ai0dktxDyCzY3
ExWeDJhqkdMnet7ByEf4zGBgwEgbeNM3sh3oeYQYc9D8jc3NpIYHMWkVOwAA
qx9XiQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 859->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFk8EJwzAMRUUPpdeO0BXaAUxWSCdwoT0FCskh5KbRk4Ch6teXIlCwZfvn
SbZur2//OYnIdNk+fZ27cazL87xP3nV43Id98dq8Wfm5FhODNbffmEb7mFZk
BXSYJmoHOql+49UkJ4UxOv0XjFFDmE7EYO+DsKAWmoKO4yr/c8ci5AzJQ2yc
1UF8nNXz6D4wjvcYcaEx5pQjYce+sTV3fQQMjjN7F8xYr5Bcst7JmA/rAblk
bzXXWAHDRVkF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 860->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoEb7BlQ
AZIcPrEGXOrQaWzmI7FRzMHlJnR9xMohmdWAbi42/zCgqkXGuNyPzS64edjM
weUGZL9jcQsDmnnooAHNHAx32aPyMdzCgEUPFn8wIItjCwcGTHFs4UkoPtDF
0eMRl7vQATY343UHFv3ocYARD2hsUs3AGxdI4YAtz+FNX0h6kdViczOp4YEv
reI3AwD+jFkF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 861->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoEb7BlQ
AZIchhgSaMCljgGHGDa+PZo5uNyEzRxi5JDMakA3F83tDWhsdIzL/djsgpuH
zRxcbkD2Oxa3MKCZhw4a0MzB5S4GXG7BYR42f6DYhw+ghT3BcMUR7+j2Iruf
kF+Q5bCZgSs8kfWjxwFGPKCxSTWDUFyg2IEjfeA1B0sewOZ+UsIDX1rFbwYA
d6pZSg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 862->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoEb7BlQ
AZIcVj4UNGATt0ej0dnowB7NHFxuIsIcXGyYWQ3o5qK5H1kOphYZk2IX3Dxs
5mBzAxIbXQ2KPmzuQXcLlvhEdz9Wt6AB5HBD9weyPF6AFvYEwxWXv7DEI7q7
cPkFWQ6bGTjDkwFTLXoahetDY5NqBqG4QLEDR/rAaw6WPIDN/aSEB760it8M
AGgWWIk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 863->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOwkAIJB5Mrz7BL+gDiF+oL1gTe2pi0h6MN56ujSay04EuCS3LwjCw
u8fbox92IjJ3n09fnpdpKq/rflncy3g+jcvm4adO9KumQv2ixOfEojgJfGiL
q681nm3hoGT19M/Xkp4MbNSWWoghDCfioEJnX+UxPsg/mjGsV1ygJ/N/MgvG
IcOKtIqN+EBdzz/tReo9hhHN0+fjGazOIbqzjRgZfz8H9ubS++VyfSza9J5u
zENIvTaMN/kLWIk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 864->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EKwjAQHDyIV5/QL+gDQr9QXxBBTwWhHqS3PF2LVTbT2TRd2LJNdmem
06S5Prr7DsDz8Hl08dUOQxwv++nlFvvzqZ82j3OaCN9MAXIdQayZSF4fnDWu
mcvkQpM3W1H/sBLjkvZENecWrj+ewvE0sA+khbEWobwXuuBpIRzrm+KW56aA
5fpheyv1KDw5i3xv7Zu8+YyDeYHcY4G1hlHSb31Qd654vpD38/9j/Vv8gOCr
w3gDVU1XSA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 865->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU8ENwjAMPPFA/TICK8AAFiuUCYIEr0pI7QPxy+hQAcK9nBOI5Ma14/Pl
kmxP1/6yAjB1z0+fbodxTPfjev45p2G/G+bk5m1u2MuyQcZhIuZGNrGW55rP
HAwxp6g2yrn4BytHe8U37322Zl8rMaBwIl2VnljWST7MRfRg/iEXN3vdVO+a
lhyL9lDo2sDwWIwX3QGfizhIPV19cX5cR34Ng+95i7/XYVFP8SqOeAOK/z96
QPT7DeMBEsBYhw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 866->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU1sKAjEMHPyQ/fUIXkEPELzCeoIK+rUg7H6Ifz26LirMJpOugbZp0plO
+thf7v1tA2Dq3l1fHqdxLM/zdp5cy3A8DHNy921k9mnVIOMwESOrjDdaB0Ss
8r0GQ64pw2Y5obu2asUyx7UFnEXsb77GUQUm8Lk1jJN6Mh6PdzqlFhorj2Jv
eUfe/Nlb9GUNCQdzKT5lnMs0tGqR9+dxzm9x+He+pp/PYYF38SaP+ANKf/q+
RC0Q+/3H8QILElgF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 867->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU1sKAjEMDH6Ivx7BK+gBildYT7CCfi0I64f4l6ProoXZZKYNdLtJOpNJ
H4frY7hvzOy5+36G8XWe5/F92S7ObZxOx2lJ7v8DrPyGF6NxKyQG5hWLuThH
E7VWPEyTwqoc0e2tXm2dc9CRcCVjq9/jcIJJfGEN4qieji6mX2qBGWuy2lSD
0KR6SPuq+gp1GZ+6A5iLHMZ0EHw6P+Fjz4oj3vOeftyH9N4g3uQhb8CDZnku
opf6z+5au6cPSSJYhQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 868->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU8ENwjAMPPFA/TICK8AAFSuUCYJEX5WQygPxy+hQqRTncnZVS25SOz6f
Hed4e3T9DsCz+X669LqMY3pf99PPPQ3n0zA5D7MaaYE8K9sXZZuR3IqzvLI4
uRir4uTFej5j/2G5teLvL/amP1nlEj1aw8gipsKjMzZO8tnICxEXs9qcKrfk
4HDyaqj66tUl7pHxvBmwvmoWon6iPFvk4TjaRxigmDX+tg/FOyF7iCPegOIf
zhfqOM4XzvoiH4byV8g=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 869->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0sKwkAMDS5Ktx7BK9QDhF6hnmAEuyoI7aK4y9G1qBhfXzKBzuc1eXmT
zJyu92E8iMjSvoahrP08l8el2Ta3Mp27aft5/HzOVMT0PSMuiBM/U+KLc82Q
Q50u5lvjIfiXyxiv2xuu9RdjWAuWU+scu3pD7ZiPx6gepgtxotMgN8b7nCyG
akg0hfWIdAKOfYx0oTHNND4w2j+Mg3XGwfqd6fd1+HtzgKc85A0w/en9Qh0S
39X8TE+dnVWJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 870->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKgzAQRT9dFLc9Qq/QHiB4BT1BCroSCrqQ7uboVWpl+P4kDuhkJvnj
myTeX++mvwCYquXVxLkex/hpr2vQxeH5GNbJ2/Y4C4CFn//Hu/d5iBhOm6px
xgJx+FitLdTJ5U2tcbHxeOMw5uF9cvlSjQMD751Yw/oDj+I6wSlZnDfiYY1k
UEykTfZROENz31X1ZC/QzFKfMHl+rKNxrgZII/mV8X9C+Wwd7huaP3u/mAPl
u6p7+gIKOFZG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 871->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCngpCexBveboWq6TjZHcDbZpsZjrJ
Zn+597cNgKl7v/r8OI1jfp63c3DNw/EwzIe75XGWAEsf/41/3uchYjhsxNFi
zJGcLlVb4xF5474CTuPvBWsRh5hRjcMEhvm4hvGWKvNRPQqdUovzRnoYIzUo
TcEc/voo6XG1PMtiL9CaJT4weX9iL1Y7UuAAYaR+ZfR/zhd56E5XMxAcLfNo
2VXd0wuf3FZE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 872->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMDD1Ir32CX7APWPyCvmAL9SQU7KF4y9NVcCEdJ6kNZHGzmTiZ
pH68uuEiIu/renT5005TnvtquzzzeG/G7fG2u7Fk/Fec5KmXJ06MWeKuDMN4
BvxKXFOQY+6K3zu2+EEX0rsSTsrqBPwwB/GK/8FeSI/Ii3KBOgp8EEM5sFqO
Doc+ol0yuailp2sxxpniHaPzQxzOMaghgAlnYQ33EOL/zPRLA1LjjB5ndpX3
tACcuVZE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 873->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMDB6KV5/QL7QPWPyCfcEK7UkQ9CDe8nQVFOI42a2ByG52kpnE
PNu++RUiMpbrp4lTPQxx/jy2yzd271e3PVa7GwvGc3GCUw8nToxZSDjDeneb
A3ENBENqKJ73XE3V8LgMVrFORh9iMF+RB7WQHlEX1QJ1FPQgN9XAajlzuPSR
2iXgRR1srofZN5bjzlPO2BOPpwG4WQ3bl7sXzIAf43f+KdOc3S/o5Z9d5T0t
RMBWRg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 874->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKAjEMRYsLma1H8Ap6gOIVxhNUcFYDwsxC3OXoOlAl/nnpBFraNPn/
N8nx9uiHXUpp7j5bX56XaSqv63653Mt4Po3L46GualmWN/JDnEVx3zfxrXhI
R6SJ8iN94rcMMYBheq651sKIuFysKc6WPonRfFMe1QJ9Ul2ohfByXAvUEGBQ
HUhXa0Y8r4GuVQ7gKkaY7wz7B7X462MDw/cpnAsy4Sd/iOP/H2jenC/5C/E1
Z/1nb/JoVUY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 875->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS6kW4/gFfQAwSvUE4xgVwWhXYi7OboWppJ585J5kH4yk5e8
JOfHa5wOIrIOv8eY3rdlSZ/7cft5pvl6mbfDU7ECNW+VGkr85F727u1nmItB
A2P30BedF3/uaZW25l1bNkY54LvRDRyZxFd9JPoxPmMerMWbE+Ss/B6ftr2g
M/Zg9HR1BDO0vcVe0n44vMjhxhvQ+UFcsyMBh+25uxcMuCvgD3msfqfm7n6B
FiH5wl3/4wsjRlTG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 876->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OqFdGYAUYwGKFMkGQ4FQJqT0gbh4dKqUi/fm/wVLb1LGf
f+wcb8/+sTOzqfu++vS6jGN6X/fzzz0N59Mwbx7yk82Lr9vanPhJXKg4Ez5m
/uOseEoT+lo1Fu4fjMB1zo0tBqwD94ARJB/PjTGYH1gHtag5Qc3Kz3he92LJ
oRoEg/WhOofSA7HYS9oPwUWGzC+Mzk9oqmoThprt5iyKPrA72OSU5xeam/cL
NLfuqpynfQCQs1UJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 877->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EKwkAMHDyIV5/gF/QBwS/UF6xgTwWhHsRbnq6FCOlssquBttvdZDKZ
ZA/X+zBuADx2n9dQnud5Lq/Ldvm5lel0nJbDvT1m4r6CtUmwH/ip7Sn7AXVs
ZkI4Ue6MJ58na+3Vaqa8tlhtYWS5nK8yTocf+3C8ch7mkvSJc1b7EZ7UWnxj
Qg4JRqRDVUfGh+aMtQz1CHrpOf+kJ2Jfrsf7cO4II+ttsxfAejZad7ExG6yF
5/yvHr1ZTfuJNwgHVQs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 878->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe8nRdqJKmM2sL202TaTKZ
9HC9D+MGwGP32Yb8PM9zfl22y+GWp9NxWoL78pWV3D+hXon4Cc6KzyIOaO9G
n4uZr8dqK54xLuwvP1N5ie17M98j00VxJDkaDiR3xMT7FR/Wi5gT47WqKWpc
xV9xYJyEDk0fik/gGrWkepBZ/mx06gmOjf14TKzNcqjZds8i1lh7Xw6jdGQ5
evT491blPPEGvOVUiQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 879->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMizggrjyBL8ADKr4wXlAkOE1CGgfELU+HST2knp1BpG1t5sR2
2sP1Mdw3ZvbcfV9DfZ2nqb4v23lzq+PpOM4/9+1pUcK3WB+F5AnOW84RZ7as
Tbg88iF3Voua1XrNK1lHb648Zlxh79hnRR9isH6hB7WQeqUrnan1uE6/0sA0
iTmgD6kHtOIs6TxEXyc95DyNY9FPxHTc4gx/ydNgHCGf9on+heZ/55Hd1fx+
fQCRhVQH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 880->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0kOwjAMtDggrjyBL8ADLL5QXhAkOFVCKgfEzU+HSjk405lQLGVzxvZ4
mh6uj+G+MbPn7jsN5XWepvK+bOfDrYyn4zhf7uuo5ml1a82Jn+Ci+gJxZsvY
Tq3I9VhtFYv3yu8tXxmX9rm3UD2yPTkH5lExWU/gwgbtlfBg/CkXZr7UouH5
ywDf60PyASxqSfUQeVkOqadxLPaTMU1t8Q3X+KmxGmvzkH8AOf+rR++t9t/H
B7ruVQs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 881->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
9ljEsahrsEdgrOYSaVcDsn3Y7MalF10el7g9wr1YzcXCRvYbTj9iY2PhY5iD
Sw+SemxuQTcLq1/R3cSA3f1Y3YINYLEbJTwJAaT4xBamDWj+xBePDUj2YgsT
DHuxmIvNDJzhyYBdLbp/kNWg2I0jPREjTigM8OZFPGkDPSwoCQ9i0ip2AADJ
2VTO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 882->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQXDxIrz7BL+gDgl+oL4hgTwWhHsRbnq6FKJPJbJsOpCHb7Ozs
bI63Rz/szOzZfT99fF2mKb6v+/lwj+P5NM4/D3llBNiDlQh1PIl7v1jCeKC9
oVbCeqK2m8taFCBP9SB15ru81nIqjeBPweNpQD+FFuaSvbImA046Sy0CXLvw
cwk0T+Vpoj5dPXCXvXT9ELyKoyW/mh/lFRxiDt78Fa8LVWOFH3P//S/o3+JH
y1vV+ACMRVTO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 883->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUUEOgjAQ3HAwXHmCX9AHNH4BX1ATPZGYwMFw69ORpJpxOkuJm0Bhuzs7
M3u8PftHY2ZT+3718XUZxzhfD+vPPQ7n07BedvnJEeAM9huhzCdR98klzAc6
d8xKOE/MdnsZQ+SxT2mQPHMt6pMaxXdRB/2IKTmgn8SbuSi9CXEoz7xcLiIK
H9DPWoAW9oF5bfKBWvbS80PhKow9/cX+tjiIPXj7V7huqBkVfOz96hec//HD
Knr8fS5sQFdK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 884->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENgzAMjHhUfDtCV6ADRKxAJwgSfSEhwQP159EpFaDDOSf0JAgktu98
zqMdmnfhnJvK76sJcz2O4fO6rT9d6J9Vvx7et2eDh9W7M3y8LyRu3xPc92q9
wCXIR7hprvoWHU/6YD1YNVGTpHpUOVEc5B/nlgb0U+kWUov2q3sydJlaCDT3
yc8ciI+RH4rHqiPAyzzJ6UfN/+ZH80tpIHOw5s/qmmAcmfqYe/RPNKfmYvnB
vMve9R8WE8pXSA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 885->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
9pjiDVjUwcQakMXt0Wgi7GpAtg+L3Vj1orEb0NVj8QdOP2AxE9lNDfj8iKYH
Qx2Sfrg8Nr+hqUd3NzaM1b9o/sDlLpxuwQIa0PyBEp6EAI4wwOYPvO5BUose
ljjDA4u56GYQqx8j/tD0oZiBxSxc8Y83XaADPHYQNAc9D+BwP970hWYXtrAj
zgwAbTtXzA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 886->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUjsKwzAMFRlK1xyhV2gPYHqF9AQutFOgkA6lm46eBDzIz09yBImJoveR
rMvzM70HEfmet9eUf/dlyf/Haf945fl2nfefY3lKJHMmqSORPKnTklOsE2mx
gZZaPabtYZGD5C1OPV7bj0Bt4aY9EnxTZ/CaOh4cn4hvdBhPx5frhYRCH5XP
XjgzYH2EfkwtztKdB+FFjqP45v4AV3EQLu/+w73ACDS6PLhbjv9wv0CLze4Y
xwrER1aP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 887->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EMw
CrBHwuhiSKABKtaAro6BAVMvDjPg+rFhbG7CBrD5AYs/GnCZi+wfBjS19ljC
CA8bQx2S/gZ7Am7A4U50/VjjDN0cLPrR3YnVLVhAA5o/UNxJCKClM3z+wOse
JLXoYYkzPLCYi80MYvRjxB+aPhQzsJiFK/7xpgs8YYAtL6LkIyx6samjJDyw
hT3BtA4GAJJwVw8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 888->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQilFBgz0EowB7
JIwuhkUdsn44G10tHjMakO3DZjcuvehm4LLPHslt2MxFdzuS2gZ7LGGE7Ec0
cQx1aGbgdQMOd6LrxxpneNyFzf043YIFoIcFijsJASS1hPyB1z1IatHDEmd4
ILsBzc2k6Mcaf2j6UMzAYhau+MebLrD4AyWvYDEfZz4h4G+i0hcWu7DFIWE/
AQDL9VcP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 889->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQilFBgz0EowB7
JIwuhkUdsn44G10tLmCPB2NTh88MfGbD3IbNXAYkeSQ2OsamB52NoQ6bObjc
gMOd2NyCEWfo5mDRj+5OrG5B9xOSe9D1YHUDDrNw+QEj7eCJ4wZ7VHUY7sIB
sLm5gVj9uOIPTR+KGVjMwhX/eNMFrjDAohbdbdj04vM3UekLi12E0ip2PwEA
nQpV0A==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 890->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKAjEMRYMLma1H8Ap6gOAVxhNU0NWAMLMQdz26MyCS+f0/aiElTZPP
S5v95d7fNmY2dfPWl8dpHMvzvF0O1zIcD8NyuXvbelWfN4egB8MYyash/vEx
Vy1PjOVmGpm2Jb1auA8+GuUAv8ljOopBcDKWihqoQ+qRk7JgT4EHayiD0FI9
NLMjNGNu5DGiw2qR+af3NNP/5y1TNvvq/9O5ECz/6MfaFafg//oeiQbT4T29
AFQFVtI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 891->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQilFBgz2QsEcT
tEfC6GJY1DUgicPZ6GpxAXs8GJdaUsXt8ajD5nYGRLg0IGFsetDZGOrQzMAZ
3kg0uhp0/RjuwWYOFv3I8jjdgu4nBsywQHEnIYCkFqsfsIQ5NoDsZ2T3oLgL
hx+wuZmo8GRgwB1/9phuwpf2senHKo4P4Ek/BM1BdycO9xMMDzxmYDMHu58A
Q45WjQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 892->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQilFBgz0EowB7
KCZSDEW/PRpNCNjjwbjUEiuOLofLD1DQgM62R4QPVj9iY2PhN6Cbg8sN9qh2
I7sFr3uwmYNNP5I6nG7BYh663SjihACSWmwYI/xxmInsB2T3oLgLi73o5jbg
cQ8u92N1M7o+NDY+MxjQ3ENUXCDbQYz5WPQi24fufoJpFAngMoN4cwBYJlQP

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 893->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQilFBgz0EowB7
KCZSDEW/PRpNCNjjwdjU4jMDn9kMWNyKbiaS2gYkvehhhNW/2NyBph9uDi43
YLEbxm/AYhZW/2JxB4Z6fG7BYh663VjjnQgzcGFkd+JyD7JaZPdgix9ke9HN
bcDjHlzuxxp/6PrQ2LjcjytuCcYFsh1Y/ErQHDxpCVt44HMLLjOINwcAH5VV
DQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 894->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQilFBgz0EowB7
KCZSDFk/nI2uFheA6ceGsajFZQZRcrj8ioWN7Cb0MGrAoQfDHWj6G5D9is0N
9mh2I9nXgMUsrH7F4g4M9fjcgsU8dLuxxTsxZuDCyO7E5R5ktcjuwRY/yPai
m9uAxz24ANb4s8d0E760j2EPFncQzDN40g9Bc9DdicP9xLgFlxnEmwMAw5FV
Ug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 895->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OiCsjsAIMYLFCmSBIcKqEVA6Im0eHqqU4zv9pLLlpG/v7
Oc7h+ujuGxF57r6PLr3Ow5Del+34cUv96diPm/vZZ9NpMZ08M/3vt/zz+ab5
umq/fOQglhmt57VYr+DdM8UzMpJTcId8870iBn92oZ4BLdgr4Cji/dxqcwo8
GT9jqGgw95yMx8da4Kd3OPS75BIeZnB+WjItGkCrqAM4qrMQ4TNbu1+gHuNv
YWEa7Tof0+NVUg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 896->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EMw
CrBHyBMj1oAsh04TAvZIbkDHWNTiMwenOJKbsPoVCxvZPehh1IBDD4a70fSj
+BObG5DiBN2cBixmYfUrDvMw3Iwe5tiAPaZ69HAhCNDcgA3DANawYUDVj6wO
PUywuh3J/XC9ONyDC2CNP3tMN8HNwGIWNv1YxfEBPOoImoPuThzuJ8YtuMwg
3hwA8y5T0A==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 897->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhYML6dYjeAU9QPAK9QQRdFUQ2oW4m6NrsdXJ870hA2l+Jvny
Jen+cu9vm5TS1L0/fXmcxrE8z9u5cy3D8TDMyd1SlsifyvKvXeUaxywDA2ts
YyDDFzI34shx52TsXKS9+pj38zm1nvQNOcpBvUmOfRTH8/6clQvh4d7V+ijI
3bOyRuTj5xr4y/sgHp6hPNTe7PzI++4XMNBH/hfkHLhe8tkdpHoO829xUYx2
zgtVwlSP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 898->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12CPY
KHJEijXYo5mBTqOz0QG6GcgYi1qcZuEQR3dbAzZ/YWHD9DUgu4+AHgzzsZiB
M7yRaAw19gTcg8McZL/gchehuEF2D3o8YXUDHjehhwO6u/C5B1kteljiDA9k
NyD7BYd7cAGs8YeuD42NzwwGLGYQjAtkO7CoJWgOWtihux9fvODyC7awJ5jW
wQAAzcVVDw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 899->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0EKwjAQXHoQr32CX9AHBL9QXxBBTwWhPRRv+3QtFt2OM4m4kGab7Ayz
s+3ufOuujZmN2+ejy9NxGPL9tJlfLrk/7Pv5sl3WEum1efrkq7sfzzwBB+6Y
YyBHXKRWcolz1OasL5JHPQ44V70hP+C/vEIOMRPEox7Fg3imqzabqAfnRDUU
NNX6KOmJteil9JXwMg7pp/Fa+l1AXuIw0FPT/w6Cl/wEG+tQ/z9+qH+D9bmO
BzhgVo8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 900->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12CPY
KHIkiKGYgU4TAlD9cDOQMZpb8ZqJQw7dbQ3Y/ICsFl0fsvuwqEN3J4Yckn4U
f2JzA644wWIGhj/Q3YIEMNRjizdsAM096PGE1Q243ITDD9jcRcgP6GGJM1yR
9KL4hYHI8GTArhZrukBjE2UGFr/gBej5BIf5+PIO1nAjMzxw5Q30cMIEAHb1
VdA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 901->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKhDAMDB4Wrz5hv7D7gLJf0BdUcE+CoAfZW5+uorDpdNIaqElNMkyG
9NlP7bcSkaXeP61fP/Psf93juAx+fL/GI9lc5zJ3uuD+cZS7+S84wEBfMsTQ
h9TmcJght8Dm0rXYp/mROoE4yan+RCvEcHEf4iY4aBkNLF5ZnaEOZ6AcDCzG
3+JVmoHxMGeROMcwTD2F19K9gPgWBpkla/hODHzcHe2pbiJ0x0p6WG8DdUpt
A0p9Vo8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 902->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENgzAMtHggvozQFegAESvQCVIJXkiV4IH4MTqgpiU5zoaTDAY7lzsr
ebw/TZeJyFhsj8ZP9TD4+ZXvH63vn1W/F8sQAe77WtyRJ7Wb/5YQP/xz7NUQ
c2CQXouHIfEHWnHdyYcT2yPui/ywPvHJNLh0HfKeeBDGDFCXqgX5oj70QDWg
juicaYH7XXlgOiwvcY1xqPMU3kvPBeS3OIgXE3hPFH7r7tC5idAzpkHlYDoo
zwphHVcR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 903->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRLGJk6E
WAMUwwCcja4WjxjcDHRMjH4Ccg3IZqG5FV0fhj+Q3IaiDw8bQx2aGQ3Y/IYe
ZuhqsJiB4Q887sLmfpxuQTfPHkdY4HIDDndgcz/WcMVjZgMW92BLg+gA2Z8N
eNyDTz9G/KHrQ2MTZQYDdjGcAD2f4DAfX95Bjz9095MSHgxY7MMWTpgAAPmy
VY8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 904->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRLGJk6E
WAMUo6hjwKIWjxjcDHRMjH4Ccg3IZhHwF4Y/kNyG1Y9Y2ITMaMDlBnQai7kY
5qADPOaiuwunW9D1I6lD9wNWN+BwEzb3Yw1XXGai24vFXVj9zoDqzwY87sEF
MOzBZi8aG5sZ2NIA3nSBJwzQ1RI0B80+XO4nNjxwhT16GGH3EwBFr1NO
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 905->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGp
rgGKMfTiMgOLGNwMdEyMfgJyDchm4fKrPZJaNPEGfH7EwiZkRgMuN6DTWMzF
MAcd4AkDdHfhdAu6eUjq0P2A1Q043ITN/VjDFZeZ6PYi6cUZHgwIefQ4Jio8
0fSjp1MUfWhsbGZgSwN40wWeMEBXS9Af6GGFw/3EhgdWMxgwwwi7nwDFZFJU

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 906->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGp
rgGKMfTiMgOLGNwMdEyMfgJyDchmEfArhj+Q3IbVj9jYBMxowOKGBmxuQjMH
3QwMPchuwWI+uvsx3ILHvAYs/mDA5QY8ZuDCOP2NZg4+d+BzC7I/kdMZwfBE
04+eTrHxkf2Mbga2NIAvXeALA3zpA5deZPswwg1fesfhF2xhjx4m2P0EAPKt
UpE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 907->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGp
rgGKYQDOxmUGFjG4GeiYGP3o9uJzNwG/ophhj+o2DDlcbAJmNGBxA4bb0dSg
68dwD7pbsJiPYi8et2AzrwGLPxhwuQGPGQT9gc899vjdgc8tyP5ETmcEwxNN
P3o6xcZH9jO6GdjSAL50gS8M0NMZQX+g2YcRbiSGB66wx0gfWM0BAMPNVJE=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 908->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGp
rgFNvMEeST02M7CINSCbg4yJ0Y9uLz5322NRh83tSPoakN2HzR1Y9OAzAz28
sLodS5hiw1j9igVg2IvLLTjCpgGLP7CGJTaAZAZBf+CKdwZMe7HxcQFkfzbg
cQ8h/ejpFBsf2c/Y3I8e7vjSBQZAzyc4zMelF1kdRriRGB64wh4jfWA1BwB7
xlUT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 909->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRYMLcesRvIIeoHiFeoIRdFUQ6kLc5ehamEV48yfVQAozk/z8
/5vD9THeN2b23H0/Y3md57m8L9vlcCvT6Tgtj/uaiKEm77K6AXeh3lnzA67X
NCb7VH+GLXh7otU5M3BzalZz1RswnDWca20N+13pIBfg0V/JpeONCx3SSxUB
Y1WH2kWhQfHIuESdnvBZ66eP6hw1K/70PduLJvgfO/i93ljX+PanHz3vm/2Q
OB9j+VWP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 910->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6GB
BnsIRpG3Z8DUj66GgLkM9khmo2NizMRnNrIbGdD8gMXsBnQ7kdyGIYeLTcCM
BnQ1WNyOrgZdP1Z/4HEXtvDF6RYs5jVg8QdGeBFhBkF/4HEPur3Y+LgAsj8b
8LgHn36M+MPBR/YzQTMYsIvhBOjxiMN8XHqR1WGEGxnhgS3sMdIHVnMApspW
jw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 911->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6GB
BnsIRpZvgOlFVo+mhpC5DPZIZqNjYszEZzZMHN292PQh+w9JX4M9mt/R7cKi
B58ZeN3AgHAnsn3o+jHcQ8Bd2MIXp1uwmNeAxR8Y4UUA4PIDtjDH5RZ87sBw
C5r/UfyCwz3Euh1rGGLJHwTNYMAuhhOgxyMO83HpRVaHEW5khAcDFncTTOtg
AABhUVaP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 912->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6GB
BmR19mhiyOrR1BAyFyTWYI9mFilm4jMbJo7uXhz6GtDtRHIbhhwuNgEz8IYZ
kjvQ7UM3owGbf3GYic88YsK0AYs/GHC5AQfA5n6s4YorfuzxuwOfW5D92YBE
EwxPHG5Hj1cU9yG7mZAZDNjFcAJc6QfdHBx6kdXhcj8p4cGAxd24/IkKADu9
VNI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 913->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0sKgzAQHbqQbnuEXkEPELyCPUEKdRUo2EVxN0dvAy6G57yMDkTMfJ7v
vcT78z3NFxH5XP+PKX/HZcnro6ubVy5DX2rxti2ItC3MQajtS5Cz/dAT4dac
JsDyOLH5qGawNNCqqMNw29XYe4DR9MzwwO8hhnp6CWYL74in6ugQxoGEx9/1
tXGOavios2eztuZhUD8JdzxX5Mf+nx0Gaon8ZPcHccis7WP8z/ghDu9jen5T
K1NW
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 914->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1sKAjEMLH6Ivx7BK+gBgldYT1DB/VoQ1g/xL0fXwophmEnXQPeRJpPJ
ND1c78O4KaU8dp/HUJ/nea6vy7b93Op0Ok5tc78sMFsW+sA8xhn4YryJt8Bt
PjfAYpxUfm8vYHnW65cD5Hnkx2rBdw8j5VB+PBEHMZz1KzTI8NZo6sZzKAdh
jD/VNTlHD3UjF6lHqM1mt6un4I7nivzU/WEzkM6F0oDEdvuAeor/P3oUwntd
P2/wJVKX
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 915->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6GB
Bizq4GLI4vZoNAFzQWIN9mhmYXMTLv2E5GBmw9Tg8WsDuj+Q3IYhh4NNyAxs
4YgtXNHNQTejAZt/cYQBPvPwhimSfmx6sLoBjxm4MIr7iYhH9LDEGR5o7mdA
czvB8MThdvR4xeY+oszA4he8AD2f4DAfl15kdejuJyc8GLC4mzj/AACj2lLa

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 916->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6Hx
G7Coa8Ambo9G4zMX3Wx0TIx+JLdgBdjMx2FmA7o/7BF+xJDDowefGdjCEWe4
ovkBwxwsfsUG8JmHL0yR9WPTgzPMsbgJm/uxhiuheGTADEuc4YHmfkLuwacf
I/7Q9aG5jygzsPgFL0BPyzjMx6UXWR0uNinhga1cIM4/AJppU5k=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 917->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6Hx
G7Coa8Ambo9GEwLIZqBjbG7FYw5OcXzmIvEb0P1hj/AjhhwePShyaGZgC0ec
4YrHLQ3Y/IsjDLCZh9MtOPRj04PVDbgAFvfj8ic+/cj+wXAXAfcjuxmvO7Do
x4g/JLuxuY+Q/xlw+AUvQLcfhxtx6UVWh4tNSnhgKxewhhMGAAA72FFa
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 918->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6GB
Blzq0MXtcdC4gD3C7AZk87Dpw2cWLjl0M/GY0YDuD6ibYBirXfao6pHlGrCY
gTMc0dxByC0N2PyBJwzQzcPpFiwA3R8wPVjdgMN+bO7HcAM+9yD5AV0vofDA
5mas7sABsLoXOc1icR8u92MLQ6LjAt1+XGbj0ItsH3q4kRMeDFjcjTWcMAAA
n5dRFQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 919->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6GB
Blzq0MXtsdBYzENW34BsDjYz8biLoBwx5kJBA7o/oG6DYZzq0O1CVodmBs5w
RHMHuh3oZjRg8weeMMBlHt4wxeEPmB6sbsBhPy4/YAtzQn5AD0tC4YHNzUSF
JwN2tchpCd08ZDsImoHFL3gBuv04zMelF8Wd9phuJjU8GLC4G2s4YQAAYvNS
Fw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 920->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSji6GB
Blzq0MXtsdBYzENW34BsDjYz8biLoBySWVj9gAQa0PzRgIZxqcNmF7J9GOYQ
CG90+7CZ0UBC+OAzD2+Y4vAHSngSA3CEAzZ34YvHBiR7kd1CKDywuZmo8GTA
rhbdP8hqkO0gaAYWv+AF6HkFh/m49KK4E4f7SQkPBizuJs4MAONRVBk=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 921->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPQQ32DNg
iqMDeyzi9ljE7dFoXOYhyTXA3ICOsbkBjzk4xaFyDdj8igSQ5RrsMTFWu9DZ
aGYwYDOHQHhjsw+ve3CYQ4x5eMMUhz+Qw5MogCMcsIYrnnhsQLIX2S2EwgOb
m4kKTyR7scVfAxY3IduBDAiZQVRcoOcTHObj0oviTnvs7idoDhYz0NM8YTMA
3BFVGQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 922->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD2UXvsEv9A+IPQL+oIV9CQU7KH0lqdXUSFmJ9kdiLrJOjsz
bNO/2/FCRJ/b8mjT9zXP6ddd18WQpudjWof3vRR4K2HK+xYM+gz6bN4en5rJ
ocEW0hDwuP19Jsirgp6Jyib7L/oucAjyZtboPMsBfTjeIr4wU8eHzrMajocs
V8eX3muzLOWBNFflSXgvgXNPHIDLuwPhvXByQDkVfVidgY7aPCwH9AnxBzRa
VBk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 923->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPQQ32DNg
iqMDeyzi9pjicLOwmYENQO1vQDYLm12EzMQlh2RWAza/IoEGdH8guQ1FHx42
ITMasPkNjY9uH7p+nP7A4Tds7sfpFizmofsDRZxYgMMPGOFKhB/Qw5KoeEVz
M1HhyYBdLQM2e9HYRJmBxS94AXo+wWE+Lr3I6hjwuIPY8MAW9sSZAQCCKVUb

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 924->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPQQ32DNg
iqMDeyzi9pjicLOwmYENQO2HYWxm4nUXITkksxqw+RUJNKD7A91t2OxCZxMw
owGb39D46Pah68fpDxx+w+Z+nG7BYh66P1DEiQS4/IARrkT4AV0vUfGK5mai
whOH22FuxekGLGZhTePYxPEBPOoI+gPdnVjikqjwsMc0A19axQ4AKSZVHQ==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 925->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPQNDAxSD
2MjiGABdDbIYNr3YzMAG0N2AzUx87iIkh2QW3B4cAFkO5p4Geyz68LEJmIER
1ljcjm4fun6c/sDhN6zux+UWLOah+wNFnEiAyw/Y3IXLLQ1I9jZg4eOzG93N
RIUnDrcjuwerG7CYhRH/2PxCKDzxqEOOI1x60d2JnueIDQ9kdxBKq9gBAIvO
Uh0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 926->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPQNDAxSD
2MjiGABdDbIYNr3YzMAG0N2AzUx87iIkBzObAckeHABZrsEeE2O1C00PNj6G
OdjCEc0d2NyCbhY2v+LyF7r7iYp3pHDDpgdfWOJyA8FwJSEeSYpXHH7BG544
3M6AZgaGG7CYhU0/VnF8AI86ZH/h0ovuTvQ8R2x4ILsDV1rFbwYAtr1UWg==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 927->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOgjAURH9cGLYewSvoAYhXwBPURFYkJrAw7np0Rav5Tl8Lk3yg/cww
f8r+cuv6jZlNzevShftpHMPjvJ0X1zAcD8Pc3KVKaD8VU73Xvqf4vid7VuKS
BkE9kGbN11LP+Y40g4PvxTYv/JY+i4aRDuWoPsCLatGspbnU/6pzd7kRp5bl
j+/+B8o0y7WUDZxj5quAzPPaPB0/Oz/h/WmAFvFxvwbgo75w/F09G8yzlAfl
Rz7KGk+9BVUT
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 928->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOgjAQ3HAwXH2CX9AHNH4BX1ATPZGQ4MF469MRock6O7swyVLazkym
XTjdh+7ZiMir/T66/L6OY/7cDvPkkfvLuZ83j2utSMtQ0lJ1rvf+UHmwJo7W
cD0kyMA8o1w6R+BfOVEuvVeSLZoD38FDmA+7R8xBsqAXO6t3Lsy/q++6l0Sz
2WPgesX4zKsQL2E+AJN5730qvelflIF4MT1dj0D01B80etQc/Ofcvng5xHI3
v/UfJotmVdI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 929->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EMw
jI8shwJg6tDEUDADFpoQsEdzA7p56PbhMAOfHMzsBmx+QALIcuh6GpD9hSus
0OSwmYER1lj8ha6mAYsfsPoDh98w1ONyCw53YYQfsjg+gKYWF8amHptZDVjM
IjpecfgFb3gi6ceIPzR9GGmEGDOw+AXdz1jDAItagv7A4k4UO0kID2xxQcif
qAAAUWFWUg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 930->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMtHggvozACjCAxQplgiDBqxJS+6j4ZXSoGoR9PaftSW6S2r6c
Y5/ur+a5E5H+8P00abh2XXrf9uPhkdrLuR2dx2IFOi1ZJ/udrc8BY8TkWR+u
S1DQoP9/VEPAUfNlw0l5C6wv69yoDtwDhzAe1BC9K2hBLlZrVBfqX913Uoed
nSogNjIWz7gy4VrdV/X7qg6SP+sf5DkOwhXNwJa5ELg/4qcgOt2dG96D9WKp
To8Pg51W1A==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 931->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EPZ
9gwYcigAXQ1UbwMuvdjMwAbs0cyxR4hhdQM2Pha3oZuPYg8OgCzXYI+Jkd2H
1U3Y5HCZg8df6GoasPiBqPBB14+kDm/cYdGPTQ++sISbh6QWPQywuYtgPDIQ
YQ4O92PzC97wRNKPLR00YHET3B/EmIHFL3gBejrEYT4uvejuRLGTjPDAMAOP
P1EBACyNVhM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 932->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EMw
jI8shyGGRR1RevEBezQ32COZi0UtBp+QfUhmN+AyFwoasPitAd196HZhCyM0
Pk5zcPgLXU0DFj8QFT7o+rH4DadfsLgHXQ9Wv6C7By2dYcPY1GMzqwHNXpLi
FYtenO7Aoh8j/tD0oZiBxSxcaQBvusAVBljUEvQHlvyOnqZJDQ8MM/D4ExUA
AMNFVo8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 933->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EMw
jI8shyGGRR1RevEBezQ3YLMH3WxsYtjcgOZGuD04QAMWfQ3o7sOiDoWNhY/L
HFz+QlfTgMUPWP2Bw28Y6nG5BY9+dHcgi+MFaHqxYRS1uMy0x3QHSfFqj8rG
6w4s+jHiD00fihlYzMKXlnCmC1xhgEUtQX9giUMUO8kID2z5n2BaBwMArilW
Ug==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 934->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EMw
jI8shwLskTADQi+GWns0mhCwR3MDFnsIugtdDo0NMxtuDw7QgEVfAxZ96OpQ
2Fj4GObgCjNk89HsQ/cDVn/g8BuGenxuwaEf3R3I4ngBml5sGEUtnrSH7g6S
4hXNzXjdgUU/Rvyh6UMxA4tZuNIA3nSBJRxQ8gkO83HpRXEnup1khAeGGXj8
iQoAQuhVVg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 935->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0EOgkAMbDwYrz7BL+gDGr6AL1gTPZGYwIFw69MBQSmzs+BOUjZN6XTa
7V4e7/J1EJHmNHzK0BZ1Hbr7cXSeobpdqzF4nm2GTofpZF/fx1ZQZ7Lk/nw4
jXEwKGggdTZ1sZjX4rijPgGGHC7PsO9EXcZhYJEG8A1mgPmoh/YNfKgrqYXA
QEfWHe/0QGfOODTW4e91SwvT/Nc8hf/L9mLFQbhSO5CzFwL1U/wU5A7x/ebO
g72p3V3/oAe9olZS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 936->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EMw
jI8shwww1OAQQzaXKGCP5gZkjEUtPnMw2PYI8xmw+RMNNKCbgeQ2ZDkMdWh+
wWcGvjBDMR9JHbp+dPdg9TeaeejuwukWLKABzR8o4UoIEPADtvDCagaSWvSw
xBkeSH5FT5dEhScDdrXo8YqsBtnPBM3A4hcMf+PyC444xhcOKO5Et5OM8MCW
pwimdTAAAP1iV5E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 937->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12EPZ
9gwYcigAXQ2yGBa9DdjMwAbsIWpR3IHNLlxuwOJmuN32CPORaVygAd0fSG5r
wGM+ul/wmYHVDWh89DhB14/uHgyAxTx0d+F0CxbQgOYPlHAlBAj4AVt4YTUD
SS16WOINDyxhCRMnNjyxxh+6PjQ2UWZg8QuG29H4WPMrujnYAJp9GPmBjPDA
FvYE0zoYAABkIFYP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 938->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12CPY
6HIYYtjUoYsjm0sMsIeobUA2C5tduNyAxc1wu+0R5iPTuEADuj+Q3NaAzXw0
exnsCZtBTHg3oIUBun5092AALOahuwunW7CABjR/oIQrIUDAD9jCC6sZSGrR
wxJveGAJS1zuwed/jPhD14fGJmgGFnGC+RA9n+AwHytA8zdGfiAjPLCFPcG0
DgYAAvRV0g==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 939->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoIboDQK
QOcjqccqZo8mxgA1lxgAdUMDslnY7MLlBixuhtuNzUx7TPUY+pD0NiC7D5c6
NL/gMwNneGPRhxyW2DBOgCaHoR6fW5D1o6UR9HgiKo4J+AFbeGE1A4vdGO7C
YT+yP5HTBinhiRF/6PrQ2OgAVxogmC5w+QVHHOMLB2R16OFCSnjgC3uCaR0M
AJwiVUo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 940->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12CPY
6HIYYtjU2aPJodOEgD3EDQ3oZhHrBixubkB2Ay5zsZjTgCxmj+o2ZDMx1DHg
kUMzA2d4Y9GHHEfYME6AJoehHpdbcLirwR6LHkJuQDMTlx+whRdWM7DYjeEu
HADZn+h6iA1PjPjDly5wpC1saQBvusDhDmzhRNAfaPYxoNtJQnjgC3uCaR0M
AM7/VUo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 941->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkI12CPY
6HIYYtjU2aPJodOEgD3EDQ3oZhHrBmxuRnYDLnOxmNOAbgaS2xqQ9GGoY8Au
14DFDGzhjSGGxkfX34DuBgIAw15cbsERv+j+QEk7hACSWoL+IBDvyGmkAZu7
8PgfPb2TFJ7Y4g9fusCRtrClAXzpApc7sIUTQX+g2YfL/cSEB7I8ulpCaR0C
AOqmVY0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 942->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
6Hwc6hrskcSRzcNnBhaxBnssZhHpBqxmo/uNkLlQ0IBuBpLbGpDMxFDHgEcO
zYwGLG7AEEPjo+tvQLeHAMBmPla3YEsHSOrQ9RDlBiS1BP1BIN7R0wiGu3AA
DDeTGJ5Y4w9fusBiFq40gC9dYAsHlDDAYT4uvcjqcLmflPBAZ+PzJyoAAEU2
VE4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 943->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
6Hx86uzR5KB0Ay4zsIg1oJuDbiY+N2AzG91v+MxEAg3oZkDdBsMo7sVhLyEz
GrC4ASOs0NSg629At4cAwFCPyy04+A322PUQ5Qa0cMPnD2xhg+5m5HjEcBcO
gOFmEsMTa/zhSxdYzMKVBvClC4JhgMN8XHqxuQPd/aSEBzobnz9RAQAStlTO

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 944->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
6Hwc6hrskcSRzYPJEQPssZiDzU243IrNzeh+I2QuAxY32yPcBsMo7sVhLyEz
GrC4ASOs0NSg629At4cAwFCPxy3YwrHBHrseotyApJaQP7C6B83NyPGI4S4c
AMPNJIYn1vhD04eeRogygwG7GE6AHgY4zMelF5s70NM1KeGB4W88/kQFALJW
VVI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 945->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
2PhY1DVgE7dHkiMG2KOZg8MunG7F5mZ0vxEylwGLm+0RboNhFPfispeAGQ1Y
3IARVljMQTeD6PBlwKIej1twxiUWPUS5AUktLoyiFk/8oqcTDHfhABhuJjE8
scYfmj70NEKUGQzYxXAC9DDAYT66HmQam/+RzSYYHmjuRXc3obQOAQCzo1OP

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 946->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
6Hwc6hrssYjbI8kRA+wR5qCYR6QbsLoZ3W+EzGXA4mYkN8Ewintx2UvAjAZs
bsDGRxJD19+A7gZcACku0NUT5RbkuMTifnLcgNcfBOIXPZ1guAsHwHAzieGJ
Nf7Q9KGnEaLMYMAuhhOg5xEc5qPrQaax+R/ZbJSwxeMGXGFPMK2DAQBXulRQ

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 947->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
6Hwc6hrssYjbI8kRA+zRzMFmJh43YHUzut/w+RUJILsZ5qYGJIziXlz2YuE3
oJtDKLzR1KDrb0B3AwGATT1Ot2BxF3pYkBzHePyAEZZ44hfZHeg0zjhhwOJm
EsMTa/yh6UNPI0SZwYBdDCdAzys4zEfXg0zjStdEhweae9HVEkzrYAAAQttU
kw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 948->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2Z0AF
6Hwc6hqgYg32aOoY0MTwAXuEORiYCDdgdTO63/D5FQlg+APqtgZkP+LwL1bz
sZjRgM0NOMIVmY8NEwRIcYGuHqdbsIAGNH+QHMd4/IAtzHH5BSW92WNxFwH3
Y/MLMeGJNf7Q9KGnEaLMYMAuhhOg5xUc5uPSi8v/2NxHTHhgC3uCaR0MAJFl
VFY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 949->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKg0AMDP0o/vYIXqEeIHgFe4It1C9BsB/Fvz26SgV1nMQMZJd9JDsz
2fLdN+1NRL7FPDTpVw9DGl/3ZfFJXfXslsPHGit0N6scgWvjXtYtMDezGgzq
RIAD5YzaPK07nHQo0WjoZfUzqZEJB/QK72D+yXOEHmfWI4uLlc9ywj12NDDP
LU3MT2F1yNuWloiftH+Qh38kVEP4ngl4H/ddHY5+xi/ihxDeV3/9jwkYgVaR

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 950->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkE32DOg
AnskeTxiDfZY9NsjyRED7PFgXGpxmYPORjcLn340NyP7rQHZjzj8i818bGY0
YHEDelihq0HX34DuBgIAQz0et2D4CYs/SI5jPH7ACEs88Ys1TogIDww3kxie
WOMPTR96GiHKDAbsYjgBmv3o4nj9gcf/2NxHTHgwYHE3obQOAQAbRlaT
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 951->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUsEJwzAMFH2EfjtCV0gHMF0hncCB9GUopI/Sn0ZvAymRj5MceiCbWPLp
Ts55fAz3g4g8j99lyK/rPOf3rVs+plwufVmSpzVWpG3XJDWSCTwjdYp1bHeg
thcGwjvHPp7u6L7UPtR400RyrV4OhxINOH+ssfeYHqoF+FCzp4XxYO9fnmpw
gDOgPhrvS2cQzQP0W82hjoZ2IX0rDsLl/QPIGcKr3ePD+if1/8xDwEvks8YH
uVJVEw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 952->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHkE32DOg
AnskjC6GRV0DujpsNC5gjwfjUovLHGxusGfA71ckgCzXgOS3Blx+xMYmYEYD
Fj+gu6kBzd3I+rC6hwDA5n5cbsHwExZ/ILuLVDdgwyj24olfrGFARHhgczNe
dxBwOwMWe1HMwGIWQTPw+R1LGKCnO4L+QPY/FvXkhAeKe/D5EwMAAAwQVRE=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 953->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPQNDgz2m
GByji2HR24CuDhuNC8D0Y8NY1OIyD6cb7LHwcQBkM2BuasDnR2xsAmY0YHED
evijq0PmY3UPAYBhLx63YPgJiz+Q3UWqG7BhFHtxmYkrDIgID2xuxusOAm5n
wGIvihlYzMKVBtDNxAtwqSXGH8j+x6KenPBgQPMLPn+iAgDq+VZS
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 954->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRRjE7Mn
rK4BilHUYaNxAZh+bJhYt6Lbgyxmj4WPAyD7A+amBnx+xMYmYEYDuhuwuAld
HTIfq3uwASzuQA4HrG7B5ics/kB2F7EAPQyw+QOne5DcjBEGRIQHNjfjcwch
tzNgsRfFDCxm4UoDONMFgTBAT0ME/YHsfyzqyQkPbGGPN63DAQDoRVaP
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 955->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSTKdYA
xSjqGLCoxQVg+rFhXGpxmIPVDfZY+DgAstkwNzXg8yM2NgEzGrC5AY2Prg6Z
j9U92ACaO1DsxecWLADdbmR3EQvQwwCbP/C6B0ktelgSCg9sbsbnDkJuZ8Bi
L4oZWMzClQbwpgtcYYCulhh/IPsfi3pywgNb2BNM62AAAFX0VhU=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 956->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRRjEyek
DirWYI8mhk0/LgDTjw3jUosF4HSDPRY+DoBsRgOS3xpw+RGfXTjMaMDiBnSz
0dUh87G6hwDAsBePW3Dpx+UuUt2ADaOYh8tMJD+j6yUUHtjcjNUdRLqdAYu9
KGZgMQufn4mOC/S8giaO1x9oYYyunpzwwBb2hNI6BAAAyz5W1A==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 957->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRJGB+hi
2NRBxRqQ5dBpAqABWT86xuKmBlzm2mNho5uFy1wkt6Cw7RHua8BmPjY2ATMa
sLgB3ewGNHcj68PqHgIAw148bkEBSPZj6CHTDdgwUfGDZB+6XkLhgWwHNjOI
0Y/hXnR9aGyizMDiF7wAS9pAFsfrDxxxSUl4YAt7QmkdAgBt71YR
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnFeMHMUWhnunZ3dnnNaADQ4XsSyyLVkYIUA8IJCAh3t54PKCECDishhs
wAEHMpick8gZxAPiEXjiBSEhDEjkYJEkkgCbYDKYXPd8VXV6zvT0zPbY5l5f
sytN7XZPhf9Un/pPqOr99/CKBfMXDa9YODI8+K9lw0sXLBxZPvjPJcvkVtqT
JMl8PoMJfzv5MxbznfwkyQT/K3WPPfaYu/fee93999+fVHyZuvvuu8999dVX
vkY91vv999/dEUcc4fbff3+5R5m6gw46KKs3Jdb74Ycf3IMPPkgfWX8PPPCA
u/nmm90BBxyQzKRtj1u6dGlPM5DbbrvNnXXWWe7cc8+VhpSpO+ecc9y6deua
gPz2229uxowZXpi6L1OXpmlWT4F8++23btWqVfSR9Xf++ee7U0891beaSdnj
9tlnnxyQO++805133nk0loaUqbvgggvcZ5991gJk5513bgIyfvz4rJ4Fcskl
l9BH1t9FF13klixZ4iqVigLx07JlArn99tvd2WefDRhpSJkyoYWPJg+kt7e3
8NFcfvnlDC79XXzxxXLv0ksvdcuWLSsG0meUlVm55557pCFl6u666y73xhtv
uA8//DCpuo8++kju/frrry7+JLUCcKkB98gjj7jVq1fLVSife+45bZ8BXrt2
rdtll13cjjvuKFehnD59utNFNaMdYMCeeeaZTUrNTNIhNQY6gOvv73dffPGF
rzEj1vv444+9slNjsN2gMi/+8Vi9QfM/+eSTUoMySH5Q7o8N6ivdfffd/hnK
QDIoZVgNn376qa8xOdYbGhrKFKRiBtV6Oiiro+2g8j0/KP6tt94q/YhGRbJE
6UVQUXrK1D388MP+PjXqsd6BBx7o9txzTz7SljJ1e+yxRzaeXQhXXnkliykb
44477vCW4aeffsomcv369W7fffeNPYVyt912cz09Pb6nqbG/KVOmuJNPPtmd
dNJJ0h9l6hYuXOgOOeSQxrgFcjKeGIGMZZhnfUjVAjaqx3oTJ07M5roWR6hW
q27x4sWR7hqsBeWJlcpkYv6RPzMKcg8DAyPBTcpQMNb8+fM74hd7F9d6UEbo
WyipCb+l9Xqst9122xXiP/300yNLNugfXBY/NA/dW/yQE3LahQH1n3DCCWP4
t2D8eF7BYUFrg77m8bMuuU+Neqy37bbbFuIXN8tdeOGFWX+QIzgs/s8//7wQ
v2h9bEsZLPTIyEhH/HiDsp6kjcxKXFtqTBU/HMJ9atRjPZ6HsAQcIW0pU88f
cV1nPNXX1+deeeUV38qOwTP4448/Mk/k559/9jwdOJMycOZVV11FH8k/zBzt
sMMObvvtt5d6lKm/3mabbYrlnBYHkC69d2kJQqbJTZ48ucXKqLGfFNsKofqH
EBQ1EBMPBmUTIkrmtBv0pptuanEIaVg0qLKmHRQGs84fgFesWDE26MYPOo6y
6v7880/54scff2w7MlrXi50cKjN86st+b79OO+207EPwwpr++uuvw9BS8/vv
v3d77723mzNnjoxKmbp58+b54Cms3wZ3XXHFFW7NmjWyFt966y2599RTT/k1
ZcWbNGmSO+WUUxhP2lKmHsfRRx/dsPFlBYAEIRL9MB2XXXYZIUAmAOGALvSK
WZhEg3kBrr766iYyYeHnnRmeV35tMiZClBag3wzKYs0DjoybAa7X620BCwNm
gK2LaQGjaFbxmCye+N8XsHKwAq7Vav89wNGekfWQ4CFJYynr3MWfUKMPs9MX
vyXHASI8Bh9ai4xcM7J+kJ5FkZdWbA9KL+gog0fLCg5KHHpk8Vx77bWlpMVD
sBEKbVnVnaQ98sgjCZPkKpQvvPBCs7RSPvTQQ+66665zN9xwg/RNmbobb7zR
7bXXXk1tiX5efvllPAK5gq9SH83CTIIvoIzWViMitd4ypYTz7r333pMxKFP3
/vvve++CniqxP66/+eYbz76d5qNSqfg5YcRKHBftguk6zcd+++3X1M/TTz/d
Mh9EIzwnO9c8c11u1dj27bffztpWjJw77bRTSyTWVVgascqNpn5Wr17dgrUo
oYReoHu2LdGc2IemtpslhN4KsD7zzDMtWElBsbatt8waV6yqAxFnkw50g1Ut
dVmsTz75pPeE5ZOkscRxJXq2GSnmedq0aZF5QokeRp0tPa8aUUTW9KxYidzI
vfy8kaZhDUofoackVRl97y1ptTZyTp061c2cOZOPXIWS9Q6HSv9JGsvjjz/e
+2LiaMtVKIl+un0m6mlu2LDBc75wsrQVVpR78DOcgNRVMx+0lU94klGPcHLK
yDkQMcDfRGEN+5K6L7/8cqPx4ynTX8jrBu5CF8gEYWPUPsHF3WIl24OFbTiD
m44171tb669YxVps1VjRAbylwDKhbId1cHCwCStrqwgrznGwX40sAZGyxYr9
7RYr2TL6IqORxjJmtFuwzp07lyxEksYS+6xpXIv1mmuuQX5pK5qbhKyKeCFN
PhFeGlkH7qWxhMsUv7Ud8BxRYd2XqdbxNWol5cSVJoMC8krEP2HCBPfOO+/4
doqL50TAEvIWocQH0PmYaPCzj0aWJo0lsaXWU/787rvv3PXXX8+zknFFuyL/
wO/so6i0zCW8Jx+RiTL1uxLHHHOMr1EfRU7N6lr7NStiwHdl7Vj9wU4TbFkM
ZNi4j8bWTEaJLE8ZDFMK7P1sg6HTxpbFQGBIjZqJAsg8bS0YmNPgM4U5pm8y
BqM9C7CXfRa6twefwH/WfsedAF+jUoBV18Ivv/zS4pvY6MrHAuP5oje2wNPH
OonmSs/sEoQNYtjbSofnTZxIjVqsRzSE9e9GuuOOO86vpDPOOEPGowyrhr2N
PIvkPVBWNV6AWAFpK/ZU7pF7YXXKqs1YlRkgepLvJFZs1CNOtowGE+LRCNME
vklCPKwzbbHARtSox3rRwy3FaCo7mqBWpsijHU12WCl4FQ2LgibaqBfZkRXm
6C+wPDaiK+v5Kn5Wk1r0bqMH8GNRAqO1z1GAH08J5P0FVr4oIv274O9Gf5qt
ZL/qjsei2ZO87sAe6Ek2M9VRBNANvrICdLP4OTGwfv36JI0lLg5hVrvFr4RG
+IBLwwZrxZc+UeLNw8qVK+WKcUMKKZoM/ymSkRQKmzZCfoECo9lXMigijSkl
54K560TzOhe4PIRzBFuVGHKBgQcMwVcLaF5dQNw1iFBcUbnHzIU5Q96QsAnj
DgwMlEoCMgbuEUqTxpKNNAxG2GBuGAY1ve3SQDofM6KcpJNwhzMzFfGjkNYN
Ajs6I3OezdFoSUybEsxvwLGgFi1a1BVW3FnCjDxWxstvU4AraEloO1qGWLGi
s/nNzjLJ1TxWDrZ88MEHGz2v3AsY2ocxYC3a2Cw7r3Zu1OXXkAVugODCNmIo
SUFovVqshw6TWiUAqBaEAXZN3HLLLU3ufQx/GKtpXO7Jd1k95KatlZ10qTCK
DwAqJgwYGRnpSvZjjz3W60HYqA5hHXry7rvv+mClGkMWjBD9U6Nm6sFT7UI9
v357Pex+v7OFYBAxC5ffXMv9xNcZHyVjNfJEQgjXGsiNxnQqGTOBNljtQFJN
UCu7sJWsCb+aqceTtf3ZgLsezZsxXX7V8ZtruZ8dHWLF6jGvskkwjhYwOXYV
2rNQih3LpInVmqnXaZdTsRuXIbNEXMPrFnvZRMHWjD2vM4QDujlUi8k7cOSP
ODC+ym2xk1BCdt1E4tpihzk3F3YsNjazGi0nlphAlpRpLSZOCSpnz57dlHQl
OQYLWKuLFY4WP6CIa4BniUfEZhK/uWYNKFvBiHkL/tprr2Uy6krDO8knf0kI
JzYI7XIuNAmIpeBeSDhRBmvB8TBZn/J8QrIcfcMNt8EsCRwYMBwfCm3pj7mE
H4MX2GuT5f4j14nymh6UDZuAoQ+SdXpQVrWeI335YJrk/6bMgfeoq8bkxklt
OnStbpDGHgjDA83HfnrmaKoRrChrpNkSFYyzi2oWdQwy55simBKHjafqZvGp
u2R3PZApH0/pOTArU6cMUCeZ2AEbkyl1J554oldwu8NhdtCbdlg3p5xkVxk3
GP4wLnJzJIveO8n57LPPdi3nYYcd5hexzKNchRInAMLI76zHg+abJKfdmcNQ
hD31UEKqYFm8eLG0DVggd5yhEEi27piPi1h2331371KH/fhQPv74493NR59X
pdQ9//zznvU5yJfGkuMCScHBxo2dANLveGnwdpWyNw6OdJ3OTKjEPA00I9B6
0BQ0B83NJCoRVBedrfgrhB03blzTuKOdhLFybswJ1v+VnHqCdUzOv1bOl156
qbScGsxrPdxAGC1gaByaxSXasGFDJicJtLycME9ZOYtO7ne7Pp944gm/Xyef
JI0le5RFcr744otN9TiRTLwq3JGdoOTkJtaE15QGYr0333wzW5/2rBL7M/JJ
0ljiVpeRHQ+NRIY9uYmlPvTQQ7uSfbTsc91gpX97Qp568CjpP92RwUVn/xHr
OtHU0xO5VfOMaRvC6lY51eVvST7+H8s0WtJlDP+WgR9viCjIvgPJmoxvjsQ1
2K/Yfd1VMcXD+KS6qkZGxe7DrHokKgiZjFlegLh9I/ekXtVIoS+zlk3d8RIj
bC2fwNtJ8Od5pyT/rsSuu+7qk5j1mMrkhBh+Yv7JkIwYGhoScKEewTFpxpAW
a1gzPCne7OiP73dwzZ5scMUCPrYQODUCc6axHk8qzmZTDLJ8+XIvQTXKMWvW
rIwVJpWcD3uaT1PONrlXp+xj0D67y6TZcjLQejgCrzJP0kwNW7nO5IFef/31
rmHaA5IK0+bCpudwkcVXXEUOQhEuwoAxXH8tLnYK87g4QKivM/qRorrJ8vZ/
VQ03QCS8SGKxIoN1dlgqqLDFiqPRLdZHH33U5zB5ubQeXzHl8Le+YprGMqYH
4kyFkiMZEH548TOUce6b5pV2CxYsMPX63fDwsD8UDY3gzPEb6hGjn4Xh5Exx
6OzrpRD0ypUrccRFbsrwSmy3ckNJ0AvOeM0ciowHRbM5bfe2kIbI1qHLv0bI
M8NBRO+q0XBg0NBFaF3fmuGafc95JbEXpYTsfwwYDXs+j170CqRibxg0vzOs
lJ8ZPa7HsG/52DG3BGAhuxxK7S+/VuNB00weuKusPDg8YXe/kUenz7w8cCHf
MZ/85hoXoaw8Bx98sJdJnkl4Mkl4jTzK1CTPq6++6v9jhP7fCI6e5Lm/SB5S
34cffjgcJPXCGPAPO6P5NX3UUUf579ARfnPokldkqvH/SMBv+vr8gJkv+dbX
qMd6vCiTdHmMi3loOtjcx+PqLZBMT7WwY4mVCTserV6pzgNub3ynT9A03rGD
zTMEXYYFkzrgKjqLYN19i2vVJhyvHMM1hmvz4ur5DzTjLuM=\
\>"]],
                 StripOnInput->False], 958->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRLGJk6k
ugZ0tdhodH1Q0ADTjw1j04dNHN0ebG5nwOJWNNCA5i6Y+gZsfsTmPzT3YTOj
AZsf0MxoQAsDZH1Y3UMAYNiLzy1Y3IVuN4o4iW7AhlHswxO/DWjhgeEuPHaj
uxmvOwi4nQGbvWhsoszA4he8AEvaQBbH6w8ccYnuflLCA1vYE0zrYAAAmh5V
UA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 959->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRLGJk6k
ugZ0tdhodH1I7AZk85H52PRhE8diJlY96G5FA8hyDfaYGMVP2PyHI9xwmoNH
D7I4sj4Uc4gE2NyP1S3oAMl+bHrIcQM2v6DYhyd+G9DCA6c5WOxGdzPW+CXB
7Rj2orGJMgOLX/AC9LyCJo7XHzjiEt39pIQHtrDHm9bhAADJUVTO
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 960->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRLGJk6k
ugZ0tQxY1OICMP3YMBa1OM3F5gY0PQ243MqAkEdmo2MUv2HzJ45ww2kOAwP2
8ENTg6wPxRwiATZ/Y3ULOkAKN2x6yHED1nBFtg9P/DYg2YstTPD6A83NeN1B
wO3o8YruPmx+wJUGcKYLfGGAIw3h9QeOuER3PynhgS3s8aZ1OAAA1oFUkQ==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 961->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRLGJk6k
WIM9mhgDFrW4AFR/A7JbsNmFyw3o9mJjQ/kN6G7FY36DPSZG8Rs2f6K7Dyl8
sJrDwIA9/NDUIOtDMYdIgKEel1vQAVJYYIsnctyANVyR7cMTvw1I7sEWJvjs
RvELDvcQ63b0eEV3HzY/4EoDONMFvjDAkYbw+oOAv8kJD2xhjzetwwEA0bhW
EQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 962->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRJGF0cH
uNQBcYM9mhguM7ABqP4GZLdgswuXG7C5GZ0N5TeguxWP2chuQnEfkXYh8xvQ
MCE96O7E5hac/sACMNTjcgs6QAo3bPFEjhuwYRT78MRPA5J78MYPFrtR/ILD
PcS6HT1e0d2HzR240gDOdIEvDLCoJegPAv4mJzzwpVVc7oQAAOC0VRM=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 963->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRQzYKFx
qUMTa7BHE8NlBjYA048NE+MGdHuxse2xsLGZi6avAcl/DejmELILid+AhrGG
IxKAq0Pno5tDCNhjNw+rnwjox9BDrBvQ/IANo9iHJ34b0PyDM36w2I3uZrzu
IOB29HhFdx82d+BKA3jTBa4wwKKWoD8I+Juc8MAIAwbMMMLuJwAL8VLS
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 964->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRQzYKFx
qUMTa7BHE8NlBhbQANOPDRPjBnR7sbHtsbCx6UWSg7kLGZNkFxIfwxxs4YgE
0O1D1ofVPbiAPXbzGPC5BYd+bHqIcgOaHwiGK574bUDzD4a78NiNnlbxuoOA
29HjFd192PyAKw3gTRe4wgCLWoL+IOBvcsIDW9ijy2H3EwDRq1PW
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 965->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
DogbkOXQaULAHg8mxg3Y3IzOtsfCxqK3AUmuAclvMEySXUj8BnRzCIQ3un3I
+rC6BxdA8he6+3G6BYd+bHqIcgOaH7BhFPvwxG8Dmn8w3IXHbpS0isM9xLod
PV7R3YfND7jSACnpggHNflzmYwUE/E1OeGDkfQJyCAAA8xJSlQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 966->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
DogbkOXQaUIAWT86JsYN2NyMzrbHwsaitwFJrgHJbzBMkl1I/AZ0cwiFtz2m
W7BhYgE29+N0Cw792PSQ4wa8/iAQvw1I9iK7hVB4YHMzKeGJNf7Q9aGxiTID
i1/wAvS8gsN8XHrx+Zuc8MDI+wTkEAAAEnVSGQ==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 967->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dogb7NHEsNG4AEw/NkyMG6AAqxvQ9eAzF5sZULc14PIjPrtwmNGAzQ1Y+Mj2
oevHcA8uc9D0o5uP1S049GPTg9UNeMwg6A987rHHdAeGuwi4H9nNRIUnDrej
xyuK+2D+IMYMBuxiOAF6XsFhPi69+PxNTnhgC3uCaR0MAHOuU5c=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 968->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dogb7NHECOlDk2+wR1Jnj0cPPrNwuQFZDwG3YPgD6rYGfH7EZRcOMxqwuQEL
H9k+dP0Y7iEAsLkfp1tw6Memhxw34PUHgfhFdweGuwi4H9nNpIQn1vhD14fG
JsoMBuxiOAF6XsFhPi69+PxNTnhgC3uCaR0MABknUpk=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 969->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dogb7NHEiDEL3VxsmBg34DITmx58+hlQ/dGA5LcGfH7EZRcSvwHdHEJhZI/p
FmyYWIDN/RhuIRQuWPRguIGAGQT9QSB+G5DsRXYLofDAcDMWvYT0Y8QfDj6u
cMCVBvCmC1xhgEUtQX9gsa8Bzc3Epi98YU8wrYMBADJ0UlY=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 970->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRTj4uMT
h4o1oOtHV4MP2OPBxLgBmz24/INPPwOqPxqQ/NaAz4/4wg6LGQ3Y3ICFj+4W
bJhYgM39ON2CQz82PaS4AVs4YA1XPPHbgGQvslsIhQeGm7HoJaQfI/7QzEGJ
Myxm4UoDeNMFrjDAopagP7DY14DmZmLTF76wJ5jWwQAAhflQ2A==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 971->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPQNDgz2m
GDZ1GOL2WPRj04sPIJuBjolxAzZ70dn2WNhYALI/GpDc1YDPj7jsQuI3oJtD
KLztMd2CDRMLsLkfp1tw6MemhxQ3YAsHrOGKJ34bkOxFdguh8MBwM4nhiTX+
0PWhsYkyA4tf8AL0fILDfFx6sbkD3f2khAe2sCeY1sEAAK8RUhs=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 972->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPQNDgz2m
GDZ1GOL2WPRj04sPIJuBjolxAzZ70dn2WNhYALI/GpDc1YDPj7jsQuI3oJtD
KLztMd2CDeMFWPSjm4/VLVgAeljA9BB0A5oZBP1BIH6xxgkR4YHhZhLDE2v8
oetDYxNlBgN2MZwAPZ/gMB8fwOlvMsKDAYu7CaZ1MAAAjppSWg==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 973->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dogb7NHESAH2mLgBm1243IDNXjQ23H349DOg+qMByS0N+PyIzsbCb0A3h1B4
22O6BRsmFmBzP0634NCPTQ9RbkBSS9AfBOIXa5wQER4YbiYxPLHGH7o+9HRG
jBkM2MVwAjT7cZmPD+D0NxnhgS2vEkzrYAAA9xNSWg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 974->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dogb7NHEcJmBDdjjwcS4AQqwugFdDx79uPQ1IGGc6nC5D4sZDUSGN7J96Pox
3EMAYNiJzy149KPoIdYN9vj9gBGuuMy0x3QHhrsIuB+bX4gJT6zxh64PjU2U
GQwMpMUFmv3Y/EgoTnD6m4zwwJYOCKZ1MAAAcYBPmQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 975->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dogb7NHESAH2eDAxbsBmLzrbHgubGDOgfmvA50dcduEwo4HI8Ea2D10/hnsI
AAw78bkFi7sa7LHrwXADrjjD4weMcMUTv+juwHAXDoDhZhLDE2v8oetDYxNl
BgMD8XGBFgboaolNFzj9TUZ4YMv/BNM6GAAAezpPmQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 976->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dogb7NHESAH2eDAxbsBmLzrbHgubGDOgfmvA50dcduEwo4HI8Ea2D10/hnsI
AGzux+kWdHchqUPXQ5QbkNQS9AeB+G3AYhYDEeGBzc2khCfW+EPTh2IGjvjE
lgbwpgtcYYBFLbHpAqe/yQgPbPmfYFoHAwAQ8lCb
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 977->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dl0cm158AKq/AdksbHbhcgMUNOByA7IePPpx6WtAwjjV4XIfFjMasLkBi5uQ
7UPXj+EeAv7B5n6cbsFiRoM9dj3kuAGvP/C5B0ktelgSCg9sbiYlPLHGH5o+
FDNwxCe2NIA3XeAKAyxqiU0XOP1NRnhgC3vizAAA65ZRXA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 978->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
zh5NDpteQgCopwHdLGLdgCyHi22PhY0FNGDR14CESbILhxkN2NyAxU3I9qHr
x3APLmCPqh/dfKxuwWUOFveT4wa8/iAQ7w1YzGIgIjywuZmU8MQaf+j60NhE
mYHFL3gBej7BIkfIHJz+JiM8sIU9cWYAACmkT9w=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 979->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRSjixGr
Dl0cm15CwB4HJsYN2OxFYzfYI4njcV8DuhlQvQ32WORwsQmY0UBkeCPbh64f
wz24gD2qfnTzsboFC2hA8weyufjsRWHj8AO2MMdqHpJa9LAkFB7Y3ExKeGKN
P3R96OmMGDOw+AUvQLMfl/mE0jhWf5MRHtjCnjgzAPOhUFw=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 980->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRQTAtjU
2WMRJ8YsXGZDcQMuN+FzKy43wMxjwGMuFvMbkNzSgGQGIbuw8RvQzcEWjmgA
2T50/RjuIQCwqcfpFhz6GdDdT6wb7BE0QX8QiHfkeER2C6HwQPYnNjOI0Y8R
f+j60NhEmYHFL/gAuv24zMdnDk5/kxEe2MKeODMALhZRnQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 981->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQitGAPRQTAtjU
2WMRJ8YsXGZDcQMuN+FzKy43wMwjpB9NvsEeExNjFzY+hjnYwhGPf7C5pQGf
P3DoRwY43YIFNKD5AyWeCAGksCfoDwLxju4OYsMD2Z8N9qhiRIUntvhD14ee
zrC4AVsawJsucJiBLZyINQdnuJEYnhhpApc/sQIAMCVRGw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 982->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2ZyAI
GrCps2fA1E+EWRjAHhVjtYuQW3G5wR4LxqcPym9AcgsME20XGr8B3Rx8bsAi
hq4fwz3YAJp+dDtwugULQA8LlHgiBJDSGUF/EIh3bHFCTHgg+7PBHlWMqPDE
Fn/o+tDY2NyArh/dbEJxgVU/NvOJMANDPSnpC0tc4DIfOwAAKbhPGQ==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 983->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHom2ZyAI
GrCps8ciToRZGMAeFWO1i5BbcbnBHgvGZR4SvwHJLTBMtF1o/AZ0c7CEIz7/
oOvHcA82gEU/MsDpFiwAPSxQ4okQQEpnBP1BIN6xxQkx4YHszwZ7VDGiwhNb
/KHpQzEDi1k40wC+dIHDDGzhRGy6wBluJIYnRprA5U+sAACfylHY
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 984->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHg0TAtjU
AfkN6OLEmIXLbHscZuJzAzZ70dn2WNgE1DYguQWGSbILid+Abg4+N2ARQ9eP
4R5s+rDoR5bD6RYsAD0sUOKJEECzE2t4IKvFE+9Y44RQeDCg+rMBn1l49GPE
H77wwGIWrjSAN13gMANbOBHjD2zuQHYzUekLzR3oaokzAwAU51HU
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 985->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHoEb7BkI
A5h6NLEGdHFizMJlNrJ7sJmDSxzdXnS2PRY2AX0NSG5pQA8jYuxC4jegm4PP
DTjcgg3jBVj0I4cDTrdgAehhQXK6QbMTpz8IxC/WOCEiPJD9iawHZ/xi0Y/L
Trg+NDYxZqCLE4oL9PDHZT4xZuByPynhgS3siTMDALYCUlg=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 986->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHooZkGh8
AFk9klgDujg2swiZb48DE+MGbHags+2xsInU14CESbILhxkY4YVuBhQg24eu
H8M92ACSPRj24nMLFtCA5g9kfxEEWOzE6Q8C8YvuDgx34XMDUljgNAsHwBZ/
GPrQ2MSYgS5OKC7Qwx+X+cSagc39pIQHtrAnmNbBAADT7VDW
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 987->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqHAHooZkGh8
AFk9klgDujgxZuEyGx0T4wZs9qKz7bGwsanFYlcDEibJLhxmYIQXDjcg24eu
H8M9uIA9qn5kcZxuwQIa0PyBbC6pbsDrDwLxi+4ODHfhcwOym0kMT2zxh6EP
jU2MGejihOICRZ09djlCcYIz3MgID2xhTzCtgwEA72xQmw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 988->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQirEAe+zCGGrQ
1dljESfGLFxmo2N0M7G5AZu96Gx8+vGZB8QNSJgku3CY0UCkG5DtQ9eP4R4C
AEU9mpuIia8GHHrIcQNef+BxD7LdpIYHhpvJ0I8efxj60MOYCDPQxQnFBYo6
e+xyhOIEmx+Q3U9KeGCYgcefqAAAkytRHQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 989->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQirEAe+zCGGrQ
1QH5DejixJiFy2x0jG4eNjdgsxeXHhx+wOemBiSM00243IfFDIzwwuGGBntU
NjaM091YzGpAcxdOt2ABDWj+gOkhxw14/UEgftHdQVR4MGBxMxn60eMPQx8a
mxgz0MUJxQWKOnvscvj8gc0d6O4nJTwYsKglmNbBAABkSlIb
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 990->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQipGAPRqNLo4u
hkVdA7o4Nr2EgD0OjG4eNjdgsxeXHhx+IOSmBnR/EmMXEr8BDeN0Aw5zkfWh
mEMkwFCPzy049GPTQ44bsGFkd+GLD2xhgDdc0dyPzS/EhCc2ezD0obGJMQNd
nFBcoKizxy5HKE5w+puM8GDAohbDP1jNAQD491CZ
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 991->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQirEAe+zCGGrQ
1QH5DejixJiFy2x0TIwbsNmLzrbHwsamFoebGtD9SYxdSPwGNEyUG5DE0PXD
zSESYKjH5xYc+rHpIccNeP1BIH7R3UFseGC4mQz96PGHoQ+NTYwZ6OKE4gJF
nT12OUJxgs/fpIYHAwEzcMcnAAQHT58=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}},
                  ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],
                 StripOnInput->False], 992->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQijFBgz1WYVRg
D8XYxIjRT4zZ6JgYNyDL4TMbl357PGwobrBHCyNCetD4DWgYrxuwiKHrx3AP
AYCuHq9bcOhnwKKHHDfg9QeB+EV3B7HhgeFmMvSjhxmGPjLMQBcnFBco6uyx
yxGKE3z+JjU8sOUNgmkdDABG/0/i
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 993->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQirEAeyjGB7Cp
scchTiqwx4GJcQMhOWRxXH7AAhqQ9DTYI/HR9aCzsfAb0DBRbkASQ9eP4R4C
AF09Xrfg0M+ARQ85bsDrDwLxi+4OYsMDw81k6EcPMwx9ZJiBLk4oLlDU2WOX
IxQn+PxNanhgyxsE0zoYAAAQq0/i
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 994->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQirEAe+zCGGrQ
1WETIwfY48DY1OEzA5/Z6Gxi9EHpBijGqgedjYXfgIaJcjuSGLp+nObgAOjq
UcwgwpwGNH/A9JDjBrz+wOcee0x3EBseGG4mQz96mGHoI8MMrOJ4AIpee+xy
xJqBTT2p4YEtb+DyJyoAACYeTqc=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 995->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQirEAe+zCGGqw
qSNGL7FmI9tBql245NDNRFeHTx+UboBirHrQ2Vj4DWiYaLdDAbp+nOYQ0I/N
PGLirwHNHyjiJLoBrz8IuAfdHcSGB7I/8ZlBrNvR9cPcTqoZWMXxAHzxRo4Z
+NIFMX7BlSYImwMA36dObA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 996->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQirEAe+zCRKkj
Vi8xZsMwKfYTkkM2kxT3I+lpgGKsetDZWPgNaJhoN0ABun6c5hDQj8s8YvRj
Cwdy3IDXHwTiH58Z+NzSgGQuul+I1Y+iDps+Es1osMcujg+guwGnHJFmkJsu
SDEDuzkAwThPcA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 997->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQirEAe+zCRAFK
9KKbA8Pk2IVLDtlMbGqIcH+DPQRj1YPOxsJvQMOkAnT9pJqDrp5Uc3CpJ8cN
eP1BIP7xmYHPLQ1I5pKrH0UdGeGByz5S4gLdDTjliDSD3HRBihnYzQEA8fNP
NQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 998->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiqkM7OloHjly
9khy2NQQ4f4GewgmaC+6GqjdDWiYVICun1Rz0NWTag4u9eS4gRr+INWcBqQ0
QK5+YvSRagY2cWL9j57WyDGD3HRBihnYzQEACnJN/A==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 999->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQiocwsKdQHzb9
RJjZYA/B5NoL00+uOej6STUHXT2p5uBST44bqOEPUs0By+GIC2L1E6OPVDOw
iRPrf/R0S44Z5KYLUszAbg4A7xhMQw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 1000->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQikcBqaDBHoIp
1U+uOej6STUHXT2p5uBST44bqOEPUs1BlqdEPyF9pJqBTZwU/+OSI8UMctIF
KWZgNwcAyhxMCA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False]}, Dynamic[$CellContext`i24$$],
                Alignment->Automatic,
                BaseStyle->"ListAnimateCore",
                ImageSize->All,
                TransitionDirection->Horizontal,
                TransitionDuration->0.5,
                TransitionEffect->Automatic],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
        GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}}], If[
        And[
         CurrentValue["NotebookSelected"], 
         CurrentValue["SelectionOver"]], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i24$$, \
$CellContext`i24$39649335$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 1000, 1}, 1000, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{309., {82.884033203125, 88.615966796875}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.773604173342923*^9, 3.773604301349017*^9, 
  3.7736044249824944`*^9, 3.7736046263917923`*^9, 3.7736052102295313`*^9},
 CellLabel->
  "Out[279]=",ExpressionUUID->"d6f32b8c-f03b-473d-bd6d-d956f6e66682"]
}, Open  ]],

Cell["\<\
When clamping just few dozen pixels, the WalkSATCRN can easily get stuck for \
a long time in an incorrect \[OpenCurlyDoubleQuote]local minimum\
\[CloseCurlyDoubleQuote] of the wrong memory to recall -- even when there is \
a unique valid solution to the memory formula given the clamps.  In this \
case, the CRN won\[CloseCurlyQuote]t stop it\[CloseCurlyQuote]s activity \
during the time that we watch it, and we will still see grey pixels at the \
end of the timed-out simulation.

Recall becomes quite effective and quite fast when a greater number of pixels \
are clamped to \[OpenCurlyDoubleQuote]known information\
\[CloseCurlyDoubleQuote].\
\>", "Text",
 CellChangeTimes->{{3.773604835419009*^9, 3.7736048681661997`*^9}, {
  3.7736049109671803`*^9, 3.773605039898629*^9}, {3.7736056631823483`*^9, 
  3.7736056856077023`*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"ed0eec3d-4abb-49d7-b2da-1728d0115feb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ImageClamps", "[", 
   RowBox[{"image_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"i", "=", 
         RowBox[{"RandomInteger", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"First", "[", "image", "]"}], "]"}]}], "}"}], "]"}]}], 
        ",", 
        RowBox[{"j", "=", 
         RowBox[{"RandomInteger", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"Length", "[", "image", "]"}]}], "}"}], "]"}]}]}], "}"}], 
      ",", 
      RowBox[{
       RowBox[{"ImageVar", "[", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "]"}], "\[Rule]", 
       RowBox[{"image", "[", 
        RowBox[{"[", 
         RowBox[{"j", ",", "i"}], "]"}], "]"}]}]}], "]"}], ",", "n"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.773605196848662*^9, 3.773605212914835*^9}, {
  3.77360527762254*^9, 3.7736054671576223`*^9}, {3.773605505083015*^9, 
  3.773605507968762*^9}},
 CellLabel->
  "In[282]:=",ExpressionUUID->"a605416d-ae15-4f57-b23a-da11e923bee3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ImageClamps", "[", 
  RowBox[{"iSmallTuring", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.7736054703108664`*^9, 3.7736054878551483`*^9}},
 CellLabel->
  "In[283]:=",ExpressionUUID->"c9129179-4d33-4cc9-a339-6462da5b3948"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"pix9v11", "\[Rule]", "1"}], ",", 
   RowBox[{"pix16v6", "\[Rule]", "1"}], ",", 
   RowBox[{"pix7v15", "\[Rule]", "1"}], ",", 
   RowBox[{"pix8v7", "\[Rule]", "0"}], ",", 
   RowBox[{"pix15v3", "\[Rule]", "1"}], ",", 
   RowBox[{"pix9v12", "\[Rule]", "1"}], ",", 
   RowBox[{"pix12v4", "\[Rule]", "1"}], ",", 
   RowBox[{"pix10v1", "\[Rule]", "0"}], ",", 
   RowBox[{"pix15v6", "\[Rule]", "1"}], ",", 
   RowBox[{"pix7v7", "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773605488888957*^9, 3.773605512901133*^9}},
 CellLabel->
  "Out[283]=",ExpressionUUID->"4bbfa6fa-01fb-4fac-a726-9226e1f19b8c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "should", " ", "recall", " ", "Turing", " ", "if", " ", "it", " ", 
    "halts"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"WatchImageWalkSATCRN", "[", 
   RowBox[{"memcnf", ",", 
    RowBox[{"ImageClamps", "[", 
     RowBox[{"iSmallTuring", ",", "40"}], "]"}], ",", "1000", ",", "5000.0"}],
    "]"}]}]], "Input",
 CellChangeTimes->{{3.773597391852283*^9, 3.773597395140417*^9}, 
   3.773603873645281*^9, {3.773603904151799*^9, 3.773603928360194*^9}, {
   3.7736040384519157`*^9, 3.773604115308587*^9}, {3.773604382285151*^9, 
   3.773604536052544*^9}, {3.7736051474615383`*^9, 3.773605155318701*^9}, {
   3.7736055281120577`*^9, 3.773605544511449*^9}, 
   3.773608026504156*^9},ExpressionUUID->"2bf74d38-c063-4f70-9106-\
74fe4dd702cf"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i26$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i26$$ = 1}, 
     "\"max\"" :> {$CellContext`i26$$ = 1000}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i26$$], 1, ""}, 1, 1000, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i26$40850800$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            TagBox[
             StyleBox[GridBox[{
                {"\<\"\"\>", 
                 AnimatorBox[Dynamic[$CellContext`i26$$], {1, 1000, 1},
                  AnimationRate->Automatic,
                  AnimationRepetitions->1,
                  AnimationRunTime->0.,
                  AnimationRunning->False,
                  AnimationTimeIndex->5.,
                  
                  AppearanceElements->{
                   "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons",
                     "DirectionButton"},
                  AutoAction->False,
                  DisplayAllSteps->True]}
               },
               AutoDelete->False,
               
               GridBoxAlignment->{
                "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "ListAnimateLabel",
              StripOnInput->False],
             {"ControlArea", Top}],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OTQ1aDTw+yPDLG5SZkPfjMw0YTEsPnFlxuJuROXGqxqUdXR4xadPXE
2oONjc0v+MwjxQ347MAmhy5ParrCZi4+v+ICpMQHNvfhcjOhsCPGH/jsIhSO
2PyASz+6OL60SIr7UdUAAFIaaSE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 2->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OTQ1aDTw+yPDLG5SZkPfjMw0YTEsPnFlxuJuROXGqxqUdXR4xadPUY
9mDxBy42Nr/gczfRbsASHtj8hMsedD3Y5HHZgU8tIXficyuuMCVKjIiwI8Yf
+OwiFI7Y/IBLP7o4vrRIivtR1QAAbrFo4A==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 3->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OTQ1aDTw+yPDLG5SZkPfjMw0YTEsPnFlxuJuROXGqxqUdXR4xadPUY
9mDxByFz8ZqHJkeUG7CEBza78bmN1HSFzVxcdhGblogNN4JiRIQdMf7AZxeh
cMTmB1z60cXxpUVS3I+qBgBQimmf
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 4->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OTQ1aDTw+yPDLG5SZkPfjMw0YTEsPnFhRAgjvRxfGFC7o6YtSiq8ew
B4s/CJmL1zw0OaLcgCU8sNmNz21EpSscfiRkF7FpidhwIyhGRNgR4w98dhEK
R2x+wKUfXRxfWiTF/ahqAJAHah0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 5->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OTQ1aDTw+yPDLG5SZkPfjMw0YTEsPnFhRAgjvRxfGGiz1us3Dx0dVj
2IPFH4TMxWsemhxRbsASHlj9j8fdxIYfNj8SsovYtERsuBEUIyLsiPEHPrtw
uZVQvsQVJvjciS+/EB8PAItHadw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 6->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OUQ1ODTw+yPDLG5SZkPfjMw0YTEsPnFhRAgjvRxfGGiz1us3Dx0dVj
2IPFH7A4wmUuXvPQ5IhyA5bwwOp/PO4mNvwwzMGlFs0uXICU+MDmPqxi6GGH
J73h8wc+u3C5lVC+xBV3uOIYXYwU96OqAQCzS2oZ
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 7->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OUQ1ODTw+yPDLG5SZkPfjMw0YTEsPnFhRAgjvRxfGGCzTssMnh4qPb
jWEPFn80YLMHh1/wuZtoN2AJD6z+x+NuosMP3RxcatHswgVwuRVrmGJxH1Yx
9LDDk97w+QOfXbjcSihf4oo7XHGMLkaK+1HVAADT+2nY
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 8->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OUQ1ODTw+yPDLG5SZkPfjMw0YTEsPnFhRAgjvRxfGGCzTssMnh4qPb
jWEPFn80YLOHgD6sbiHWDVjCA6v/ibCfYPihm4NLLZpduAAut2INUyzuwyqG
nr7wpDd8/sBnFy63EsqXuOIOVxyji5HiflQ1AHPdaNg=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 9->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQy
Gx0gy+OUQ1ODTw+yPDLG5SZkPfjMw0YTEsPnFhRAgjvRxfGGCzTssMnh4qPb
jWEPFn80YLOHgD6sbiHWDVjCA6v/ibCfYPihm4NLLZpduAAut2INUyzuwyqG
nr7wpDd8/kBxP5HhRChf4oo7XHGMLkaK+1HVAABDWGiX
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 10->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDX49CDLI2OcbmJAlcNlHjaakBg+t6AAEtyJLo43XKBhh00O
Fx/dbgx70P2BFEco5hLQh9UtxLoBS3hg9T8h+wmlKxxxSoxduAAut2Ljo9uL
Uww9feFJb/j8geJ+AmmeqPSHQz+6OL60SIr7UdUAACVTaJU=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 11->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDX49CDLI2OcbmJAlcNlHjaakBg+t6AAEtyJLo43XKBhh00O
m1p0c7Hag+4PpDhCkSOgD6tbiHUDlvDA6idC9hMZJtjsJmQXLoDLrdj46Pbi
FENPX3jSGz5/oLifQJonKv3h0I8ujissSHU/qhoApo1pEw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 12->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDX49CDLI2OcbmJAlcNlHjaakBg+t6AAEtyJLo43XKBhh00O
m1p0c7Hag+4PpDhCkSOgD6tbiHUDlvDA6idC9hMZJtjsJmQXVoDDn9jMIymt
oacvPOkNnz9Q3E8gzROV/nDoRxfHFRakuh9VDQBYSmmR
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 13->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMVwApg8Z43QTA6ocLvOw0YTE8LkFBZDgTnRxbHYhm8uA
wyxsatHNxWoPuj+Q4ghFDlkfuhwudxPrBizhgdVPeNyNK11hCxNsdhOyCyvA
4U9s5pGU1tDTF570hs8fKO4nkOaJSn849KOL4woLUt2PqgYA4fdpUA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 14->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMVwApg8Z43QTA6ocLvOw0YTE8LkFBZDgTnRxbHYhm8uA
wyxsajHMxWYPenwgxRGKGWjm4PIjiluwqMGlBz08sPqJAdOduPyHL0yw2U3I
LqwAhz+xmUdSWkNPX3jSGz5/oMcxPjuJSn849ON0N5o5pLofVQ0ARrxojw==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 15->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMQyAZicyxukmBlQ5XO7ARhMSw+cWdHcT6050cVz2wsxF
DxNsZuB0AzZ70OMDKY5QzEAzB5cfUdyCRQ0uPejhgeEnLO7G5z98YYLNbrxp
CFdawuFPbOaRlNbQ0xee9IbPH+hxjM9OQuL43IzT3WjmkOp+VDUAf+hoTg==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 16->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMQyAZicyxukmBlQ5XO7ARhMSw+cWdHcT6050cVz2wsxF
DxNsZuB0AzZ70OMDKY5QzEAzB5cfUdyCRQ0uPejhgeEnLO7G5z90eRS/YbEb
bxrClZZw+BObeSSlNfT0hSe94fMHehzjs5OQOD79ON2NZg6p7kdVAwASJWjM

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 17->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMQyAZicyxukmBlQ5XO7ARhMSw+cWdHcT6050cVz2wsxF
DxNsZuB0AzZ70OMDKY5QzEAzB5cfUdyCRQ0uPejhgeEnLO7G5z90eRS/YbEb
bxrClZZw+BObeSSlNfT0hSe94fMHut/x2UlIHJ9+nO5GM4dU96OqAQDhm2iN

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 18->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMQyAZicyxukmBlQ5XO7ARhMSw+cWdHcT6050cVz2wsxF
DxNsZuByA1Z70OMDKY5QzEDWhy6HI4yIdgOW8MDwExZ3Y5iFxR/YwgSb3XjT
EK60hMOf2MwjKa2hpy886Q2fP9D9js9OQuL49ON0N5o5pLofVQ0AQLlpDQ==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 19->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMQyAZicyxukmBlQ5XO7ARhMSw+cWdHcT6050cVz2wsxF
DxNsZuByAy57UOIDKY5QzEDWhy6Hxd0NONTgdANaeGD4CV0PNrOw+AOXP7Gl
F5xpCFdawuFPbOaRlNbQ0xee9IbPH+h+x2cnIXF8+nG6G80cUt2PqgYAmRNo
zg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 20->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMQyAZicyxukmBlQ5XO7ARhMSw+cWdHcT6050ceSwxVCL
FE7oZmGYjcUNWO1BtwspjlDMQNaHLocjjIhyA47wwPATjvBBNwuXPLo/saUX
nGkIV9rE4U9sdpOU1tDTF570hs8f6H7HZychcXz6cbobzRxS3Y+qBgCRMWnK

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 21->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45NDUwMQyAZicyxukmBlQ5XO7ARhMSw+cWdHcT6050ceSwxVCL
FE7oZmGYjcUNDWj60dWisO3RzEDWhy7HgMMtxLgBR3hg+AlH+DSgmYVLHt2f
2NILzjSEK23i8Cc2u0lKa+jpC096w+cPdL/js5OQOD79ON2NZg6p7kdVAwAZ
E2jK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 22->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45dDX22M1iQLMTGeN0EwOqHC53YKMJieFzC7q7iXUnujhy2GKo
RQondLMwzMbihgY0/ehqUdj2aGYg60OXY8DhFmLcgCM8MPyEI3wa0MzCJY/u
T2zpBWcawpU2cfgTm90kpTX09IWFj+FGLP7AyGN47CQkjk8/TnejmYM3jLHZ
iaIGAEJAaIk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 23->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45dDX22M1iQLMTGeN0EwOqHC53YKMJieFzC7q7iXUnujhy2GKo
RQondLMwzMbihgY0/ehqUdj2aGYg60OXY8DhFmLcgCM8MPyEI3wa0MzCJY/u
T2zpBWcawpU2cfgTm90kpTX09IWFj+FGLP7AyGN47CQkjk8/TnejmYM3jBkI
qQEAWGNpSA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 24->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45dDX22M1iQLMTGeN0EwOqHC53YKMJieFzC7q7iXUnujhy2GKo
RQondLMwzMbihgY0/XDaHou99mhmoKnH5Ud0uwi6AUd4YPgJR/gQ8ge2MEF3
L4ZdaO7AmTZx+BOb3SSlNfT0hYWP4UYs/sDIY3jsJCSOTz9Od6OZgzeMGQip
AQBVGGoH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 25->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQHDyIV5/gF/QBwS/UF0TQU0GoB/HWp2vBlmR2JjWQbLK73ZlM
uofro7tvADx336XLr/Mw5PdlOx1uuT8d+ym4/01gTFjsvMdsi1HFXYxzkq4F
wiyn5YQ65ngou+ZrcWHe//Jkf6ltyC104lqhtuAw0veLTQI3UQ3Kh6nHWC0O
4d1behl91u6hNGG+Uj9E7GqQBsxVvQ/jWh//X+IcOIp7hB4zmE6Xlv5SK9MX
rX5xeTHnAzsdaMY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 26->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSM
zQCjkQCKPC45dDX22M1iQLMTGeN0EwOqHC53YKMJieFzC7q7iXUnujhy2GKo
RQondLMwzMbihgY0/XDaHou99mhmoKnH5Ud0u/C5ASPe8YUXjvAh5A9sYYLu
Xqzhx4BpNwpAtg/dLix2k5TW0NMXFj6GG7H4AyOP4bATV7jgC3+sYYUjX+DL
L7jUYaoBAHAsaUY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 27->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0kOwjAMtDigXnkCX4AHWHyhvCBI9FQJqT0gbnk6LYUqGY9dIiWpl3gm
4+Z4e7TdTkTGZlra9LwMQ3pd97NxT/351M/Bw3eKZJ0WXfbPtyw2jiruxTBH
ea2fL6udKycH0+OA5zA38kVckPe/PNFfamtyC52wlqlNOGQ4v+5KcLHfkO/d
EbEiDqbvkV6OPlv3YJogX6qfWOxqlHjkXbD+IK7rw/+L2IYjuYd5Yw6mp0uk
P9WKaSE1d1dj2cp5A13+aQU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 28->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk8ENgzAMRa0eKq6M0BXKAFZXoBOkUjkhIcGh4pbRC6VFyfd3aKQkxHHs
l+9weQxtdxKRqVqGNrxu4xjm+3ldPEPfXPt1s/52kajLoNv8+ZZtjS3b9/bQ
R3msny2q7TuTk9NjwHPoW7KVWJD7X060p9oa30QnjGViE4YI5/dZSV6sN/h7
d8QYJQZTd8KEbw05j+5BuZCX6Sc2d9bSfISV1QfzujZ8X2RtGMk9zD/m5PR0
KelPtWJaSM7uaixHPm+1HmjE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 29->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszigXXkCX4AHRHxhvKBIcJqEtB0Qtz6djSHUOg6l0tolaWzX
7f5y728bAFM3T316nMYxPc/bJbim4XgYluLu8wHZ5snW9f2PNeZR1rMFNaOa
aSxY3ZdN42fGE9yqpnS6nPm60uJ0/6mT8xFviauwHLbwKlP/dzXBy/dN+xU+
c7c0uHsXmvitsc7WOaQu1qv8g+euRskntKr7Yd4wx+9LxE6jOkfkLfcFvvzy
X3qlvECtPfQYrT0vueZowg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 30->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQHDxIrz7BL+gDFr9QXxBBTwWhPYi3PN3WiiSzs8ZAk242mZnM
JvvLvb9tAEzd3PXpcRrH9Dxvl+CahuNhWJK7zwdkmztbx/c/1phbmc8W5Ixy
prFg9b5sGj8znuB2uUCnmzOfV1qc7j918nzEW+IqLIctvMq0/zua4OV603qF
z9wtDa7uQhPfNdbZOofUxXqVf/DcVSv5hFZVH+YN5/h+idhpVOeIvAXh/HgL
kf/SK+UFau2hx2iteQHNF2lA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 31->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU1sKwjAQHPwQfz2CV9ADLF6hniCC/SoI9UP8y9FtrUgyO9sYaNJ9ZHYy
mxyu967fAHjspqlLz/M4ptdlOxu3NJyOwxzcfz8g2zTZsn7+sdg8yni2IGYU
M40Fq/dl0/iZ8URtFwt4rvnWuDjef/Jkf6mtyy10YiyHLbTKtP+3mqjL/aZ8
hc+1Wxxc3wUnvmvMs3UOyYv5Kv3ga1ejrCe4qv5w3dDH90vYjqM6R6QtCGfl
LUT6S62UFqi5hxqjlfMG7lFpAQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 32->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EOwjAMszggrjyBL8ADIr4wXlAkdpqENA6IW5/OxhBqHaej0tqlTh3P
6Q7Xe9dvADx209Sl53kc0+uynYNbGk7HYQb33wfINk22rJ93LDGPEs8WYEaY
aS5YfS6b5s/MJ2o7LNDZ2mtpcbr/1Mn7pbcut/CJuRy38CrT+d9qoi73m/IV
P9de0+D6LjTxXWOdymOFV7pYr/IPvnY1St+EVtUfrhvu8f0SsdOoviPyFsTT
+Bci/6VXygvU2kOPsZbzBnjuaMI=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 33->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU8ENwjAMtHggvozACjCAxQplgiDBqxJS+6j4eXRailByPieN1KSxnbvr
OT3dX91zJyLjYZ66NF2HIb1v+2XzSP3l3C/J4+8RMZ0nXdfvu6x7HHneNMgp
5JRjiZbnTDm+IR7hdrlAZy1W0+J0b9SJ8dxbV5v5hFgOm3hlcP6/KuHFfkM9
w0fulgbXd6IJ7xrqDHvJ+rPlbkIs5y5Gzku0sv4gbxgj3psS/1rfEXkrgFP5
FyL/qVfMCym1hx5Lq+YDZ0logQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 34->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkj0OwjAMRi0GxMoRuAIcwOIK5QRBgqkSUhkQW45OSxkc+7klUn+Sz7Ff
PudwfXT3jYg8d+OrK6/zMJT3ZTtNbqU/HftJ3P8ekarjS+fv91/muR9Wr5po
6jTlXKLtvqqcv/p8UDtoCWezlujEErj/5PTr1tsQ65iIy8b6vHSm0A8bp8k+
uAtUe40h9B2Y/F1b4iQduTwv+SexdjNsXWCl/vi66Rp5D71YPQd4G/poeIkl
8x+9Ii9MnsV+CsQ0Z/wAf/xnfw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 35->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwkAMHDyIV5/gF/QBwS/UF6ygp4JQD+Jtn25rRbKTSXWhu81OMpkk
7e58664rAPfNuHXlcRyG8jytJ+NS+sO+n8Dt5wGqjZvN5/sds83L49USzAgz
zQVr46pp/sp8InfAEp3NXYIrLUH3nzr53vc2+JImpcv7Mq+qKczD+1kSJ74F
lfuXBjiurw0dG2YhdCpc6gLpUP1DzN0sn1doVfNpOJfuVO/FLDg21MH/mDt5
DpmWrP+yV6oXjmdxnhA+TY0vcLln/Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 36->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwjAQRT8uxK1H8Ap6gMEr1BNE0FVBqAtxl6PbWpHJnz+lgSZNfvLn
ZYYcro/uvgHw3I1dV17nYSjvy3aa3Ep/OvaTuP99QLWxs3n8/mOec/N6tUQz
0kx7wdpz1bR/ZT8RO2gJZ7OW6IolcK/k5HWf27CXmBQX3y/EFkxNLL/PknOJ
v+dcwwDn9Z8n/KEWglPpkgvEIfLJXqH5uIJV1afxXFpTuRe14LPhHvzG3Mh1
yFiy/MtcqVw4n8V6Quxp7vgBjkJovA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 37->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0EKwkAMRT8uxK1H8Ap6gOAV6gkq2FVBqAtx16PbWpFM5qU4MNOmP/n5
SaaH673pNpIeu+lo2ud5GNrXZTsbt7Y/HfsZ3H+3NNp02PL8vGux4/L4aAlm
ATPmkpVxfivkoVzZonjKKcBRC+kG/swfe0a+QRPpivVVuUFTkcv7WRKX8Hud
/2iQ4/rZif5qFqCTcNSloAP6Gbmq5fOCVppPwbn2jXoPs4ixVR1wr+l+Z//C
Wv+xV9QLx7M6T4FPUeMbuYJoew==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 38->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk8sNwjAMhi0OqFdGYAUYwGKFMkGQ4FQJqT0gbh2dlqLKcT6nREoa5/fj
96PH27N97ERkaKajTa9L36f3dT8L99SdT90MHn5bZNTp0OX7vcsi+2XxUQNM
HabsSzS3s1tcHIoVLbKnmAI4ciHe4D/Sx5qRrkrmm3j5/IrYwCmLZfU0sAv8
W57/cLD5rHLAv+gF8CS8xsvOXHWGtnoMXKk/mc/aG9UeeuFtizxgrmm+o3+h
Vn+s1cZsVvsZ6a06H+yWabg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 39->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDD0Urz6hX6gPCP2CfcEW6kkQ9FC8+fRqLZKdnURhV9eZTGaT
3F5D211EZKrWrU2fxzim+XndDu/UN/d+A+v/Ell03XR//75lP+Nj8UUdTAFT
riWax9klkIflivQw3uMgTr2wPETf49OaMa5Kps184f2K3MRTlsvy1IkDHGtk
NSIPVuc4O/6LXhCfDI982ZkLZ+isx8Qr60+mGf1jtSe9wNjiHmSu2Xx7fYzq
T2t1MpthPz3ewfkCoRlpdw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 40->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKg0AMDS5Ktx6hV2gPEHoFe4Ip1JVQsIvizqOrtUh8eYnCzJh5+bzJ
y+X5btpKRD7neWvK9973ZXicFuNVutu1W8D6v0RGnTddz9+/rDZ+Fh8R130e
e89yCdS0S6AO1nK1DV8WH/kgTrkkvG185E97xnxVXE/CHOrv2JucHtZPgzjA
sUeoc8TB5tnsgL/TgvBkeMbLzlw6Q0caE65Mn13O7I71nmiBse4dZK7ZfEc6
Zv2nvTqYzVTPyG/zmQCAQWk2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 41->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkssNgzAMhq0eKq4doSu0A0SsABOkUnuKhAQH1Bujl0eFnN9/DEhJcPz6
Yvv+6prPRUSGat6aONZ9H7/tdRHeMT0faVHe/ktkCvMWtnP9l03GT+sn1Ic8
jr5nsQRy6iWQB3OZ3IqX+ZdskJWyONw6fsme1ozZAhPjwveZ3IQpyxXs240f
qQ3W8AyDjrPLBX7kZpxM73HpmXNn6KjHhJX1J4vp3bHak16gr3kHmWvTR8WL
Pl79aa0OZtPtZ8lut/kBEgdo9Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 42->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNks0NgzAMhS0OVa+M0BXaAaKuQCdIpXJCqkQPFTdGB0qFnOdnA1ISHP99
sX15vpu2EpHPed6a/L33fR4ep0V45e527RZl/V8iY5q3tJ6/f1ll/LR+RH0q
4+h7Fksgp14CeTCXya14mb9ng6yUJeDW8T17WjNmC0yMC99nchOmIleybzd+
pDZYwyMMOs4mO/zIzTiZPuLSMxfO0F6PCSvrTxEzumO1J71AX/MOMtemj4oX
faL6R7XyZjPsp2e32Uz7FWi2
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 43->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU0EOwjAMizggrjyBL8ADKr4wXlAkOE1C2g4Ttz6djSGU2m42qd3aJrYT
d6f7q3vuzGw8zFOXp+sw5Pdtvyweub+c++Xw+BtmJc1TWt/fb1vX+Pjzguep
xvH7CsuA0w8DHuQibqdX5bdiUKvUEuj2+K142TMVC5qULqoPuYWmiitx7ZQn
eoM9VPcFsch3oalAbKRT9S/S5bnDO7TlsdCq/Kkwoz3Ve+EF5lIdorfko9OL
OQpL+m3btdP/0qid4v4xH4wuaDY=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 44->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMPPFA/TICK8AAESuUCYJEX5WQ2gfil9FpaYOc8zWtlDSJ7fPZ
l5wfr7Y7ABibaWrj+zYM8XM/zptn7K+Xfjae1gGkME1h+f/WWPbI6/Wz9kS2
HI9ANoFjz5MYNiYxnsqd8eA5OC4oc1i75FLhbfG3/GXPlC9xUrxcfZxbcCpy
BV+7ixO94R6q+8JYTnfBie9ajafqX42XzV29Q3saC65KnwKzdqZ6L7TgWFeH
6K3T0fDlGIUl9cZ+7e69bNTu/P4+X6r2Z/U=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 45->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMPPFA/TICK8AAESuUCYJEX5WQ2gfil9FpaYPc8yWtlDSJ7fP5
nJwfr7Y7ABibaWrj+zYM8XM/zptn7K+Xfjae1gGkME1h+f/WWPbI6/Wz9kS2
HI9ANoFjz5MYNiYxnsqd8eA5OC7Y5rB2yaXC2+KX/KVmypc4KV6uPs4tOG1y
BV+7ixPasIbqvjCW67vgxHetxlPpV+Nlc9fu0G6PBVfVH8YqnintRS8UN6cZ
aM19NHw5RmGVNNmr3b2XQu3O7+/zBW4FaHU=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 46->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4ZXRa2iD3fE6lpElsn89n
n+7Prt8BeB2mrcvv6zjmz20/Xx55uJyH2XhcF1DStKXl/ztjuaOe18/aC9lq
PBLZBI59L2LZmMJ4KnfFg+fguGCbw9ollwZvix/5S82UL3FSvFx9nFtw2uRK
vnYXJ7RhDdW8MJbru+DEs9biyfyc3jx/gX72zdVmuQZ1Rv1hrPBNaS96obg5
zUBn1snw5RiFFWkS9sngtPBCv7/PF7ZwaDQ=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 47->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkOwjAMHHFAXHkCX4AHRHyhvKBIcKqEVA6IW55OS5vKGY8TKavt8Xji
0/3VPXcA3odp6frPdRz7720/Xx79cDkPs/G4TiCnaUnL/j9juaOc12HtmWwl
HolsAse+ZzFtTGY8lbvgwXNwXFDnsHbJpcHb4kf+UjPlS5wUL1cf5xacqlzJ
1+7ihDasoeoXxnL/Ljhxr7V4Mj+nN/dfoF/ly7VZrkGd0f8wVvimtG/0vh1O
M9CZdaJaQ01U31DezS/ozRZe6Lf5/ABUfWiy
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 48->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vhA/PXobOyh1HFaqVvbuK7j
5HR/dc8dgPdh/HT5cx2G/L3tp80j95dzPwWPywRKGj9p/v/XmPdY18uw8UKx
9T4SxQSPPS9i2jvVmdEh+eA1qHzsG4V4nZaGbssf4aVnCkualC6XX+CRxILu
sd/ki/SQOFhXVSeuu9DEtWnpZH3cE67/Av8qLOdmdQd5RvVhrio3e6a8b/S+
Hc4z0Jp9olxDT1Tf0LsbLujNFl+I2zA/D11obw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 49->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsOAiEMnPhh/PUIXkEPQLzCegJM9GsTk/XD+MfR3XUfKdMpJECh7TAd
erq/uucOwPswLl3+XIchf2/76fDI/eXcT87jMoGSxiXN+9/GfMZqL8P6C/nW
fCTyCRx7X8S0OdWd4SHx4DmoeuwbhXAdlwZvix/FS82UJsRJ8XL1BRrJWFAe
6026SA0Jg3lV/8Q1Ck6sR4sn8+OecP0X6FfFcm2Wd4QX/A9jVbXZO6V9o/ft
cJqBbNaJag01UX1D725xQW+28MK4LeYH2TBnbw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 50->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksOwiAUnHRh3PYIXkEPQLxCPQEmdtXEpC5Mdxy9rW3NY5gHCfB4n2He
wOX57voGwOe8LF383scxTo/TenjF4XYd1mC7TyCFZQnb/rOxnXHY+7DxRLGj
HoFiAsf6k5i2JvMZHhIPJQfVj70jEW7BpcLb4nv5UjOlCXFSvIr+HI1kLqiO
9SZdpIaEwbyyd+IeBSfWo8aT+fGfkHlCP5mLPMZ3cF/qfRgr6836lPaVv29H
oRnIVv07NQrL08R9J4NTw3Pz/jkzbaVnMA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 51->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMDC7ErUfwCnqAh1eoJ3iCXRWEuhB3PbqtSpk3mcTA+zQvmU4m
OVzvXb8xs8du3rr6PI9jfV22y8etDqfjsDzuf8tsKvNWvufnDj40945WWhz0
Mw76J7Ewp/EBD4lnnsMaW3wMc5VcEt6IH8VLzZQmxEnxcvUFGslYozzWm3SR
GhIG82r6xDUKTqxHxpP5uflMZtf15s8c8z+4LtUfxmpqQ5/SPpl9NKeZ0V3V
H+QorEiTsE+Ak+GFcWvMG6TDZ7A=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 52->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEOwjAMi3ZAXPcEvgAPqPaF8YIiwWkS0jig3fZ0NkCV6zit1K5N3cx2
cro9x0dnZq/jtoz5PcxzXq6H/XDP0+U87Zf9f5qtaVvS7/vdQwyHu8eR6jwY
5zwYX8XEN1UMeMh85jkUbPIY5iq5NHhj/ggvPVOeECfFy+kLPJJYo3fst/BF
1prq7PSzRjybfutqIXgqftbgxf0iNbA24i3zBfXhXJU2jCnvG72Pw3lmtGef
SGvoieob+m/BBb3ZyhfiCuYDzodorg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 53->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFyIW4/gFfQAwSvUE0Swq4JQF+KuR7dVKZN5kxjI7+W9YWZe
Dtd7128APHbz0uXneRzz67JdLrc8nI7D8rj/TWBK85K+++dMMR7hnUcqcTiu
OByfzOSaIkY8LB4ihzU3xRzlark0eDN+Ld965jwRTo5X0FfxyOZC6tRv44vt
tfQ56FeNfIevDb0wPB0/NHjpf7EaVJvwtniV/ihWoY1jzvvG3+cRPIOc1SfR
qtiKVfOk2ifCsdz+5a3Yb94yaG0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 54->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMizigXXkCX4AHVHxhvKBIcJqEtB0Qtz6dDRByHGdUatemiWc7
3V/u/W1jZlM3L319nMaxPs/b5XCtw/EwLJe77zRrZV7K5/veQwxHuMdRPA7G
GQfjTUyscTHgIfEI1+USJufhvxyXFd6In+VLz5QnxEnxQu6N9PA55BrVsd/C
F9lr6nPQzxrxbLo29ELwzGIZL34vUgNrI94SL+kPYzltGFPer7x9HMEzoz33
kbQyNmNlnqR9AhzJ7V/eD/sFeIZoLA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 55->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksKAkEMRIMLcesRvIIeYPAK4wla0NWAMC7EXR/dGRWpvE7Ghv6lk6Kq
0rvzrb+uzOy+mZa+PI7jWJ6n9Xy5lOGwH+bH7Xea1W5aus/+PktMR/Ouo/M4
GieOxmswtcbFhEeIB1yXC0zHGfoclwXeipXlh55FnohuYkV9qdDDe5NrqKPf
lrwZdKHPjX5q1LvFtfQ04pnFMl78L6EGagPvEC/pD7GcNo1F3i/8fR2NZ4Yz
+witxCZW5knaJ8EJuf3L+2G/AJjEZ+0=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 56->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksOwjAMRC0WiC1H4ApwgIgrlBMEia4qIZUFYpej0/KT8zIukZLGv6ln
nN352vUrM7ttpqPL9+M45sdpPRuXPBz2wxzcfrZZSdOR3t/X3fn8auIqlhAT
ON5fxPY1lc/9S+IBt8oF5tdXgNv0stC3x4rypWZKE8ebWGouBXxoN7mGOupt
QczAC3Nu+JOjt03XUlPVZ+SL+uJ7kRzIDX1LvGA+xKq4eZ/SfuHt+9VoZrhz
juBKbGJFmoRzcjiyt395P+wnt+JobQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 57->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADKr4wXlAkdpqENA6IW5/ONtDkOs62Su3aJPVs
p6f7s2l3ZvY6DEuT39e+z5/bfjw8cnc5d2Py+J9mJQ1L+n2nPcSmAbEqD2PO
Jcohjvl4ERPvVDH4l8QjXBWv7hNXyWWBN2JF9dIz5QnoZizVl0J6+Oxqje6x
3xbkLOAiatybCd6Q07iBZxRD/5Q37F9VS9qYt8QL+qN8Qt2o3Xm/8PZxOM+M
9txH0srYjBV5EvYJcCS3tboZ+wsj0Gis
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 58->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFyIW4/gFfQAwSvUE0TQVUGoC3GXo9tWKZPJvBpIm7zPvHmT
d7g+uvsGwHM3frr8Og9Dfl+20+WW+9Oxn5z73wZKGj/p+5/PZJtX5Ke1+JL4
GAetvZjNOZWNalk8wXX2Kl+4Wi4rvBnf8azsUrfRhPrW2u5divSj9yYWkqd6
I/Ah4GJi3MxUd/hcp6lyiWysn9NG9atipTflbfGC93E6cd/ce6P9yuzzajSD
nPUdpVfFdjMc1eV8Nw+W27+4BfsDXb5oqg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 59->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6bUFoMhnXUhbbsT0e
53R/dc8dgPEwb12ersOQ37f9ojxyfzn3i/P4W0BJ85a+53on2yqRn+TvS+Lj
PGjtxSyOqWxUy+aTvM5exQtWi2UDN+d32Cu71G04oVit7eZSpB/Vm7eQOOUb
gQ8BFvPG/ZlKh491nCqWyMb8OW6Uv+qt9Ka4bb5gPo4n7pt7b7jf+PssDWeQ
u85RetXc7g9HdTnecWmxmRl47j4D3Ghp
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 60->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAQs3igfhmBFWCAiBXKBEGir0qVygPxy+i0BaGLY1Mpac+X87m+
HG9TP+wAPLpl6/PzMs/5dd2vwT2P59O4Jg/fBZS0bOnz3r4Dtj0uH55fLlEu
8qDFi1ixpsJCL8lHvAqv6kmr1PJHd+RX2iuc+jaehFrureZS6H84bs6C6thv
mBx8Lz6j7kwVQ9cqT1mLw6J/yhv2rzoLwkm35DPzYa7m/sH4a2KnTfE6j2UN
z4vrRF87p8Cv+NQMtHdvK79oKA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 61->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAQs3ggvozACjBAxAplgiDBqxJSeSB+HZ22oOrOsYmUpPHlfK4v
h+uju28APHfT0tXXeRjq+7KdD7fan479HNz/JjCWaSnfffkO2DJcPIw1VigW
edDio5gxJ2GhluQjXoWnfNIqtQjNil9pTzjVbXwhbqVr5SBP2CN5F5THfsPE
4GvxHfVm0hk6V3nKWhwW/VPesH/pLggn3ZLP9Ie5mvcH4685O22K13ksc7hf
nMd1//UpxJvei3+PM3mCD7nHaGU=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 62->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6I257ONhBKXJtK7ZakcRyn
h+u96zcAHrv56OrzPI71ddkuxq0Op+OwBPffDUxlPsrnu/4H37pcPKxfrFAs
4qD1T2LHnOQLtSQeBAfqIeUTV8lFcFb4invyU91GF8JWvJr+jEbyLiiP9YaJ
wdfiO+rNJBs6V2nKXJwv6qe0Yf3SXZCfeEs8Mx/Gat4fjL7GdtwUrtNY5vC8
OI/r/ptTiDezF73HnTTBG5TlaOU=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 63->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwkAMHPyQ/noEr6AHWLxCPcEK+lUQ2g/xz6PbVpHJ7MRAtt08Jslk
95d7f9sAmLr56OvjNI71ed4ul2sdjodhce6+CrzKfJTPd/0n2yqZn+TnK+Jj
HBXCZOWcYKNaDktnYbticn2dIfSiNRJ813uwS92GF8F2fTXzJRzZWEie8o3E
h7yWxrg3E+7wuY5T7SWzMX+OG+UvxELs0rfFS/ajWM37Q8Jvcs96c7gZxzZH
96V5Wvffnsjf7N7Mzho4wRuVo2im
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 64->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDxIrz7BL+gDFr9QX7CCngpCexBvPt22ikxmJwaybZLNJJns
/nLvbxsAUzcffX2cxrE+z9vFuNbheBiW4O6rwKvMR/l813/yrZLFSX6xIjHG
USFMVs4JPqrlsHQW9ism19cZQi9aI8F3vQe/1G14EWzXVzNfwpG9C8lTvpHE
kNfSO+7NBBs+13GqvWQ+5s9xo/yFuxC/9G3xsrchWM37Q8JvYme9OdyMY5uj
+9I8rftvTxRvdm9mZw2c4A2llWfn
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 65->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwlAMHFyIW4/gFfQAD69QT/AKuioU6kLceXTbWmQynfRBXpvfJJm8
U9s3jx2A52G8mvq6DkN93/aTcq/d5dxNzuMiwKeMV/l953+yzSfz0/n7ivgY
Rw9hsnBOsFEth6WzhFjB5Po6Q+hFa+iMrk+DaXtxPJnabi/MiXJkYyF5yjcS
H/JaGuPeTNDhcx2n2ktmY/4cN8pfiIXYpW+Ll70NwdL3wbOvuDd61pvDzTi2
ObovzdO6W3si/2r3ZnaWwAm+eLNoZw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 66->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszigXXkCX4AHVHxhvKBIcJqEtB0QN57ONlDlug4iUtstTp3E
zf5y728bAFM3b31+nMYxP8/b5eeah+NhWMDddwGvNG/pc67f5FstwskKlgRj
HjXi5MV3Kh/lclzaSxUrnJxfe6hq0Rzao6vTcNpajMaqs+UQTVQjGwu5p3oj
wBDn0hg3M26Gmh7/qDPyFXNxpJ+NJa0YC/PSXTeD+maFT+sws97MTzB/jhfi
c/VWvcHoj0CTX+9EePP2pndelSZ4AyZ3aKQ=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 67->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDggrjyhX4AHRHyhvCCV6KkSUjkgbnk63VSNJ2OIlNWxPTN2
0z3b/mBmr9O0tPl9G8f8uR/nyyMP18swG8/bNCtpWtK6L2d4W0Zkh7HbEtkw
Dg+IiRN93BvkUrGYi/tLMTE/c3BYOAdzVDhFTIlFaMw6yxikCWsU/hXnyu9P
L3CdS4Ah4qd8laYKs+RhtY/sF/UXtEJbmBd8VQ9yzfZ4jIO1F3fuTcbNfHBX
eB03+61/odhhncBe1V5wx+k0sS/p3Wki
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 68->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAURD8uxK1H8Ap6gOAV6gki6Kog1IW4y9Ftq8hk+qKBNE1+/vyZ
yd+db911FRH3zfjp8uM4DPl5Wk+bS+4P+34Kbj8zoqTxk97r/C9n82jFZXxj
yWKK40MwdWpOdSa1CMu1VHcNU+u7hoqL13CNxBMwkQt47D4jxh+P/G4x7EUd
wG71gr9zaXBo6aNc8pQ4o45Y5mC/0F3xSmPNupJLPUhvgDzce9h7bzpv16Mr
8a20xW//i2E338n9cG7Qw9TbES/O2Wjh
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 69->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwjAUszigXhmBFWCAiBXKBEGCUyWk9oC4ZXTagpDj+EGkfF/iZztv
f7n3tw2AqZuHPj9O45if5+2yuebheBiW4O7TgZLmIb3ndU1na4vi1L6xJDHG
0UaY3PlNdUa5HJZqqe4KJudXDRUXzaEaHU+DabkYj9Vni/HHI71bBLvJY7Cj
Wog8av4p0OdqzXnqOFsdaN/YenF3ySuOhXnpratB9weWh3pv9lqbylv18Oz4
Vtrw2/8i2OE/qR/KzdSwq23gBfXoaWE=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 70->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEUCy7ErUfwCnqA4hXGE1TQ1YAwLsTdO7ozo0gmzdMH/b42zUuz
O9+66wrAfTN2XX0ch6E+T+tpcan9Yd9Pye2nAVHGrrzHeU57c2R5im+uSI5x
NAiTG99Z7NFbWSiHkBp0LwS34SJ8oTU6ngbTcjEaq84W449GejYEu3nHYGde
yDRq/impz3nNaeo42zrQ3rF+cWdJK86l79Jd50H3B5aHam/W6k3lrfXw6Pgu
asNv/UOw039SPZSb8bDzNvACCmVpIg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 71->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozACjBAxAplgiDBqxJSeSB+Hp22ILicz8VSmsZOzuez
d+dbd12Z2X0zfrr6OA5DfZ7W0+FS+8O+n4LbzzLzMn7Ke5//wTdbFgf7xgrF
EIcNMHHhm8YHuTJjDk41sM8JN3AhvpbgK+6NX3ERGrPOEuOPRnzXCTvkSbDV
LGQahT4l9alZ43wZZ1mHxTdyXtRd0ApjS3lVf1SepjaOs/bizLPJvLke3LkP
Ye5sWX8n7LRPEA+9F7XzzPxyvQDLTGlh
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 72->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS7ErUfoFfQAxSvUE0zBrgpCXYi7HN0OHWrm5WUMZGDyZl5e
Pt34HKaDiLxO6zGk921Z0ud+zJdHmq+XOYPn4qv1m2vxbFpiTdzYjvWAWR40
w2nd/qliJldkqEGhBowp8DotoFcCfqa9ijMtpMfYZ8rxp0f4VoHb5Qm42S5E
PXJzCupTzB28ZZppHeL/0H1pvZUaa+Vl82F5qtoQx96Te6SN8QrEcA6uz8L7
7/Y0+M9wN3tSO+7ML9cX7dZooA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 73->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB7Eq0/oF/QBxS/UF2zBngpCPYi3PN0uXWp2MlkDKTSzmSST
dONzmA4i8jqtnyG9b8uSPvdj/nmk+XqZM3guvlq/uRbPpiXWxI3tWA+Y5UEz
nFWuybGYrRUZ9qAwA8YUeNGxXwn4FXvHOOuFaIw6U44/GuFbBW5XJ+BmtxBp
5PYUzKdYO3jLeqZziM+h99J6KzXWqsv2w+pUsyGO2pP/qDfGKxDDPTidhevv
7jTIZ7jbPZkdb+ZX6wu42mhf
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 74->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS7ErUfoFfQAxSvUE0zBrgpCXYi7HN0OHWrm5WUMZGDykpdv
Nz6H6SAir9P6DOl9W5b0uR/z55Hm62XO4LnoKv2mWjSLFlsTN7JjPWCWB8Vw
VrEmxmI2VyRYg0IPaFPgRcV6JeBXrB3trBYyY5wz5fgzI/RV4HZ5Am52C9GM
3J6C/hRzB76sZtqH+Bh6Ly1fqbFWXrYflqfqDXGcPflHtTFeARvuwc1ZSA/s
ToN4hrvdk97xZn65vpkbaCA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 75->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeoHiFeoIR7Kog1IW4y9HtYKnTNz/VQAYmf/KT
/Mzhem+7jZk9duPRpud5GNLrss2XW+pPxz6D+8lHaz7uk2fzKbaKFzZjDbCS
h1ZwLnKLnBIra0XGHhwzMObgpbNfC/idvTOuehEaU2fJ8UMjvnVwV3UCbvUX
Io2qPbFP1F/MKLRQPcs5DDlWY+Hbf3Ys9ir/htBp5iNO7cU96k3xGmLcQ6Xz
miaGuiJf4dXuxez8M99ab26vZ6A=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 76->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRYMLcesRvIIeoHiFeoIRdFUQ6kLc5eh2cKjjm59qIIXJb37+
/MzufOuvKzO7b6ZPnx7HcUzP0zofLmk47IcMbktO0b3TS+bwUlvEq5ixDljN
w6g4v3qrnhqrZ0VBDY47sObgZVKvBfxO7awrLcJj+iw5fnjEfx3czZyAW72F
yKNmT9QpOKUfFmuW9zD0WIuF//6zY7FX+TaETzMfcXovzpE2xWuocQ+Nz0ue
GOaKfoU3uxd355v5zHoB7HFnYQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 77->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD2IV5/gF/QBxS/UF6ygp0KhHsRbnt4uLjU7mWwDadkMO5lM
9vyYhlcnIu/j+hnS5zbP6Xs/5MMzjdfLmMFTyTX6X2rJHFpqTdzEhvWAWR4M
w1ndNXcsZntFgRoUZsCaAi8m6pWAX1E71pkW4jH6TDl2PEJNCtyuT8DN3kLk
kdsT6iSc1A/hOqPaFtHbJWfHKTXW6sv2w/pUsyEe7CXyn82I89g/7sH53PJE
oC+5z3C3ezI7vpl/rwU/j2fh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 78->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwjAQXDxIrz7BL+gDgl+oL4hgTwWhPYi3fboNhrqZnc1CWpIhM7Oz
OT9e43QQkXXYPmN+35Ylf+7Hsnnm+XqZC3iqa6v0W1pXKa1nXdzUjiXALA+W
4WzumjuKfETbYcwncFp97EET1xXjDfkVvRP/zgvJGHOmHJFG4EmB2+kE3Owt
RBkhl+uRcNI8hPuMzvaK3i7ZO05psZ4umw/TaXpDPJhLlD/rEfuxf5yDy7mX
iYAuuc9wN3vSO76Zv9YXTB1nog==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 79->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCexBvebpdXGp2MtnAtuwOmUkm
OT9e43QQkXXYPmN+35Ylf+7Hcnnm+XqZC3iqZ4v0O1pPCa1vXdzEjiXALA+G
4WxyTY4iH9F2GKsTOK0+9qCJ64qpDfkVayf1u1qIx+gz5Yg0gpoUuJ1OwM12
IfIIuVyPhJP6IbzO6G2PaHfJ3XFKi/V02XyYTtMb4sFcIv9Zj9iP/eMcnM89
TwR0ST7bTTd70jvuzF/rC28daCI=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 80->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKg0AMDB5Krz6hX2gfsPQL9gVbqCehYA/FW56uS7e6O5lsIEqMmUwm
uTzfw9iJyOe8PYb4vc9zXB6nFLzidLtOKdln3yz8XLMn0/ytmZfjnz1X1gmJ
pc5pqGsRo+z5N4xNzuOJswG2BuvIF+sUeTb4Gy5EY9SZYng9HE5mXuzjYLNb
8DRCLDMjwaR6COfpfdvNu10SG0ypc62+hnthbAeUh7MXT382I85TvnEPRueW
JgJ9ST27TbN7MjvezNFrBe7RZ+E=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 81->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHxy+g0ItDkfI4lV7Jdn8/n
nO6v4bkDMB/WzxCX6zTF922fg0ccL+cxF4/FVwtfT8WzpZLr1rH986/VfRAx
2loKbS9j1DN/xrGpeTx5N8JOwTrz5b7EPDv8DRehMessMbwZDiezL89xsNVb
8DRiLLOjwJR6QPP0cl2NoGODibbWm2u4V6ZuIHk4d/H0N7wJF5TjOxide5qA
5op+9TbN7cXu/Ga2WR/N4Ghh
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 82->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEOwjAMszggrjyBL8ADKr4wXlAkOE1C2g4Ttz6dVRTWOk4jZVLqxXHd
nO6v4bkDMB/WzxCX6zTF922fi0ccL+cxg8eSa4RvppI5Ujnr4tj++WN1H0SN
Fkuh7WWOeuYvuDaYp5PvRtwp2GS93JdYZ0e/0SI8Zp8lhzfD0WQwnuNwq13w
PGIuc0fBKf1A9R/thDrregRdG060WG+u0V6FegOpg70XtadN8YLO+B2Mzz1P
QHNFv9pN8/bi7rwz26wPKjloIg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 83->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKAjEMRYMLcesRvIIeoHiF8QQVdDUgjAtx16M7g9VpX34bSCH9Tf5P
msP1Mdw3ZvbczccQX+dpiu/LdglucTwdxwXcZ58tfD1lXyzluy5u65s/VuaZ
iK3GUqhzWaPk/Bljh7V0sjfUTsE79TIvUWdHv9MiZsw5yxolF7mFJoeRR2Cu
R1GTutTO0N17vjX019iNiqsxoxLjTnJPSqzH67QXpv5A6uDsRdzSpuoa7vgP
bs69mRh4Rb7aTff3onfuzMr1AZFIaKI=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 84->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IW57OKgprHbdUyqTUjR1n
OVzvw7gB8NgtnyE+z/McX5dtSm5xOh2nBO5zLCd8wnKkY/mui2N988PKOogc
NWahrmWOUvN7OGdOtPpkb8RtwYfiVvzO/7+Z8awaNczt5sTaoieHsY7AnEfB
yd7Uzqh5VO/5LchfYzcqLfheGOOdNOqnxHq60qvQqbwxzrMXeas3xQu64//g
5tybCUhX1KvddP9eeOedWbXegb1o3w==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 85->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAQs3ggvozACjBAxAplgiDBqxJSeSB+GZ1WBJrYTiKl1dV3Z597
h+tjuG8APHfzY4iv8zTF92W7BLc4no7jAu7znU/43pTvclL+1sWx5vyxsg4m
Ro2lUNdyj5Lzdzjmngiqj3tKHmotjhemLrHOoHnWM/aqUcO9xSfmNpoEYx6D
yYymJ8/mdsb5UeVzLmi+xm5UXFAtjPFOJtJTYj1eO6vhkf1Dx3sTt7SJZ9A3
/wdX0/QExGvq3W7Kvzez886sXB/gFmie
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 86->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKAjEMfbgQtx7BK+gBilcYTzCCrgaEcSHuenSnWCV5eZlAWtL38m0O
18dw3wB47pZjGF/neR7fl20zbuN0Ok4N3HddpHy1dm1S+1uGg+4/Zv0gbHis
Fu/LMVxOmNoysXG4Tu6NYtcSVcW2fpXrLJHHXOao2Jar5mP/pwqb+8l6z7DQ
o4jJvamdUfNwfOaanp1P8vaTdHeFHWLCY2t5Za8iT9g/rMxe2FltYWaIN/+D
8klnAsor/C2udizcxGN/4ANvYmhd
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 87->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe+nR3sWo6mTSQljTJTJLm
cL0P4wbAY7ccQ36e5zm/LtvVuOXpdJxW577qIumjpeoqpb5FftD989k8CBut
r6Q2lzEaTpjaIrE4XCf3RtgleVXYNq9wncnHcSzHKGwbq+Zj/0fNjPvp8iic
YBeiGfV4Ikw5D9NzkxO8fSXcXWE7TLS+Hq/sVfC4/YOvv2dHtbmZwd/8Dyon
nAmIV+Rbf7hjonfemT/XG8U1Z10=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 88->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkOwjAMtDigXnkCX4AHRHyhvCBI9FQJqT0gbnk6jQgwmYxjyU3jZWxP
fLw9xmlnZuuwfcb4vCxLfF33+XKP8/k0Z+eh6Cbho6lollRsnt/o/PkwD3Ir
G/hSqHMZo6pp0JsniMN98j9hp9Cqwsa8xH2GNo5jOUZhY6ziB99HccbzdOso
HGcXPI56dTxMyQfMXOU4tq/0dpdjG0yrfb26clbogd+Ae5Tci7vXW8OZtaec
n3JcTozqinz0uzsmZued+dd6A2bzZ1s=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 89->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UssNwjAMtTggrozACjBAxAplgiDBqRJSe6i4eXQakYLz7BdLbprYz37+
nO6v4bkTkfmwfoa8XKcpv2/7cnnk8XIei/FYdZX0Va1aROsbs0tw/jDbm8E2
b9Ji1GAxRpNTDDcmNg7yxH+IrclrFNviFHkm74e+6BPFtr60PzgrwimapeOM
ccgusB7RPJ2YYT9MzQ2GvG3S2130dTGltfXyhrUaDjgD5OhmTO6Mm+uZ+DOs
HzC0JwJ5A7y10x0Lased+ef6AEAEZhw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 90->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UssNwjAMtTggrozACjBAxAplgiDBqRJSe6i4eXQakYLz7JdIbhrbz37+
nO6v4bkTkfmwfoa8XKcpv2/78njk8XIei/FYZT3pK1qlHK06Zpfg/mE2ncE2
OmkxarAYo8kpXIf5Qp74D3E0eYliW5wiz+T90Bd9otjWl/YHZ0U4RbN0nDEO
2QXWI5qnEzPsh6m5wRDddnq7i74uprS2Xt6wVsMBZ4Ac3YzJm3FzPRN/h/UD
hvZEIG+At3a6Y0HtuDP/XB8WpGbb
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 91->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMtHggvozACjBAxAplgiDBqxJSeSB+GZ1WpOCc7xLJjWr7zmfH
h+tjuG/M7LmbP0N+nacpvy/b5eeWx9NxXIL7avNJXyvVllOqT8WN3D/M6nPY
xmctpjgscjQ1TfuwHtWJvQFPSdEYt8cV1JliHuZiDuP2uXI+pB+mib1l0Iw8
YhfUjGSdDiedh+u5wQjfenq7i7mB09pYry7t1WnAN0CN4Y3Fv9IWZmbxpv0D
Rs7EoC7B+7jcMdI77sy/1gffs2db
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 92->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKAjEMDS7ErUfwCnqA4hXGE1TQ1YAwsxjc5ehOsaPpy0sLaWk+Ly+f
0/01PHciMh/Wa8jLdZry+7Yvn0ceL+exGI9V1pO+olXK0aqL7ELeX8ymM7GN
TtoYNbGI0eSUWIf5KE+sDXA0eWHYNk6RZ/J+6Is+DNv6hv0h9TBObJaOM+IE
uxD1KMzTwaT9MDU3MYFuO73dRV+HKa2tl5fWajjgDJCjmzH7W47AzfVM/Bvi
sFkTbA30OEPbCzd7UjvuzD/XB6RkZxw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 93->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04Kwe1i85elusavpZNJCWppmJpOk
p/treO5EZD6s25CX6zTl921fLo88Xs5jeTxWW1f6mlYrS6svehdy/jCbz2Ab
n7QYNVjkaHJK7MN8VCfWBjyavDFui1PUmXwcxmIM47axYX9YbqKJzTLERTUS
TqyN5ulw0n6YmhtM4NtW7+9irOOU9q2Xl9ZqNOAMUKObMbtbjaDN9Uz8GfKw
WRNuDfw4Q9sLN3tSO/6Zf64PA4JnnA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 94->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwkAMDS7ErUfwCnqAwSvUE4ygq4JQF+IuR7eD05LPew2kQ5OXl+/p
/hqeOxF5H+bPUD/Xaarf2779POp4OY/Neew6S/mrdm2i3cb8At41ZrGZWGcT
H6MmNnK4nMJtMR+sE/RmebRkRdyWX2OdJeMiNmIQt8XS+aDcoCa0SxrHegSc
sbd0H2QeLnfEmp5dDLEtsnW7EZs4xfu28qK52RrSXRXgj3she0K1pZlJfikP
2jXgVmKPO7SzSDcGek83sub6AT/LZ90=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 95->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS7ErUfwCnqAwSvUE4xgVwWhLsRdjm6LU01eXooD6dDkvZfP
5HC9d/1GRB676dPV53kc6+uynX9udTgdhzm4bzad8jFtNh9tviwu5P5yFp/h
Op94jhouarickvswH62T9GZ1tERj2lZfsc4ScYhFDNO22HQ+LLd4LMb+4dEe
gYMzCjMjs0BNijU9O07iW87a7iI2aIqPreVlc7M1hL2CvOGN2b+tEWoLM5N4
pzrsrYm2Jn58QzuLsGPQO9uZX643W15nnA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 96->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMDS7ErUfwCnqA4hXGE1RwVgPCuBB3ObpT7Gj68lIsZMok7718
msP1PowbEXnsls+Qn+d5zq/Ltvzc8nQ6TiW4r7ac9DGtVo5WXxQXcn85q89w
G5+0HDVc1GhySuzDfLRO0pvV0eSNaVt9xTqTxyEWMUzbYsP5sNzSYjH2D4/2
CByckZsZmQVqUqzpueEEvvX0dhexTlPaWC8vm5utwe1VJy/2Q+sWwrd1ir9D
HfbWRFsDP76hnYXbMeid7cwv1xvmXmgc
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 97->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMDS7ErUfwCnqA4hXGE1TQ1YAwLsRdju4MVk1eXoqFTJnkvZdP
szvfhutKRO6b+TPUx3Ga6vO0Xn4udTzsxyW4bTaf8jZtthxtviwucH9jlme4
zmdiWjwXNVxOyX2Yj9ZJerM6WqIxbauvWGeJOMQihmlbbDoflls8FmP/8GiP
wMEZhZmRWaAmxZqeHSfxfU5vdxEbNMXHennZ3GwNYa86ebEfWrcQvq1T4p3q
sLcm2pr48Q3tLMKOQe9sZ365XgWLaJw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 98->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMDB7Eq0/wC/qA4hfWF1TQ04KwHsRbnu4uVk0mk2IhW5pMJsls
dufbcF2JyH0zf4b6OE5TfZ7Wy+NSx8N+XILbZvMpb9Nmy9Hmy+IC9zdm84S8
xce0+FzkcDUl92E92ieZzfJoica4LX/Al4hTrIU4wm2xqT5Me/FYjP2Tx2bE
HNQoaEa0YLoFrJnZ5SS+z+ntLmIDp/hYry7TzfYQ9qpTF+ehfQvJt31KvFMe
9q8JtyZ+/IdWi7BjMDvbmV+tF3B2aRw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 99->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMDS7ErUfwCnqA4hXGE1RwVgPCuBB3PbpTrJq8vFQDaWlevq/Z
na/DuBKR22Y5hnw/znN+nNb1ccnTYT9VcNt0kfTS0rRKabYIF7g/mI4T8haL
lWRjMYepKbEN69E+yWw6T0lef+V3/qCOU/E+aEOeQ34Y92J9Efsnjs2IMciR
44xwwXhzvmpmExPY3tLbXfR1OcVivbqMN92D26tOXZyH9i0kXvcp/g7zsL8m
uUtgxz/UXLgdg9nZznxrPQGdgGjd
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 100->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFyIW4/gFfQAwSvUE0Swq4JQF+IuR7fBoMnMpBZe07x53+kc
rvdh3AB47JbXEJ/neY6vyzZfbnE6HacM7ostT/hYKpafVHw9HHR+sToP5o4W
S6HN5RpNT/R93M/OaXar66Sg9q++xJMJp9AY9jHPXX4c92hjGVvLc7M7vhxH
wpnhwvEmsdXONpe/ofV4J46tffKPTY+uJo0uRVcrfXkfOzfNJZxBz24doxGZ
DdqX82u8qzHa3Wnm1+sNpcVoHA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 101->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADJr4wXlAkdpqENA6IW5/OKirU2g5Uyro2TuK4
OVzv47QB8NitnzE9z8uSXpdtOdzSfDrOxbmvtq7hY7laWbneRX7Q/vW1cTBn
9L489LGco6uJ+I7rWZ5Rb5S34/Qnv+DJRFMohu9Y51Afpz16bMTLxTnurFek
kWjmahq8YJuebSz/Q/NxT4xt7+SNTY1wJs1cdm8A/KzL/VjexEs0g+5hHjMj
wg1al+Nbv8yY4cM4jgfehl1n2w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 102->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADJr4wXlAkdpqENA6IW5/OKirU2g5Uyro2TuK4
OVzv47QB8NitnzE9z8uSXpdtOdzSfDrOxbmvtq7hY7laWbneRX7Q/vW1cTBn
9L489LGco6uJ+I7rOZ5hb5S34/Qnv+DJRFMohu9Y51Afpz16bMTLxTnurFek
kWjmahq8YJuebSz/Q/NxT4xt7+SNTY1wJs1cdm8A/KzL/VjexEs0g+5hHjMj
wg1al+Nbv8yY4cM4jgfeU3toWw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 103->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+ItT7fBUJKZWQxs0+zOzu5O
cro/x2kH4HVYP2N6X5clfW77cnik+XKeS/BYbV3Dz3K1snL1RXHQvsXaPJgz
+lge+lzm6Goi9nE912c4G/F2Pf3hFzyZaArFsI91DvVx2qPHRn25PNc76xVp
JJq5mgYv2GZmm8v/UD6eibGtT+7Y1HD6CqfRaeML6vI8tm/qSzSD7iGPeSNy
99C6nN/G5Y2ZfhjH+cAX5jZomg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 104->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+ItT7fFUjYzsxjYhGRndyaT
nO7PftgBeB3mqS/v6zSVz22/bB5lvJzHJXlcYx7dL+oaCKvNg3Joa7cczB5t
rma8XYuJo5oz5nM6a9DK+mPfRtOf/oKnqMwLxfAZ+5z647xHi810uTqnnf3K
PBLPHKfBCzbc2da6/wnjs+sFPZM3NhzOX+lpfNr6Jbx8H6ubdIln0DXtY/6I
vD2Ul+tjXv6Y0cM4rge+CwVoWQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 105->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFyIW4/gFfQAxSvUE1TQVUGoC3GXo9ti1ZeZeTXwEvJ+M2+S
3fnWXlcA7ptxa7vHcRi652k9XS5df9j3U3A727iat5XZEE4bx0Is1sHcUcdK
htvUOXEV42M8x/Pjk9mob8XpT3/JJyuMC81hH+uc6kMc4h1LNUmd4856ZRqJ
Zg7T5EtumNnWuv8Jo7PrBfXJGxsMp6/0NDp9+yW4PI/lTbxEM+iZ9jF/RN4e
isv1MV4S7jy7+zM/rBfD9WgY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 106->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAQs3igfhmBFWCAihXKBEGCVyWk9oH4ZXRaUSCxfaXSNU3uzva5
2V/u3W0DYGymV5cep2FIz/N23lxTfzz0c3K3xPS078hLoFhtHiu5sg9mjzqX
I962rimfbM6Yz+n8nMlshFtp+oMv9RSZeQmHfXQ+h/6QhnKPtZ6gz2lnvyKP
xDPHaeojLyIv5RuKxzNxrXiDOscczl/BND598QJensfqJl3iGXQNccwdkX8P
5eX+Mp8D7Ty7uzM/rhcCxmfZ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 107->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRb84IK6MwAowQMQKZYIg0VMlpHJA3DI6rSjC/v4ukdw0ceJv
v/hwvXf9BsBjN326+jyPY31dtvPiVofTcZid+8WmUT7WFoOZpR8rPnsPYg3v
a5lu8WfsaGKP9VSe371QG/y+y+lP/CZqsNZYl+IwR8U55UM52DXW7iT3VO6O
V4n1Kg4qVsYtY5GxDP+I8bim8JbMBt7HGoov67Nu6D+hq7gGBpRXYIY4p3FE
j4S3R8JK5WBYhD6i2lXP/LTeqp5oGA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 108->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS7ErUfwCnqAwSvUE4xgVwWhLsTdHN0WK768vNRAOp3J7+Ul
h+u96zdm9thNn64+z+NYX5ftfLnV4XQcZuN+0UnKR9uiBqe024oNfcAuBeJC
3eJ9UJp443oK5/ct9Gb+3WH6k7+JHlAb16U8zKPiOeWHMODd1mKSOIXd8VVi
v4oHlSvjLeMi4zL8W8zHPYVZZrsq5sD8S94Ag5uBkU+WU9QI2Bgvzw3ONI/Y
kTB7S7hSGICLsEfUu9qZX603w7xomA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 109->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHigfhmBFWCAiBXKBEGir0pI5YH4ZXRa0YJzd24juWni+Hw+
+3h7tN3OzJ7N+Gnz6zIM+X3dT4d77s+nfnIeZhtX+lqZzdzu7edfYtZirfbL
5eJkXvfGryLuMJ/iudwVwPe4xGkDv4gaIs2kLonPqPNqXwxyG79VvFSc4l7p
lbhepYPCinSLtIi0pH9jPKyJehnNqugD6i91cxyqHhi8iTBFDuKGfLFvbg9x
xIxQ7y3Wijg4LWiOoHY1M/9cH++JaRY=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 110->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQXPyQ/noEr6AHCF6hniCC/SoI9UP8y9FtsdXNzGwb2IQk+5id
2ePt0XY7M3s249bm12UY8vu6ny733J9P/fR5mG1c6WtlNnOnt9//ErMWa/W/
XC5O1nU+fhXxhvUUzuWtQH6flzBt5C+ih4gzyUviO/K8qotBbWNfhUvFKewV
X4n7VTyoXBFvEReKT8SB2kX6kpbRrAodCIvizWGoNDDwiXKKGoQN8aJu7gzz
iBkh7S3mijA4LmiOoHc1M/9aH+SYaZY=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 111->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzydVrRgjyfBkpsm3sZj
H673rt8AeOymT5ef53HMr8t2vtzycDoOs3G/6CTpo2VRmNPq177GtGLh7VJM
nKxrfKwU8cb1FM71rVB+mzdg+pO/iB5qnEleUrwzz825gGoj+ipcKk5hd3yl
2K/iQeWq8aY45Z6dnf8R83FPYZa1XRVzCFgUbwaDmwHIp5ZT1AjYBEfgGo3+
OcZxq2wCc8BguAh7RL2rnfnVegPhp2oW
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 112->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6rWjBHk9iyU0Tb+Ox
T/dX99wBGA/zp8vTdRjy+7ZfLo/cX879YjyuOkv6alkV5rT6s28xrVh4uxQT
J+saHytFvHE9hXN7K5Tf5g2YGpgtlsLYBWeSlxTvzHNzLqDaiL4Kl4pT2B1f
KfareFC5VE72rfXs7PyPmI97CrOs7aqYQ8CieDMY3AxAPoq7So2ATXAErtHo
n2Mct8pGmNUMLRdhj6h3tTP/Wh8T1GsW
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 113->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6rWjBHk8SyU0TLzMe
53R/dc8dgPEwf7o8XYchv2/75fDI/eXcL87javNKXyurwezWfv4tp5UL75fL
5ElcE2NXEXeMp3hud4Xq27qBU4Oz5VKYu9BM6pLimXVuzgWEjRireKk8xd3p
lWK/SgdVS9Xk2FrPzs//iPW4pzDL2lsVcwhclG6Gg5sBKEZpV8EI3IRGYIxG
/5zjtFU+4qxmaLUI74iw1Zv5Y30AL+9r1Q==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 114->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9ksENwjAMRS0OiCsjsAIMELFCmaBIcKqEVA6IW0anFS043y+J5KaJY/v7
fx+uj+6+MbPnbvp0/es8jv37sp0Pt344HYfZuV9sWulreTFzu7eff41pxVrp
x+XisK5741eGO61HONe7LPl93oCpgdljyYodOENeUjwrz01dTGpbfEu4KI6w
F3yl2C/xQLkop76t9Vz49d9iPu0paFnTBHQIWIg3h8E0L9SleSEtaF4Cvxb3
ah6YkaC9clLTwfWMcyS1aWb+tT7PKWuW
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 115->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgkAMnHAgXnmCX8AHEL+AL1gTOZGY4MF426cLEbQ7neImZZfttp1O
53i990MF4HGYP316nqcpvS718nNL46kdF2ez2ry6j+XVYHZrX/8WsxeL0i+X
iZN1zRu7srjjegrndpcpv83rMO1gtlgyYxecSV6IR9ffv7mAasO/VbhUnMJe
8NX5fhUPKpfKyW+jngs/n+HzcU9ultFMCDfrIeTNYADnFXWVXtQslF4cv/B7
mEdoJNIfY1YztFw4HVFtpZlfrTcU3mtX
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 116->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksOgkAMfWFh2HIEr6AHIF4BTjAmsiIhwYVxN0cHImj7+pxJygCd9n2m
5/vUDRWAZ70+uvS6zXN696ft45HG62Xcks0e62o/kfeA2W1880dNqRY+L5ep
k7jmjF1ZYRCe4nn8y9Tf9g2cCpwtl8zchWeOk9AJ6hnwFAYIG/Gs4qXqFHfn
Vxv1Kh+kRtGTz/7T7PL8jtiPNal5CXdicoyh/GV8xg3zR1xYn7oL5swegTEK
+rnGeatyxFndofUizBFhq5n5YS3Cm2vV
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 117->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEOwjAMBC0OiCtP4AvwAMQXyguCRE+VkMoBccvTaUUL9maSSG7aOt5d
b3y4Pbp+Y2bP3fTo0usyjul93c4f9zScjsOc3C8xrfM38hLmdh+//FrTqrWY
x+XqkNed8SsTh/CRzvVfFnzFDZoamqmm5VnQBH2aYBZ8xGHCbeVZ0kV1pD34
Bf6QD9gjYOrZWs8hr+9W4mlPNC/FnbiccpC/yq+8iE/eVTgMNKtH4d7cXsWB
GanNn2qmO/ReFHMk3DQzf64PEMhs1Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 118->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwjAQHPwQfz2CV9ADBK9QTxBBvwpC/RD/cnQbLHQyO2lgm7b7mNnZ
Pd1fw3MH4H2YH0P+XKcpf2/7+vHI4+U8Vudxsfmkv5XF6ilp/e/84Jt9HEN+
eyivyeUcrQfhwVyEj/IMvUluSdG2OLucLc0aTqZPSM2A5zAg2IixjpfLc9wb
vYw+Tgfbo6mpsb2eG7++I9bTnty+hJmQTzGcvoqvuLa+066DAcNZNWrmRne3
jtmR3v4pZzdD1iLskWC7nVmxfvjbbJY=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 119->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwjAQHDyIV5/gF/QBwS/UF0TQU0GoB/GWp9tgoZPZSQPbtJ3szuxk
T/fX8NwBeB/mx5A/12nK39u+fjzyeDmPFTwuMa/0j7JEXSWt/x0O3hnjM4Tb
RXlNLudoPYgO1iJ6VGfoTXJLirGl2eVsedZoMn1CagY+xwHhRjzrdLk8p73x
y/jjfLA9mpp6ttdzg+s7Yj3tyc1LuBPClMP5q/zKa+s77zocMJrVowajvVvH
zEhv/lSzu0P2IsyRcLuZWbl+x2RsVw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 120->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwjAQHDyIV5/gF/QBwS/UF1TQU0GoB/GWp9tgoZPZSQLbtJ3dncls
TvfX8NwBeB+WxzB+rvM8fm/78vEYp8t5KuBxjWWlf+Q1yspp++9w8M4Y5xBu
F9VVtVyj/SA6WIvoUZ3hbFKbU4yeZlfT86zSZM4J6Rn4HAeEGzHX6erVqYdZ
/jmPgmeO0+RzbuvMFa7viP10vu6+hJkQphzOJ+VXXtvfedfggNGsHlUY7c0+
rVk7TDS7GbIXyqnc7s5sXD8EgmzX
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 121->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwzAMMz2UXfuEfaF7QNkXuhdksJ4Kg+4wdsvT17BCZUUuC6Shlh3J
cs735zg1ZvY6rZ8xva/Lkj63tvw80nzp5wJ2217X8Nt522XlYY8r3PBEDHMA
lwvqXC3W8H1GOoQWC3RWvSFuXkvFITSrmiPPstBZaef+jvzh/GB2StffdRSP
PKo8U5wiH3OjnsM3Jmbn9Ip5YczNBDD2TfnE/Mwr71feBRwmNLNHDoMzvCea
tcJIs5ohesGczK3ezM71BYUJbRY=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 122->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwzAMMz2UXfuEfaF7QNkXuhdksJ4Kg+4wdsvT17BCZUXuAmloZFuy
nPP9OU6Nmb1O62dM7+uypM+tLT+PNF/6uYDdttc1/Hbedll52O8VbngihjGA
ywV5LhdzuJ6RDqHFAp1Vb4ib11JxCM0q58izLHRW2rm/I384nvoLc/7ksYeZ
7pRHlWeKU8RjbNRz+MbE7JxeMS+8czMBzIhD+cT8zCvrK+8CDhOa2SOHwRnW
iWatMNKsZoheMCdzqzezc30B2hhtlg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 123->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDB6kV5/QL9gHSL9gX7CFehIK9lB626fXpYKT2YldWMUkk5lM
PN+f49SY2eu0Psb0vi5L+tza8vFI86WfS7Lb7nqG383bLScPe1zlDd+YwxrI
ywM4h0UM9zPSIbRYoLOaDfPmtVQcQrPCHHmWhc5KO8935A/X03wh5g+OPcwU
Ux5VnilOUY+10czhPyZ25/SKfWHM7QRyRhzKJ+ZnXtlfeRdwmNDMHjm9EAv7
RLsO+ji82CF6wZzMrf6Z3Z8v0ZNtVQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 124->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDH6Ivx7BK+gBileoJ1jBfhWE+iH+7dHtYqGTyaQupEvzmslk
T/dnP+zM7HWYP315X6epfG779vMo4+U8tuBxsfl0P6uLtVO71a/ihjfGMAfi
8kCdq8Ua7mfEQ3CxhGeYDePmuQSMBD/kb2hWBc/Anefb0ofzab605k8da1jJ
pzQKmilMkY+52czpGxO7c3y5l3mf2wnEjDCUTozPuLK/0i7BMMGZNXJ8wZf2
yXad9HH1YoeoBWMytnozqz5f/5ltFg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 125->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwkAMRT8uxK1H8Ap6gOIV6glG0FVBqAtxN0e3g4UmPz8zMC2dzE9+
Xnq6v8bnDsD7sDzG8rnOc/ne9u3jUabLeWrB47qXNfx3XXdbddjOVRz2bWP2
jonLZXROazWcD+RDeEHiM/Rm4/BeQg3hW2l6zKrwGbxzfz0+fJ/6SzViZo4L
MaxCw4wCs05N1SPPTPGUHBDz8Xz5bugNPgaqoTiFnBAsOb9il9RwPBJGzq85
S/Nks07yOL2YoWXBNbm2+mc2Pj8oPWxV
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 126->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwkAMRT8uxK1H8Ap6gMEr1BNUsKuCUBfibo5uBwsmPz8zkJZO5md+
Xnq6P4dpB+B1WB/D+L4uy/i57dvHY5wv57klj1usq/yibtFWLf99lYd925w9
Y/JyGZ3TWg3XA/mwXsgP+wy9kbaWGD3fStNj5jyJPkE1mVHgw+epv1QjZua4
EMMqNMwoMOvcqXrkmSmekgNiPZ4vnw29wedAdyhOoSYES66v2CV3OB4JI+fX
7KX9Z7NO6mR66yv0Qt7k/0F64AtbSmvV
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 127->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwjAQRT8uxK1H8Ap6gOAV6gkq2FVBqAtxl6PbYMGZP38SmJZk8idv
fnK6P4dpB+B1WD/D+L4uy/i57dvkMc6X89ySxy3WUX5Rt2ijlv+6ysP+bc7u
MXk5jM5prYbrgTgsC/EwZ+iNtLXE6HErTc8zxyT6DH6QR8EfYrBz9DTizpwv
5GEVGuZU3NmZjhkxF9iyNybuzvFC7w29wedAZyifQk0IL7m+8i45w/mReOR4
zVraf3bXSZ1Mb7lCL8Qm3wfpgS+Qs2yU
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 128->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwjAQRQcX4tYjeAU9QPAK9QQV7Kog1IW4y9FtsOCfP38SSEMy/cmb
P3O6P4dpZ2avw/oZxvd1WcbPbd82j3G+nOcWPG5zHeU36zbbqOV/ruKGK8bw
H4jLATqnRQ3fZ8SBLMTDnCE30tYSZ49baXqeOSaRZ/CDPAr+EAPuracRNXO+
kIdVaJhTcWdvOmaLMbdPeF0NLbKEulOPhP6AGL+vfAp3mvASVnxX9Uu4k/tP
eYS8cJbmn9U6uSfTI1fIhdhkf5De7AvWlWuU
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 129->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKAjEMDB7Eq0/wC/qA4hfWF6zgnhaE9SDe+nS3uOBkMmkhLWk6yWSa
0/05TDszex3WbRjf12UZP7d9cx7jfDnPLXjcbF3lZ3Wztmr536u44YkxfANx
uQDnsIjhfEY8kAvxYZ6hN8LWEq3HW2F6mjlOos+gB2kU9CEO6FsPI/7M6UIa
VoFhnsrPajrOFmPOT/i6P7Sktum3cj4gxvWVTiGnCS3hxLpqXkJOnj+lEfKF
u7T/7K+TPBkeeYVeiJucD8KbfQHtpGwU
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 130->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKAjEMHDyIV5/gF/QBi19YX1DBPS0I60G89eluccHpdNJAW9o0k8kk
p/tznHYAXod1G9P7uizpc9uXyyPNl/NcnMdtrTb8Vt5WsTz8350ffLKP/5Df
GsVVsRyjeBAemkM5GJys/wW34tTh7WJ6mmXhGPFWnbt9geRGq6XjpT1z2I5v
pJG7RzkrzojzOT5NTWjxtL/6184H+TS/06nBhNGSTs7r5qXB1PlzGjFfegvr
j3od4ETxzKupRbjZ+ZB44Av0sWuU
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 131->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwjAQHDwUrz7BL9QHFL9QXxBBT4VCPYi3PN0GC04msw1sQrK7s5PZ
Pd/n8XkA8Dqu25je12VJn1tXLo80XfqpOE+brWv4Wd6srDz8350ffLKPY8hv
F+VVuZyjeBAeWkM5GJys8YJbcTKcFUv/EGmWhWPEW3Xe7QukNlotHS/tmcN2
fCON3D2qWXFWTTU24Fv1EEFt+Fg7H+TT+k6nBhNGSzq5rpuXBlPnz/WE+dJb
+P+o1wFOlM+8mr8INzsfkg98AUIFbBI=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 132->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwlAMRAcX4tYjeAU9QPEK9QQV7Kog1IW4+0e3xYLp+5MG0tImmUwm
Od2fbb+T9DpMj7Z7X8ex+9z288ejGy7nYQ4eF5+s+XlZfLbS/P+7uOI7xmJO
iFsLdavaWEM8gQd7kIPBKcwHrp0DvSIW6zLNCjhmvKnz5l6E3qq1dLy4M4ft
+HJep4PlmehWacrchO9qh0p6y+Rm96F1nPpRJ/Zn32rngYu7lwqT95fx5mxb
82e7TnCy+sirmgXc7H2gXvoC7pJr0Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 133->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwjAQHPyQ/noEr6AHKF6hniCC/SoU6of4l6PbYNHNZMbANqT7mNnZ
Pd7mYdwBeHTrZ0jPy7Kk13VfHvc0nU9TcR42W0//sbxZObn//Vd+xDv6Ykzw
yxPyqtyYw/VAPBiDOYg6meOpruyDsGItznOaZeLoeLPOf+cCwkarpeLFM1O1
FV/uV+kgeRrdGk051vCtZgiDDfF2+4Haz/qxTozBOM3MofVzs2j2z/Hm3kS/
bmfU/jWauLmEnhV37kHGffV5A4b3a5I=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 134->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwjAQHPyQ/noEr6AHKF6hniCC/SoU6of4l6PbYNHNZMbANqT7mNnZ
Pd7mYdwBeHTrZ0jPy7Kk13VfHvc0nU9TcR42W0//sbxZObn//Vd+xDv6Ykzw
yxPyqtyYw/VAPBiDOYg6meOpruyDsGItznOaZeLoeLPOf+cCwkarpeLFM1O1
FSb3q3SQPI1ujaYca/hWM4TBhni7/UDtZ/1YJ8ZgnGbm0Pq5WTT753hzb6Jf
tzNq/xpN3FxCz4o79yDjvvq8AbgGbBI=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 135->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1UkEKwjAQHDyIV5/gF/QBxS/UF0Swp4JQD+ItT7fBgpvZmUAa0s3Ozs7s
6f4cpx2A12H9jOV9XZbyue3b5VHmy3luweO21zX8dt12W3X4/1dxxDPG4psQ
lyvkdbkxh/FAPKhG4iBwKuEzruyDakUsznOadZxEn0kPGAzK7WqzBoYXe6aw
VU3uV+kgeRrdkqb81vDtPISpDXF384E+zvqxTlyD6yTPofVzXqT5c7y5N9Gv
mxk1f0kT50vo2emh/Jbe4AuHFWxT
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 136->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1kkEKAjEMRYMLcesRvIIeYPAK4wkq6GpAGBfirkd3ioOmPy+BTumk+fn/
p4frY7xvzOy5Wz5jeZ3nubwv23a4lel0nFpyv64lhu+q62pRh/9/ypvffc7f
cXkMV9fV+hrFM+EhPQIHwKmCr7ioQ3p5LK3LPOs4gc7ghyUYUtv1Vg8SXmGe
gE09VS/5gDwT34Knepf4il7Foxz5/Dv7gP7kr/bQPmHmxv6RNn9XeQXeqg30
Zm+G3l/wJJuL05z5QfPG2dgH6UdsFA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 137->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1kkEKAjEMRYMLcesRvIIeYPAK4wkq6GpAGBfirkd3ioOmPy+BTumk+T//
p4frY7xvzOy5Wz5jeZ3nubwv23a4lel0nFpyv64lhu+q62pRh/9/ypvffc7f
cXkMV9fV+hrFM+lDOEIPgFMFX3FRh3B5LK3LPOt6Ap3BD0swpLbjVg+SvsI8
AZs4VS/5gB4nvgVP9S71K3oVj3Lk8+/sA/jJX+VQnjBzY/9Im7+rfYW+VRvo
zd4Mvb/gSTYXpznzg+aNs7EPYixr1Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 138->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1kkEKAjEMRYMLcesRvIIeYPAK4wkq6GpAGBfirkd3ioOmPy+BTumk+T//
p4frY7xvzOy5Wz5jeZ3nubwv23a4lel0nFpyv64lhu+q62pRh/9/ypvffc7f
cXkMV9fV+hrFM+lDOEIPgFMFX3FRh3B5LK3LPOt6Ap3BD0swpLbjVg+SvsI8
AZs4VS/5gB4nvgVP9S71K3oVj3Lk8+/sA/jJX+VQnjBzY/9Im7+rfYW+VRvo
zd4MvT/Czt6F94L8wHnTbOwDcQNrlA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 139->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1UkEKwkAMDB7Eq0/wC/qA4hfqC1bQU0GoB/G2T7eLFWcnM4F02WYzmUxy
uD7G+yYinrvlM5bXeZ7L+7Jtl1uZTsepBferLzZ8va7erA7//yoeeGIM30Bc
GuR1uZjDeEE8qEbiIHAq4TOu7INqIRbnOc06TqLPpEcYDMrtarMGhleap8BW
NblfpYPU2OiWNOW3iq/o19Y2XNJ+RB9n/VQ9zk0zgPOH7fYlYfL+Od7cm+jX
7YzaP4Xt9gK1UHrIeavZxAfAkWxT
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 140->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1kkEKAjEMRYMLcesRvIIeYPAK4wkqOKsBYVyIux7dKQ6Y/rwUOmWa5v+f
n5zuz3HamdnrsH7G8r4uS/nc9u3nUebLeW7B47bXNfx23XZbdfjfU9z86WP+
jYvjcnldrs9RPBMdwhE0AE4VfMXFOoTLY2le5lmnCeoMfliCIbkdt3qQ6Ar9
BGzi1HrJB9SZ+BY81bekF+rNYp0W6F+YA+Anf5VDeULPjf3Det1bn5vqljvE
gZmh+SPsbC68F+QH9pt6Y1+SCWyQ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 141->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1kk0KwkAMhR8uxK1H8Ap6gOIV6glG0FVBqAtxN0e3gxUzyZeBtMy8/Ly8
5HB9jPeNpOdu+YzldZ7n8r5s2+VWptNxauB+teUMX6urtVOH/zvhsn+LWR/B
XRELsT9L4ivUkONNPENvFlfCBTj7XD4u06zjBH0GPZTkcLFdba9BwivME3JT
Td8v6YA8E92Cpt6X+EK/GdZxgfmFPYD6pK+v4euEmYv1w36Nr41Nebs3zAM7
Q/tHubO9sFqQHjhvmo0+oydtEA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 142->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx1kk0KwkAMhR8uxK1H8Ap6gOIV6glG0FVBqAtxN0e3gxUzyZeBtMy8/Ly8
5HB9jPeNpOdu+YzldZ7n8r5s2+VWptNxauB+teUMX6urtVOH/zvhsn+LWR/B
XRELsT9L4ivUkONNPENvFlfCBTj7XD4u06zjBH0GPZTkcLFdba9Bwovyej+q
6fslHZBnolvQ1PsSX+g3wzouML+wB1Cf9PU1fJ0wc7F+2K/xtbEpb/eGeWBn
aP8od7YXVgvSA+dNs9EHfwhtzw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 143->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsKwkAQC36Ivx7BK+gBileoJ1jBfhWE+iH+7dFtseJsJnFgukznkUx2
D9d7P2wAPHbzpy/P8zSV12W7BLcyno7jktyvPlv38br6YrX7/Vd5xDPmYg1E
jJxLvV83/VVggHgrnmm3mIfhIjjzLO5zmjWcxJ5JD5gZ1NtgswaGl5rLdQqT
95X9iqfRLWnKtYqvwHK5hou4v/QOBL7ajTEYJ905tH5y31Abey1vpyModvej
5qh5zAFil2j/3lfUDG+QhG2O
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 144->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBi19YX1DBPS0I60G89elusWIymWCgW7rTZCaT
Hq73cdoAeOzWz1ie52Upr8u2HW5lPh3nBu77WmP4rNpXizr8/lscHXe7zTU1
vjifGQu5xOPy4XVaDVZ3FTpDb6RHauEgrIoe2DPHi3iH67r+/s0FxM0eJLpU
Xb6nOLlfma90Jr4FT9V7y96YmAFjTouYX3gHgl/1xhzME2YO7Z+ck7lrc1Pd
mY+gczYfVUfVYw2IvbjIPOPZ4A3UoG1N
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 145->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKAjEMHPwQfz2CV9ADLF5hPUEF/VoQ1g/xr0d3ixWTyUQD3dKdJDN5
7M638boCcN8sn7E8jvNcnqd1e1zKdNhPDdz2s9jwPrWfZnX4/rc4Ou5uG2ty
fHB+MxZiicfFw+u0GqzuKnSG2kiP1MJGWBU1cM8cL6IP53X1/ZsLiJt7kOhS
edlPcXK9Mv5HrcGfe6r2LdsxMQPGnH4xv7AHgl/VxhzME2YO3T85J+NrY1Pd
WR9Bb7EjaR6VjzUg1uIs6xnPBi9MiW0O
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 146->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRT8uxK1H8Ap6gMErjCeooKsBYVyIux7dKXYw+f0pBjql/U3y
ksnh+hjvGwDP3fIZ0+s8z+l92ZbDLU2n41TEfV2LDd+V6yqWh9+91VF1t1tf
E2PV+cxa40t5nD88p2Ww3FlwNrURj2RhIy2LGrhnvZ5GfbT83Rig3NyDgEvF
5XcqJ9cr/eH5o5j8RuZXvCJXpDl+8f+aORD5VW2OTeTJtK+x1bxIbp6/HnfU
R9BZzEgYR8VjBrS1OPu3Z/gAXr5tjA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 147->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8uxK1H8Ap6gOIV6glG0FVBqAtxN0e3g1NM/vwMBtJhmiZ5
+c3h+hjvGwDP3fIY0+s8z+l92ZbLLU2n41SC++qLDV/P1Yvl4ffexlHj7rS5
psYa5zvHmlzq4/LhOS2D5c6Cs5mNeCQLG8WymIE162ka6Wj5uzVAvVmDgIt1
VPyqJ88r8+H5o5r8jeyvtBS9opjjF/+v2QPRX83m2ESfTOdaW+2L5Ob963FH
OoLuYkfCOqoeM6Cdxdm/muEDvfxtTQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 148->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRb84IK6M0BVggIoVygSpBKdKSOWAuGV0Wtoi++c7IlKSJq7t
5x83/aO77wA8D9PSpddlHNP7up8PtzScT8NsPK4TyO20tMv+/TZ3dv7uQLv1
NTE2O5/ZVvhSHucPz2kZuBbmLGojHsnCg2xZ1MCa1TSNdLT81Rig3KxBwMU6
Kn6Vk+uV/vD8UUz+R+ZXWopckc3xi/cr+kDkV7U5NpEn077FVv0iubn/atyR
jqCz6JEwjorHDChrceNfzfAB/xptzQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 149->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfErU9nA7alnhOY1HZpGjt2
uzvfmusKwH3TT01+HLsuP0/rIbjk9rBvh+T2O4CS+il91ve/2bNj2sN8Dlxr
MMY8x6quMEdy6lH3abFYC/MttNk8nF74o1wRGtizyNPQD/yBAeJmDwJOxuXz
ipP1ynrU/XuYku9HvNDm3Rvdq/J5inklHKWt6k3wFFpHbPVeZN/8/qK+lTbG
EXevahW29y6sF+w5Y4ae4QVTtW5L
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 150->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8Mjot0Na5ng2VktRxfGef
vTvfmusKwH3Tb01+HLsuP0/rwbjk9rBvB+f2u4CS+i19zve/ubNrusP8Dhxr
MEY/2yquMEdy4lHnabG4FuZb1Gb9cHLhj3xF1MCaRZqGeuAPDBA3aRBxMi6/
VZxcr4xHnb+HKfl+2Is58fpGfVU6TzafhKNqq3ITPIXOEVvNi8yb5y/KW9XG
OKL3KlZhe3NhtWDNGTPUDC+mxG7L
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 151->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVoABIlZoJwgSvCohlQfil9HbAm2d6zlQKUkdx+fz
2YfLvblVAB77cWvi89z38dXuJuMau9Oxm5z1dwEpjFv4nO9/c2fXcof1HTjW
YMx+tlVc4hzBiUfO02JxLZxvU5v1w+HCH/mSqIE1K2la1AN/YIBykwYeL9ZR
vVM5uV4Zj5y/hynz/bA3c+L1jfqqdF5sPglH1ZZxE3kSnTO2mhfJm+evxFvV
xjii9ypWYXtzYbVgzRmzqBkG99NvSw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 152->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAQszggrjyBL8ADKr5QXpBKcIqEVA6IW55OC7SdcZ2EQ5ZJZmyP
k0N3b28bAI/dMLXhee778Lpsx+Aa4ukYx8v9bwCpGabmu3725syO+QxLHrjW
YNh7F4u6xBwmz+HB62SOlQaBkwifcWUfxGWxuI49K3la9AN/YIC4yYOcLvZR
5SlO7lfWw+vPYUq+Srz6J7l3o3dVPs8xr4SjenPaBE+idcJW/0Xq5v9X0q16
K/jotOZwanimZ/aHNVc9wxsQW28K
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 153->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHVHyhvCBI9FQJqRwQNz+dltWeTJJDkjqxZ8ZT
787XflgBuG3mrU/34zSlx2m9BJc0Hvbj8rj9LMC6eeve5+vb3fn1u8M/D1zr
MPx7iEWdMYfLC3iIOpkj0yBwjPAZV/ZBXB6L69izmqesw6imiQHiJg9KuthH
lac4uV9Zj6i/hCn5RJzNp+AqvQX94v9lc1DgV3yo8BidX2w1L1I3z19Nt+qt
4mvQWsJp4bme2R/W3PQMT0YUb0s=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 154->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAvfIEvgAPqPhCeUGQ6KkSUntA3Px0WlZ7OkkOSerEnhlP
vb/cun4DYGrmrUv30zimx3m7BNc0HA/D8rj7LMDaeWvf5+vb3fn1u8M/D1zr
MPx7iEWdMYfLC3iIOpljpUHgGOEzruyDuDwW17FnJU9Zh1FNFQPETTk5Xeyj
ylOc3K+sL/Ra5ROxEbeaxdxb0CL+32oOMvyKDwUeo/OLreZF6ub5K+lWvRV8
DVpzODU81zP7w5qrnuEJeRxvCg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 155->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAvfIEvgAPqPhCeUGQ6KkSUntA3Px0WlZ7OkkqJalje2bs
eH+5df0GwNTMW5fup3FMj/N2Ma5pOB6Gxbn7LMDaeWvf5+vf3fn1u8M/Dpzr
MLw/2CLPmMPFBTxEnYGDtRLfqjbvR0YLf+QzUQPrKPWUdRjlVDFA3BST08V9
VHGKk+uV+YVaq3zCNuJWs5jzBS3i/VZzkOFXfCjwGJ1fbDUvUjfPX0m3qq3Q
16A1h1PDczVzf1hztWd4AoiUbsk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 156->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksOwiAQfXFh3HoEr6AHIF6hngATu2piUhfGHUe39UNmHg9oAhRmeJ9h
Dtf7MG4APHbLNMTneZ7j67JdN7c4nY7TGtz/BpDCMoXv+vk3Z3bkMxFPwePk
z9zJe5T3EnOYPIcHr9NxsFbiK7zZuMmRPojLYrEHWRdRM/bJeIUmhQHippya
Lq6jylOc7Ffeb3jt8ol9Im7Vi7WY0yLer+iDCr/iQ4Mn0frHVv0idXP/tXQr
b426Oq01nB6e8cz1Yc3dmuEN2XxuiA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 157->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksOwiAUnLgwbj2CV9ADEK9QT4CJXTUxqQvjjqPb+iHvDQM0oRR4zK/v
cL0P4wbAY7e8hvg8z3N8Xbbr4han03FaD/e/AaSwvMJ3/nybPTvynjhPwePk
x9zJa5T3EnOYOocHr9NxsFbiK7zZc1MjfRCXxWIPMheRGftkvEKTwgBxU01N
F+eo6hQn+5X3G167fGKdiFtlInsIpEX8v6IPKvzszWkVPInmP7bqF6mb+6+l
W3lr5Oq01nB6eMYz58Oau5nhDb6Lbwg=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 158->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKQjEMHFyIW4/gFfQAxSs8T1BBVw+E50Lc9ei+56ck00mx0E+adGaS
Zne+DdcVgPtmXob8OE5Tfp7Wi3HJ42E/Ls7tdwIlzUv67O+zubOz3gl/SR6n
DvOm2mjfFeYwcQ4PXqfjYK3E1+Rm/SZG5kFcFotzkHURNeM8Ga/RpDBA3BQT
6VK46k8jPNbZ0xBhSj5hF+KOtDc9BNIi/q/pg16dIu2Cp9D+w1b9InVz//V0
q9w6dXVaIxwEsaSLc3Hj35rhBZFjbog=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 159->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKAjEQLDyIV5/gF/QBwS+ML4igpwFhPIi3PN0Zl9BdqQ4Gsndq6fTu
fBuuKwD3zTwM+XGcpvw8rZfNJY+H/bhcbr8dKGke0md+r82Z7fVM3JfkcWoz
b+oe7bvCHCbO4cHrdByslfgab/bexEgfxGWx2IPMi8gZ+2S8RpPCAHFTTKRL
4ao/jfBYZ09DhCn5xL4Qd6S9qSEQl/i/pg56eYq0Gx7n38w/bFUvUjfXX0+3
8tbJq9Ma4SCIJV3sxbV/c4YXYHJvCA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 160->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKAjEQLDyIV5/gF/QBwS+ML4igpwFhPIi3PN0Zl9BdqQ4Gsndq6fTu
fBuuKwD3zTwM+XGcpvw8rZfNJY+H/bhcbr8dKGke0md+r82Z7fVM3JfkcWoz
b+oe7bvCHCbO4cHrdByslfgab/bexEgfxGWx2IPMi8gZ+2S8RpPCAHFTTKRL
4ao/jfBYZ09DhCn5xL4Qd6S9qSEQl/i/qA5kniLthsf5N/MPV9WL1M3119Ot
vHXy6rRGOAhiSRd7ce3fnOEFBKduyQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 161->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbgQtx7BK+gBgleoJ4hgVwWhLsRdjm6rEmZe3gQDSTvJ5H0m
c7jeh3ED4LFbliE/z/OcX5ftGtzydDpO6+H+N4GSliV9v59/s2dn3RPnJXmc
OsydGqO9V5jD5Dk8eJ2Og7USX+PNnpsc6YO4LBZ7kHURNWOfjNdoUhggbsqJ
dClc9aYRHuvsaWCtXT4RF+KOtDc9BOIS7xf1gaxTpN3wKJ8WV/WL1M3919Ot
vHXq6rRGOAhySRd7cePfmuENgHFuig==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 162->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUskNwjAQXPFAfCmBFqCAiBZCBUYir0hI4YH4uXQSDmt2PGuw5Hs9x3p3
52s/rMzstpmHPt2P05Qep/WyuaTxsB+Xy+2nm+VuHrr3/FrDGfZyJu5z53FK
gzdlb/W7zBwQ5/DM63QcrJX4Km94DzHSB3EhFnuQeRE5Y5+MV2lSGEbcFBPp
UrjqTyM81tnSgDn+ySf2mbgj7VUNGXGJ/4vqQOYp0o7e0D/MX1xVL1I3119L
t/LWyKvTGuFYEEu62Itr/+bMnvs/bks=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 163->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUskNwjAQXPFA+VICLUABFi2ECoxEXpGQwgPxc+kkHNZ4duxgybc9x+7u
L7d+2JjZvZuHPj5O0xSf5+2yucbxeBiXy923m6UwD+Ezv9dwhj2fifsUSpzc
4E/em/+XmAPeFXhW6iw4WCvxOW94D2+kD+JCLPYg4yJixj4Zz2kiDNbAuWnp
Urgqp4rTeW5o4Pyv8ok9+6lpdzVkxCXyV6sDGaeadvSG/mH+4ap6kbq5/lq6
lbdGXAutNRyrvCVdrsaw/RszewG1bG9L
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 164->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDggrjyBL8ADIr5QXhAkOFVCKgfELU+nZYkmk7GplKSJk1ls
78634boys/tmnob8OE5Tfp7Wy+aSx8N+XILb7zAraZ7SZ33/wxmOeibiJbU4
9YM3dW/9u8IccK/Bs1Znw8Faia/zhnG4I30QF2KxB5kXkTP2yXidJsJgDVyb
SJfCVTVVnJ3nQAPX/y+f2LMfT3vXQ0Zcon5eH8g8edrRG/qH9Yer+kXq5v6L
dCtvQV4brUEvendRl5cL1hbmzF62K28K
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 165->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwjAMtTggrozACjBAxAplgiDBqRJSOSBuGZ2WT2Q/P5tKSZo4eR/b
u/NtuK5E5L6Zp6E+jtNUn6f1srnU8bAfl+D2O0RamafyWd//6kyPfkbirVic
/qk3fS/+XUMOdc/gidVpOFAr8DlvOq7uUB/ApbHQA80LyRn6RDynCTBQA9Ym
08VwWU0Zp/OcaMD6/+Uje/QTaXc9JMBF6hf1Ac1TpF170/7V+sNl/UJ1Y/9l
upm3JK9Ga4QjwV3QFeUCMdOcyQuWbG7L
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 166->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbgQtx7BK+gBgleoJ4igq4JQF+IuR7f1E2Ze3gQLSZpM8j4z
szvfhusKwH0zT0N+HKcpP0/rZXPJ42E/LsHtdwAlzVP6rO9/c2ZHPRPxkjxO
/cybukf7rjCHuefw4HU6DtZKfI03Gzd3pA/isljsQeZF5Ix9Ml6jiTBYA9em
p0vhqpoqzsZzRwPX/x8+7jf2E2lvegjEJeoX9YHMU6TderP+zfrDVf0idXP/
9XQHeYv2TmuEg+Au6YpywZjdnOEFGyFujA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 167->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKQjEMDC7ErUfwCnqA4hWeJ6igqwfCcyHuenTf81Mm00mx0G/SyWSS
3fk2XFdmdt/My5Afx2nKz9N6uVzyeNiPi3H7nWYlzUv67O8zvOGsb8Jeksep
A/7Uu7X/CscAP4dnnqeLwVwpXpMb2sHHceJB+I1/pIvQjPNkPObEGMyBa9Pj
pXBVTVVMpRFzkDnaf/G43zgf1YuRzcUS9Yv6QOoUccfcUDPYf7iqXyRv7r8e
70C36N68KRzYwzp1tGDMrmb2AvnBbks=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 168->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtHpAXHkCX4AHRHyhvCBIcKpUqRwQtzy9LUtkT8ZupMTZPB6P
fbyN/aMTked+Wfr8ukxTfl936+Geh/NpWB8PvylS0rKkr/3s1Z2e9Y68l2Rx
6lA+9SytX8EY6p/BE8vTxECuEK/JTb+rP4YTDsBv/nu6EM0wT8RDToiBHLA2
ES+Gy2rKYjKNkAPNcUOvAr7YE7RPUDPkIZZn1B91eDp5Wqk4pgbK/nFZ/pQ3
9l/E29HNOzd3DEdZt06BFogZaiYzhQ5vCg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 169->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKAjEQLDyIV5/gF/QBwS+ML4jgnAaE8SDe8nRnVEJ3pToGsvSS6upK
Dtf7MG4APHbLMuTneZ7z67JdjVueTsdpDe5/EyhpWdJ3/5yNz87qE/GSPE4d
5k610d4rXMPkOTx4nq4Gc6V6TW82bnIcJx6E3+RHugjNuE/GY06MwRz4bXq8
FK56U1VTacQcZI9/9Cp0l/+E/CesGfOA5yl7g88PdYq0MnVAuIVwVf+SN/8/
pZHlKnSL7MancMwevlNHC8bsaoY3SB1vig==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 170->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKAjEMHPwQfz2CV9ADFK+wnqCC+7UgrB/iX4/urkpJppNa6DPJZDLN
4Xofxg2Ax25Zhvw8z3N+Xbbr5Zan03FajfvfBEpalvTdP2fzZmd9E/aSPE4d
Jqbe0cYVzmH8HB48T5eDuVK+pjZrNz6OEw/Cb/wjXYRmXCfjMSfGYA78Nz1e
Clf9qcqpNGIOssY/ehWK5Z6QfcKaMQ94nrI2eP9Qp0grkweEWwhX1S95c/8p
jSxXoVt0b94Ujtl7fRFpwZhdzfAGfxRwSQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 171->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKAjEQRBsX4tYjeAU9QPAK4wki6GpAGBfiLkd3RiVUV1eMgUwmv+rX
1dmdb8N1ZWb3zfwZ8uM4Tfl5Wi+TSx4P+3HZ3H67WUnzJ33G9z+sYa9rYr8k
r1Mb3Klzi/cKx4BzTs88p4vBrBQv5Ib7cMYxcSP9cL7li/CM82Q9ZmINZuh5
22NTNeWacL49Bq7/L78K3eX48p2wZ8xhnlN5h/4rds4tsEMcI91Cuip/yc3v
T3mErMK31jysKR0YW3WSdcT2r2f2ArzgcAg=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 172->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhR8uxK1H8Ap6gOIV6gkq2FVBqAtxN0e3tUoz3yTOwPwnLy8v
OVzvbb+R9NhNS9s9z+PYvS7b+XLrhtNxmD/33ymlZlqaZf+cte5q1vmzsz6i
L+xkzyrfU+Rr7JL1V86THDOuiJflxn9jk3HiAH5hH+niaMY8iUdOxCCHmrY1
bl5NWRPmW+PA+v/Tiz3H+FGPhT2EmFH9rP4ed+ZWcDd1EnATcL38Xd7sP08j
y9XRLboXbx5ODU9lHpmGwIzsFqw3FQlwhg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 173->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHPWAuPIEvgAPiPhCeUGQ4FSpUjkgbnl6WxbVGY/bSM7i2tPx
2Mdb3z4aAM/9tLX5dRmG/L7u5sc9d+dTN388/AwoadrS9/zcsZxIi/3jbA44
l+Jg7/B+zqlwYXxmFfYlbxV/wnH8UMdYc4vwXXyki9CM62Q85sQYzEFpG/FS
uKqn3BOud4sD939NL545NRtqxhivBP+M+mf1V9y5Nsfd9AmEWwhX1S558/wp
jSxXoVv0dj6Fs4UHXUu1Ig2pN8AIlvtvxQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 174->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPyQ/noEr6AHWLxCPcEK9qsg1A/xb49ua5VmJ5N2IftIk+lk
kuPt0XY7AM9m3Nr8ugxDfl/30+Oe+/Opnz4efgaUNG5pPr93LCfSYv84mwPO
pTjYO7yfcypcGJ9ZhX3JW8WfcBw/1DHW3CJ8Fx/pIjTjOhmPOTEGc1DaRrwU
ruop94Tr3eLA/V/Ti2dOzYaaMcYrwT+j/ln9FXeuzXE3fQLhFsJVtUvePH9K
I8tV6Ba9nU/hrOBFulcako5R3FzPB237b0U=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 175->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmhK9ABIlYoEwSJvipVKg/EL6PTUlCd8xksOUlT+3I+
u7mOXb8DcD/MS5cf52nKz8t++bjloT0Ny8/jx4GS5iWt+/uMbUfa/Btnc8C5
FAd7hr/nnAoX5s5Y4bvkveJPOI4f6hjrzgjfxUe6CM24TsZjTozBHJS2ES+F
q3rKPeF6/3Hg/v/Si2dOzYaaMcYrwZtR/6z+ijvX5ribPoFwC+Gq2iVvnj+l
keUqdHO8xJshjsKjHNlHa5GG1BvgBURkbwY=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 176->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqEVA6IW55Oy1ZnPA5YcpK69mTi
8eZ46c4LANfVuHT5th+GfD8sp49T7nfbfvq5fjtQ0rik1/48Y96RZv/k2Rpw
LeXBnuHjXFPhwsSMFY4l7xV/wnH8UOdYd0b4Lj/qi+gZv5PvZ06MwRyaWH9w
U5qyJvzeXxxY/1a/eObUbKgZY7wS3Bnp942jznF9inpldALhFsJV75e8ef6C
HkUzJHkJbZ1eaOBRjdTRWtRD0gZ4ALYxcAQ=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 177->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAQszggrjyBL8ADIr5QXhAkOFVCKgfELU+nZevE4wlEytLpjOPY
szleuvMCwHU1Ll2+7Ych3w/L6eOU+922n36u3xMoaVzSa3+eMe9I8/zk2Rpw
LeXBnuHjXFPhwsTMKBwTHCv+hOP4oc6x0w3Cd/mRLkIzfiffz5wYgzk0sf7g
pjxlT/i9vziw/y29uOdUb6geY7wS3Bn5942jznE6RVoZn0C4hXDV+yVv7r9A
o6iHJC/hrfMLDTyqkT7aEWlI3gAPkU9whA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 178->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAQszggrjyBL8ADIr5QXhAkeqqEVA6IW55Oy9aJxxMiZel0xnHs
2Z2vXb8CcNtMS5fvx3HMj9N6/rjk4bAf5p/bzwRKmpb03l9nLDvSMr95tgZc
S3mwZ/g411S4MDEzCscEx4o/4Th+qHPsdIPwXX6ki9CM38n3MyfGYA5NrEBX
idHwhN/7jwP739KLe071huoxxivBnZF/vzjqHOdhpJXRE4RbCFe9X/Lm/gs0
inpI8hLeOr/QwKMa6aMdkYbkDfAE75FwRQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 179->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8MjotBeqczyFS4tS1L+ez
d+dbd10BuG/Go8uP4zDk52k9fVxyf9j308/tZwMljUea7fuOxSIt+xtnc8C5
FAd7h/dzToUL4zOrsE9wrPgTjuOHOsZutwjfxUe6CM24Tn6fOTEGc2hiBbpK
jEZPuN5/HLj/Lb145tRsqBljvBK8GfXv50cd43oYaWX0BOEWwlX1S948f4FG
0QxJXqK3rl/wVuVbHRyW0DGKm+t5Ada2cAY=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 180->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqEVA6IW55OS4E643GI5Dhx7Ml4
2Z1v3XUF4L4Zty4/jsOQn6f1dLnk/rDvp8ftR4CSxi3N+n3GopEW+frZGHAs
+cGe4e0cU+HC2MwqbBMcK/6E4/ih9rHiFuE7/6guomacJ//PnBiDOTSxgrpK
jEZPON9/HLj/rXrxzKnZUDPGeCX4M+rfz47ax/UwuNt6gnAL4ar8JW+ev2Be
ohmSvERvHR68VvG2rg5LcI785hxfv6FvxQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 181->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRb84oF4ZgRVggIgVygRBglOlSu2h4pbRaSlQ+9sOlZI0rf3y
/Z3jrW8fOwBjM09tni7DkJ/X/bK55+586pafh88ASpqntK7vd2wr0ja+cTIH
nCsYKl/uAcPkVcYpHrTOSKPST5xCfMkpNMxDfBMf+eJ4xnXy+ayJGayhygp8
dRmVnnC9/zRw/2t+8Z3z7obRBF+Ld2bUv9936BjTw2Av/QRxC3G9+r2alB+s
KfK3xgl6a3iwq5cvfTUsR3MUt9b4Akz0b0c=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 182->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEOwjAMBFccEFeewBfgARFfKC8IEpwqIZUD4pan01KgznodKiVpWnuy
Xmd3vnXXFYD7Zpy6/DgOQ36e1tPmkvvDvp9+bj8DKGmc0ry+37GsSMv4xtkc
cK5hVPl2Dzgmrzau4qHWyUynQXAK8S2n0HAP8V185IvwjOvk81kTM1hDkxX4
KhmNnnC9/zRw/1t+8Z1Td8Npgtaizoz69/uOOsb1MNhbP0HcQlxVv6qp8oM1
Rf62OEFvHQ9+VfnWV8cSmqO4ucYXYWJvCA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 183->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRS0OqFdGYAUYoGKFMkGQ6KkSUjkgbhmdRm2Q/f2dRnKjNM7L
93fOj9cwHkTk3S2fIX1u85y+92NZPNN0vUxl87TFMvo18hZl1Lnu1X3R+z05
qxjmvF7DnWzWeYYnVicynQbCycDXnAzhBvBdfuQL8QzrxPtREzJQQ5MV+EoZ
jZ5gn/c0YP9bfuGbY2/DaQKm8QjujPr3/y82h9XM1tpPAW4GLquf1WT8QE2R
vy1O0FvHEz+z89pXxyKao7y1xh/5Jm4I
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 184->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRb84oF4ZgRVggIgVygRBglOlSu2h4pbRaSlQ+9sOlZI0rf3y
/Z3jrW8fOwBjM09tni7DkJ/X/bK55+586pafh88ASpqntK7vd2wr0ja+cTIH
nCsYKl/uAcPkVcYpHrROZhoNDqcQX3IKDfMQ38RHvjiecZ18PmtiBmuosgJf
XUalJ9znfxq4/zW/+M55d8NoIqbyiM6M+vf7Dh3j1eztpZ8gbiGuV79Xk/KD
NUX+1jhBbw0PdvXypa+G5WiO4tYaXzpTbog=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 185->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEOwjAMBFccEFeewBfgARFfKC8IEj1VQioHxC1Pp6Wg2utNqJS6UePx
ep3D9d71GwCP3fTq8vM8jvl12c6bWx5Ox2H+uf8uoKTplZb4+cYakdb1O2dz
wLmG4fLtHghMjvac48HrZGbQIDiF+JZTaIWH+OF8zRfhGffJ9VkTM1hDk1Xx
VTIaM+E5NzWAav7xi++cuhtBEzGdR1SzNj+n12oWddXe+gniFuKq/lVPzg/W
JDQq34IuMVs5J4oq3/oaWEJz7dzS4xuyLW5J
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 186->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHxy+i0FKh9OZdKjhP1fLbP
PlwfzX0DoN+NR5OHc9fl52U7PW65PR3b6ef+Y0BJ45Fm/75j8UiLfXE2Bhxr
OFy8fQMVJ3uLc3zwdTJnVYPgKcRveQqZ/IjL4SNdhGbcJ+fnmpiDMatcga7c
h5o354z2RepK81/T61/+asfEDJxGlJO1+WHh8eEMg7eaQcVPmqteWD+OVfsS
7ZCsK9Ia4m68ire6Vlyi5gg39/gC+m9tyQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 187->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4ZXRaSlX7ck6lxEljn89n
n+7Prt8BeB2mrcvv6zjmz20/Xx55uJyH+fH4X0BJ05YW+ztjs0jbWv1sDDjW
YLh4ewcqTLbWz+HB82TMioPAKYRvcQot+RGW8490EZpxnZyfOTEG+zSxAl25
DtVvzhnNi9Q1yNnK15qNihP1wGkk+sXaVXNiOYu86q56UOE36lc1Oc7MSXCs
alO8Iq0hzsaq+PW/1EJwjvyWGr+tlm2I
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 188->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfErU9nY0xLHadiUpd2i13H
yeH66O4bAM/d+Ory6zwM+X3ZTodb7k/Hfvq5/y2gpPGV5vjdY41I61ryLAaM
NRwV3p4Bx8nR5lV8qHUyp9MgeArxW55CSz7EVeVHvgjPuE6+nzUxB+c0uQJf
uQ7Z70afJZ58V/h/7lOz4eYE3rNKB/WLvXNz0tAcnVUPHD95rmph/xir5iWa
Iakr8hpib6LCL9+lF0JzlDfX+AEBuW1H
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 189->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAESuUCYJEX5WQygPxy+i0lKrO+ZJSyXHS2Jfz
2cfbo+12AJ7NuLTxdRmG+L7up8M99udTP10efgakMC5h9t89Vo+w2hJnc8C5
BiPLt2fAYbK3cRkecp6M6TgInET4FieRyY+wsviSLkIzrpPfZ06MwTFVrIKu
XIfsd6XPMp90V/n/vKdmw80JvGYZD+oXa+fmpMK5dFY9cPikebV+5sycBMdN
nJrWEHvjVf7yX2ohOJfi5ho/ry1tBg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 190->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8MjotBdU5XwyVHCeqfT6f
vTvfuusKwH0zHl1+HIchP0/r6XHJ/WHfTz+3HwNKGo80+/cdi0da7Btnc8C5
BqPKt2/AYbK3cRUeap6M6TgInEL4FqeQyY+wqviWLkIz7pPrMyfG4JgQq6Er
9yHnHcxZ6cC6q/x/6qndcHsialda0LxYO8c34Nx6qxk4fNI87J85MyfB8SdO
pDXE3Xi3c0p31pw4tuLmHl/1PG4G
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 191->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAihXKBEGir0pI5YH4ZXRaCqp9voRWShw39vl8
zuF6b7sNgMdu3Nr0PA9Del22k3NL/enYT5f77wJyM27NbD9nLBbNsn5xNgec
azBcvvWBgMnWxjk8eJ6MGTgInEz4FifTkh9hufiSLkIz7pPrMyfG4JgqVkFX
7kPOuzJnpQPrrvLX1FNvI7wTUdtpQfNi7QLfCueSr2YQ8Enzav/MmTkJjn9x
VvxzZ2PDm1O6s+bEsRQ39/gG0JFtxw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 192->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEOwjAMBFccEFeewBfgARFfKC8IEpwqIZUD4pan01JQ7fUmUCl1o9qT
9Tq78627rgDcN+Ory4/jMOTnaT1tLrk/7Pvp5/azgJLGV5rj+xtLRFrWN8/W
gGsNw9XbPRCYHG2e48HrZGbQIDiF+JZTaMmHWC6/5ovwjPvk81kTMzinyar4
yn3IeTfmrHxg31X9P+epuxHuiTjbeUHzYu+C3obm2l7NIPDJ82b/rJk1CY0/
ObXZMw8xhjunfGfPSWMtb+7xBRWgbkc=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 193->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAESuUCYJEX5WQ2gfil9FpKajO+ZJSKXGs2ufz
2cfbo+12AMZmutr4vAxDfF33s3OP/fnUzz8P3wOkMF1hsZ83Vouwnl+czQHn
Gows3/rweYlrmLgMDzlPxnQcBE4ifIuTmJP6CIt7kLoIzbhPpwfqGByzpa3S
lfuQ867MWenAuqv8f+rxTsg9EbUzLWherJ3jW+Fc8tUMHD5pXu2fOTMnwXET
pzR7xoO3bueU7qw5cSzFLT2+ARa+bsc=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 194->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfErU9nY6AljluY1GZVE8d2
ujvfuusKwH0zbl1+HIchP0/r6XDJ/WHfT5fbzwJKGrc0x/c/loi0rG+erQHX
GgxXb8+IdYV7mDyHB8+TMQMHgVMI3+IU5qQ+wmIN0hfEO9YZ/EDECD1IdxWr
UsM65Lwbc1Y+sO+q/p9+/CbkOxG9nRc0L4cNwbfBuXZWMwj45HlTP3NmToLj
T5za7BkPMbJ26Tt7ThxrebPGFySRbcc=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 195->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDgl+oL4igp4LQHsRbnm5rBbOzs5pCsl2SmcxM
sr/c+9sGwNTNU58fp3HMz/N2aa55OB6GZXH3GUBJ85TW+v7HtyKJUWHA2IrD
4OseHmewye4zWmB1MqfTIHgK8dc8hTWpj7jYg8wFfo19ujzQwEG+Q64Awz5Y
e+gnwKvcFb7lPH4T8p2Is00WdF+GG0LvD81Rr+4g4m3yz5pZk9D4lye6e+aD
r+xd5s6Zk8Zo3+rxBeu8bIY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 196->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszigXXkCX4AHVHxhvKBIcJqEtB0Qtz6djSHROA50UptFrR07
6f5y728bAFM3b31+nMYxP8/bJbnm4XgYlsPdZwElzVta4/sf34gkVoUBYysO
g69zeJzBJnvPaIHVyZxOg+ApxF/zFNakPuJiD7Iv8Gfs0/UDDRzkO+QKMOyD
tYd+Arzqu8K31OM3Id+JqG16QfMy3BB6f2iOcjWDiLfJP2tmTULjX55o9swH
H9m77Dv3nGpH91aPL/68bQY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 197->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPoh/vYIXkEPELxCe4II9qsg1A/xL0dvawWzk9maQh7bZGZn
Z3O6PbqhAfA8LlMXX9dpiu/+sAb3OF7O43rYfgeQwjKFbf3s8VsRxMgwYGzG
YfB5jBJnsMHeM1pgdTJnoUHwJOLPeRJrUh9xcQ3SF5RnXGfhByo4qG6XS/SB
+6166tbj4JXvCl+Tj9+EfCcit/GC+mW4IfTuaPZi1QOPt6p+1syahMa/POKf
ejNGM/u55zt7Trm9e1uNM1wRbMc=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 198->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDxIrz7BL+gDgl+oL4hgT4VCPYi3PN3WCmZnZyWFZBuSmZ3Z
3eNt6ocdgEe3bH1+XuY5v6779XDP4/k0rpeH7wJKWra0xc8/fhFJrAoDxlYc
Bl+f4XEGm+w7owVWJ3M6DYKnEH/NU1iT+oiLPci6wN+xT1cPNHCQ75BL9IH7
rXoa+gnwqu4K35KPZ0LOichtakH9MtwQev9ojs6qBxFvk3/WzJqERnBupUvN
FPPBR/Yu6841p9zRu83jGy+GbIg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 199->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHDyIV5/gF/QBwS/UF0TQU0FoD8Vbnm5rBbOzsyWFZBuSmd2Z
3dP91T13AMbDvHV5ug5Dft/2y+GR+8u5Xy6PvwWUNG9pjd9//COSWBUGjK04
DL4+w+MMNtl3phbYOpnT1SB4CvHXPIVrUh9xsQbpC/wd63R+oIGDdIdcog/c
b9XTUE+AV74rfEs+ngk5JyK38YL6Zbgh6t2oOTq7HBu8TfoFXzQvah4kT9BL
xwcfWbv0nT2n3NG7VeMHwRdsCA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 200->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfEjaezMSQSxxmd1HZVYsdO
szvfuusKwH0zbl19HIehPk/r6XKp/WHfT8HtdwGvMm5lPj//+J0oYhkMGGs4
HN7eEXEOW3ye0wKvkzmlfhXjuMlxmtRHXOxB9gUxxj5DP9DAYfX86W3m1fpg
7amfBK/6rvAt9Xgm5JyI2q4X9F6OG0LvgubsHmos8Db5F3zZvKh5kDzJWwY+
xJO9y75zz6l2ljd7fAPYeWvJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 201->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYg3n25rBZPJZOnC7nabzCST
5HC9d/0GwGM3HV19nsexvi7b+XGrw+k4zMb9bwPvMh1lub/f+N8oYhsMGGs4
HJ4X4RzWYgrlAp+n/W99GRNsbDc+Lie1iIs1yLog2lhnqAdWcNh8WlzcB9Fv
1dNUT4JXdVf4NfF4JuSciNiuFtQvxw2RbyPn7B1iNHhX6Rd82byoeZA8SS8D
H+LN2mXdueYUO/NbNH4A1z9rig==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 202->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfEbU9nY0gkjlOtUtt1qR07
zeH66O4bAM/dtHT1dR6G+r5s58Ot9qdjPwf3vwmMZVrKsn+/8d9RxDQYMNZw
ODwPwjmsxRTSAq/T/ld3VWwsIm7uOE1qEBd7kHVBjLHPUA/S1MIGT5ku4dX6
YO2pnwQv6y/wa/JxT8g+EbldLei9HDeE3obm7BxyNHhX+Rd8Wb+ofpA8yVsG
PpGLvcu6c80pd3Zv8fgBzmpriA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 203->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4ZXRaioRzPodWStLEvrN9
9uF67/oNgMdu2rr8PI9jfl228+WWh9NxmI377wJKmra0nJ9//E4ksQwGjDUc
Dg//XhTW+ifKBXWe9l35hja2G58qJ/WRTlyD1IW1EHU6PSinFrb84+IeiH6r
nob1BHipv8CvicczIedExI60UHeXbyPn6F71AG3eVfULvmhe1DxInqCXjk/E
4tql7jxfFDvyW2p8A3Aoa4Y=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 204->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbn25rBZPJZGlhd7ubZDKZ
5HB9dPcNgOdu2rr6Og9DfV+28+VW+9Oxn4373wLGMm1lOb//+J8oYpkYcKzB
CPGI76OKtf6FuMDztO/KN7Wx3fg4TuojnbgG1qmpJdlC7gxbaUS9kbxErY4n
9ZTzca+UDqy7il+Tj2dCzonIbW0OS9wD3wbn7O56gDbuqvoFXjYvah4kTtLL
gCdyce1Sd54vyp35LTV+AAIga8c=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 205->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVoABoq5QJggSfVVCKg/UX0enpUg453NEpSRNbJ/P
Z59uj35oADyP69bnVzdNeb4etss9j5fzuBnb7wKWtG5pPz//+J1IYpkYcKzB
cPHw74uKtf6JuKDkad+Vb2hju/EpOKmPdOIaWKeqlmRzuSNspRH1RvIStRY8
RT9rfVY6sO4qXuFHd5dP1MtclK7q7vhWOIfaoMSs4f5Vv8CL5kXNg8QJeunw
RC6uXerO80W5I7+9xjc5L2xH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 206->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwjAQHHqQXvsEv6APCH6hviCCngpCe5De+nRbK7g7mQ0GkjTdzOzs
bI63Z/9oAEztuvT5dRnHPF8P2+Geh/Np2ILddwJLWpe0759v/HYkMQ0GjDUc
Ds+DcA5rMYm0wOu0/9XdMMZxc8dpUoN84hrYp6qXFCtyR9zKI+qN1CVqdTpF
P2t9Vj6w7wqv+KNzkU/Uy1qUr+pc6K1oDr2B56zx/lW/4Ivei3oPkifoZcEn
cnHt0nd+X5Q7urfX+AY1/WwI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 207->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWEehBvfbqtFUwmk9KF3W2aZDKZ
zfH2aLsdgGczHW19XYahvq/72bjX/nzqZ+fht4GxTEdZ7u83/jeK2CYHnGsw
XD4vyhsJA6a+4wLP0/5XsamP/SbGcVGLdJLcFVelJflC7QxbaURvk2rKuIhx
WU1+Z6UD667yFX5mh3qiX+aidFV24LvCOdUGHnMNd1P/Ai+bFzUPEid5y4An
anHvUneeL6qdxS09fgAzG2yI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 208->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKgzAQHPpR/O0ReoX2AMEr6AlSqF9CwX4U/3J0tRa6mcwGhbzc3ZnZ
Sa6PVzecALybderip52mOPfn7fCM4/02bsHLbwAprFPY1+8e/xVBDFMDrjUY
WT1/VJcIA4Y/04Jcp/2vct0Yx21OEBwQeahoV1qVlxRLzO1hK4/oblxPGRdl
nsfJ96x8YN9VvcL3zgWf6Je1KF8LbAi9Fc2uN8gxa7iH+hd43ntR70HiOHdZ
4Aku7l36zu+LuL28vccF3qRsRw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 209->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbn06XVDkjsdppCRNbc/Y
Y1+en+Z9ANCfpqPJw73r8vdxnB+v3N6u7Ww8/zcwpulI6718m39yC3uJNRjL
MjGbRXEjYZQYi2e4JQfnb2IcDtutTxIcEH6o5K5yreip9LBcYT8o71J7TVPG
hfeLOLnPSgfWXcUr/Ojt+ES9nIvSdXdOdnIOtcEW0+EKzav1C7xoXtQ8SJyg
lw5PcHHtUneeL+KO/NYafxQQbYQ=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 210->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwiAQnHgwvfoEv6APIH6hvgATe2pi0h6MN55ua5WswyyQAKW7OzM7
cLw9+mEHYO6WpY/PyzTF13W/Hu5xPJ/GNXj4TiCFZQnb/vk2/7zJ8RT+cfL4
5fCgukQYucbiGW2Sg/WbmgKH4zYnCA6IPFS0K62en44flsu9D9Kde695yrgo
8zxOvmflA/uu6hW+dy74RL+sRfnafCcNza433h1YH8jzav8Wz9TWNIK5la4G
n8RG2bv0nd8XcXt5W49vcBluAg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 211->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwiAQ3HgwXn2CX9AHEL9QX4CJnpqYtIfGG0+3tUrWYQYkAUqXnZ2Z
5XB9dPeNmY27eenidB6G+Lxsl8Mt9qdjvwT3n2mWwryEdX9/u39qYjyFX5w8
vndwQF4CjJzj8Rw3WgP5u5wCB+P+TiA1CG/PpeDOuCo/hR+ek+wH8M7aa55W
dLB+1vrMfEDfWT7DV+eiHtGLXJivzXfS4Cy9UT3wPpj9r9/jQb8UR8PajFej
HsW2Ujv1Hd8X1Fb3Vo0v/PVtwQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 212->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksOwiAQnbgwbj2CV9ADEK9QT4CJrpqYtIvGHUe3tUrGx3sgCVAKM+8z
c7g+uvvGzMbdvHRxOg9DfF62y+EW+9OxXy73n2mWwryEdX9/u39q4n0Kv3ny
+L7BAXEJcuQYn89xoxjI38UUefDevwkEg/D2XArujKvyU/jhOcl6AO+sveZp
RQerZ63OzAf0XeljPcTOBR7Ri1wYbrNPRJ2a3qgaeP1m/+v3+aBeiqMhNuPV
wKO5rdROfcf+Amz1btX4AnbWbYI=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 213->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMi/hA/HIErgAHqLjCOEGR4GsS0vYx8ZejszE2BddeK7V7pHEc
O6f7q3nuzKw/jEeTh2vX5fdtP308cns5t1Pw+NtmnsYjzc/ve/inNsY9/eOs
a7mDC/IcMNaciBe40RqMg8LBuJX5XuEduRTcGVelp9AjcpJ+AO+lZoGFPog+
mJ9bPjMdUHfVH5sh6SWbMVE7xjaxDfgKn6raKA9i/zVfUsnbQ66aFzYPFEd4
WeCRWtg71R3nC2qre3OPH2F0bcE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 214->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksOgjAQnbAwbDmCV9ADNF4BT1ATXZGYwMKw69EBETK8vmebtHxmOvM+
c36821dlZkM9H2383Po+jvfT8vGM3fXSLcHmt81SmI+wPr/v7p/aGE/hWGdf
Ww4uuJegxn7H13PYaA+GQdXBuOX3UwG3x5JhZ1iVnkIPj0n6Abi3nlkt9EHw
YH7+85npgLorfmyGpJdsxkRvH1NcDrneG+JTURvlgedf8iVw3OiXwmjYm+Eq
9KO1LedOdcf5gt4qb+U4ATKDbkE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 215->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksOgjAUfGFh2HIEr6AHaLwCnKAmuiIxgYVx16MDIuQ5nbE2afm0b2be
TI/XR3uvzGys56WNz8swxFd3WD5usT+f+mWz+UyzFOYlrM/3u/unJu6n8I2z
j+0MDqhLgLHXeDynjXIwDQoH9y2vTwXdXkumnWlVfgo/vCaZB+jeODMszEH4
z/L8lTPzAX3/h0/dKZoJ6Re1oDcU20CvyKnojcrA91/KJXDdmJfSaMjNdBX4
KLblvVPf8X4Btzq39jgBEWBvAA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 216->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUskNwjAQXPFA+VICLUABFi2ECowEr0hIyQPxc+kkhETL7AzGkp3D3tk5
vL/c29vGzIZmXNr8OPV9fp6308c1d8dDN23uPtOspHFJ8/P97v6pifslfeOs
YzmDA+oKYKw1Hs9xoz0YB4WD+xbrS4W35xK4M67KT+GH5yTzAN5Lz4CFOQj/
WZ6/cmY+oO//9FN3imZC9CIX9IZiG/AVOVW9URl4/Ra1S/0eD/JSHA17M16V
fhTbonbqO94v6K3OzRpfnGBvgA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 217->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA++UIXAEOUHGFcYIisa9JSOMD8dejszGYghOvVGr3SGo7
TvaXW9ttANyb8Wjz4zQM+XneTh/X3B8P/RTcfTZQ0nik+fl+N//U5nhJvzjL
+ubwonuFMJY7Fs9oCzkiDQqH4/D3S0W31eK0R1qVn8IPq0n2AxSHr8F5Kvhs
nuLkPkc+sO//8KmZCnsS1MtauO8hNkiv6FPVG8ODCBde52r9Fo/6pTTyPIS6
KnwhNnztoe88X8St8uYaX/1vcAA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 218->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwjAUszggrozACjBAxQplgiDBqRJSOSBuGZ2WT/RwbEKkpJ+XZzt2
NsdLf14AuK6mpU+3/Tim+2E5f5zSsNsOc3H9nkDupqV7PZ/v4Z+bXM/dN04Z
nz08qC8TRumJeEGb5FAaHI6oc39u6I5aKu1Kq/PT+BF12zxAdZAHylPDF/c5
Ts5Z+VD5+gefu1MyE3Fe1sK5S2yQXpNT05vAA4WLWufP80c8ystp5PsgdTX4
JDbqs0vfWS9xS8+KTw+jMnA/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 219->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREcsEFuOwBXgABFXKCcIEqwqIbWLil2OTssncifjhEhJP47H
L+Mcro/uvgEw7uali9N5GOLzsl0+brE/HfsluP9OIIV5CZ/n+9388ybHU1jr
5PHbw4PyEmnkHKtn2GQNxeDpiDjnpwa3ZSnYFavnZ8UP9lblruIgD5SnjXq1
mpKLfCh8/aOed6dkT8R5mYX7LrVBvE6fmt6YOlC6KDmr57d61C+Pke+D5GrU
k9oozy59Z16qLT3LPr0Az6dw/g==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 220->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREcsEFuOwBXgABFXKCcoEqwqIZUFYpej0/KJ3PE4IVLSj+Px
yzi78627rgDcN9PS9Y/jOPbP03r+uPTDYT/Mwe13AjlNS/o83+/mXzQ5ntNS
p4zfHh6Ul0mj5Fg9wyZrKIZIR8Q5Pze4LYtjV6yRnxU/2FuVu4iDPFCeNurV
akou8sH5+ke96E7JnojzMgv3XWqDeIM+Nb0xdaB04Tmr57d61K+Ike+D5GrU
k9rwZ5e+My98zHlWfHoB5Kdxfg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 221->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwjAUszggrozACjBAxAplgiDBqRJSe6i4ZXRaoNGL49dESvpxnu34
5XR/dc8dgPEwL12crsMQ37f98vGI/eXcL+DxP4EU5iX8nt9388+bjKdQ8uSx
7uFBdYk4co3lEz4LDafe42Hc1lcawveak/ROOPvkfV4enK2qLXBQH1QmDb0t
TemLclC5tvS8OyV7Is7LXrjvkhvkt+HZzcboQPGi9rl5fstH/fI88n2Qvhp6
khv12WXu7Bc1VmWWc/oAhTFxfA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 222->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwiAQnHgwXn2CX9AHEL9QX4CJnpqYtIfGG0+3VUuWYbaQAKXDzs7O
crq/uucOwHiYly5O12GI79t+OTxifzn3C3j8TyCFeQm//ftt/nmT8RRKnjzW
OzwoLhFHjrF8QmeRw4lnnmRwxS1zCN1rvNROOOvke54f7K2KLXBQH5QnjXxb
OaUu8oF9V/GK3zsrH7he1sJ9l9wgvQ3Nrjcmj3xXqHVu1m/5qF+eRn4PUlcj
n+RGXbv0nfWixirPsk8fEW1yfA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 223->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgjAQ3HgwXH2CX9AHNH4BX1ATPZGQwIF469MFlWY6zJZNWmi3OzOd
7fnRt6+DmY3NPLVxug1DfN+Py+IZu+ulW5Kn/zBLYZ7C7/v9hz1vcD6FEifH
eoaD6hJh5BrEEzoLDqeecRLkFbbkELrXeqmd8qyTz3l+sLeqtsgb9UF5ssNX
45S6yAf2XdUrfG+tfKhxoxfeXYqzqLOi2fUGeOS7sq3O6v0Rj/rlaeT3IHXt
8Els294d97knGLJfyJN9+gD2bXL8
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 224->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgjAQnHgwXH2CX9AHNH4BX1ATPZGQwIF469MFFbKd7tAmbaHbnZnO
7vnRt68DgLGZlzZOt2GI7/tx+XnG7nrpluDpP4EU5iX89u+3OVOT4ynkONtY
7/CgvEQYW47Fc3RmHCKfcZKI2/yCw9G9YrnaKc46+Z7yg731crM4qA6eJxW+
PU6lK8NwfK3xqZ5ya0JczM31lVwgvRXN0hvDAw8Xpc7d91s8qpfSyP3g6qrw
udgo327PuSZ2qF5hT4APwV1yuw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 225->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwiAQ3HgwvfoEv6APIH6hvgATe2piUg/GG0+3VSHLdKaQAC3DzgwD
x9ujH3Zm9uzmoY+vyzTF93W//NzjeD6NC3j4d7MU5iH85u+3W1Md8RRqntLy
HmxQl4Cj1Hg+4rPSEPXIkwTu61caxHfmot4BR5+4T+WB2bLaCje4B5ZJQ29L
U/mqOEiuLT31puidgJY6f9aXWgZ+G55lNk7HGK/VPpvn93xwX8ojvgfqq6FH
uW19dr+uMMRpZiWnD9BZcfo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 226->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDggrjyBL8ADon6hfUGQ4FQJqT1UveXpbYFE9sR2IqVZJp4Z
2709P/37RETzZf/0cemmKa7D+Ti84vi4jwd4/U+iFPZP+K3fPbuzJuIpSJ4y
8hscEJeAo8RwPsWn0DDikScZOI+vNBTfmUv1Djj6xHdWPSovngbkh6vog6OH
/fT6jHvhU/Hr1cs6e3pe/lnf1CLw2/Bs1obpkMZL0mczf84H/bI84v+g+mro
qdxU587vLQxxtWalThsc8nG7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 227->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUVsKAjEMDH6Ivx7BK+gBildYT1BBvxaE9UP869HdVVuSaSZb6HOamUly
uD6G+0ZEnrt5GfLrPE35fdkul1seT8dxAff/KVLSvKTf/j2rNzYRL8nytFH/
4IC4AhwtRvM5Po0GiUeeQnAd32k4viuX6x1w9In/WD06L5EG5Ie76UOgh/2M
+oxn49PxG9WL3SO9KP+qT7UE/K54prVROuLxivW5mr/mg351Hh3M5SG9pHzi
8Dk5Mgxxt2atTh/RlXE9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 228->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUVsKAjEQG/wQfz2CV9ADFK+wnqCC+7UgrB/iX4/urtrSpslY6DOdJDNz
uN6HcWNmj92yDPF5nuf4umzXyy1Op+O0gvvfNEthWcJ3/5yrNzURT6HlKSP/
wQFxCThKTM1HfDYaIh55ksDr+E6D+M5c1Dvg6BP/qXp0XjwNyA/3pg+OHvbT
6zOeG5/Er1cvdff0vPyzvtQy8PvHs6xNpWOM11qftFaB+8Z+dR4JRnlELyWf
ET6So8IQpzUrdXoDkVpw/g==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 229->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUVsKAjEQC36Ivx7BK+gBildYT1BBvxaE9UP869HdVVvaNDNbmL7SSdKZ
w/Ux3DcAnrt5GuLrPE3xfdkuh1scT8dxAff/AFKYp/Bbv/vqzgrGU2h5yshv
eFBeIo6SU/MJn42Gkc883d/Q53cawnfmkt4JZ5+ePvO5HCBtUB9UTVb0uJ9e
n3nf+BR+vXpZZ0/P+3/WN7VAflc8m7WpdKB40fqUtQraN/er8ygw5rFCvkO/
8t/rewtjXNas1OkDHyBwvQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 230->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUsOwiAUnLgwbj2CV9ADEK9QT4CJrpqYtIvGHUe3VSEwzAOSx+/BzLx5
p/treO4AzId1GvxynSb/vu23w8OPl/O4JY//AIJbJ/dbv/vszgrOB1fipBHf
8KB/gTDSnxxP6Cw4OKBxqtoIW3II3RFLalc4PZ2GF00MEDeoD8rTDh/3s9Vn
3hc6hd6WX9a5xdeqP/KbXCC9Hc2mNxkPFC5KndIrp3VzvyqNIsc4Vsh3qFeu
Pb+3cpyXniWfPgsocHw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 231->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUsOwiAUnLgwbj2CV9ADEK9QT4CJrpqYtIvGHUe3VSEwzAOSx+/xZoZ5
p/treO4AzId1GvxynSb/vu23w8OPl/O4JY//AIJbJ/dbv/vszgrOB1fipBHf
8KC6QBipJscTOgsO1geNU/2NsCWH0B2xpHaFY/nZ8KOLAeIG9UF52uHjfrb6
zHvlu6pX+Na5xdf6f+Q3uUB6O5pNbzIeKFyUOqVXTuvmflUaRY5xrJDvUK/8
9/zeynFeepZ8+gDiN3D8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 232->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwjAUs3pAXDsCK8AAESu0EwQJTpWQygFxy+htgVYvrl8SKb8msf3s
nm7P7tEAeB3noYvv6zjGT39YNvc4XM7Dctj+O5DCPITf/F2bb17n8xRynK2t
d7jRu0QY2xuLJ3RmHKwPGmdXG2FLDqF7xZLaFY7nZ8GPKgaIG5SD8rTCx3mW
cua18l1pVfjevsTHmFm+8GvJ7lqdwuOqN4YHChe6duZWujmvnUbHY68W6bfC
MzPXLv87xoOTl7gDTDsfcT0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 233->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssNwjAUszggrozACjBAxAplgiDBqRJSOSBuGZ0WaPXi+r1Eyq9JbD+7
h+uju28APHfj0OXXeRjy+7KdNrfcn479dLj/d6CkcUi/+bs237zO5yXVOEub
73Cjd4UwljcWT+isOFgfNM6qtkBPpHvGktqVVs/PiL+FAeIG5aA8bfBxnlHO
vFa+K60K39tHfIxZ5Qu/luqu1Sk8bnpjeKBwoWtnbqWb81ppdDz2apF+Kzwz
c+3yv2M8OHmJO8AH9C5xvQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 234->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAQs3pAXPsEvgAPiPhCeUGQ6KkSUjmg3vL0tmyauJ5ERMrWTG2P
Zw7Xe9c3AB77Zeni8zyOcbrs1sstDqfjsD62nwmksCzhvb/O5ps3+T2FHOc3
vjE8xL+JcUF4QmdRHzTOJjeBnXEI3RZLav9Da5G/hgHiBtVBeVrh43qW6sxn
5bvSqvC9e4mPMbP6ws8li7U6hcdVbwwPFC507sytdHO9Nhodj71cpN8Kz+yc
u+w70WNer3AMMAPBmnD8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 235->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAQs3pAXPsEvgAPiPhCeUGQ6KkSUjmg3vL0tmyauJ5ERMrWTG2P
Zw7Xe9c3AB77Zeni8zyOcbrs1sstDqfjsD62nwmksCzhvb/O5ps3+T2FHOc3
vjE8xL+JcUF4QmdRHzTOJjeBnXEI3RZLav/H0xJ/LV8QN6gOytMKH9ezVGc+
K9+VVoXv3Ut8jJn5DD+XLNbqFB5XvTE8ULjQuTO30s312mh0PPZykX4rPLNz
7rLvRI95vcIxwAxOuHF8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 236->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksOwiAUnLho3HoEr1APQLxCPQEmddXEpC6MO45u64fAMDxSEigUmN/j
eL0Ptx2Ax34ZBv88z7N/Xbp1Mfrp1E/r5uHXgeCWwX2/n3nyr9Z5P7gcJ7b/
GW7ibmBcEJ7QaeqDxim8CeyMQ+gOhFto35Kpxd/yC+IG1UFl2uDjelp15rnK
XWlV+LW1xceYWc4o70nsVKfIuJkNcsyoIc1BeGdupZvrVWjkrIX/WpfnLDzh
Ub0R9lvNLOb0Bt3OcPw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 237->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksOgjAUnLggbj0CV4ADNF4BT1ATWJGY4MK469EFVEKn09fQ5PXfmXnz
Wt8f3XAC8DzPXedf12ny71u1LHo/ts24HF5+AQQ3d+47rvPdXi74PLgYZ2v/
O9zE28C4IDyh09QHjZPkJrAjDqE7EG6i/YinFn8pXxA3qA7K0wIf19OqM8+V
70qrws+tLT7GjHxG+k5i73UKj4vegLAgfBC5M7fSzfVKNLLXIv9cyHsWnvhn
6o9wvlnPNp8+kcNwvQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 238->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vYx8Zejs/GYNtdJRaV07Zra
jtPD9dHcNwD63Tg1eTh3XX5ettPmltvTsZ0O998ALI1T+nzf68U/L/jc0hpn
Hr8cHuKuMS4IT+gM9UHjmJentDi6jXAL7f94GvHX6gVxg/qgPK3wcT+jPvNa
+a60KnxvH/Ex5spnlPck9lKn8LjqDQgLwgdRO3Mr3dyvQiN7Ler3QuZFeOKd
qTfC9bqezT69AFThcT0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 239->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vhA/PXobDym1rULVEqbtZnj
ONkcL915AeC6Grcu3vbDEO+H5fRxiv1u20+P67cBKYxbeJ1PP7tzxu8plDjz
+sTwEv8mxgXhCZ5NftA4ycUpLoZ3ItyK+z+amvw/1QuKB/VBadqqV/Sz1Wf2
m32Bz+dmis/KR50718LVUmDnfAX3r9qAsEC42Z2cL65f4Ll5KXKY+p3JuBae
mDM1I1yv1WzW6QFn6XD8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 240->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKAjEQC36Ivx7BK+gBildYT1BBvxaE9UP869HdVXdp06TowPQ5zWTS
2Z1v3XUF4L4Zhy4+jsMQn6f1tLnE/rDvp8vt14EUxiF85vc6O3PO9ymUOIvN
MWzibWJcEJ7g2eQHjZNcnOJieCfCrbj/o6nJ/1O9oHjQPyhNW/W6/zTnvG7+
C3w+11M8V2vUuXMt+J3EzvkK7i1tOM9sBW52JvuL6xd4rl+KHKZ+5zKuhSf6
jHVV9VrNFp1emPhxfA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 241->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOgzAMHPVQ9don9AvtAyK+AC9IpfaEVAkOiJufDnRBiT0ONFLiEIfx
eCaX+6t+HgD0p3mp41B1XRyb4/LxiO3t2i7J83cCEuYlfOJ7n5x5U+cl5Djr
+N3Rg/wrGhcKj/As8gPHEe+ex4XwFoVruP+jqVN/V7+wXDMfmKZb/TI/nXO9
L/oCv573pnQ0e9jamW8FX5j/jHtJG1MHCQckedK7rk15My0Z3yTu6Z/V28Qj
74xiw+apZqtOEyhBcfo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 242->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsOgjAQnPhh+PUIXkEP0HgFPEFN5IvEBD6Mf3t0QYW001nAJn1sp8zO
Dnu8PepmB6CvhqWOz0vXxdd1Pwb32J5P7QgefhOwMCzhu3/OyZ03GbeQ88xj
esNDfGvMC+ITOj1dGU48xu8Fd6ZF6DbiLbT/46mTf0u9E69RXHjBtax4X/xP
557Prk7Sqvzy4qV8zJn5DM3r9slCT3keFHmQaECCi9o5t9StvFR6k31L/Srf
Kp/oM8mNEpeezT69AQNfcno=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 243->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkssNwjAQREccUK6UQAtQgEULoQIjkVMkpOSAuG3pJEAiezwbY8nxZ+3Z
txMfb4+22wEYm+nTxudlGOLrup8X99ifT/0cPPw6YGH6hO/4mSd7Xue4hVxn
bcsZbuKusS5IT3B6XFmcdIzPA5LDUg7i9u4pnqqnojZm9OpddI3WhRdcS8X7
4n86+zx3OYlV+eWtt/KxZuYztK77TjbelOdBkQcJA5K4qJ1zS27lpeJNxn/q
V/mqeuKdSW2UcenZ6tMbwG5y+g==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 244->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkssNwjAQREccEFdKoAUowKKFUIGRyCkSUjggbls6CZDIHs/aWHL8WXv2
7cSH673rNwAeu+nTxed5HOPrsp0XtzicjsMc3P86YGH6hO/4mSd7Xue4hVxn
bcsZbuKusS5IT3B6XFmcdIzPA5LDUg7i9u4p9qanojZm9OpddI3WhRdcS8P7
4n86+zx3OYm18KuyruVjzcxnaF33nVTelOdBkQcJA5K4qJ1zS27lpeJNxn/q
V/maeuKdSW2UcenZ6tMb+Exyuw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 245->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDotUJSczw2REjtxcj5f
vDvfuusKwH0zLl1+HIchP0/raXPJ/WHfT8HtdwKWxiV97NsvzqLJcUs1zm/M
d3iIty4nCE/wjHhVccIxvg84HhUfwTt6p7g3NRW1Mceo3hnXaO+04FpEPpmz
cc5+yLORL+opts6Hz139m+qrqE8WeirSoNTUlE9nrn76C8dbaan4Fvaf+lW+
Jp7oM4kNH1/W7AUzYXI7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 246->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwiAQnHgwXn2CX9AHEL9QX4CJnpqYtIfGG0+3VWtgdhYkgV1Y2Jkd
9nB9dPcNgHE3L12czsMQn5ftsrnF/nTsl+D+O4EU5iV87NvPzrzJ8RTKPL+x
3uEh3hpMUD7B0+NVxClP4vuA4VHwEby9d4p7U1NRG3P06l3zJtpXtXDwJGbj
nH2XZwPP6ym2xofFLv5N9ZWnTaWnPA1yTZPy6czUT39heCstFd/M/lO/wmvm
E30mc8PG65q9AI6vcfw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 247->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
BrORxHBhdPkGe1Rz4ACmBh1g0YthJwOaeVjcictdKPJo5jSgq2dgwHAHinuw
uBuXPmxuJximWPyG7kZc/oWZ24DGxwgLdL9gsQ+rnQTE0dk43UnAPlxpCp0m
xm6UeMOWrnClEzxpClcYIIdpAzY2mhiG/9HiAsPd2MISm3uRaGL8j80+guZh
SWdYzWbAlMcfZgCi3HJ6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 248->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpAfDsCK8AAESuUCYJEX5WQygP159HbAkXJ+Zw0UmLHTuzz
2af7s+sbEXkdl6OL7+s4xul2WC+POFzOw+psf1tEw3KEr/zoic3b6NeQx/mv
7Q0u8tfkFIhHcHq4Mj/EUXwvYnBkeAhu7x/DXuWU1IZ8evVucRXuhguspZCP
9tOxo+7irOTzZgrlntxZ39hceXNSmCmPg5RTZTrYTP3QC4ObccnwJnJP/Sxf
NR6ZMxpbrL/M2QwX+nL6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 249->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksOwkAIJS6MW4/QK+gBJl6hnmBMdNXEpC6Muzm6/WmYx6N0EgY6FHg8
aG7P9rETkddhuNr8vvR9/lz348c9d+dTNzqPi4iUNFxp1pOt3jxBf0l1nv/5
/YOHxJqaAvkITiE+EwN5CtTWfhSDPYhj2ENOSW/IJ3KgYxFrxQHDFdSj83Te
0XZxBvW8nUK9pXY1N7ZX3p442Ne40ZwWZsOb6R9mYXAzLhlepbf0z+qF+cie
0dxi/eucfQErbHK7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 250->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
BrORxHBhdPkGe1Rz4ACmBh1g0YthJwOaeUhuQxdDdxc2eWx+a0CTR8cYbieg
D1s4EQxTAuGB4V80vehuRQkDdHdh8Qc292PEJw5xdDZOdxKwD1eaQqeJsRsl
3vDEC0Y6weF2fGGDHKYN2NhoYhj+R4sLDHdjC0ts7kWiifE/NvsImoclnWE1
mwFTHn+YAQCG9nI7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 251->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
BrORxHBhdPkGe1Rz4ACmBh1g0YthJwOaeUhuQxdDdxc2eWx+a0CTR8cYbieg
D1s4EQxTAuGB4V80vehuRQkDdHdh8Qc292PEJw5xdDZOdxKwD1eaQqeJsRsl
3vDEC0Y6weF2fGGDHKYN6Gws8hj+R4sLDHdjC0ts7kWiifE/NvsImoclnWE1
mwFTHn+YAQDQDXJ6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 252->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDggrjyBL8ADIr5QXhAkOFVCag8VNz+dlk3JeBw3khM3rj3j
cQ7XR3ffiMi4m7cuT+dhyM/Ldvm45f507Jfg/msimuYtfc63X9x5hnFNdZ3/
+v2Di+QaTIF6BTe8Q14sznpTiKMZ7kEe0ynUNNDD9Au5yBXzFLGEY6EulZbO
PcViPAM8703huQa7mltjLuadONxb2pSaKvokbvqHWRjezsyNX5xr+md4YT3y
zmhtsfG2Zi8jK3L6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 253->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDggrjyBL8ADIr5QXhAkOFVCag8VNz+dlk3JeBw3UhLXrj3j
cQ7XR3ffiMi4m48uT+dhyM/Ldvm45f507Jfg/rtFNM1H+txvu/B5G+Oa6jr/
9fsHF8k1mAL1Cm7oQ14sznpTiOM23IM8plOoaaCH6RdykSvmKWIJx0JdKi0d
P8ViPAM8703hvQa7mltjLuadONxb2pSaKtokbvqHWRjezsyNXdxr+md4zXpY
S4gOTr+xZi8MSHK7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 254->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksOwkAIJS6MW4/gFfQAE69QTzAmumpi0i4adxzd1l9mHo+hkzDQofDg
weH66O4bERl389Xl6TwM+XnZLh+33J+O/eLcf0VE03ylj37bxZsn6NdU5/mf
3z94SKzBFMhX1IZvWBfzs94U/Cim9iCO8RRyGvBh+oVYrBXjFLGEYyEvFZfO
O8VidQZ43k6hXoNdza0xF7MnjV3yOCg5VbSJ3/RP8Kq6nZkbu9Br+md4zXyY
SwgPTr8xZy/BSHM7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 255->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwjAMtTigXhmBFWCAiBXKBEGip0pI7QFx8+i0/JQ8P8dEcpzYsZ/9
4v3l1g8bEZm7Zevz/TRN+XHerpdrHo+HcXXuPiKiadnSW7/Ohc0T9Guq8/zW
9w0uEmswBfIVtaEN62J+1puCH8XUHsQxnkJOAz5MvxCLtWKcIpZwLOSl4tKx
UyxWZ4DnzRTqf7Crf2v8i5mTxix5HJScKp6J3/RP8Ey+1ryI1c3+PbwoH+YS
woPTb8zZE2JKcr0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 256->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
BrORxHBhdPkGe1Rz4ACmBh1g0YthJwOaeUhuQxdDdxc2eWx+a0CTR8cYbieg
D1s4EQxTfOGBzb9oetHdih6fDeh2ofkDmzqM+MQhjtUubO4kYB+uNIVOE2M3
SrzhiReMdIInLeEKA+QwbUBnY5HH8D8W+zDMw5deGDBpvP7HZR8h89DNYsAS
Djj8SzjMAKvgcn4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 257->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
BrORxHBhdPkGe1Rz4ACmBh1g0YthJwOaeUhuQxdDdxc2eQy/MaCqa8CCMdyO
xXyc7ic2TPGFBzb/oulFdyt6fDag24XmD2zqMOIThzhWu7C5k4B9uNIUOk2M
3SjxhideMNIJnrSEKwyQw7QBnY1FHsP/WOzDMA9femHApPH6H5d9hMxDN4sB
Szjg8C/hMAMAzRpyPw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 258->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwjAMtTggrozACjBAxAplgiDRUyWkckDcPDotEOQ+PyeNlMTx9/k5
h+u96zci8thNR5ef53HMr8t2ftzycDoOs3H/2yKapiN9749sdNFGu6Zlnv8q
PrggTknO4qdGLthQh7iY3fUmSz/EYv0YbhbHeGpyKjzGxinxc3xAHYprJf9u
noGe1mI4V8w7etfqRXy5uddyW7w44wY3llNFmdhd/6Sey1f7L+Lvav9RvVY+
zCWEh6DfNmdv0Dhyvw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 259->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
BrORxHBhdPkGe1Rz4ACmBh2g6WvAYiZMXQMSG+Y2dDF0d2GTx/AbA6o6dLcg
q8Pmbmz6UPxMbJji0IOsD5vZGOGBZg/WcMXiD2zqMOIThzhWu7C5k4j4xsXH
Zx+u8MKId3xmI7sXPY4JhA1ymDags7HIY/gfi30Y5uFLLwyYNF7/47EPr3no
ZjFgCQcc/iUcZgDnW3JB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 260->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwjAMfeKAemUEVoABIlYoEwQJTpWQ2gPi5tFpgaDEfjaNlMTfZz8n
+8u9v20ATN189PlxGsf8PG8X5ZqH42FYnLvvBiTNR/rcb7myeVv7JbU4v1Vi
9FJ5QjBLnFRy6U3bdF/Mb7ihjdO91HGsb5bXcF47UyenzmPYZh6qDp0r4cHi
zHs6dloLWMWN/SGmR/W8eZl3j7CdflktppclWiZ+w5/UM3jRf4G9Q/5BvRBP
Y4HMweH7f2YvYEByAg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 261->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUssNwjAMfeKAuDICK8AAFiuUCYIEp0pI5YC4eXRaICjYz24jJfH32X7J
7nzrrisA9814dOVxHIbyPK0n5VL6w76fnNvvBlTGQz73W25s0bZ+lX+c36ox
dpk8JZg1Ths5s4H1QHK0wVfjp/3YWSTOY3GznAY5bR7DhvWbOpTXhfy79wzs
tBawaDb2h5ie1Yv4cu+eYQf9slpMr0utTPxuflLP4WX/Bf5O50/qpXgWC4SH
YN5ZzuQFSldyAA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 262->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUssNwjAMtTggrozACjCAxQplgiDBqRJSe6i4eXRaIMh9eU6LpSSOf8+/
w/XR3Dci0u/Gq0nDuevS87KdPrfUno7tpNx/j4jpeOnnffNOFh3Um87j/Cjb
IIGfkZjZzhxPZSSvmo+5+AZ6mg/WorEfs1vsaeDj/aJ6Z3rAoX1d2f9inoGc
Yomsqo3tUDjLP7ANsFnf6Z4Az7DYP5M5vpivlLUjtkXxavsi5Vutv4LH5oV5
4J6x3mK9iz3TF7qpcf4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 263->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFA/TICK8AAESuUCYIEr0pI7QPx8+i0UJA5X0KJ5CS2E599
9vZ0bS8rAEMzbm2+Hfo+34/rSTnnbr/rJudmFsDSuKXX+bw7G2Yd6VtM6D7O
Z/kYiHYjgcA1n4Oyibxqf8zFN/LLfLiWVP6n3klOK/xyvFJssJ9wJK8L+Q/9
LNglFrCoNjVDxV7+gW2ErXiXc0J3haX09zJ3D/1FrJ2xrRSvNi+IZ7X+Cp7q
F+fBc6a45Xp/cpYeprtxvw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 264->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqEVA6Im59OCwW5k4lJpCy2kxl7
4t351l1XAO6bceny4zgM+XlaT8Yl94d9PwW38wQsjUv67O+z82G2kZbThO1x
fsNjoPQbTQhe8zkon8gremMO3ygu8+FaCGtxX9yTmgb6Ml4NGxwnHqlro/7F
f1b8kgtoqo3xVU/x3sJtxK10l31CZ8Wl7O8wdy7+F2XtzG01vKhfUO5h/QGf
+i/Og/tMacv1/tUsvQBK6HK/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 265->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4eXRaqJB7uZhUchLb6Z19
8eF67/oNgMduWrr8PI9jfl22s3PLw+k4zMn9YoClaUnf/XN2MSw+0tpM+B7n
93kMlHEjg+A1X0MQg6pB/GMO3ygv6+FeCGt1X9yTmgb6Ml4NG5wnHqlro/7F
e1bikgto6o3x1Uzx3sJtxK10l3MSzFJNA6+puXPxvih7Z26r4UXzgnIP+w/4
1HtxHTxnSlvu969m6Q1eWnKA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 266->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4eXRaqJB7uZhUchLb6Z19
8eF67/oNgMduWrr8PI9jfl22s3PLw+k4zMn9YoClaUnf/XN2MSw+0tpM+B7n
93kMlHEjg+A1X0MQg6pB/GMO3ygv6+FeCGt1X9yTmgb6Ml4NG5wnHqlro/7F
e1bikgto6o3x1Uzx3sJtxK10l3MSzFJNA6+puXPxvih7Z26r4UXzgnIP+3cx
5lPvxXXwnCltud+/mqU3pVpzAA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 267->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQNz+dFirkTiYmkbLZ8Yw9
8eF67/oNgMduWrr8PI9jfl228+WWh9NxmJ37ZQKWpiV998/Z2bDckeL5i3UY
qzgeFOfjmdd8DoENKgcRYw7fyC/z4VoIa/VevJOaBvoyfw0blAOIR+raqH/x
nxW75AKaamN81kf5W7iNuJXusk+CXqpp4DU1dy7+F2XtzG01vKhfUO5h/c7G
fOq/OA/uM6Ut1/tXs/QGNKZyvw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 268->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQNz+dFirkjichkZI4drzM
2Ifrves3AB676ejy8zyO+XXZzo9bHk7HYTbulw1Ymo70vT+y02F5I9X3z9fF
WPnxIj/vz3nN11DRQdUgfMzFN7LLehgLxVr9F/9UXoVTccIxAveItbJf6GUD
/6GfBb3MBTRh4/jcf2Vvyc08h7kqzUlllkoceE7NyaG/iNg5t5XiiZ4H2d1V
/E7H+VS/uA6eM8Ut4/3LWXoDc2hygA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 269->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQbDyIV5/gF/QBg1+IL4hgTgEhHsRbP91EQyirq8cMzNYz1UtV
H673ptuY2WM3Lk37PA9D+7psp8ut7U/Hfnrcz9PMy7iU7/45g83mu5X6XLDg
Y8GpQTjEc1zHHCo2UzkIjIN/p3eZD+XMvn7+i38qLtfpAqN0CdxbzJVxQcsV
/Ac9E7uMZRQvqY39s/7qfU1s5jn0VdYnlV7KOEBOHc6sEeqUceWZP6F5OMNe
rR9sHE/pxXlwnyluud6/nJU37klywQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 270->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizggrjyBL8ADKr4wXjAkdpqENA6IW57OBtNkHKdsUtc2rePE
7uF6b7qNmT12469pn+dhaF+X7bS5tf3p2E+H+3mYeRl/5Tt/1hCzeW+lPhYs
5Fhw6iMc4pnXsYZKzFQNAuOQ3+lc1kM1c66f++Ke4uU+XWCUL0F7i7UyLni5
Qv/gZxKXXEZ8SW+cn7HqfA036xzeVYUz4880QE0d1uwR+pRp5Vk+4XlYw1zt
H2LMp/ziOvidKW2537+alTdy/nKC
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 271->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAQC36Ivx7BK+gBFq9QT7CC/SoI9UP8m6PbailjJlO7sO9NMpPZ
w/XetBsAj90wNPV57vv6umzHza12p2M3Xu6nDlgZhvKdP2t3hmmPstxnrOOY
caoRzuNZ13wMC2dQMQiMOX6jexkPxcxcP+/FO6XLeZrAqLoE7xFjZVyo5Qr/
Qz2Tc6kF0ktyY37Gqvs12uyz+luZZqafeeA9NbfmGvk6ZV5ZxidqHtZuVvnz
e/4zgYf/E3NB+6ry/etZeQNCDXMC
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 272->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPiPhCeUGQ6KkSUjkgbn46LVSVmYybRkrsLGM7
Mz7eHm23A/BsxqXNr8sw5Pd1P23uuT+f+unyME/A0rikn/367gzzHml9Llhn
F5wahPN4zmscKzgD1xBgfH1G97Ieqplj/b0X71Re/qcJjNKl4B5lrYxb0zLi
X+oZ1VXhoJZPahbcb8nNPKveinJG+SMOfH+Y81kjr1PElUXxhOaF76z6P7/n
ninicD9xLGhe1X+rnKUPcghzvw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 273->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPyQ/noEr6AHCF6hniCC/SoI9UP826PbainrZLZpIO/M7mRm
j7dH2+0APJtxaPPrMgz5fd1Pm3vuz6d+ujzMHbA0Duk3f9fuDPMeab0vWDcv
ONUI5/Gc1zhWcAbmEGA8P6N7yYc4c6y/9+Kdysv/NIFRvhTao+TKuDUvI/2l
nxGviga1fNKz4H5LbtZZ1VaUM8ofaeDrw9yaPfI+RVpZFE94XqzdzDyU/1wz
RRyuJ44Frav6b12zD0c2c0E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 274->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAQC36Ivx7BK+gBileoJ1jBfhWE+iH+zdFttcI0TVgL233MbCab
zOF6b7sNgMdu/LXleR6G8rpsp82t9KdjPwX38wCiGX/Nd/6s0xnmPZrlCLEP
jiHN/NG9EJi/vGAscwbmYO5kfkFxyYc4M9YiX+SpuvzOEHeUL+xD5sBYUlfD
j/Okn45XRYNaPemZif9Tm3VWveVquvpOg9wfkdbsUfbJaRUOT3i+WqeZeSj/
uWdWONxPjAWtq3pvXbM3blRzwQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 275->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vhA/OXobDCkxHMok7o+kjqu
nd351l1XAO6b8dfVx3EY6vO0njaX2h/2/RTczgOwMv7KZ36v3RnmPUocJvbG
MbiZP7pnAvObZ4yVnIE5JHc8P6O45EOcGSvkizxVN+Qhvp3rZ9ggDowldU34
cZ70M+PV0KBVT3qWxP+pHXROeiurmdXPNPB+mluzR96nTCvuj1+eL9ZuZh7K
f+6ZBQ73E2NB66re29bsBa4Sc4I=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 276->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVqADRKxQJggSfVWqVB6In0enhSI513NppMRJ7Jwv
Pp9uQ9tVAB7HaWnz8zKO+XU9zId77ptzPzvrZQKWpiV97Wfv7rCckcpp4mzs
g7M86J0JzF+cMVZwB+YQvPH8jPySD3FmrCJexKm8RRzKv3P+CBvEgbFkXQN+
HCf1jHht1WBHPqlZ4N+Tm/tP9VaUM8of1cDraW7PGnmdolpxf2xpvto7yzyU
/twzKxzuJ8aCrqv67/+avQEm93ND
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 277->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAESuUCYJEX5WQygPx8+i0UCTnek4bKXESO3cX
28fbo+12AJ7NuLT5dRmG/L7up8M99+dTPzkP8wQsjUv62e/e3WE+I5XTxNnY
B2d50DsTmP84Y6zgDqwheOP1GfmlHtLMWEW8iFO8RRzKvzN/hA3SwFgyr4E+
jpP1jHTVcrCBT9Ys8G/h5v5TvRVx+tooLokHx8u1JX+tX7g/ajVf7J1lHar+
3DMLHO4nxoLOq/rves4+zBlzBA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 278->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHx8+i0UCTnco4aKXESO+eL
z6f7q3vuAIyHeenydB2G/L7tl8Mj95dzvziP6wQszUv62e/e3WE9I5XTxNnY
B2d50DsTmP84Y6zgDswheOP5GfkrPoIzY1Xxqi6Ut4hD+XeuR4QN4sBYsq4B
P46Teka8WjXYkE9qFvi35Ob+U70V5fTaqFwSDy4va0v+Vr9wf7Q0r/bOMg+l
P/dMhcP9xFjQdfUj0qv+4wfpJHKG
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 279->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADLF6hnmAF/SoI7UfxL0e31QrZ2cnShX0mmcxO
crq/uucOwHiYly5P12HI79t+uTxyfzn3i/G4TsDSvKTf/j27N6x3pHKauBvb
4HYeFGcC8+9njMVvglcrxvMzsld8BGfGqvyVLpS38EP5d9YjwgZxYCypa8CP
/WQ9I14tDTbkkzUL7Ftyc/+p3opy+tqoXBIPLi/XluytfmHMVs2rM0Qc/SPU
BGW86q8KC1pXP6J61Zp9ABEQcwQ=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 280->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMHHFAvfIEvgAPiPhCeUGQ4FQJqRwQNz+dForkTMYRjZTF24xj
e3+597cNgEc3HX1+nsYxv87bWbjm4XgYZuNu2YCl6Ujf+/N2OiwyUrlNyMY2
uJsXxZnA/PkZY7FO5NWK8fkZ2at8RM6MVfmruhBv4Yfy74wXYYPthCXrGuTH
frKfQi+5sI5P9iyw/8PN86dmK+L0vVFcEg+Ol3tL9ta8MGar59UbIo7+EdYE
ZbyarwoLuq5+Rf2qa/YGWqZyxQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 281->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHx8+i0UCTnfIkaKXEc23eO
7dP91T13AMbDfHR5ug5Dft/2i/LI/eXcL8bjugFL85F+8nt3b1h1pHKb0I1t
cJIXxZnA/PsZY/GbyKsV4/Mzsod8RM6MFfxVXYi38EP5d8arYYPthCXrWsmP
/WQ/xbvkwna+wIPSl+UWbp4/NVs1Tt8bxSXx4Hi5t2RvzQtjtnoe7hBx9I9q
TVDGq/kKWNB19avWr1izD121c0U=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 282->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBBq9QTzCCXRWEuhB3ObqtVsi8vBQH5pPfe5kk
h+u96zcAHrvp6OrzPI71ddnOwq0Op+MwG/fLBqxMR/nen7fTYZFR2m1CNrbB
3bwozgTmz88Yi3Uir7UYn5+RPeQjcub/B39VF+Jt/LCOl2GD7YQl65rkx36y
n0IvufA/X+BB68t3eCNy8/yp2co4fW8Ur8SD4+Xekl3Ol6hzgyd6Ht4QcfSP
tCZo49V8BSzouvqVzUqs2RsaInLF
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 283->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe8nR3dYV0MlkstGmaZCZN
crjeu34D4LGbjq4+z+NYX5ftrNzqcDoOs3G/bMDKdJSv/NzdGxYdpd0mdGMb
nORFcSYwf37GWPwm8lqL8fkZ2UM+Imf+f/BXdSHexg/reBk22E5Ysq5Jfuwn
+yneJRf+5ws8aH1ZhjsiN8+fmq2M0/dG8Uo8OF7uLdnlfIk6N3ii52GOIOLo
H2lNFE6SB88Z19WvbFZizd7onHKG
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 284->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAihXKBEGir0pI5YH4eXRaKJJzPodIiZPYuXPO
Plzv/bAB8NjNS1+e52kqr8t2OdzKeDqOi3O/TsC6eem+9rN3d1jP6Opp4mzs
g7M86J0JzF+cMRbfibxab3x+Rv6Qj8iZ/x/ilS7EW8WhjZdhg/2EJXVN8uM4
Wc9Mo5YGf/gCD+pYtmGPyM39p3or4/S1UbwSD46Xa0t+2V9C5wpP1Dz0EcQ7
+keqicJJ8uA+Y139kPWSmr0BD7pzBg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 285->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEWCVyWk8kD8PDotFMk5n9NIiZPYuXPO
Plwf3X0D4Lmblq5/ncexf1+28+HWD6fjMDv3ywSsTEv52e/e3WE5o9TTxNnY
B2d50DsTmP84Yyy+E3m13vj8jPwhH5Ez/z/EK12It4pDGy/DBvsJS+qa5Mdx
sp6ZRi0NVvgCD+pYtmGPyM39p3or4/S1UbwSD46Xa0t+2V9C5wpP1Dz0EcQ7
+keqicJJ8uA+y7Tw/nXNPjC6c4Y=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 286->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHx8+i0UCTnck4rJalj+845
+3R/dc8dgPEwb12ersOQ37f9Yjxyfzn3i/O4LsDSvKXf+f13d1htpHKZsI19
cCd/lGcC8x9njMV3oq5Wjq/PyF/VI2pmnipe6UK8RRzKtzNehA32E5bUNaiP
42Q/I41aGmzwVTwoY5XWStdQ52C2Ik7fG8Ur8eB4ubfkb80LY7Z6Xs0RRB69
I9RE4QR18JxFWnj/tmYf08l0Bg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 287->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAESuUCYJEX5WQygPx8+i0UCTnck4rJWly9tk+
+3h79MMOwLObtz6/LtOU39f9crnn8XwaF/CwLsDSvKXf+f13b1jvSOUycTfG
4E7+yM8E59/OmIvfRF4tH5+fEV7lI3LmOJW90oXiFnYoa2e+iBuMU01S1yA/
tpP9jDRqaSDqbHF4e46v4lV1ss7BbEUxfW9UXMmHUveqTw5vzQtztnpezRGE
H9URaqJ4gjx4ziItPL6t2QenAHOI
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 288->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAihXKBEGir0pI5YH4eXRaKJJzOZtKSZqcfbbP
Plzv/bAB8NjNW1+e52kqr8t2udzKeDqOC7hfF2DdvHXf8/Pv3rDe0dXLxN0Y
gzv5Iz8TnD87Yy5+E3llPj4/I7zJR+TMcRp7pQvFreyQ80XcYJxqkroG+bGd
7GekUaaBqDPj8PYcX8Vr6mSdg9mKYvreqLiSD7XuTZ8cns0Lc2Y9b+YIwo/q
CDVRPEEePGeRFh7/r9kbIh50CA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 289->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAihXKBEGir0pI5YH4eXRaKJJzOZtKSerYPl/O
Plzv/bAB8NjNW1+e52kqr8t2MW5lPB3HxblfF2DdvHXf8/Pv7rDa6Oplwjb2
wZ38UZ4JzF+cMRbfCV5Zjudn5G/4CM5cp4lXulDdKg45XoQN9tObpK4BP46T
/Yw0yjRAntvUoXiltdI11DmYraim742qK/FQ6970yfmzeWHMrOfNHEHk0TtC
TRROwIPnLNLC+/9r9gazVHTH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 290->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAihXKBEGir0pI5YH4eXRaKJJz9oVKSerYPl/O
Plzv/bAB8NjNW1+e52kqr8t2MW5lPB3HxblfF2DdvHXf8/Pv7rDa6OpliW3s
gzv5ozxLMH9xxljiDsxB5Hh+Rv7AJ+HMdUJ8pgvVreLQxlPYYD+9KdVV8OO4
tJ9Ko5YGaOeGOqqXol54J+ssZkvV9L3J6qZ4qHUPfXL+1rwwZqvnYY6Q5NE7
pCYZjuDBc6a08P7/mr0BxsZ0iA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 291->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADFK9QTxDBfhWE+iH+7dFttUIymYmBPDb7mp3d
w/XeDxsAj9189Ol5nqb0umwX4ZbG03FclPt1A9HNR/e9P+/sD6uMrtwh5GAd
spsX+YWI+bMLjmX+wBiMT44vSF/hEZg5T2WveKG8hR3a8VxssJ5qkrwafGwn
++k4anGAtm+Vx/XS5KvqZJ7NbLmceW9UXhkPJe9VnzJ9a14KGQIbcwp6sx/V
YTlRccQ8gXzsfFG9/zl7A4p7dEk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 292->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAvfIEvgAPiPhCeUGQ6KkSUjkgbn46LRTJGS+tlKTOeGxn
7OPt0Q87AM9u3vr6ukxTfV/3i3Gv4/k0LuBhXYCUeSu/8/uv7rDaKO0SxxbG
oE7+iCdOzL+fcKzgDlxDwNH1CeGmHqdmzmP8PV0ob+OHPF4UG4zTm1xdg/rY
z+1npFGmAXKuyRP1Mshn3sk6B7MVzglansd3NVW6mz4pPJsXriWNx1jC8/rP
M2PiOPME4oTzRe/d1uwD9kZzyw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 293->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAQs3ggvozACjBAxQplgiDRVyWk8kD8MjotFOni2KFSkiaO7xzf
Ha73ftgAeOzmqU/P8zSl12W7bG5pPB3HBdyvA8jdPHXf9fMfzrDu0ZUji31m
DGHlj3hZxPzdyxzLnIE1GE7Ulwmv9AjNnMfqd55yPDTigbQIj4rc5k2ulk6/
rKfzSHkm8ilulcfV0uSL75c+m9rYPkHJU3zpafSd6xRw2V9GSzMeYw2eqj/3
TBWn0U/cd8qLiP/37A1rUXOK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 294->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszigXXkCX4AHVHxhvKBIcJqEtB0QtzydDXbIXCdMars0cuLa
Od6e/WMHYOrmra+vyzjW93W/BPc6nE/DkjysC7Ayb+V3fv/dHdYYZbtMxMY5
uJM/whnV8HjjWsEdmEOA8fyM8g0XwZn7SO6ZplwPST0QF+4B6h28KfIy4i/9
TPxqNBP9FLbpE3kZ9PPvlzoH3oRzgi1O4aWmXnf2yeXlfAVc0nqcS3DKf56Z
pk4yTzx3Sguf/6/ZB2ZvdAo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 295->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwkAMszigXnkCX4AHjPhCecEgwakSUntA3PJ0Wugh9Tih0iyZyI7r
5Hh79o8dgKmbt76+LuNY39f9EtzrcD4NS/KwLsDKvJXf+b27N6wxynaZiI1z
cCd/hDPi8HhjruANrCHAeH1G+UaL0Mx1pPbMU+ZDwgfSwjVAtYN/inoZ6Zf9
TPrVeCbqKWxTR+jmGsrX0OegN+GcYItTeOmp95375PJyvgItKR/nEpzqP89M
w5PME8+d8sLn/3v2AV1+dIo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 296->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDot9JGcz6ZSkjqOz+ez
D9fHcN8AeO7mbaiv8zTV92W7GLc6no7j4tyvC7Ayb+V3fv+bO6w2Sr9M2MY+
NCd/FGeE0cYbYwV3YA7o37nahN9xEZw5j+Seacp4yPE6LpwDlDuoKeplxF/2
M+mX00zkU7Euj+DtdBC6hjqLGtScdH2BfxNp08Z18xL45XwFXFI89iVxqv88
Mw4nmSeeO6VF6/+v2QcV93TJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 297->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8Mjot9OGcz6ZS4jqO7cv5
DtfHcN8AeO7mbaiv8zTV92W7OLc6no7jEtyvC2hl3srPfv/NGVYfpV9N+I1j
MJY/ymtUw+Y3rhWcgTGgv+feJuIOi8DMfST2jFOuh7xeh4V7gHoHb4pmGeGX
80zm5TgT/VSu6yNwOx5Er5Bn8Qalk24u8Hcibmxep5cgnunFYcnqccxYxqHm
z5pxdRI9se4UFzb+n7MPACN0CA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 298->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOAjEMszggrjyBL8ADKr4wvKBIcBoJaTggbn06MzCH1HFCpa5pHdfO
4foY7hsAz908DPV1nqb6vmyXza2Op+O4BPdrB1qZh/Kbv2tzhnWP0vcm9o1j
MDM3etcIw75vjBWcgTmgv+f+JuKOi+DMeST3TFPGQ47XceEcoNzoeUSaRvqn
fiZ+Oc1EPvXW5UGcP9Mk1Fn8QdVJ5wv8nb+awmCxTyae1Yv0OMLjmJmZh/Kf
a8bhcD0xFoJ/mCb9kpp9AOMJdIY=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 299->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDotVCi+nF0pSR3H57N9
h+tjuG8APHfzNtTXeZrq+7JdjFsdT8dxce7XBViZt/I7v//NHVYbxS8TtrEP
zckfxRlhtPHGWHwneLk6IO4Cf8dFcOY8knvWU8ZDjue4cA5QbngeUU+j/qfz
TObV9UzkU7FdHsT5s56EfRY1KJ24uaB/E8W3cU4vgT/Ti5xxhJf4mIeaP2vG
YUZ4QmdSX1RvqMM/9gdVGnSE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 300->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4eXRa6CO+nF0pSR3H5/PZ
p/tzGHcAXodlG+r7Os/1c9uvxqNOl/O0Oo/bAqwsW/mfv//mDpuN4pcJ29iH
5uSP4oww2nhjLL4TvFwdEHeBv+MiOHMeyT3TlPGQ4zkunAOUG55HpGmkf9rP
pF+dZiKfiu3yIM6faRLqLGpQc+L6gv5NFN/GuXkJ/Nm8yB5HeImPeaj+88w4
zAhPzJmcL6pX9rN5A3wBXhp1BA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 301->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDot9BFfzqZSkjqOzxef
c7g+hvsGwHM3T0N9naepvi/bxbjV8XQcF+d+HYCVeSq/9fvf7GG1UfwwYRv7
0Kz8UZwRRhtvjMV7gpe7B8Re4O+4CM6cR3LPasp4yPEcF84Byi3ul2kZ8Zd6
Jnp1NRP5VGyXB3H+rCZhncUdVJ84XdCfieLbONcvwv+vX6TGbCu+oh/ac0p/
7hmHqfAYC8mbhfdLPV3NPotmdMM=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 302->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDot9BFfzqZSkjqOzxef
c7g+hvsGwHM3T0N9naepvi/bxbjV8XQcF+d+HYCVeSq/9fvf7GG1UfwwYRv7
0Kz8UZwRRhtvjMV7gpe7B8Re4O+4CM6cR3LPasp4yPEcF84Byi3ul2kZ8Zd6
Jnp1NRP5VGyXB3H+rCZhncUdVJ84XdCfiWrTxrl+Ef5//SI1ZlvxFf3QnlP6
c884TIXHWEjeLLxf6ulq9gE0dXVD
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 303->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8Mjot9BGfz6ZSkjquz+ez
e7g+hvsGwHM3b0N9naepvi/bxbjV8XQcF+d+XUAr81Z+5/e9u8Nqo9jVhN3Y
h+7kh+IaYfTxjbH4TvAydUDcBX7HRXDmPJJ7pinjIcczXDgHKLeoL+tlxF/2
M+mX00zUqWJdHsT5M01CnUUNak4MX/hvIm36ODMvwv9vXmSP2U70Vf13tQt9
DU6Ex1hI/llYv+yn0ewDrE91BA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 304->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFU8ENwjAMPPFA/TICK8AAESuUCYJEX5WQygPxy+i0UCT7ck4rJant+Gyf
nePt0Q87AM9u3vr8ukxTfl/3i3DP4/k0LsbDuoCS5i39zu+/0WGVkfwqQi5s
gzn5I79CGNa/MBbrRF6uDghdYK/qEDlzHJl7i1PGQxvPYjD+37eqSdkERpS/
7GejX06Gjqd8Jd9B/BYnIc+iBjUnri+o70TcWD83L8K+NS+yxyyrfMU82Huq
/zwzDlPhMRYabxbeLvvpOPsAfVd0ww==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 305->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0sKwkAMfbgQtx7BK+gBBq9QTzCCXRWEuhB3ObqttpBkXkIHZtI3j7z8
pqf7s+t3AF6H6ejq+zqO9XPbz+BRh8t5mMnjsgEp01H+9vet7rBgFLuFYPEc
lPXL+YnT0P7itTbkZeoAuQv4pg6Ss49Dc8966vWQ62kNr7/6NjUxjmhk+Tfz
TOZlcDAj5kv7HcTPehL2mdTQYCirZsPiMrwu814Iv6nfzJfMnL6joH5Wq38z
RpPpeS0k/ywsz2Zntb+oP3MC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 306->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADFK+wnqCCfi0I64f416O7qyukk2looY80zCSZ
5HB9DPcNgOduPob8Ok9Tfl+2i3HL4+k4Ls79uoGS5iP97u/b/GG1kepdhF3Y
B3PzIlwhDosvzNWRV1UHxF/D7+oQOXMcmXukKfMh5rMczP/HupqUT3BE+bt+
Bv3iHFQ8hZV6d86Y6p3TOeByOdrVqk1pBRPX4NnfpbfCirmSc9SoX9Xq+gXo
ePA682wpLaxf9a7m/gDPkHJB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 307->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU0EKwjAQHDyIV5/gF/QBwS/UF0TQU0FoD8Vbnm6rFTaz0yWBJE2mO7uz
057ur+65AzAe5qXL03UY8vu2Xw6P3F/O/QIe1wmUNC/pt3+fzR3WM1I9izgX
xmB2HhRXiMPGF+ZqqKvSAXG3gTsdombOI2uPesp8iPksB/P/Y50mhQmOqH7n
Z+AX16DyqVjZ78ZvTHnn+hxwuRrt2NKmegWT18Qz3tTvIFZ5r95n/Uqr8ws1
7viYC8E/ixpX3tXcH5gxcgI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 308->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfErU9ngyGljpttUtulaVzH
7uH66O4bAM/dOHX5dR6G/L5sp+CW+9Oxn5L7eQAljVP6rd9/s4c5RqpHEXHh
HMzKH9UVwrD1hbFW8Kr6gNhr5F0fgjPfI7lHmjIeYjyLwfj/WtfTgqYt/Zta
LvjFHNR9qlbqvfKNKe+czgGW40hey95amsLwYZ8IM9Q7qFXeq/Pcv+rV+YU6
7/AYC8H7Qp1X3tXYH5TmcsE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 309->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAUHFyIW4/gFfQAwSvUE0TQVUGoC3GXo9tqhZd5k9cW0jR5fZP5
5HB9dPcNgOdufHX5dR6G/L5sp8Ut96djPxX38wBKGl/pN3+/zR7mNVI9ilgX
rsHM/FBfIQzbXxhrBa9KB8Reo+50BLwVf8VHncs6IjyLwfj/XqdpwdOW/00v
F/JiDuo81Sv9XnnHVHbO5wDLcaScpbaWpzB8OCfCDP0OelX26n/Wr7S6vFDX
HR5jIbhfqOsquxr7A8HwcoI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 310->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU1sKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+7dFttcJmMptayGOT7GRm
Jz1c712/AfDYTV2Xn+dxzK/Ldg5ueTgdh3lzvzTA0tSl7/iZuzUsMVLZTMTG
e3Ajf5RnhOHzjbH+4FXogFgL9iWHgLfir/ioe1lHC89jMP4vt9K0UtOo/mEt
A5/VPPJIeV29G1Hj5t2oY8Uj0lacI5+ltigfjg/7RJjNejdylffqPOtXWiu/
SHuFx1hY/19ab6XEfgMe/HDD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 311->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPiPhCeUGQ4FQJqRwQtzydForkTMamkbI4jp0Z
j/eXe3/bAHh009Ln52kc8+u8nY1rHo6HYXbulgmUNC3pu3/O5g6LjVTPIuzC
PpidB8UVymHjC+dagaviAXHn+CUGB7fCr/Cof5lHlM/m4Py/2IbTH1xe/d1a
Ojqrs6eR0rrpG1Hj8G+0tsLhcavekc6SmxcPg4d1opxhvYNYpb16z/wV10Yv
4u7h4j5reJgR9UqFFW/agnFB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 312->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzydFoqUjMemkbI4ju2Z
iQ/Xe9dvADx209Ll53kc8+uynY1bHk7HYXbulwmUNC3pu3/O1R0WG6mdRdiF
fah2HhRXKIepVedagavhAXHn+A2GALfCr/CouqAaUb46B+f/xRpOf3B5+rta
Ov+szowv+mvTN0LjsDasrXT2uDXv6J8jbqpHSmrjTQ+t0TuIldqK98xfceWe
Ye4eLu4zw6MaUa80WPEGG0hx/g==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 313->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADFK+wnmAF/VoQ1g/xL0d3V1dIJ9NooY80TTKT
zu58664rAPfNtHT94ziO/fO0no1LPxz2w+zcLhOwMi3ls7/P7g6LjVJPE7ax
D27nQXFGOUItn0vlp9oVD4i7hj9gSHAr/Aq7qguqkeXzOTj/NzZw+oGr1X/1
xybeZ2fGl/110I3ocVob0VZ9bnELOnL/nHFTGrFSxwcN/dPvJFb2Vrxn/oor
a4a5t3CxzgIPNzKtVFjxAi66cb8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 314->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA/HIErgAHqLjCOMGQ4GsS0vhA/OXobDCk1HEDlfpuHDv1
7nzrrisA9800dP3jOI7987SeN5d+OOyH+XK7dMDKNJTP/F67Myx7lLqb2Bvf
wc3cKM4II+TyWAqfclc6IM4a94FDwlvxV9xVXlCODM9jMP43Nmj6watVf/XH
Jt5na+aX/XXwjahxmhuE06hzS1vwkfvnTJvyiJU6Pnjon3onsbK24j3rV1rZ
M6y9xYt9FnS4lnml4ooXD8lyPw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 315->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNU1sKwkAMHPwQfz2CV9ADLF6hnmAF+1UQ6of4l6PbaoXd2UlqYR9Jmslk
mh6u967fAHjspq3Lz/M45tdlOxu3PJyOwxzcLwuwNG3pe37uhQ+LjVQvE7Zx
DMXJD+UZYTS1CiyJT7WrPiB8TrzhEPBW/BV3VRdUI8IrMRj/l9v0tMLL0199
YxPvR3fmp/T1+lQah7VBOI7OXm/NHBFfrzc1I5bq/H80aDCD3EhbNUvcB/uM
cZxaprCw/r9Es1JxxRtyuXKA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 316->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFyIW4/gFfQAD69QT1BBVwWhLsRdjm6rFd6bTKKF900zmZmX
3fnWXVcA7ptp6vrHcRz752k9Hy79cNgPc3C7DMDKNJXP+t5Xd1jOKO0wcTaO
oVr5ozwjDFerwpL4VLvRAXEXxB2HhLfir7iruqAaGV6NwfjfXKfpB6/If/XG
Jv7P9sxP+RvpVB6ntUE4gc+RNtdHxDfSpnrESpv/jwcOM8nNvFW9pHQwD6db
1OI87jvlRR1Xb9dwxQu/uXMA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 317->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA/HIErgAHqLjCOMGQ4GsS0vhA/OXobDCk1nEClfpIuzi2
l9351l1XAO6baen6x3Ec++dpPQeXfjjsh/lxu0zAyrSUz/4+V3dYYpR2moiN
31DtPCjPCMPVqrAkPtVudEDcBe+OQ8Jb8VfcVV1QjQyvxmD8b67T9INX5L/6
xya+z87MT/kb6VQep7VBOIHPkTbXR8Q30qZ6xEqb/48HDjPJzbxVvaR0MA+n
W9TiPO67hnc1sl5puOIFsLZywQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 318->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHmLjCOEGR2NckpPGB+OvR2WBIqeOESn03ju3m
cL33wwbAYzcPfXmep6m8Lttlcyvj6Tgul/u1A7Wbh+47f9bmDOseXdur2Fe+
g5m5UVwlDJfLYEl8yt3ogDgL7h2PhHcYo3xRvJlHgGcxGP8X6zT94RX5r/64
ivfZmvlF/iqdyuM0Nwgn8DnS5uqI+EbaXDwMf/G/kQcOM4nNvFW1pHQwD6db
5OI4rruGt2lZrTRc8QZn1HNB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 319->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUjkOAjEMHFEgWp7AF+ABEV9YXhAkqFZCWgpEl6ezC1vY43FEpByO45mx
48P1Mdw3AJ67eRnq6zxN9X3ZLsatjqfjuDj36wRamZfy279nc4fVRvGzCbux
D2bnQXGNMAKXwZL4xO3ygLhL/EFLR7eKUdoVr3uHPp7Twhwg7gQrxP2hP/xn
pqvHY+qm6hv6RtS4yw3CSeqc5Rb6iPRmuYV4GP3if7MaBEzWrPAEruollQfr
CHkLLo7jvnO6zej1itOKD5HydEE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 320->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUjsOwjAMfWJAXTkCV4ADRFyhnCBIdKqE1A6ILUenhQ7280vUSEnqpH4f
x+fHqx8OAOZuWfr8vk1T/tyPa/DM4/UyrpenbQIlLUv6779vc4YtRvKziLjw
HczOg/IKYQQugyXxidv5gDir3ActDd0qR2lXvO4/tPGcFuYAcVewQt4O/eE9
a7paPKZuqr6hb0SNm9wgnEqda95CH5Fe5S14heE1+XtqEDSxZoUncFUvKR+s
I/gWXJzHfed0m9HqFacVXzsBdME=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 321->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0OgjAQhV9cGLYewSvoARqvgCeoiaxITGBh3M3RBWUxP28ampTSlnnv
m2HOj1c/HADM3fLo6/s2TfVzP66bZx2vl3G9PG0TkLI8yn/9vaszbHsUO4Xs
xd9BrX64OHEawUtpUX3nbfIAOUvuA0uDm8UwduZrvkNbz7B4DzjvRCvE7eAP
/zPjavmourH6hr4hNW56w+kkdc5yC33keFluIVcoXxW/pwaByTMzPaLLeonl
oVnF6yReQrS0huFWo9UrhhVfF1J0gg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 322->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREcsEFuOwBXgABFXKCcoEl1VQioLxM5Hp4UunPE4EClN8/Gb
sZPD9d4NGwCP3fzp+ud5mvrXZbtMbv14Oo7L5n7tgJX5U77j59+tYZ2j1N3E
3HgPbuRGcUaMoOVYkk/aVR4Qa8l+8NLwrWKUd6VbnUObV3lhDZB2wgpxP/zL
+8x8tXRc3VR9g46ocVMbxEnqrFjgc3TPWW4hVzhdF/9PDYIn9qx4gqveksrD
ezXmJFomWJ5R+Xat9VYqr3gDTmF1Ag==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 323->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUjkOAjEMHFEgWp7AF+ABEV9YXhAkqFZCWgpE56ezC1vYk0lCpByO45mx
ncP1Mdw3AJ67eRny6zxN+X3ZLsYtj6fjuDj36wQszUv67d+zu8NqI8Vpwjb2
we08KM4Io+ByWBKfuEMeEHcVf6FF6OZce9oVb3iHNl7Qwhwg7gpWEdfRL/tZ
09XiEXWr9Zxz7P0xX9denRUW+J3os8qtyBWO18X/U4NCE2tWeAJX/SWVh9dq
jFPhMoHlMYJuN1p/JWjFB/dwdYI=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 324->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzydFnpwJmPHUpI6bmbG
y+n+HMYdgNdh2Yb8vs5z/tz2q/PI0+U8rcHjtoCSli39z9+3ucPmI9WrCL9w
DOa0Jt4Vwmi4DJbEJ+4qD4g7J95oEdo51552xVv9hxiv0sIcIG4Hq3nX0S/7
6enq8QT1bXhEL0NuEI5TZ4XF+myPPV6ZKwyvwjB30bzI/B1Nrl6Rf1NfED9b
oIvnrLBuY9GsVFrxBSSndb8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 325->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAQszigXnkCX4AHRHyhvCBI9FQJqT0gbnk6LRQ08ThJpKyT2I5n
jrdHP+wAzN0y9PF5mab4uu7XzT2O59O4Bg9bB1JYhvCdP2tzhm2PkPck9olj
MLNt4l0iDMdlsCQ+cWf/gDgrxJ0WoZ3/2tKueLN78PcVh8rDD9f9qaGrxlfM
Z0lXi6fir+MRuaxyg3AKPiss57/yt+HN/x2MfpXfggdOE2tWeAKX64F9Zzyu
maxVdHGdJdZtWq1WMq14AwFjdX4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 326->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPiPhCeUGQ6KkSUjkgbnk6LRTJGU+SWspiOx2P
pz7eHv2wA/Ds5q2Pr8s0xfd1vzj3OJ5P45I8rAtIYd7C7/zeTQyrj5CvJPzE
OZjTmvguEYarZbAcvuCV9QERK+QdF8Gde21xV3Wzd/DvVQ3V7x/X9dTgVavH
Pdb+s7orjiV93dyQFs3aIJyCzgrL6a/03aINTF0IHBOrzYvsX+EJXJ4H1p3x
eGYyq/DiOUvM21htVjKu+AC803U9
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 327->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPiPhCeUGQ6KkSUjkgbn46LRTJsSdOLWVxnMyM
HR9vj37YAXh289Tn12Wa8vu6X5x7Hs+ncQke1gFImqf0W797dYbVRyqHEF9s
DGrVRt6JwXBcCsvhE11FHiBnlbjTQrTbXFvaGW9xD/4+42D5/nFdTg1dEZ/N
Mfpntmcaa/V1fWNq0eSGwanUmWG5+rP6bqkNFC8IjjqL+oX+McOLYpX8C3wY
fmuBLttnYnUri3ql0IoP9sR0PQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 328->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbn46LRTJscdJI2Vx7IzH
45zur+65AzAe5qXL03UY8vu2X4xH7i/nfnEe1wlImpf0279ndYfVRiqnEFus
D2rXg7wTg+FyKSyHT3gVdYDcBX7HhXC3tba4s7xFHHw8y8Hq/eO6miJeDf1Z
P2t9ZmfGMdLX6WO0aOZGgLMBy2nC9N2iDQx/1t9AA8ep8pbqSuKjfyaGq1ic
IJfmZf+ZWN5q1P5KwRUf1sdzvw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 329->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREcsEFuOwBXgABFXKCcIEl1VQioLxM5Hp4UunPEkbaR8HCf2
y8Sn+7PrdwBeh2no8vs6jvlz28/GIw+X8zA7j0sHLE1D+s+/tdvDYiOV3YRt
7IObfRP3jGKEXC5WiC+4indA7FX8gUWws05r7CpvcQ7xPOtp6h4xsD6Sa0V/
9Z+tf1ZrxVjTN+hDWqzmRiXOhlhBE6XvFm1A/Op/KxoEpsZdqas4X6szI1bj
OJVcnovrzJjbtVatFKz4AgfQc4A=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 330->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KAjEMhYMLcesRvIIeoHiF8QQVdDUgjAtxl6M7o4OkLy9pob9pkq+v
OVwfw30jIs/dPAz1dZ6m+r5sl82tjqfjuBj3axfRMg/lN3/X5kzWvZS2K9kr
2sTMthE/hRgul4nl4hOu5h1CzgK7YyHsqFOPneVt7om/j3oq8wMG1IdydfRP
/zPiSt5vczJ9nT6gRVZj7A8inVkspwnTt6PN38/ys/8NNHBMiS/VldyP6kyB
VTFOkMtyYZ0pcpuW1UrDKh8433QA
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 331->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwjAQhR8uxK1H8Ap6gOAV6gki6KogtIvibo5uq0Xm500aSNP8vfny
Zk73V/fcARgP86er03UY6vu2XyaP2l/O/bJ5XDsgZf6U3/j9V2tY5yi2C5mL
34MadSP3xGmEWEor6BMu8w6QtWQ/sBB279MWO4trzsFyez3D4mPAxU60slxm
/DSfGVfj/Tom8zf4AxurVWMsB5nPTCt4wvzd8OZ/T/OT/GYeBKbGXeorOZ/V
mThW8TpJLM3l60w8t2qtWjGs+AC37nSA
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 332->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhR8uxK1H8Ap6gMEr1BOMoKuC0C6KuxzdVotkkpd0YP4nyTcv
Od1f3XMHYDzMQ1en6zDU922/bB61v5z75fK4dkDKPJTf/F2rM6x7lLYL2Yu9
g5p1I3ZifLhYypfzT7iaf4CcBfeOhXBbnbbYWdzmHcmB1VOYnWHIfEW5jPhp
PiOu5P86JtPX6WN0zmqM5SDSmflymjB9N7T522l+kt9IA8eU2FJdyfuozsSw
CvNDYmkuW2diuVXLaqVhxQeoq3T+
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 333->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFks0NwjAMhZ84IK6MwAowQMQKZYIgwakSUnuouHl0WqiQf57TSEmaOra/
PPt0f3XPHYDxMC9dna7DUN+3/XJ41P5y7hfjcZ2AlHkpv/37rf5hPaPYKeQs
3ga160H8xMUIudQw8Uk87SOKI7yN2AML4fY6bbGzvOYeLLePZ1h8DrjcSays
lhk/rWfG1Xi/zsn0Dfo4nVs9xmqQ6cxiBU2Yvhva/P00P6lvpkFgavhSXcn9
rM/EsQqLQ3JpLt9n4rnVaPWKYcUHyKt0gA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 334->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozACjBAxAplgiDBqxJS+6j4eXRaqNDlck4jOU5i+Xw5
+3R/dc+dmY2HeevydB2G/L7tl8sj95dzvwSPq5l5mrf0898zvNl6t1Sai7tz
zMDjEnlOGFUtWAW+wMMcBx7V30S84iJ4s05b3FVd9twD1hN5FmZUO8CKehnx
l/2MeDX+jzWVvpU+pHNrxlQPpM4BVqWJ0ndDm38e8mcceGvNi+yxwmvFgv8X
+Eb1EUfUQl48Z868YbVmpeBqHwl0dEE=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 335->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMHFyIW4/gFfQAD69QT1BBVwWhLsRdjm6rReYlk9fA+4ZMJpMc
ro/uvgHw3E1b17/O49i/L9v5ceuH03GYnftlAVamrfzO753+sLxR6mXibd4H
OtlEnDmMkIuswhd4HGPEI9Qm/IGL4O11WuOu8vrT98DryTyrBZc7wcp6mfGX
/cx4NernnErfoI/TuTVjqgdS5wQraKL0XdHmH8f8PQ79teZF9ljhtXxJ/RU+
XH7G4Rgg8PJzZp43WWtWKq74AO+OdAI=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 336->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAESuUCYJEX5WQ2gfil9Fpoaqc8yWJ5CSOlfP5
7PPj1Q8HAHO3bH1836Ypfu7H1XnG8XoZ1+BpMyCFZQv/83c3b9h8hNyS8BPH
YE67xL9EGC6XWRm+wLN/kuHhahNxx0XwZp1a3FVePrkHrKflmRkodwGr1MsS
f9nPEq9K/Tan0tfpQzrXZox7wPW3sJwmSt+GNvs/y59xzFttXmSPFV4tVqg/
wxeaSQ0Ax4t1lrlEDjlPu2Zf/opzQQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 337->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKAjEMHPwQfz2CV9ADFK+wnqCCfi0I64f416O7q4ukk2kaSF+hk8kk
h+tjuG8APHfzMuTXeZry+7JdLrc8no7jEtyvDpQ0L+m3f8/mDesdqfYi7oVj
MLs18a8QhstlrMIXePZPMTxcbSLuuAjerFOPu8rLO/eA9bQ8KwflbmC1etni
L/vZ4hXUb3MqfZ0+pHM0Y9wDrr+H5TRR+na0+f+z/BnHvEXzInus8KJYo/4K
X2gmNQAcL9bZ5TIWzUrFFR/xf3MC
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 338->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3PN1dXSSdTNtAms2GTiaT
Hq6P4b4B8NzNx5Bf52nK78t2SW55PB3HpbhfHbA0H+kXv9/uH9YcqXQTuXEN
LnoT94wwQi9nBb7A83fM8QiziXrgInizTj3uqi9H3gHr6XkWDupdwartssZf
7rPGqzG/76n0DfqQzq03xjvg+XtYQROlb0eb/z3Pn3FcvfVe5I4VXqsm5jfG
F5pJDYDAi3UOWjtrvZWCKz7PjnQC
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 339->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDotVMg5X5JITuo6OZ/P
Plwfw30D4LmbtyG/ztOU35ft4tzyeDqOS3C/GmBp3tLv/H67f1h9pNJM+MYx
uNMv8c4II+Ryq8AXeP6NOR6hNhEPXARv1qnHXeXlk3vAenqehYFyV7Bqvazx
l/2s8WrU73MqfYM+pHNrxrgHXH8PK2ii9O1o83/n+TOOi7fmRfZY4bVion5j
fKGZ1AAIvFjnoLVbrVnxd4APzFtzww==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 340->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDotVOhiX5JIjps6Pp/P
OVwfw30D4LmbtyG/ztOU35ftcrjl8XQcl+B+NcDSvKWf/37TP6xnpNJMnM3H
QJ6XyDOHEWrRKvAdprkcIx6hNxEPXCo1GKvHXdX13s/A68k8C4OrXcGqzbLG
X86zxqvRP9dU+gZ9xCybtRv997CCJkrfjjb/PObvcSjeei9yxgqvFRP9m8cX
mkkNgMDL6xy0ptV6K3wH+ADfzXOE
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 341->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDotVOhydpJITuo6OZ/P
Plwfw30D4LmbtyG/ztOU35ft4tzyeDqOS3C/GmBp3tLv/H7TP6w+UmkW+KYx
0MkreGeC4XLRKvAF0+SNEQ9XWxB3XCo5GKvHPcqrp/ZA9WSehUFyV7Bqvazx
D/tZ49Won3NG+jp9gl42czfq72E5TSJ9O9r83zF/xaF4a17C+iM8wY3mQXVX
PNUs1ABwvFRnpzWt1qzwHeADVNx0BA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 342->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqEVA6Im59OCz1MJraJ5Lipk5nx
crg+hvsGwHM3b0N9naepvi/b5XCr4+k4LsH9aoCVeSs///2mf1jPKK2ZczaN
gTwv550JRsdFq8EXTJM3Rjq63Jx4pyXgYKx/2j1e9doDrSfrbAzCHWBFvYz0
u/2MdCX5M6dX364+Ti9T7iR/5e1mKupHwuviQfQrDsWzeTHREuIJrjcPmn+D
79TMrQHQ6dI6KxevbFb4DvAB64l0RQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 343->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQHVxItx7BK+gBgleoJ4hgVwWhLsTdHN1Wi7y8+TQwmSRD3nvz
Od4e/bATkWc3b319Xaapvq/75XKv4/k0LsHDaiJa5q38/PcMb7LepbSmzl05
JuBxOf+UMAwXrAafMJX+KOgwuTlxoyXgQKwt7R4ve+4B1xN1NibEHWBFvYz0
u/2MdCX5I6dXX1Mfp5cpd5I/85qZivqR8Lp4QvoZB+LZvDBmiEe43jxw/n9P
WgwO4jlnrjNz4cpmpc3xA/oHdEM=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 344->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPwQfz2CV9ADLF6hnqCC/SoI9UP826PbqpTsZBID2exuYGby
OFzv3bAB8NjNR9c/z9PUvy7b5XHrx9NxXJL7nwO1zEf5xs/d/K1WWq/iXTkH
whBYVbjkMua0AU5XUwfEX5B3WgIOi/VPu+wpRZ4B99PqbBzEHWCBuRO+cJ6R
rqR+y6n66/ojZplyJ/Uzr9upaB4Jr8QD6Wcck8/2hTFDPMJV+8D1r5G0OByL
J+7cZ+aylu1KW+Mb5R10BA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 345->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPwQfz2CV9ADLF6hnmAF/SoI7Ufxb49uq1J2J5M0kH0FZiaT
Pd1f3XMHYDzMS5en6zDk922/XB65v5z7pXj8J1DSvKTf/j1Xb2ukNou4F66B
MARWESm5qjDaAKOr6QPizakbLQ5HjbWlXXpKO8+A/VTYIA0RFpg74HPnGeja
0uj5a/wRswy5g/6Z1/wpbx4Br8SreNbgOpy+A00uHuGq/2B0kT72THogzuwz
c9UR/ZW2xw/mlnSC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 346->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPwQfz2CV9ADLF6hnqCCfhWE+iH+5ei2KmV3MkkD2Vd2M5PJ
Hq6P7r4B8NxNQ9e/zuPYvy/beXPrh9NxmIP7vwNWpqH85u+6OlustG5ibxwD
5RC5TLjEqsxxAxyvpg6IsyDuuAQYda417lJTmk28cX1RDorDvzO6n+mf9jPh
tcYx0tfpI3qZYif1M677U1E/ElyZr8JZjOMI6k44hfkor9La8SJ+rJnUQOCy
zqx1bdlfaWv8AClqc8E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 347->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQNz+dliVKxlODJWdzPJ6M
sztfu34F4LaZhi7fj+OYH6f1vLnk4bAf5uD244ClaUjv+bWuzoql1k3sjWMg
DIFlwmWtyhw3aLxyFy1Onc9xxyWo8c3/xV1qSrOJHNcX5aA4fJ7R/Uj/sJ8B
r0iDSN+lXv3zx7gHTkv4PInN/QjqSryqTjGOY+HdAadFPMJVWjtexI81kxqI
uqwza11b9FfaNz4BHZd0wQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 348->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDigXnkCX4AHRHyhvCBIcKqE1B4QNz+dlqVKxpPBkpO6jseT
cfaXe3/bmNnUzUufH6dxzM/zdgmueTgehiW5+7qZp3lJn/39XfxbLdXuJHbM
GWAQLCdOexUWuBnHq/o37uaQD1xEj1/9P+5UU9id1IS5MDfIW6xzOK/0l/MU
vJQGSt+gD+is3hjOIGhpsY5i4zxEX4pX9FkN89a4t+DUxBPzrOKSF/BDzagG
pC/qjFqXpt5KfccXe/B0gA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 349->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPyQ/noEr6AHWLxCPcEK9qsg1A/xL0e3VSm7s5NAA9lXSGYy
2ePt0Q87AM9uXvr8ukxTfl/3y+Wex/NpXIKHvwOW5iX99u+5eFst1W7ibhwD
1RC1TLjEKqzhBl2vwnd6M4o3XAIMlaO4S01pN5HTzEU5KA7NDYwdzW3De4hF
mErfRh/SWf4Fkaf6Z1xVR87Dm6E3jwJnNY7D6Tvg5NYL5lndS17EjzWTGghc
1pm1Li36K3WPHx7Yc78=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 350->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS6kW4/gFfQAg1eoJxjBrgpCXYi7HN1WpWReXtJA5hfy8vIy
x9ujH3Yi8uzmpa+vyzTV93W/XO51PJ/GJXj4u4iWeSm//Xs2b6uV1pXcFWMC
GARLidNaxhw34XhN/YCfQtxxSWogZsSdagq7kpwtbJvreoo0JfpHZ6dXwiub
X6av00c4H3zDPNY/1o36dvOIZhjNw9RZDeMS9J1wCvGSeTZ3ywv4oWZUA1IX
dUatrWV/pe3xAx5lcv4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 351->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOgkAMbPgw/nIEr6AH2HgFPMGayBeJCX4Y/np0QA12p9OlyT7Lzkyn
nO7Prm9E5HVcpi6/r+OYp9thPTzycDkPa7L9DRFNy5S+62dv7rZI5VByVswJ
YBAsJYNymXDahOMV/IE+hbzTUuFAzEg79RRWJW/2sO1bV1PkKfE/2ju/KrrY
t8jJ/HUYwvXgHfrK6kfeqG7Xj6iHUT8MzxaYl6DuqF6p4FX6WZytLtCHnlEP
CC/6jF7b2PtX/jXOPl5yfg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 352->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOwjAMs/hA++UIXAEOUHGFcYIiwdckpPGB+MvR2QBVneOUVUpfWe3Y
2f5y728bAI9umvr8PI1jfp238+Gah+NhmJO7XwCWpil918++uisjLcPE2TgH
whBYJkJyVcPVBo234A/qM8q7WhocjBnVLj2l1cSbf9j1W6cp8lT4H+2dXyu+
kXU2/HUY0Fx8x74q/cwb6Xb9iHoY9aPiKYPzCHRHetHAa/Qz8p3rY8+kBwJb
ees8FBzyfyoa3xzacb0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 353->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMi/hA/HIErgAHqLjCOEGR4GsS0vYx8ZejswGqOsfuKqWvrHbs
7HR/dc+dmY2HeerydB2G/L7tl8Mj95dzvySP/zDzNE/pt3731V0ZaR1Ozo45
AwyC5SQoVzVCbcbxVvyiPod8qKXBgZiqduoprE7ebGHXb4Mm5SnxX+2DXxvf
yDob/gYe41x4h74y/cirdId+qB6qflQ8ZWDehG6l1xp4jX4q37E+9Ix6QLCZ
t8FDwkH/p6LxAznpcj0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 354->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADBK9QTxBBvwpC+1H826PbqpRkdyYNbJLNY2Zn
ktP91T13AMbD3HV5ug5Dft/2S/LI/eXcL5vHfwCW5i79xu+8WFtbqsNIbn4P
DoNgGQnKVbRQGzhexS/qM7cfamlweExVO/XUjUbubGGXd4Mm5SnxX82DXxtn
ZJ0NfwMPOJdf874y/Z5X6Q7vod6Q5ah5yhzuDNWt9KKB13hP5buvT2mo8Ag2
8zZ4SDjof1o1fgDp33H+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 355->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtDggrjyBL8ADIr5QXhAkOFVCag8VNz+dliLkjMdupCxO4vHM
JKf7q3vuRGQ8zENXp+sw1PdtvwSP2l/O/XJ4/HURLfNQ1vm7Nnv/VtquJFY8
E8AgWEo6rWVacwcwGxxbP+CncO64EN5Ma8adegqzkpwtbJvrNEWeEv+jtfNr
407IM/HX1RFeC/fQV6Yf60a63XtEb8hiaevYWOAO1R3plQQvec/Id+QXaUjx
MIfEtrH/gTkrpw/yPHJ8
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 356->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHigfhmBFWCAiBXKBEGir0pI7QPx8+i0gJBj37mWnMR1cj6f
e7w9+mEnInO3LH19Xqapvq77NbjX8Xwa1+Th5yJalqV898/ZfPtbaV1BrD4n
DgNgKXBYy1hzx2E2OLY+4acuH7gA3qjXjDvU1O0K3mxh27ehJ6Yp0J+dg14b
dyjPRN9Qx+mc6W51Rf37uqzvMA82QxRLW8fG4u7Q/4twonjJPJnunh/rIcXz
b0BsDc4LzUreZ/ByvQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 357->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDpt4eGez42w5LiuE/ty
l8P10d03AJ67cenq6zwM9X3ZTsmt9qdjPxX3PwesjEv5xvnb/ZutRDeRG9fg
ojdxzqhHmOVssYd6Lvr4+Qk+o3rAInArnGvYU05dNHEm6KIcVEc8F/hKdFQY
/tmT4lzhN8whnjPemVd1f56b3Tvo0dCW5/k5PgftSd9Xgonrmf6tWuBXcNbi
IGCEzr1JvZRW+AAQLnK7
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 358->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qAxS/UF6ygp4JQD+ItT7etIulMptWFbJpmNzOZ
7O58a64rM7tv+q2pj2PX1edpPQSX2h727ZDcfszMS7+Vtx+/w79xFTZPYsec
BR9Xcs+hBmGFNTkDNSd1Ir7g55AnLgnvjOccd6lp8J7coblkZpA3vkd6iTlm
HP45I3nO6Es4oLPSHXXN+kdc1TfNY2G2iBdxYmxwRr4vwQnzav6/5mI91cMS
XqYtaQj9yvf07fEF4s5yeg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 359->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMtDggrjyBL8ADIr5QXhAkOFVCKgfEzU+nLYvcGU8rLCVp6sSz
OLvzrbmuzOy+6aemPo5dV5+n9bC51Pawb4fk9jPMvPRTea/jd/g3RuHhyd4x
Z2GNkdxzqEFYISZnoOakTsQX/BzyxCXhnfGc4y49Dasnd6gv2TDIG98jv0Qf
Mw7/nJE8Z/wlHPBZ+Y6+ZvoRV+mmfiz0FvEizjeovgndqBd1CE6qn3O5WE9p
WMLLvCUPQa98Tz+NL3ndcvo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 360->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUUEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbnm5bFdJJZouB3XSb3cxk
5nC9t90GwGM3bm15noehvC7b6XAr/enYT8X9dwHWjFvzyfO3+zdHE5clZ+Ma
XPaRvDPqEbBcLO5Qz0Ufjy/4GdUDl4R3xrPGXWrqsiVvgi/ZAtUR3wW9hI8Z
h3/uSJ4VfQMO6ax0Z12z+RlXzR38WPGW8TzOL0J/iLl5Xp5DcFJ+1mq+n5ph
DU9qC+oF4VfmFd6a3XN6
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 361->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQtzydtixyxp4gLDlLHXvG
4+7O165fAbhtpqXL9+M45sdpPV8ueTjshzm4fTtQ0rSk176czbfFkvcS3AvH
YHZrQV6hGg7LWPWGalZ1LL7gVyjuuAS8I54t7lJTs5cgx80lclAcPs/pJeYY
cfjnjeTZ0Nfh0NtQd4iz0FnNy2lC2qjZMp7F+ZirD9E39cdzVZzUPFuxUF/q
4Ree1BZUCzVG+D99e3wCH31zuw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 362->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkKAkEMDB7Eq0/wC/qAxi+ML2hBTwPCeBBvebqzKGQqVQ0G0umebJXK
HK6P7r4xs+duPLr6Og9DfV+20+NW+9Oxn5z7r5p5GY+y2Pkevs1Ssjp5O/os
2Cgkz6FG6hVkFQM1V3Vif4HPwZ+wENwMZwu75DRYJzlpL0wN/JbzEl9ijwzD
PzESZ4Pf1AdiKe8m7oJnta/ECXCjdov9Yp+fpPom5ob5cK/SL/bZ8lF+YYZm
PcxhcwRh/wfWWHI/jH10Ow==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 363->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMtDggrjyBL8ADKr5QXhAkeqqEVA6Im59OWxa545kILCVO4m08
zu58bbuVmd0249aW+3EYyuO0ni6X0h/2/WTcvpeZN+PWvPR8Dm+zNHk5uTva
LOgoJM4hR6oVZOEDORd5Yn2Bz8GesBDcDGcNu+Q0aCcxaS5sGdgtxzEu2BwZ
hn98JM4Kv6kO+FLeTZwFz2peiA+5UbPFerHOR1J+E31DfzhXaUfsP9gov9BD
NR/GqP8F/cr/9O3xCefLc/w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 364->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMHHFAXHkCX4AHRHyhvCBI9FQJqRwQNz+dtiwy43GBSI6TeBuP
szmem3YB4LIatqZe931fb4fleDnVbrftRuP6KYCVYSsPPZ3d27RKFBN3Yxuc
9kvEGeXw8UY5gg90vo/6CT4je8AicAecydtXTp02ERPmogRkR4xTXKg5Kgz/
+KQ4Z/gNdchX8o7knPCczYvxMTfZbLmer/NaIT+Svqk/nmtqZ+w/2CS/1MNs
Po7J/hf1m/6nd4938WVzvQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 365->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMDH6Ivx7BK+gBFq9QT7CCfhWE+iH+5ei2VUuczFRdyL6yO5lM
sjlemvPCzK6rfmrqbd919X5YDodTbXfbdnCuX2bmpZ/Kcx334W4cJZuTc8SZ
RtzHO8BxwIixHTDYG+Th0RdxymduDn40xjvxFHdfNQ2rkz+pLswM/CY0xZik
jozDP28kzxl9ad8w3kTLtBc6q3qlHgJtVG0xXozzHgnfRN6QH9ZV+pH7Dz6q
L+Qwi4d/VH9BvrKfphwf1bNzPQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 366->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMtDggrjyBL8ADon6hfUGQ6KkSUjmg3vz0LqDIjMcBIjlx4mQy
Hvt0vbf9TkQeh2Vq87MZxzx1+3Vzy8PlPKzB49tENC1Teq2bb862kbwp2Vuc
MqxvzwBHAcP+rYDB7iAPtTGLkz5zU4ijMd6OZ3D2VVOzKnnj6sJMIC6Bpvgn
qSPj8M+dkGdFX9o3jDfR0vmBzlG9XA9VNIryLgP6xeFLkDfkh3UN48j9hxjV
F3Ko4uGbqL8g37CfSo4zeuRy/g==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 367->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMtDggrjyBL8ADon6hfUGQ6KkSUjmg3vz0LqDIjMcBIjmbk8nM
xKfrve13IvI4LF2bn8045qnbr4tbHi7nYU0e3yGiaenSa9zmZm9ryYeStcUp
zc7tHuAoYNi3FTDYGeShNmdx0qc2hTwG4+14Bp589dSMSu64f2EhkJfAU3yT
cGYc/jlT5Rn4S+uG8SZeunngM+NFa6jiUaS7NKgXhy+BbtCH/xrmkfsPOeov
aKji4Z2ovkBvWE9F4wxh9HK9
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 368->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMtHpAvfYJfAEeEPGF9gVBglMlpPaAuPnpXUDUjMcBIjmbncmM
7f351l4rERnreWrz/TQM+dHtlsMl98dDvzibl4lomqf0XNe9uVtH8qbkbHHe
w+7tHeAoYNi/FTBYDPJQ67M46VObgh+N8XY8g5x8zalZlbxxdWEm4Jcgp/gn
4cw4/BNT5Bnkl/YN4x3lpKDfYUW1IvWgNWRn2eJtvzh8CXSDPqxr6EfuP/ho
fkFDEQ/fRP0FeqMabBony2NyfA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 369->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtHpAXPsEvgAPiPhCeUGQ4FQJqT1UvfnpXUDUjMcpkZzNyWTG
k9P91TwrEemPc9fk4dp1ebwdlsUjt5dzuyTrT4homrv0Hte52Vtb8qFkbXG+
zc7tHuAoYNi3FTDYGeShNmdx0q82hTwG4+14BjXZrakZldxxvrAQyEtQU3yT
cGYc9vaL/gW1oHUGno539HZBv8OKvCJ+UA/ZWrbz9r84fAl0gz70Ncwj9z9y
tL6goYiHd6L/BXojDzaNE/Rycvw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 370->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAQG3FAXHkCX4AHRHyhvCBIcKqE1B4qbnk6bUHUeDwpkbLOxLE9
OVwfzX1jZv1uHJo8nLsuPy/baXPL7enYTsH9p5uVNA7pPc9rOJsbzpDLe8T5
NlxbjFMIA98shKFymEfBGOKkX22F4twVb+bpcJUvNU/N47GfChvvOk0rXqg6
Kg5r59X6BV5In4mn4x29XdHvsAKtqh6yhmpvSz7+F4dvgW7Sx3UN48z9j5j0
lzRU8fhO9L9Ib1SDReMLgp5zPQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 371->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDggrjyBL8ADon6hfUGQ4FQJqRxQb356FxC1xmNDpMRJ7EzG
Y5+uj/a+E5HnYV7a+mqGoY7dfjncan8594vz+JkiWualvO26N3frsNbE4tni
fIfdS4yjgGH/VMBgMchDrc/iAJ6CHyfjjTwVLNUl01Q8HurJsO1bLR4r04LV
kXH4dZ/WL9CC6gw8He/o7yR/hxXkyupBa8jOssW7voKYsL8CTqkfuf/ho/pC
Dikevon6C/KNarDlOAGi3HL+
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 372->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS6kW4/gFfQAxSvUE4xgVwWhLsRdjm5bxYaX94YOZJJp0peX
z/H26PqdmT2b6erK6zKO5X3dz497Gc6nYXYefmLm7XS1X73Y4dtyog6x+I44
/xNt0zgOGDGnAwaLQR4efREH8Bz8KIw38nTQtC+1nhrvQ5oLEwO/wEo5CWe0
WV2KF52f6AXtM/BMvFXuSv0JS9TK5kFnyN62xqe9ghi5X4JT1Y/cN/hof6GG
Kh7+o/YL6lUzWGv8AB36c34=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 373->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBxS/UF6xgTwWhHsRbnm5bxQ6TydKFbLJNOjuZ
7PH26PqdmT2baevK6zKO5X3dz4d7Gc6nYU4efmbm7bS1X7/E8G1Z6KGWz4jz
XxhbjuOEgXc6Yaga5uGYQxzCc8qzKd7M08lLXWqamtYhzEWZUT7BCncKzhyr
vjJecn6JFlJn4hl4Z3dX+g9YSa9qHnKG6mxrfXhXVJO+r4RTNc/cN+SkvtiD
xX/UDKW2qB31m81g7fEDADNzPw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 374->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMizigXXkCX4AHTHxhvKBIcJqEtB0QtzydbSAWHLtUaps0lWs7
3V/u3W1jZmMzLV15nIahPM/bObmW/njo5+LuM828nZb2vS9xOFtG3MNdzCPO
d8TYNI4DRnzTAeOHG8GLOhIO4DnUcTLeyNNhp77UPDXuQ+oLmwZ1gZXeJJwx
ZroUL9o/4QX1GXgm3urtiv6EJbSyftAestzW++lfwR35vwSnah25s3Oig3qC
408PqbfRO9CrerBqfAHnC3LB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 375->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMDC6kW4/gFfQAxSvUEzxBVwWhXYi7HN22io2TmeeD902YZGbe
/nLvbhszG5tp6crjNAzled7Ol2vpj4d+Du4+08zbaWnf+3IOb8uIe8jFe8T5
jng2jeOAEWs6YPz0RvAij4QDeA5xnKxv7NNhp7rUNDWuQ/KFTYO4wEJNmY94
ZrxUX7SW0ILqDJ4lD1XtCv+EJbgyP2Qu4tman/4V5Mj/JXqqxoWfWDPxYJrg
+OMh1TZqB3yVByvHF9yucoA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 376->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUfLgQtx7BK+gBileoJ4igq4JQF+IuR7etouO8mTaQJukL8+aT
3fnWXlcRcd8Mn7Y8jn1fnqf1eLiU7rDvxuL2MyNqM3ya9zrt4d80cIW7fEac
78B9eJxKGNizEsYfN4GHOhIO4VWq81S8mWelVfqieAM/5UPKRc2gusFiT1WO
vFe6HC/Zy3ghfabMUoau94z+hGW0Yg5LHiU8yDG9K7pj35fhNFs3eXLPpEN5
wmMhQ+ktekd6XQY/jS8ce3JB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 377->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkU0KwlAMhIMLcesRvIIeoHiFeoIKuioIdSHu3tFt61/83gwG8vJeUyaZ
mc3x0p4XEXFdjUfb3fbD0N0Py+lx6vrdtp+a61dGlGY8mmed7+nbHLmmf/nO
OJ/I9/A4BRh5ZgHGz24CL/OocIBX0GeqvblnQZW6qL3TfkqHyheVgb7BoqbK
R94VL7eXnGW0kDrDs8pDNzuAQ53NXlITVuMr9c5z3lHhh+ENfvTV9o2fnFnx
UJow/ngotc3aga/z4MvxAfl7csE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 378->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwkAMRIMf4q9H8Ap6gOIV6gkq6FdBqB/i3x7dtmqJb2cwsJvdpkwy
M7s739rrKiLum3Fru8dxGLrnaT1dLl1/2PdTcftZEaUZt+ad53P6NkfO6V/e
M84S+RwepwAj9yzA+JlN4GUeFQ7wCupcam7OWZClLmruNJ/SofJFrUDdYFFT
5SPPipebS/YyWkid4VnloesdwKHOZi6pCbPxlXrnPt+o8MPwBj/6auvGT/as
eChNGH88lNpm7cDXvqeF4wsCinNB
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 379->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFksENwjAMRS0OiCsjsAIMULFCmSBIcKqEVA6IW0anLbRyXr6LJSdOE3/7
f/dwfbT3jZk9d8PSpte579P7sh0Pt9Sdjt14uf+5WW6GpfnuU+y+TeZ395Zn
j7OYjy3GycDwNTP6KHoTeFnksNZsxTvkFzzEG8XB4KGm0EfpUM1FueE+wKKm
ao6MFa+oL1kr0GINw8+Kusk8AyZ1DvqSmnAP5kq9fZ3ZKnyr+WfUYs7qfTBP
1qx4KE1of2YotfXagW/4Py0cPyPicwA=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 380->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMPPFA/TICK8AAFSuUCYJEX5WQ2gfi59FpC62cyzmWnDhNfLbv
en68uv4AYGrmpUvv2zimz/24HJ5puF6G5fL0d8DaeWl/+xq7b6v53b3ls8fZ
zceIcYwwfE2jPrLeBJ6JHK61WfaO8rM5xBs1A8hDTokfxUOhi3LQfYDFnCod
OVZzRX3JWgEXNQyvFfMm80CYzHPQl+SE90BX5tvX2azARzm/US3Oqd4HenLN
mtbFDCJHaSi59dwxJ9H/tM/4BTONcr8=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 381->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UlsOwjAMi/iY+OUIXGEcYOIK4wRFYl+TkMYH4i9HZ29lrt1IXdpltR1n
1+e77U5m9jmPjzZ978OQfo9qOrxSf6v7qXhZl5k346NZ8rwP7+aIOXyL54iz
R9ybxnHAiJwOOg7aCJ6TO8i1hUMdF9ONOh0y9YXpJj1l/MwX8OhQF1joKZsj
7llfShflEl6UMHAWrB9Wlz4LXdQTzGKu6Hfk2SLDt7x/By68U6yLeSJnadZZ
D+QOmyH1NnqHnqj/ae/xD/Cccz8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 382->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkkOg0AMizhUXHlCv9A+APUL9AVTqZyQKsGh4pans7Sg4LGJNGSGMLbj
cH19mrYws6GcH036Pvo+jc/Lcnin7n7rlmL1X2Zez4/6l9d9eLdGzOFbPEec
PeLeNI4DRuR00HHQRvCc3EGuLRzquJhu1OmQqS9MN+kp42e+gEeHusBCT9kc
cc/6Urool/CCYohZsH5YXfosdFFPMIu5ot+RZ4sM3/L+HbjwzmldzBM5z2ad
9UDusBlSb6N36In6n/YeJ3NZcwA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 383->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUkOwjAMHPWAuPYJfAEeUPGF9gVBoqdKSOWAuPnpXaDImYyppcRJHI/H
49Pt0fYVgOdx3tr0uo5jeneH5XJPw+U8LMH6uwBr5q35+PXs3lbz3v3lu8f5
mT8jxjHC8DWNeGTcBJ6JHK61mVGcl+LNPI281EXxhsZgLQpdSKMsDo3Fmqo5
8ln1FfGStQItJEYwC9WPioc6B7ykJuyDubLevs5mBT7K/o1qcc7feDBPrrk3
i+zvTg44R/VBONHs8h4n45hyvw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 384->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfELU9nGwilxt6o1KZtUsdx
ujvf2usKwH0zLG15HPu+PE/r8XAp3WHfjc7tZwLRDEvzttM+3U0j2xTL54zz
HXkPjxOEkXMG8ai4CTzHXfEL8vNUvJlnkJV8FG9oDNbiRxfSiGv+R1PVR95z
XXO8ZC6jhcxjeqHqUX6rs+ElNWFr+sp6V/EgDnQn/5fhNOs3/eScS72oYhfe
gN+oOgjH9a6u8QWVenG/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 385->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMRK0uqm45AlcoB6i4QjlBkOiqElK7QOx89H5A4AwzpZESJ3Fk
P49zvN7brjCzsZqXNj3Ow5Cel3I53FJ/qvvFeXhPM2/mpXnZdR/u1hFteIvn
GOcz4t50HIcYMacDR8ZG4il2xufgx8m4kdPBUh7GbTwGavGjC2iENe/RlPUR
91jXFhfNJbSgeUQvWD3ML3UWXFQTtKKvqHf23oAB7uj/EkybftFPzLn3z2Tj
Tw+ptlE7y/3qP31rnABxy3GA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 386->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT8uxK1H8Ap6gOIV6gki6Kog1IW4m6PbVpHJ9//aQDJJJsy8
/Jnd+dZeVwDum2Fpy+PY9+V5Wo+HS+kO+250bj8TiGZYmred9uluGtmmt3zO
cb4j7+HjBMXIOYM4KjYRz7ErviA/T8XNnEFW8ihu6BisxY8upBH/eYmmqo68
53/NcclcRguZx9RC/Uf5rc6GS2rC1tSV9a7egxjoTvaXYZr1m3pyzqU9U40/
NZTaZu1Q+2U/ZZ3wAm6YcUE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 387->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfELU9nGwilxh6r1CZtKsdx
sjvf2usKwH0zHG15HPu+PE/r8XIp3WHfjcHtZwPRDEfztpOf3qaVbfrL94zz
XdmHxwnCyDmDeFTcBJ7jrvgFxXkr3swzyEo+ijc0BmvxowtpxDUv0VT1kX2u
a46XzGW0kBimF6oeFbc6G15SE7amr6x39R/Egd7kfBlOs3HTT865dGaq9aeH
UtusHeq4nKesE151p3HB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 388->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT8upFuP4BX0AMUr1BNEsKuC0C7EXY5uW0Um3/+NgWSSTJh5
+TP7y63rNwCmZl66dD+NY3qct8vhmobjYVicu/cEcjsv7cuu+3C3jmjDWz7H
OJ8R9/BxMsWIOTNxFGwinmNXfJn8PBU3c2aykkdxQ8dgLb50IY34z/9o6vLa
ela4ZC6jhYxhaqH+o/xWZ8MlNWFr6sp6F+9BDHQn+8sw/fQ7dsdV6ZliVGoo
tY0cKP2yn6JOeAKGM3IC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 389->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT8upFuP4BX0AMUr1BNE0FVBqAtxl6PbVpHJ9/+0gWSSTJh5
+TP7y727bQA8mnHp0vM0DOl13k6Ha+qPh35y7r4TyO24tB8778PdPKINb/kc
4/xG3MPHyRQj5szEUbCJeI5d8WXy81TczJnJSh7FDR2DtfjThTTiP6/R1OW1
9VzgkrmMFjKGqYX6j/JbnQ2X1IStqSvrXbwHMdCd7C/DVPU79hpXpWeKsVBD
qW3kQOmX/RR1whtfkHHD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 390->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX4tYjeAU9QPEK9QQRdFUQ6kLczdFtq8jP93/bQDJJZph5
+ZPd+dZeVxFx3wxLWx7Hvi/P03o8XEp32Hejc/uZEdkMS/O20x7upoEWYvmM
eb4D9+HzJOXAmkkcFZvI59gVX5Kfp+JmziQreRR36BysxY8upBG/eYmmrq7t
5wyXrGW0kDlML9R7lN/qbLikJmxNX1nvKj6Ige7k/zJMf/2OXXBxHmSpYvkt
podSW+Tg2uo/oU7xArCQckM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 391->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHmLjCOEGR4GsS0vhA/OXobOOh1NhbpDZtkzqu
09351l5XAO6bYWrL49j35Xlaj5tL6Q77bgxuPwOIZpiat5/W6Wyy7FMu7zPO
z/IaHicII9cM4lFxE3gh7nCtrwXFeSjezDPIS10Ub2gM1uJPF9KoikNjsaau
ru3nAi9Zy2ghMUwv1HtU3OpseElN2Ju+st5VPogDncn/ZTjNxh13wYtxMpcq
l99ieii1zTy4tvpPWSe8AIeucsM=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 392->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHmLjCOEGR4GsS0vhA/OXobOOh1NhbpDZtkzqu
09351l5XAO6bYWrL49j35Xlaj5tL6Q77bgxuPwOIZpiat5/W6Wyy7FMu7zPO
z/IaHicII9cM4lFxE3gh7nCtrwXFeSjezDPIS10Ub2gM1uJPF9KoikNjsaau
ru3nAi9Zy2ghMUwv1HtU3OpseElN2Ju+st5VPogDncn/ZTjNxh13wSs4D+YN
/BbTQ6kt4Ve11X/KOuEFYwNyhA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 393->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAQs3pAXPsEvgAPqPhCeUGQ4FQJqRxQb/P0LiyaOJ4wUjJJJ7Ed
Tw/XR39vADz3y9Sn13kc03TZrZtbGk7HYS22nwFYt0zdO29r920Ln91Z3nuc
X/g1NA4PELeRjkxbBY+1K31G9UKL0M06jbL0RemGxmAvCl/Io6wOjcWeRrxh
P//oklyBFxIj6IV6j6qHPge6pCecg76y357nGwU+yvcbcfGdaj3SXtMltGRn
3Z1aD6W3hJ9xq//J+4QZATBzhA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 394->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUcENwjAMPPFA/TICK8AAFSuUCYJEX5WQygPx8+i0BSrnck4tJU5i53w+
H2+Prt8BeDbT1qXXZRzT+7qfL/c0nE/DHDz8FmDttLVfv5zd22Leu1y+e5zV
/BkahxeothGPjFsFj7krfkbxgovgzTyNvNRF8YbGYC0KXUijLA6NxZpGdcN5
bvCStQItahg8C9WPioc6B7ykJuyDubLevs7fCnyU/RvV4j/VeMRd8CryEPTA
f4IZSm0JP9MkmvPa4wctc3ND
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 395->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAvfIEvgAPqPhCeUGQ4FQJqT0gbn46bVnkjMfFUuKkjsfj
cfeXe3fbABibaevK4zQM5Xnezpdr6Y+Hfg7uPguwdtrat1/O7tti3ru3fPc4
P/NnaBxeoNpGPCpuK3jMXfEzigcugjfzNPJSF8UbGoO1CLqQRlUcGos1zeqm
8/zDS9ZKtMjy1CxUPyqe6pzwkpqwT+bKevs6Xwv4iL0a1eKc1XjGXfAK75D0
wDnJDKW2hF9pov4nrxNeLIJzww==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 396->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkssNwjAQREc5IK4pgRaggIgWQgVGglMkpHBAubn0fPhoM54Jluy1s874
ebyH66O9VwCe+2lo0+vc92m47ObFLXWnYzcn608HcjMNzTsu8/BtaTGGvbyO
Or8W59A63EFnZ+JYsW3oMbviy5QvWAQ3c2aK0hfFDa3BXhS+kEerPLQWe+rO
te/5h0ueZbxw/6m3UPdReeuz4ZKecDTvyn5/W1FXtMfWl2HazDt25lL74O9Q
6DjfQF6QfszLeoo+YQTecHOE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 397->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOMGQ4GsS0vhA/PXobOOh1LVLpbZpkzqO
09351l1XAO6baen6x3Ec++dpPR8u/XDYD7Nz+5lATtOS3vtih7tlxD3E8jni
/Ea0oXF4gnJn4lFwa+Ax94JfxEL91mFwrRJX6aJ4Q2OwFpUupFHhh8ZiTV1e
288/vGQuo4V7p3qh6lF+q7PhJTURvVZ9Zb2/IyeyKab5vwSnpt9xZ14qDr6G
CsfpBtKC8KNf/qeoE16TIHQC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 398->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUsOwjAMREcsEFuO0CvAASKuUE6QSnRVCaksELscnf6onMk4WEqT1Ml4
8tx0z7Y/AHidpk8b37dxjJ/7cd484nC9DHPyvA0ghekT1nlZm39L2Nmc5b3V
2cOuoXV4gGon8pF5q+ix98yf1UJ519Pgt0pdxUX5htZgFgUXYpTlobWYqVfX
7ecfX7KWw8K7p3rheWSuLmfHl2Qieq36yrx/kQKt6Qy/NVEt6bGSr3neQ52D
/4ZCx+MGYkH6Ni/7aTnhC0TddIA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 399->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUVsOwjAMs/hA/HIErgAHqHaF7QRFgq9JSOMD7a9H3wOEEs8pVGqbNq1j
O6fro73vADwP89LmVzMMeez2y+GW+8u5X5LHzwRKmpf03tfY3K3D7uYtny3O
d9gYGocnqHYhHo5bBY+5O34WC9u/EQZrlbjKF8UbGoO92PhCHrk8NBZ7GtUN
+/mDl6wVeBH9U72IOLKvoc8BL+mJ6HVNB/eyJIrpDWstVEtyrOSrnEF3FEca
/tEuvbU84POyn86zCbh5dD8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 400->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAFSuUCYJEX5WQygPxy+i0BSH7ck4bKbETJ+fz
Ocfbo+t3AJ7NtHTpdRnH9L7u5809DefTMAcPvwnkdlrar118c7YMa81d3luc
/7A+NA5PUO5MPBy3Ch5zd/wsFsq3DoPyMM8CV+mieENjsBaFLqSRi0NjsaZR
3rCfK7xkrkCL6J3qRcSRdQ11DnhJTdiu1MG9tP+lwEdZa6ZckmMlXuUMOiM/
qmFL7VJbywM+LvvpNPsA44t0AA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 401->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4ZXTagpB9OadESpzE8fnO
zuF67/oNgMduWrr8PI9jfl228+GWh9NxmJ377wRKmpb0scve3C3DWvOWzxbn
N+weGocnKHchHo5bA0/iJB9fyF9xEbwZv8JVdVK8oTFYQ6WHtJUgT6sWUd6w
nyu8ZK7gj0RxqhcRR/ue412dA16yJmxXdHAv7X+p8FFrLZRLcmz4m5xBd7SP
NPyjXdbW8oD3y366mr0BOSJzvw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 402->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+5ei2VWQzmd0ayHOT2ZnJ
Hq73rt8AeOymocvP8zjm12U7b255OB2HObj/dqCkaUifeVmbs6XZ2dzlvcX5
NbuGxuEOyl2IR8UtwJM4qX5fKN5wEbwZv8FVPine0BisodFD2oqTJ/JC/Rlr
Yl0RL5nLqRHvnfU7yg+6z+8rnx1e0hOeV3TwXzJ/0B23vpz6WYuHnEFntPY0
/KNdemt5oI7Leqo8ewMD4nQA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 403->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAvfIEvgAPqPqF9gVBoqdKSOWAesvTu4CQPbHdRkrsxMl4
PPH18Wr7E4B3tSxt+jTjmKbuvG6eabjfhjV4+U0g18tSf+3mi7NtSCvu8l7i
/If0YePwBOXOxENxC/CYu+InsVC+VRiUh3kWuJZOFm/YGKxFoQtplJ08kabW
n3FNXFfEy8zl9Ij3Tuod5Qfd5/dKZ4eXqQnbnTr4L5k/6I7bX07/7MVDzqAz
8r0ajtRuait5QMfNflKazR08c8E=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 404->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAMHHoovfYJ/UL7gJAvJC9woT0FCskh5OanZ2kp0liSDbbkRaPR
WLfnp3ufAEyXbenS3I5jWvrzvnml4XEf9svrbwK52Zbmaw9fnB1DWvGW9xLn
P6QPG4cnKHcmHopbgMfcFT+JhTJWYVAe5lngWjpZvGFjsBaFLqRRdvJEmlp/
xjVxXREvM5fTI16c1DvKD3rP8Upnh5epCdtKHfyXzB/0xu0vp39q9yFn0Bn5
rLcaldpNbSUP6Huzn6ROWAH8cnOC
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 405->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksENwjAMRb84IK6MwAowQMUKZYIi0VMlpHJA3DI6bUHIebFTESlxEsff
3z8+XO9tv5H02E1L2z3P49i9Ltv5cOuG03GYnfvvlFIzLc3HLntztwxrzVue
Lc5v2L18HE4hdwKPjFsFj9wzfhZLZWyGgTzkWeB6Onm85WNQi0IXaJSCPDVN
vT9jTayrxsvNFfRIFGf1ruUX3jM+0zng5WpCu1IH/5L8hTdhfwX9s+avchbu
sKfe/9TuamvjlfvJPYGH9AYQe3OA
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 406->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkksOwjAMREcsEFuOwBXgABVXKCcIEqwqIZUFYpej05aPnFfHFZESO3E8
Hk+yO9/a60rSfTMsbXoc+z49T+txc0ndYd+Nwe1nSrkZluZtJ9+cTcNac5d7
i/Mb1pePwynUzuBRcAvwyL3gZ7E0zy0wUIc8Z7ieTh5v+RjUYqYLNMqVOpGm
3puxJ/YV8XJrVf5INL8jqi/cZ36hc4WXqwntQh98S/IX7lT7rfyfpXjIWTiD
T73/6d3V1uarjJN7Bg/pBRWKdAA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 407->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwjAQhR8uxK1H8Ap6gOIV6gkq6EoQ6kLc5ei29YfJ50uKgWTyNzPf
vGRzvLbnhaTbahja7r7v++5xWI6LU3fZbS/j4frdpdQMQ/Oy0zzsTS3acJfr
GOfb4lzYD34JMWLOBI6MzXAl4yPyxVj69c1iFJipBTWxuSoxHYPLl3XhXD4W
NXVvxppYV43L5ir8kVr/tFp+4T79M50LXFYT2pk6+JbkF+4U641Mc2vz/pZZ
2MOcev9Tu9U2+is/J3sCh/QE2PJzgg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 408->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkU0KwjAUhAcX0q1H8Ap6gOIV6gki2FVBqAtxl6PbVpHJdF5LA8nLz/v5
3uR4ezTtDsCzGpYmvS59n97X/Xi4p+586sbHw28CuR6W+munPd1Ngy356pnz
/AfvIfcUlyUH18zCUbAZrmxioHycC/PYIkfAbGsaXUJuzP2cFlFuzuvqLGnq
/sz1FLFF8SFnoG+k91J9iL/GFzoHXFYTtSt96F8qP8Qn7JeZ1s7m/y0z5E72
qveW3q22HI/yXdmzcAAfeBB0Ag==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 409->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUUEKwkAMHDxIrz7BL+gDil+oL1jBngpCPYi3fbptFZmdTlq60E2yTSaT
yfH2aNodgGc1XE16Xfo+va/7Mbin7nzqxp+H3wfkerjqr518epsOW8rVmHH+
h33IO9VlweCeWXgU3AyvbGqg/BgL89oCI+BsexpdQt6Y5zktImzGdX2WNHU7
czNF3KL6kGegb6T3Un9IvtYXOge8rCZqV+bQXSp/SE44L3Nai83+LWfIm/iq
95bZFSMrD8LTHToM4AOdEHSC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 410->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUUEKwkAMHDxIrz7BL+gDil+oL1jBngpCPYi3PN22imRnJ1u60E2yTSaT
yfH26PodgGczXV16XcYxva/7Obin4Xwa5p+H3wdYO13t1y6+e1uOty6XY4/z
P94Hvbs6Iwzf04hHxk3wMlED5uexUNZmGAFn2VPoEvJGmae0KLQljSzoU9NU
4aqZIm5RvdKgtutI71p/UD7XZzoHvKQmbFfm4F0yf1BOOK/ntBaL/UvOoDfy
We8tszOGMQ+HxztUGMAHCC51Ag==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 411->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfErU9nGwilrl2o1KZtEsdx
dudbf10BuG+mo0+P4zim52k9Py5pOOyH2bn9bCB309G97XIPf8uKNsTyO+J8
V7yD/kNeJoxYMxOPgpvglUUOmF/EQp1bYBjOsqbQxfJGHae0qLQljbKp09JU
4aqeHDeXrzRozdrp3aoPiuf8QmfDS2oS7D998CyZPyjG9hs5/XoLXJ5r5WM/
ar0tjtMNpg/C4xkqDOAFjbd1Qw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 412->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUcENwjAMPPFA/TICK8AAESuUCYIEr0pI5YH4eXTagpBzOYdGSuwk9vl8
3l/u/W0D4NFNR5+fp3HMr/N2vlzzcDwM8+fuuwFL05E+dvHd27K8dbF89zi/
5X3Qu8szwvA1jXgU3AQvEzlgfh4LdW6BEXCWNYUuIW/UcUqLSlvSyII6LU0V
ruop4hblKw1as470btUHxXN+oXPAS2ri7Jo+eJbMHxQT9us5/bsLXDXX4i/V
PuutcKLeGaPgSXg8Q4UBvAHmt3XD
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 413->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUkOwjAMHHFAXHkCX4AHRP1C+4IgwakSUnuoesvTu4CQMxmnkZLYiT0e
j2/PT/s+ARgv69HGqRmGOHfnzXnF/nHvt8/rbwMprEf43rtt3vZlbxPLvsX5
L2uD3k1eIgxbMxGPjJvglUQOmJ/FQpmbYTicZU2hi8sbZZzSotBW6KHq1DRV
uKonj5uXrzSozdrTu1YfFM/5rJHiJTUhTY/64Fkyf1CM26/ldOQLXDXX7C+U
NuutcLzeGSPjSXg8Q4UBLDZEdYQ=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 414->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUsKwkAQRAsX4tYjeAU9wOAV4glG0FVASBbB3RzdJIr01FR3Bubfn9fV
p/ure+4AjId56fJ0HYb8vu2XyyP3l3O/fB5/EyhpXtJ3X8/mbR12N7Z8t3H+
w55B78avUAybsxBHxUZcXEcTJ9X+hf4bloBZ1aBYXG60dkqLRluhh8oTaari
qpo8toibNYh67ekd5ecesz9rpLikJqTpVh3cS+YH5XDrtUxbd+ZmdtJR9b3S
F2Rr7ZzaVT2Vv4nHPVQxgA99NnTD
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 415->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhQcX4tYjeAU9QPAK9QQRdFUQ6kLc5ei2Vcqbl5epgeZ/Xr55
08P10d03ZvbcjV2XX+dhyO/Ldlrccn869tPh/veZlTR26TvOc9ibG45wl9eo
szScG+1DXCENfLMQh2MjLs6j0kk+vtB5xRIwqxwUi+ROtaZikN4KP9Q7kadK
V+XUYou42YOo1i2/o/e5xhzPHiku6Ql5upbHEgPMbv5H/tU/sLZmbmYnH1Xd
nb9Gd/FeIwfWcJykxzVUGmYfg5t1QQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 416->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT8uxK1H8Ap6gOAV6gki6Kog1IW4y9Ftq5TJz5+pgSaTpPnz
5ieH66O7bwA8d2PX5dd5GPL7sp0mt9yfjv20uf99QEljl77jHJu1udnR/Mtz
q7M0G4PWzblCGjYnr1VsxMV1KJ3CWoDPEjCrGhSL5E6tpmKQ3pJGcfJEnipd
VZPHFnGzB9Fde35H+fmO+Tx7pLikJ+TpWh3LGcNcxX/U37yBtTlzM7va4320
frs6zn1bjYqT9DwfKp/xAUANdQA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 417->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkssNwjAQREc5IK6UQAtQgEULoQIjwSlSpHBA3Fx6PqBoPZ51Yin+bXb8
duzzo29fDYD3cera+LkNQ/zeD/PiGbvrpZuDp/8HpDB14Tcuc7O3NDuaf3lt
ddZm56B9k5dIw57JexkbcXEdSiexFuCzVJhVDYpFcodSUzFIb0kjOefUPFW6
qiaPzctXHtTu2vO7dj7fMeezR4pLekKebtWx5hjmbL6j/uINbK2Zm9lVjOMo
/XZ1xLtgjYyT9DwfMp8xAmUcdYA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 418->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk8kD8PDptQZVzOadEamK78fl8
8eH66O4bAM/duHX5dR6G/L5sJ+eW+9Oxn37ufx9gadzS95xtF5uXP91d9j3O
srwNirs8Iwxfk2MFN+LFfSgcYywg5tLgrHpQXCTvVGMqDlJbwrCgTktThat6
irhF+UqD1ltHerfq8xtzPmukeElNSNO1PpYcx7mw/+i/moE1n3lD2JFPM2LE
v7on6vKcVX0QXqRDoTM+N5V1QQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 419->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4eXTagirncg5EamKn8fl8
9uF67/oNgMdu2rr8PI9jfl22s3PLw+k4zD/33w+wNG3pcy62u1uWP91b9j3O
urwNundxRhg+J98V3IgX16FwjLGAmEuDs6pBcZG8U42pOEhtCcOCPC1NFa6q
KeIWxSsNWr2O9G7l5x5zPGukeElNSNNfdawxjnNh/1E/96uaCfaZN4Qd+TQj
RvyrdyIvz5kxT8KLdCh0xhu4lXXB
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 420->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRYMLcesRvIIeYPAK9QQVdFUQ6kLc5ei2VUr6+jMOdCaZTn7+
T3K4Ppr7xsyeu2Fr2te579v3ZTs6t7Y7Hbvx5/73mXkZtvI9JzvcTSue4S39
iDOvaBvuQ5wDI+bk3YIbeFGHwnFimeVcKpyVBsVF8i5rTMVB1hYYnuSp1VTh
Kk0Ztyxe1aDW66zetfzsMeNZI8VLzhRq+k/HnMOAkcRnehc6ORP02UsTduZD
r4P/6p3Iyzlz8gSeiiWG2QeEpHbB
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 421->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszigXXkCX4AHVHxhvKBI7DQJaTsgbn0620BTZuxSaW3SJY7j
9Hh7tN0OwNhMW5ufl2HIr+t+du65P5/6+efh+wElTVv6nIsd7pYVzxDLfsRZ
V7RB9yGvEEasyXcbbsSL+1A4hbEAz6XCWfWguEje6RdTcZDaEkYxdWqaKlzV
k+Pm8pUGtVk7vWv1ecaczxopXvJNkab/+lhrgDBMvut30ye/CfZ5lhC285UG
oFgXxzbE3ASeymUM4A1hU3aA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 422->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOgzAMHPVQce0T+oXygKhfgBcECU5IleBQ9ZansxQhdzKOGonEDvZ4
PM69ezXDBcBcrVsT389pip/2ujl9HOvHuP28HR+QwrqF77nb5m5f9jSx7Fuc
c1kbdG/yEmHYmnz3w414cR8KJzEW4HMpcFY9KC6Sd8gxFQepLWEkp05JU4Wr
evK4eflKg9KsPb1L9XnGnM8aKV7yTZGmWZzSyizm/0//WS1+E+zzLCFsz1ca
gGK9OLYh5ibwVC5jAAsUYncA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 423->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UUEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsTbPt22SonTmSx0N0mTyWRy
uD66+wbAczdeXX2dh6G+L9vJudX+dOynn/vfB7QyXuX7znaIzSe+IZf9iLOc
aIPioa4RRuzJsT9uxIvnUDiNsQDPJeGsZlBcJO+yxlQcpLaE4fTJNFW4aibH
zdUrDbJdO72z/rxjrmeNFC+pmdmHm2PpAcLgnSTz875WHAQncG+2na80AOW6
PLYh9ibwVC1jAB8QIna/
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 424->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kVEOgkAMRCd+GH89glfQAxCvgCfARL5ITPDD+MfRBVRSH9PdhN122U6n
M4frvW43kh67caub57nvm9dlOyW3pjsdu+nn/vtJQzVu1eec43A3r3iGt8wj
zrJiLNyHugEYsSfv/riBF+dwOAOxpJxLgbObwXH5rZKm9IB6Ou4rPZCXNHW4
bqaMW1bvNCh5neld6k+PWU+NHC+rWeJHNsfSQ8CgJ4X56deKg+Ek9mac5U4D
4W32jrGMbwbP1RJDegNK9HaA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 425->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUEKwkAMRT8uxK1H8Ap6gOIV6glG0FVBqAtxN0e3rSLx9acOdCZJk5+f
n9351l5Xku6b4WrL49j35Xlaj86ldId9N/7cfj6pNsPVvN/JDrHpxDfk0o84
3xNtIR7qKjBiT8Z+uIEX53A4lVhSzsVwJifL3Wgx4605ntNipi1my/RZ0tTh
upkyblm902Bp11bvP/25Y9ZTI8fLapbsI5uDu7S7XtCUfC0Hw0nsTTvznQZC
bpZHW35vxHO1xJBe0uN1gA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 426->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUEKwlAMRAcX4tYjeAU9QPEK9QQV7Kog1IW469Ftq0j6/qR+6P9Jmkwm
k8P1XrcbSY/deNXN89z3zeuynZxb052O3fRz//2koRqv6vPOdojNJ74hl37E
+Z1oC/FQNwAj9mRswQ28OAdxFj20zLNcDGdystyNFgVvlXhOi0JbzJbps6ap
w3UzZdyyeqfB2q6t3n/6c8esp0aOl9Us2Uc2B3dpd72iKflaDoaT2Jt25jsN
hNwsj7b83ojnaokhvQGeAXYA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 427->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkVEKwkAMRAc/xF+P4BX0AMUr1BNUsF8FoX6Ifz26bRVJ307qQneTbTKZ
nTlc73W7kfTYjVvdPM9937wu2ym5Nd3p2E0/999PGqpxqz7nHIe7ecUz1DKP
OL8VY+E+9A3AiDN5t+AGXnwHcRYztKyzXAxncrLcjRYFb5V4TotCW7wt02dN
U4fr3pRxy/qdBmteW73/zKfH7KdGjpfVLPEj85teWq9XNCVfy8FwEmczznKn
gVCb1TGW9414rpcY0htNEHaA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 428->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kU0OgjAQhScuDFuP4BX0AMQr4AlqIisSE1gYdxxdQEOmX9+0Cf1jOvPm
e+fHq+sPZjY1y9Sl920c0+d+XA/PNFwvw/rz9P/M5naZ2t+67d3dNvzqYnn2
efbh94Z7925GDl+Td5k26GIfzJPVsDxOahGaqUlqFywK3VbmUywKtugt4lNj
qvKqniJt0XvFoOZ15H2tPj2mX2SkdElmgR+R3/RSel3piXqlBqHJWJv76KwY
GGKjOFGb3MlDccvudmZfnVt2Pw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 429->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9k0sKwkAQRBsXkq1H8Ap6gOAV4glGMKuAkCzEXY5uPiI9b6pnIPPtrq6u
IufHq+sPZjY1y9Sl920c0+d+XA/PNFwvw/p4+n1mc7tM7b5ue3e3Db+6WJ49
zn/4veHe5c3A8DV5l3EDL/ZBnKyG5XGSi+BMTpK70KLgbSWe0qLQFr1F+tQ0
Vbiqp4hblK80qHkdeV+rT4/pFzVSvKRmgR+R3/RSel3piXwlB8HJWJv76Kw0
MMRGcXwz8Z8IPOpGvD33C4d0dgA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 430->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkksOwjAMRC0WqFuOwBXgABVXKCcIEqwqIbULxK5Hpx+EnJdxiNTETuzx
eNzj7dk9dmY2NvPWpddlGNL7ul+ce+rPp355PHw/s6mdt3Y7V9vdrcufLpa+
x/ktbxvuXd4EDF+Tdxk38GIfxMlqWB4nuQjO5CS5Cy0K3lbiKS0KbdFbpE9N
U4Wreoq4RflKg9qspd5/6nPGzKdGipfULJhHNG/OUs66omnEv/h3FGdfm3bk
Kw0MsVEc3yLewKNuxNtyP4spdkE=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 431->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUsKwkAQRBsXkq1H8Ap6gOAV4glG0FVASBbiLkc3H5GeN9XjwPy7q6ur
jrdn99iZ2djMS5del2FI7+t+udxTfz71y+fhO82mdl7abV/P7m0dfnexvHuc
3/Bnw7vLm4Dha/It4wZe7IM4WQ3L4yQXwZmcJHehRcHbSjylRaEteov0qWmq
cFVPEbcoX2lQ81rq/ac+PWY+NVK8pGaBH5Hf9FJ6XdFU9ksOgpOxtvC2+kd8
HxvFCXzlG/GoG/G23A84rHYA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 432->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUsKwkAQRBsX4tYjeAU9QPAK8QQjmFVAiAtxl6Obj0jPm+rJwPy7q6ur
Tvdn2+3M7HWYlja9r8OQPrf9fHmk/nLu58/jb5qNzbQ0676c3dsy/O5iefc4
/+HPhneXNwLD1+Rbxg282AdxshqWx0kugjM5Se5Ci4K3lXhKi0Jb9BbpU9NU
4aqeIm5RvtKg5rXUe6M+PWY+NVK8pGaBH5Hf9FJ6vdF/wZEcBCdjbeFt9Y/4
PjaKE/iqD+JRN+KtuV/BrHaA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 433->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUsKwkAUCy7ErUfwCnqA4hXqCUawq4JQF+KuR7cfkUwmbzow//fy8pLT
/dl2OwCvw7S06X0dhvS57efLI/WXcz9/Hn8TGJtpadZ9OdPbMninWL0zzn/w
GfJOeaNgcE19y7gJL+1DcbIayOMsF8NZOVnuRouCN0o8p4XFpt4ifWqaOs9c
TxG3KN9pUPPa6r1RXz3W/EzngJfVJPAj8lu9tF5v9F9wVA6GE7S28bb6p/gc
G8UZfNeH4qluirfmfgGXjnWA
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 434->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUkOwjAQszggrjyBL8ADKr5QXhAkeqqEVA6IW55OF0CO4ymRss94PPbh
em+7DYDHblza9DwPQ3pdttPllvrTsZ8+958J5GZcmmWfz/Q2D94pVu+M8xt8
1kF5WTC4pr4V3ITX9z8b7lUNlHGWi/B1/VvuRouKN2o8p4XFpt4ifdY0dZ65
niJuUb7TwOkUTfXC1YfEa36hc8DLahL4EfmtXlqv//RfcVQOhhO0tvF29U/x
OTaKM/iuD8VT3RRvyX0DrrJ1Ag==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 435->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUkOwjAQszggrjyBL8ADKr5QXhAkeqqEVA6IW55OF0CO4ymRss94PPbh
em+7DYDHblza9DwPQ3pdttPllvrTsZ8+958J5GZcmmWfz/Q2D94pVu+M8xt8
1kF5WTC4pr4V3ITX9z8b7lUNlHGWi/B1/VvuRouKN2o8p4XFpt4ifdY0dZ65
niJuUb7TwOkUTfXC1YfEa36hc8DLahL4EfmtXlqv//RfcUT55jhBaxtvV/8Y
DxIbxRl814fiqW6Kt+S+AXNjdMM=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 436->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkssNwkAMRC0OKFdKoAUoIKKFUMEikVMkpHBA3LZ08gHkfRknK232Z4/H
MzneHk27M7NnNXya9Lr0fXpf9+PhnrrzqRsfD99pluvhU8/rtHd30/Cri+XZ
4/yH33O4vAwMX5N3BTfw+r1nwX1Rw8o4yQV82avEpU4W8Aam4qDq0ZdInzVN
lWeqp4hblK80UDpFk16o+oZ45hc6B7ykJoEfjOc/VPhLrzf6X3C08k5xMtYW
3q6+eTxDbBQn8FUfxKNuxJtzPxyBdUM=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 437->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkssNwkAMRC0OiCsl0AIUENFCqGCRyCkSUjggbls6+QDyvowXS/u3x2PP
Hq73ttuY2WM3Tm16nochvS7b6XBL/enYT4/7zzDLzTg1yzrv3d1sfnW+PHuc
n/k9zcVlYPicvCu4gdf3PQvuqxxW+kku4MtaJS77ZAFvYCoOKh91ifpT66nS
TNUUcYviGaP+SG1QC5Xf4M/4os9B/2RPAj3ozz9U6Eut/9S/4mjlneJkzC20
rb55PINv5CfwVR3EY9+It8S+ATOQdcM=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 438->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkkKwlAQRAsX4tYjeAU9QPAK8QQRdBUQ4kLc5egmcaD/S3Vs+HMP1VV/
d77V15Wk+2aY6uZx7LrmeVqPh0vTHvbt+Lj9DKmvhql6r9M+3E0W1+DLc8zz
s7inhbgeOWJN3hXYgOv73hvssxoq/SwW4GWvNi95UoIbOR0GV4+6ZPwsceo0
cz1l2LJ4xrg/sjSohasv+DO+4Dnhz3KS6EF//qFCX2r9p/8ZRpV3DpNY22i7
+BbzCb6Zn+HW9cF85M3m0wtekHZD
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 439->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhR8uxK1H8Ap6gOIV6glG0FVBaBfFXY9uW0Uy3yTTgXZ+kry8
vOR0f7XPnaThMP/aNF77Pr1v++XySN3l3C3G4++Tpmb+Nd99PZu3ddnd+PJu
cf7LnrlM3AQMm5NvGTfBX3WczCbDNeICvqzVxaVOhlehB/T0tHCxjbaRPjVN
vZ55NUXconjG1GYk1Hsjv+DP+EznQD9Xk6Af9OcMZf1lr4M5Yb2cFUV28pbK
OrZsXj5HgyKvynNRB/Com4unD9KCdUM=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 440->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhR8uxK1H8Ap6gOIV6glG0FVBqAtx16PbVpHkm6QdmP/kJe8l
h+ujvW8kPXfj0pbXue/L+7KdLrfSnY7d9Ln/TWloxqX57vPZvM3D7saWd4vz
H/bMYfwGYNiYfHO5CfbyPIjjYsjbhbkgX3INcamTyavSA3pGWoTYhlumz5Km
Uc0iTllumT99lnok1XslvmBPf6dzol+oSVIP2rOHXH1Z66RPyJe9ouyfeUs1
j7W/KF6gQRVX9bniATzqFuLpA+vcdQQ=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 441->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksOglAQa1wYth7BK+gBiFfAEzwTXZGQwIK44+gCGjPT6cBL3n9ep+28
86NrXgcAQzUPTRlvfV/e9+OyeZb2emmXy9OvA1M9D/V3XtfmbG12NrG8tzj/
ZtfczLuJMGxOPnPcQPHwOhjH5YCPk1yIL2uVuOyT4RX8ID+VFxLbaMv82fJU
1Uxpyrhl7/e82IpXtVD5QfH83vmc8JGeJPXgeP5Drr5c6+SfsF7+K8jumTcQ
dezdqXzCg5AXcR10EB77JvHwAQT6dYQ=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 442->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOg0AMszhUXHlCv9A+APUL9AVTqZyQKsGh4sbTWboo8TgwEsyWcWwn
58eraQsAQ7n8mvS+9X0a76d180zd9dKtl9X3A6Z6+dWfeVubs23Y2cTy3uL8
h13zMO8mwrA5+cxxA8XD62AclwM+TnIhvqxV4rJPhlfmB/mpvJDYRlvkz56n
qmZKU8Qten/kxV68qoXKD4rn987ngI/0JKgHx3MPufpyrYM+Yb3cK4jumTeQ
6zi6U/mEB1l/iXWmg/DYN3f2w8MM7BB1RQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 443->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAQszggrjyBL8ADKr5QXhAkeqqEVA6IW59OWxZ5HCeN1GSSmTq2
J4frve02AB67aWrT8zwM6XXZzptb6k/Hfk7uvx8wNtPUfNYlprNl8Eq1umec
/+BYB/03CgbfqWeBG6QeUYfihDsQ6ywX4ataLa76RLwyP8RP54XFJm0lf2qe
up45TTU8F695Uat3vXDeOH6Or8NSv9VL1w+t1zcU+qu9LrwT1atvBaW88gZy
HWs5vZ9rpS5oMXGmQ/DUt3D2w8MbnDV1hg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 444->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRBc/xF+P4BX0AMUr1BNU0K+CUD/Evx7dtkqZfZ3GQJNNMp3s
zO7h+qjvm4h47oapbl7nrmvel+24uTXt6diOl/vfF9FXw1R91ymWs2noKlju
lWceGnPIfz049E2epdwC+Mg6yJPeiIyzuSBfarW89EnyWvgBP50Xllu0rflT
8tTVzGkq8bn4nxclvKuF88bl5/J1XPSbXrp6EM8eSvVlrVf6hHrZK4nP5axY
U9viHd9XLHBJi4kXOsBH39LZrPEDYeJ1Rw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 445->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRBc/xF+P4BX0AMUr1BNU0K+CUD/Evx7dtkqZfZ3GQJNNMp3d
ncnh+qjvm4h47oapbl7nrmvel+24uTXt6diOl/vfF9FXw1R91ymWs2noKlju
lWceGnPIfz04NCfPUm0BfOQ+yJNyRMbZWlAve7W81EnqWugBPZ0Wllt6W9On
pKnzzPVU4nPxPy1KeOeF08bV5+p1XNSbWjo/iOcbSv7S65V3wn75VhKf81mx
xtviHfMrFriU18SLPsBH3dLZ3OMHK391CA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 446->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRBc/xF+P4BX0AMUr1BNU0K+CUD/Evx7dtkqZfZ3GQJNNMp3d
mc3h+qjvm4h47oapbl7nrmvel+24uTXt6diOl/vfF9FXw1R91ymWs2noKlju
lWceGnPIfz04NCfPUm0BfGQd5Ek5IuNsLaiXWi0vfZK6Fn7AT+eF5RZta/6U
PHU9c5pKfC7+50UJ73rhvHH1uXodF/2ml64fxPMNpf6i12vvhHr5VhKf67Ni
TW+Ld8yvWOBSXhMvdICP+tPZrPEDvn91iA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 447->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkk0KwkAMhYMLcesRvIIeoHiFeoIRdFUQ6kLc9ei2VcrL12QcaOfv5SXv
ZQ7XR3vfmNlzN/7a8jr3fXlfttPmVrrTsZsu97/PbGjGX/Od57WczUNnwXKv
PMvQNYfEDeDQnDxztRnw5nWQx+UwjwtrQb3UGvLSJ6lr5Qf8jLwIuUVb5k/N
06hnkaastiz+nxc1fNSLKL8Bz3jnc1JP6EnSD+L5hjQPe529E+pl/MKR9Rm5
WX/1jvkVC5zLG6xXOsBH/e5s0fgBo2x2Bg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 448->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAUCy7ErUfwCnqA4hXqCUawq4JQF+KuR7etInlp3jgw/0zee8kc
rve22wB47KahLc/zMJTXZTtvbqU/Hfv5cv/twNhMQ/OZlzWdLY1nwuqeeX6N
19ro3SgcHFPPQm4QPGIdyhNiIOJsLpKv1mp5VSfKa6WH6Om0sNxUW6ZPTVPn
maspyy17/0+LGt554eJD8Po+6JzkYzVJ/FC8/qHgr3id/ROtV/9K4HM+M9Z4
W73T+IwVXIhr1qs6hC/zLvDhDWRpdkc=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 449->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAUe7gQtx7BK+gBileoJxjBrgpCXYi7ObptFclLkzow/0zee8kc
rve220TEYzcObXmeh6G8Lttpcyv96dhPl/tvj6jNODSfeV7D2dxwBizvkefX
cM0N3lXiwJh8VlUM2Kd74kkxIuNkLpQv1yp5WSfIa6EH6am0kNxQm9LH5mXq
cDW53Nz7f1qs4ZUXKn4Qnt8nnU0+UhPjB+P5DyV/yWv3T7he/iuJT/mMWOHt
6h3HRyzhUlyxXtRBfM67xBdvS4d2xw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 450->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMizigXXkCX4AHTHxhvKBIcJqEtB0Qtz6dbSDkeDZU2tq0iRM7
2V/u3W0TEWMz/bryOA1DeZ63s3Et/fHQz4+7zxdR2+nXvvflDHfLwh182Uac
78IzL4irhIE5+a6qHGCnd8JJOSL7yVqoXuYqcVknqGulB+mptJDYwE3pY+sy
PBwnV5uL/6fFL3/VC5U/yJ/jk86mHqmJ6Qf78wyl/lKv3ZwwX56VhKf6jL7K
Vm+KQ4g4M0/qvOJBeK53CS9eHvx2iA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 451->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMtHpAXPsEvgAPiPhC+4Ig0VMlpHJA3PL0LiBkT2ZKpCxO7Ik9
49Pt0Q2NmT2Py9Ll13Wa8rs/rMY9j5fzuD6232lW0rKkz76d3d02/O580fY4
v+HPOFxcIZjex98V9keqMTH36h+LfphLwdxJrRQXeTLCKcFUfOxxE3DBpnmJ
OlRNKjcV/4+LPX+mBfsfNcb4wLPIh3Ii9EB/7KGgL2it+gTrxV4JeExn78ts
9sZqMBIn+omdqzoAT2kX8GwGDXh2Rw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 452->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAvfIEvgAPiPhCeUGQ4FQJqT0gbnk6bVlkT8YkUhYn9sTj
8f5y728bAFM3L31+nMYxP8/bxbjm4XgYlsfdZwIlzUt67+vZ3K3D7saXbYvz
G/bMw8QVgWl97F1Rf6Qak3Ov/oH341wK5y64SlyuE0RNBWZUj3+1cbhky7wC
HhGnKLcovlWL1qw0bPz35cu27AfWRdRS6cH+3ENOX9I66hPmy73i8JTO1lfZ
6k1xgIgL+kmdKx6EF2nn8PACFod2xw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 453->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz2CV9ADFK9QTxDBfhWE+iH+5ei2VctmOmMCSXaTfc3O
Hq73ttsAeOzGo03P8zCk12U7KbfUn4799Ln/biA349F87lkOb/OKd7BlPcZZ
VpR5Bb+YG5S7yAWyNfZZ1J6pzgWnqSVz7QKrjMt9Qsj1J6bsh+otYVP9sXUZ
HA6Tq83513pR2ysOK/l+eFmX88C8iF4qPtieZ6jgl7h2c8J4eVaKeIrnaKt0
9acwQPiZeVLyCgfFc9wV8fAGiDx3CA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 454->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHRP1C+4Ig0VMlpHJAveXpXSCSPRmTRsrixLFn
PL4+Xt1wEpF3sy5d/LTTFOf+vBnPON5v4/Z4+U2RFNYlfPf9rO72oXf0JXaO
Yf6yof7p3AK5dZ6MrcgRypiIPSFusX6IJSH2CneDk9TC1JTEpPVgtQVurD4u
LodHVc8DuBh21jP/ZqFhJV/mizbtB9SF1JLpgf7YQ0Zf0NrrE+SLvWLiMZ21
L7PZG+Mg5J/TT+xc8IB4nnYmniytWneI
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 455->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtDigXnkCX4AHRP1C+4Ig0VMlpHJAveXpXSCSPRmTRsrixLFn
PL4+Xt1wEpF3sy5d/LTTFOf+vBnPON5v4/Z4+U2RFNYlfPf9rO72oXf0JXaO
Yf6yof7p3AK5dZ6MrcgRypiIPSFusX6IJSH2CneDk9TC1JTEpPVgtQVurD4u
LodHVc8DuBh21jP/ZqFhJV/mizbtB9SF1JLpgf7YQ0Zf0NrrE+SLvWLiMZ21
L7PxzdHCjED+iOWK54IHxPP6y8STBcr9d0c=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 456->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMtHpAvfYJfAEeEPGF8oIg0VMlpPZQccvTaQuR7MmYNFIWJ449
4/H58eqHRkTmdl36uNymKb7vp814xvF6GbfH7jdFUliX8N33s7rbh97Rl9g5
hvnLhvqncwvk1nkytiJHKGMi9oS4xfohloTYK9wNTlILU1MSk9aD1Ra4sfq4
uBweVT0P4GLYWc/8m4WGlXyZL9q0H1AXUkumB/pjDxl9QWuvT5Av9oqJx3TW
vmAn9uZoYUYgf8RyxXPBA+J5/WXiyQckDHfH
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 457->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAMFDmUXPOEfqF9gOkX0he40J4CheRQcvPTs7QBaTSqDV5ky9JI
M+fHu381IjK169Lnz20c83w/bcYzD9fLsD12vylS0rqk776f1d0+9I6+xD5i
mL9sqH86t0BunefA5nIkHxOxF8Qt1g+xFMReqd3gJL0wPSUxaT9Yb6E21p8Q
V1AHO2POGi6GnWnm33QcVvJpPWib6gF5Ib1kfKA/asjwC1xHOsF6USsmHuNZ
+4Jd2FvABR2BntjZ1QFxGHcutiw/VHgI
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 458->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAMFDmUXPOEfqF9gOkX0he40J4CheRQcvPTs7QBaTSqDbalRJZG
mjk/3v2rEZGpXY8+f27jmOf7aXOeebhehu1n99siJa1H+t67rb7tS98YS/wj
h3nLlnqnawvU1nUObK5G8jkRe0HcYuMQS0Hsld4NTjILM1OSk86DzRZ6Y/MJ
cQV9MBtr1nAx7Ewz/7bjsFJP60H7VA/IC5kl4wPjUUOGX+A60gn2i1ox+RjP
OhZ8qrmAC7oCPTHb9QF5GHcutyySVHiI
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 459->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDxIrz7BL+gDFr9QX7CCngpCexBv+3QtbCWZnbgLaZNumkwy
c7w9x8cOwDJ8H2N+XeY5v6/7Nbjn6Xya1stDNaAkb9s3VN+9q/1yRbzVcP+q
k3RvUG/bx+J1PVJbk7EXxg2fx1gKY+/M7nCKXbidippyH2q3NJvaT4grmEP5
3LOHS2FXmvlnDYedflYPNpZ6YF7ELhUfnM8acvwS15FOeF7WiquneLa5FEvN
BVzIE+hJ+c0cVEdx19TGB9FyeQg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 460->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDB6KV5/QL7QPWPoF+4IttCehoIfibZ9uhbUkk0l3IZq4MZlk
5vx4j69ORJb++xjz5zbPeb2f9uCZp+tl2i+HaiIlWTu+SfXNu9ovl8RHDfMv
O4n3Fuit+2i8pkfyNRF7Qdxi8xBLQeyN2Q1OsguzU1KT7oPtFmZj+wlxBXMw
H3u2cDHsTDP/zHHY6Kf1oGOqB+SF7JLxgfmoIcMvcB3pBOdFrWA9x7O+g5hq
LuCCnkBPzHdzQB3GnastG5oTeMk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 461->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKg0AMDB6KV5/QL7QPWPoF+4IttCehoIfibZ9uhbUkk0l3IZq4MZlk
5vx4j69ORJb++xjz5zbPeb2f9uCZp+tl2i+HaiIlWTu+SfXNu9ovl8RHDfMv
O4n3Fuit+2i8pkfyNRF7Qdxi8xBLQeyN2Q1OsguzU1KT7oPtFmZj+wlxBXMw
H3u2cDHsTDP/zHHY6Kf1oGOqB+SF7JLxgfmoIcMvcB3pBOdFrWA9x7O+g5hq
LuCCnkBPzHdzAF7GnastG68TeUk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 462->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4ZXSolFbx+UwiubGbxHf2
+XR/DuMOwOvw+wz5fZ3n/Lntl+CRp8t5Wg6P1YCSrK3/UH2zV9vuinjNYd6q
lTQ2CLvFafkajORzMvfCvGHvMZfC3Du1G56iF6anIqfsh+ot1ab6E/IK6lA+
Y/Z4Ke5qZv6Z07CD185DG8t5ULqoPcCW+rOWpHU0J1wvz8qWg+NAS4cdvRH9
cyuYJ+W7Ooiv0s7lxhfhyHjJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 463->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPIo+WaErtAOYLpCOoEL7StQSB4lP4+ephhjnU+kAsUWsaST
7s6P9/jqACz99zPGz22e43o/7cEzTtfLtP8csgMpWP9ZyA46s5e3Ii416lxl
4b/edZ8ar+kR2pqMPTFu2HeMJTH2g9kNTrGLuq+qKfehdkuzqf24uJw51J17
HuFS2JVmvDqKC9WfOeZ83pHCo/Th8QHKZw0ZLolrTyc8L2ul1ODY4dJgUZpz
uJDm6EndmzkIr+KuqY0NTpt3SQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 464->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRYMLcesRvIIeoHiF8QQj6GpAGBfirkfXkVKa3xfGQqYN0/78
5P/D9THcN2b23H0/w/g6z/P4vmyX5DZOp+O0/NyXMMvJx2+lEiZ7iXoX8orR
vqWV/qvd1mn5uhqpx1TuWXmbv6dcsnJf6d3xhFm0dQkT50Gzld5oPiGvoA86
a801XsSdPBPhkBZUXzXW9zoj4kP+iPTQuauHnJaideQT7Ve9UjE0D7R0XMhz
gRa4Aj/RuetD+JJ2HbZ9APqhdwo=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 465->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFyIW4/QK+gBHl6hnuAV6qog1IW4y9G15VHyphPbQNqG5jOZ
SdM928cBwOv0e7T5fRvH/Lkfp6DPw/UyTD/PxQFLtc+WioPexZdcEZuqVZb2
zfZzPF7fh/NNYDfGjTqPsRhj39i9wum5gJv1p6fkYwe3ip8QV7CH+uaZW7gU
dnUzUR+lhZrPGnM9c6TwqPuI9GDe+YZ8HWsd3Qnvy7ey9OA40HKFJaoR/K1M
cSW4lXsQXqUduB++aLB3xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 466->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD1Ir31Cv2AfsPgFfcEW2pMg2IP0lqdX261kZydqIC7BJDOZ
5Hof2udJRF7n+dPGqRnH+O6qJXjE/lb3y89LchENuX8tJBd4k6+5JFZWyywc
w7Y4lq/tg/lKuCvyljwPuShyd2Yt+oIuf8t0IT29fnvaMn3ovKHE9DAY5h6v
I1pszcd2wfBxx1iPGjE+7D68faDueEO2DnetgEnvi9zK2gNjZ5cFF6+G6FcY
04poS+cAvmx3NvdX+wEHn3gI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 467->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB6K1z6hX2gfsPgF+4It6Eko6EF6y9Ot7SrZ2dnVQFyCSWYy
ye31bvtKRKb6+2n93Iyj/zwva9D54XEf1p/X4CLqYv+ZCy7wBt9zSayslpk7
h21xLF/bB/OVcFfkLXEeclHknpk16Qu6bBbpYntKud+RtkwfOi/oW8JgmEe8
zmhRmo/tguHjjrEeNWJ82H2gNuy1eNEuIU7qSvdFbmXvgXFmlwmXXA3RLzGm
FdGWzgF82e5s7r92AUpRd8k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 468->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB6K1z6hX2gfsPgF+4It6Eko6EF6y9Ot7SrZ2dnVQFyCSWYy
ye31bvtKRKb6+2n93Iyj/zwva9D54XEf1p/X4CLqYv+ZCy7wBt9zSayslpk7
h21xLF/bB/OVcFfkLXEeclHknpk16Qu6bBbpYntKud+RtkwfOi/oW8JgmEe8
zmhRmo/tguHjjrEeNWJ82H2gNuy1eNEuIU7qSvdFbmXvgXFmlwl2robolxjT
imhL5wC+bHc291+7AKNReEk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 469->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDD0Ur32CX2gfsPgF+4IV6kko6EF6y9NbdSvZ2dnVQFyCSWYy
Sd292/4iIlP1+7R+bsbRf57XJXj54XEflp+34CLqYl/NBRd4g++5JFZWy8yd
w7Y4lq/tg/lKuCvyljgPuShyz8ya9AVd/hbpYntKud+RtkwfOi/oW8JgmEe8
zmhRmo/tguHjjrEeNWJ82H2gNuy1eNEuIU7qSvdFbmXvgXFmlwl2rgZnYMa0
ItrSOYAv253N3Wq/f6J4Cg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 470->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbnq7VtWRnx7SBdAlNMpNJ
dudbd10BuG/eny4/jsOQn6f1GFxyf9j3489tccBS7R9LxUFv8SlXxKZqlaVl
2B7H8/V9ON8Ed2PeqPOYizH3P7M2fUmXn1W6+J6I+81pq/SR85K+EYbCnOO1
RItoPrULhc875nrWSPFR98HaqNfjVbukuKmL7kvcytSD48hFnawB4bMprYS2
jQ6Cr9qdz/1yeAGQGXfJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 471->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe8nRdrZJOx+wG0hKaZCaT
7s7Xrl8BuG1eR5fvx3HMj9N6Ci55OOyH6XFbHLBU+9tScdBd/JcrYlO1ytIy
bI/j+fo+nG+CuzFv1HnMxZj7n1mbvqTL1ypdfE/E/ea0VfrIeUnfCENhzvFa
okU0n9qF11Bio61njRQf9T9YG3UzD7VL3kE4P2OCenAcuaiTNSB8NqWV0LbR
QfBVf8Xnfjg8Acykd0s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 472->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjxhX4AHVHxhvKCT2GkS0jggbnk6jHUo9Uy7SFkVLbUd
N013b/sdgMfh82nj8zKO8XXdT8UtDufTMP08pgQs5PmNkBJ0pvz1itrUXRVh
G7fn8Xo9Dveb0G6sG3kfazHW/mfWFS75skTmi8dEGa/mrfJHzkv+ljgUZ03X
Fi9K86m38B5Kbqzvs0dKj9oP9kadrEO9Jb9BcX7mBGFwLXBBWuTOiR1h/GwO
xYWKD0Kv2hXfO2t4AzOzd8s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 473->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRQcX4tYjeAU9QPAK9QQR7Kog1IW4y9G1GmXy80w7MA2hM///
+ZPd+dr1KzO7bV6fLt6P4xgfp/V0ucThsB+mn9ucZimU+Y6Q0+TM+auFe6Je
irCM2/N4vR5H6xNoT6rbyjrVklT7n1krXPHlG4UvHtPaeHPekj84r/jb4iDO
OV1LvGjNR7vwHiK31f3qEemh96He0Kk6aJe6g+b8yumwkuArlvpb1EEP7QKD
vAJvKx9AL70VX/vR8ASRtXhJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 474->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtHggvozQFWCAiBXKBKlEX5WQygPx8+hQmiLnfLi15ERRnLvz
OU13b/udiDwOn6XNz8s45td1Px1ueTifhunyWFJEU53fSCUF9pK/WnJW9pZF
2sZteaxei0O1icdR0Kd/7h2H4cFeHS5oWaLyxWJKjLfmLfOH9gv+RhyMc03X
Fi+i/tgsrIeUW/x79IjpYf8DvWE76mCzdDOJ+kdOg6WAr4CF+FVdoAP9c8G8
It46H4he9lds7azhDek8eAg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 475->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfELU+HoUlLXaclUtatbWzH
2eH6GO4bAM/d9zHk13ma8vuynT9ueTwdx/lwvyRgqcxfpCVBq0ujd+N9X6si
/cftebxej8O6jPmZx2sNtBQcEPjqvvIIq+7Kj1SeKbyet8qfqN9eH6qutR/p
jrzo9cez8B7KGhAe+xzoUf8He6NW1qFmWc2k1T9zOiwjfCMsxi/uNXSwf1Uo
r4S3am6stzXjVesHo9V3Rw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 476->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHx8+hQVAnnck4suWmc+Hw+
53R/Dc8dgPnw/Qx5uU5Tft/26+aRx8t5XA+PmwOWSv9Z2hy0Ojf6N477XGVJ
1Pbu7vhYwTPgZVw/qGPBeVUDAr/HnzAKXTwm2ng9bZU+nFfNM+o32EfxiHek
Ra8/noXXUOaA8FjngI96H6yNWpmHmmU1k1b/XNNhGeEbYTF+ca/Bg/WrTGkl
tFVzY76tGf+5fgCNL3eG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 477->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAMFDmUXvOEfqF9gOkX0he40J4CheQQetPTk5RA5dHIFiiOF43G
M748P8O7E5H5vH2GvNynKX8fp33yyuPtOu6b/ZEimsr8RTpSYDSp8K+4bmtZ
JNLbpjlj1wqeAS/F/kEfDfZdDyH4Lf6AUehiMaWO19KW6YN1zs/ovsE8Wo94
R1q07odeWA1pjQAe6hzwYe8DtWEj8mBeOk9q98eeBksBXwHL+WrPVXigfi6Y
VkRb5hvyqHn857oCXqx3Rw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 478->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+7dG1UnAzmU1c2KR5zczO
9nC9D+MGwGP3GYb8PM9zfl22y+KWp9NxWg73awKWyvxGWhM0uzT6Nt73b1Uk
we3T3fF7hc5AlzF/wGPBecUBgd/TTxiFLx4Tbbyet8qfqF5VR8THnD1d/3jR
q4974T2Ub0B47HOgR/0f7I2aWYfqZdWTVv3M6bCM8I2wCny+19DB/lWhvBLe
qr6xjlaPf1rfr7t3xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 479->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAQC35Ifz2CV9ADLF6hnmAF/SoI7Yf4N0fXSsHZNDM6MN12H0k2
6f5y728bAFP3fvT1cRrH+jxv549rHY6HYV7cLQ1YaftTZWnQ6Nro3Xjen1VV
BLdvt8fPNToDXcb8AY8F6ysOCPxMO+ODfPGY0Hg8F3mr/Am1iXtEfMz5S1ea
5R98KivvoTwDwmOfAz3q/2Bv1Mg6VJarTLL7M6fDMsI3wmrweZ/XlGiRpbwS
3qrcWEeW8VfrC7+ddsc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 480->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUUEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfELU+HoR0S1ymLlHVJW9uN
D9fHcN8AeO6+n6G+ztNU35ftXNzqeDqO8+Z+ScBKzF+UJUGrS6N/476/q6II
bp/ujO8FnYkuY/6Ex5L9hgMCv6ed8UFz8ZjQeNzLZqvmk2oT78j4mPOfrq6X
K/iUV4qfPWa/eljK92ZNuEF8wUuqV7+fOR1eqAmzwedzrCvRIkPNSsxW+cY6
Mu8CHj6QQXgE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 481->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IW54OQzukjlOolLVJW9uL
e7jeh3ED4LH7fIb6PM9zfV22S3Kr0+k4LZv7NQArbXxHWQM0uzBaG9f9XTWK
4PbhzvhaozPRZcyf8FiyHzgg8HvaGR/UF48Jjce1rLeqP6k28R8ZH3P+0tX1
8g8+5ZXiZ4/Zrx6W8j3MCTeIr/GS8nCv977EWwk5IlbTXz7HuhIv5FC9Er1V
vrGOzLsGD28jUHiE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 482->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfErU+HoR1Sxx6RsjZpY2dx
D9fHcN8AeO6+n6G+ztNU35ftHNzqeDqO8+F+caCV3n9WFgetwRvtG+djrbIi
uKOHOzHX9Wn6asxveJo5TxwQ+Gu9Mz5oLhETGo9zbrZqPlyX9HT/a2KXd32r
efzjU1opftaY9VrDUrqn1XAr/fltsNaqLr0v8VZSjIyVdI33uC+jhTQ1KzFb
pRv34bTr8PABJix4Qw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 483->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAQs3ggvozACjBAxAplgiDBqxJSeSB+NzoU9XFx7BLJTXLp2Zdz
DtfHcN8AeO6+n6G+ztNU35ftvLnV8XQc58P9AiBKi98oC0BzQtA6OJ5z1ShC
OyP9k2NNnaauYH2jE+a804DgX6ud+UF9yZzQfBxzvVX94Tywtruv2bu4q1v1
45+e8krps8fs1xqX8r2bjbbyv/FReK3yuvcl3kq3R88lfUXPoxCC3+Xku/Ka
e811OO8aPnwAhG54BA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 484->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfELU+HoR1S1x6VsjbpYidx
D9fHcN8AeO6+n6G+ztNU35ft7NzqeDqO8+V+MSBKa79VFgPtyYLOwfGcq1YR
3NnSPznW1GnqCuY3PGHuOw4I/LXaGR80l4wJjccx15uaD+eBuV2/xndxV7ea
xz8+pZXi5zmwXmtYSvduN9xK/0ZHobXK696XeCudjx5L6ooeR1kIfJeTe+Uz
z5rrcNo1ePgA7X14hA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 485->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUEOwjAMs3ZAXPcEvgAPqPjCeEGR4DQJaRzQbnn6GNoh9ZwQKeuWtrZn
n+6v4dkBeB+/j6F+rtNU59th/XjU8XIe181+a8BK278qW4NW10bvxnN/V1UR
3L7dGT9rdAa6jPkDHgv2dxwQ+Jl2xgf54jGh8XgW/ZvyJ9SWeB/dy+aRbuXH
Pz6VleJnHzivDEvlvlsDbpW/ypIzSP+fOSkfX4zV+MvnvKYkC1nKK+Gtyo11
RNk1eFgA8Il4xQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 486->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUcENwkAMs3ggvozACjDAiRXKBIdEX5WQygPxu9GhqA/HOEek9No0Fzv2
4Xofxg2Ax+7zGOrzPM/1ddkuH7c6nY7T8nO/JtBKzG+UNSEnZZP3pnW+66IY
bE7q4VrgmfBqiu9wEPuUS8AgHN3VcmctQFhuJvw8rWW7OX1Sbh3ts3u9esbb
6fEPz3nl8FUH9as368cXdybYzn/npXrQ3V8xxR8OnRX01T7m1PHChtPKaOt8
Ux6Zd2Ee3hHSeIY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 487->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUUEOgzAMszhMXPeEfWF7QLUvsBcUiZ2QJsFh2q1PZ0wcEtfpIoXSEGLH
voyv4dkBWPvvY8jv+7Lkz+O0X6Y8367z/vF8JFCSz1+kI0GnyULvhev2XxVJ
YNs0PbbmeAa8CuMrHPg+5uIwDA7vKrlbLWCw1EzoeVyrduO5jVlg7Gjf4B7V
I95Kj394yiuFzzqwX61ZlS/qDLCV/8pL9qC5P2OSP5HPlb7cZzk1vJChtBLa
Kt+YR+Sdm4cNYkx4Rw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 488->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszigXXkCX4AHTHxhvKBI7DQJaTsgbnk6DO2QuE5XKWubtbYT
9/x4DeMBwNL9PkN53+a5fO7HdfMs0/UyrT9PWwDWx/iPfgvQ7MJobZz3d9Vg
Xg53xueCzkSXMb/iQjzHfQh1QODv6SedFZ7Tp/A4V9XGuA0sMHejXrXP8plu
1Y89PuWV4uc+mNhnWJUvak64lf/KS/agWT9zkj8el7FCf91gHBXqHWV3fK28
5l6zjsy7gIcvcnd4RQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 489->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfELU+HoR0SxymVsrZpYzv1
DtfHeN8AeO6+n7G9zvPc3pftsrm16XSclsP9GoANMX5jWAM0uzBaG+d9rRrM
y+Hu+FzQWegy5i+4rDgP94iHey31k86E5/QpPM4pzIDbwQJzd/pV+ypf6Vbv
8Y9PeaX42WMT+wpL+Z7mglv5r7xkD7r9Myf543HTP6B8RcZRNcZ83IeqQ17z
W7OOyruAhw8zLniE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 490->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAihXKBEGCVyWk8kD8PDoU9WGfzyGS69iJ785x
D9fHeN8AeO6+n7G9zvPc3pftEtzadDpOy+F+NcCGaL81rAbyzoz2xnlfqxbz
srk7Phd0FrqM+QsuK87DPeLhXkv9pDPhOX0Kj3MKM+B2sMDcnX5VXOUr3eo9
/vGpWSl+nrGJuMJScw/e1Sgv9SJj9OpYr5yr0Jj+ATVXZBxVY8zHfag65D2/
NeuoZhfw8AHXVHhF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 491->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMi3ZAXPcEvgAPmPjCeEGR4DQJaRzQbnn6GNohce1SKeuStrZT
93R/jc/OzN7H72csn+s8l+V22JJHmS7naVvs9zDzIcdvDHsYzCEc/h3r8Swb
yIsR9sRa0il0OfILLhfraR/wYK9SP+is8II+hoc1hplwG1iG3I1+Wa7qSje7
j398zCvGjx47yRUW8z3N4QybqV6rMVrnUC/1lWis3gDz1QSO6oENdlfkbplv
qEN5l/BsBShjeMU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 492->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMi3ZAXPcEvgAPmPjCeEGR4DQJaRzQbnn6GNohce1SKeuStrZT
93R/jc/OzN7H72csn+s8l+V22JJHmS7naVvs9zDzIcdvDHsYzCEc/h3r8Swb
yIsR9sRa0il0OfILLhfraR/wYK9SP+is8II+hoc1hplwG1iG3I1+Wa7qSje7
j398zCvGjx47yRUW8z3N4QybqV6rMVrnUC/1lWis3gDz1QSO6oENpovcLfMN
dSjvEp6tDZB4hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 493->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHigfhmBFWCAiBXKBEGCVyWk9oH4eXQo6sO+3AVLbmonPp9z
Od6e42NnZsvw/Yz1dZnn+r7u1+Bep/NpWjcPm5t5yf6zsnm0kt3h3zFvBAPw
HGqThzMxl3gKXo79RS8X++kc9MFZJX/g2eAFfgwPcwwz4XawGj0787JY5RVv
dh//+jGtWH/U2EmssJjuaQ01bKV8rcXo1SFfqivh2LwBpqsJHDUDM8aL3C3T
DXko7RKefQD5k3hH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 494->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwkAIJB5Mrz7BL+gDNn6hvmBN9NTEpD0Ybzxda3qAYUASul12GQZm
j7fn+NiJyDJ8P2N/Xea5v6/7dXPv0/k0rYeHzUW0ef9Z29xa867wrxgXggF4
CrnOzR0bczwTXor1k1qanLt7UAd7TfkDz4Bn+DE8jDFMh1tghbyiX5r3h1c6
O6JL2Z9w7KyefQ92n2Ex3d1qcthK+UrEqPKQL9WVcAxvAHR3tYtecH7BGC8y
W6Yb8si081w/Q354iA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 495->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMizigXXkCX4AHVHxhvKBIcJqEtB0QtzwdhnaoHaeiUta1aW3H
6fH2HB87M1uG72esr8s81/d1vy7udTqfpjV52MLMC8ZvlC3aUTCc/p33TWAQ
ntNdiOZMuwc6E13O/AmXJ3k4Rzxca6qfdAa8Rp/iZg6FCbgF1won875XU29f
5TI//qrPNHbGx94FnxM96n2wN2qWei1i9O6xXtlXoTG8Aeo7cHdqYf/CULqE
t6pvrCPrHWr9AMCNeQg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 496->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEXRWEdiHucnStdDF5eRkMpHSSmfde
Psfbc3zsACzD9zPW12We6/u6Xw/3Op1P05o8bA5Y8f6zsnlrxbvRv3EcAoPw
jN46b+60Macz0WXMn3BZknf3iIdrTfWTzoDX6FPczKEwHW7xZ4WT9b5XUy+u
clk//qoPGjvj496FPid61H5wb3o705slz6BbPxA1AVJj2AGau+NOagk1KFO6
RG/V3FhHNjuv9QNxnHmI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 497->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszigXXkCX4AHVHxhvKBIcJqEtB0QtzwdhnZIXKdEyrS1ne3Y
Pd6e42MHYBm+j7G+LvNc39f9+nGv0/k0rZuHrQErsX9VtvZVYhu9G69DYBCe
0b+h3Rm/FnQmuoz5Ey5L9sM54uFZU/2ks8Fz+hQ3cyjM4IfDUtrYs398nGdP
V+qdyKU7HzR2xsfeNT4netT9YG96d6aXJWfQnR9oNQFSY3MHfLuSONkMqpQu
4a3KjXVk2UWtH9Cregg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 498->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF1Swp4JQD+ItT9dClc3szGIgZZvsTiaT
HK73ftwAeOw+n354nud5eF22y89tmE7HaUnuVweiy/6NYT3/rMsedA6OQ2AQ
XtDb5MWdMlbydLyC65taYfLpHtXhXi1/4mk1ha7NNRRm0oNmp3Cc9q2eWnGV
c3r81R80tqvH2lU6Gz5qP1ib1s60ZskzaPYP1JwAybHagdILkziuB2WKl9BW
zY15uNllrm8H2HqI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 499->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHHoQr32CX9AHBL9QXxBBTwWhHsTbPr0tVMlOdtLAlu0mmZmd
zen+Gp4dgPdx+Qz5c52m/L0d1p9HHi/ncd3stwAs+fjVsOX/lXwY5cZ1BBiE
Z3TXRXGmrJU6lS5jfsFlYt+dIx7utdVDqVN6ipibOSJM5wfNLsJR3quesFNX
PigvdvtDjK342LvKZ6Eneh/sTevNtGbJM0BqYAK1JqDWKLAQ6AhxVA/RUryo
c/aadajZea0zUEp6xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 500->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDe+nRdWKWZZGIhSzZtZyaT
Hq73YdwAeOw+n6E+z/NcX5ft8nOr0+k4LZv7NYBWbHxrWPPfKjYa5Y3rCDAI
z3H30Z3pa71Opasxv+BpYt+cIx7uVeonndJTxNzMEWEaP2h2EU7mfXrvjy7p
XTCXtD/E2IqPvXM+Cz3R+2BvsjeTzZJngJJgAl4T4DUKLAQ6QhzVQ7QUL3zO
XrMONTur9Q1NaHtH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 501->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRAc/xF+P4BX0AMUr1BNE0K+CUD/EP4+uhVqT2Zk1sCVJk9m3
s9mdb/11BeC++Xz68jiOY3me1tPiUobDfph+bucAXl0b3z3M82V0v1jOinVz
lzVIL+SuozpT79WczNWwIOoobscSPDC1Wn7itJ5C5+YcSrPxg3qndDLv03t/
uKx3oi9pfdDaLh97F3w2POp9sDfZm8l6yT1Al2gCkQmIjEYLgkPquBrUcHkR
5+w1c7jetaxvdIZ7xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 502->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDH5Ifz2CV9ADFK9QT7CC/SoI9UP88+haaOtmMpMuZNlXJpOZ
Pd4eXb8zs2fzm7ryuoxjeV/30+ZehvNpmC4Pc5h9Wh/Lmc3rdbT/WN+SvctF
DMALteuo3tRnNU/k5bhYxGG8FZeggehV8geeUlPjtbEGw3R6gHcMJ9M+zdvg
JbUjvqT9GcdW9VC7oLPgw/4HapP9mcxL9CD1ZckT/oR7skYeFEf1wIaqa3GN
WiMP5Z3n+gUuY3uI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 503->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUVsOwjAMs/hA++UIXAEOUHGFcYIisa9JSOMD8dejw6QxUtfJKmXrI7Gd
+Hh79MMOwLP7fvr8ukxTfl/38+Gex/NpnB8PSwAl1fG7w7JfV/rHmivOVW2i
esJruG2YHHtndbKuSgtanEL6ivPOeZaHe3X1k053ptDczKEwq3mQdwonmn1Y
t6HLnZ3wJewPGtvji/pXWM0M1T/oWeolL9mD0BfmJH+UJt6zDonj9aCWx4t2
z7NmHZ53tdYP0I97Rw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 504->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUsOwjAMREcsEFuOwBXgABFXKCcIEqwqIbWLil2ODpVKiSdjN5LbfO3n
mdP91T13AMbD99Pl6ToM+X3bz4tH7i/nfj48LgGUZOO3h2W+jvSP9a5Ym7eJ
3lO+pnYd1Z16r+ZkLsOCNk8hvuKc8z3FvMlPnK6m0LW5hspp9CDvVJ5I+/Dd
BpernfAl7M/R2KsX9a9yNRqqf9Cz5CUv2YPQF65J/igmnjOHzOP1oIZXF+2c
tWYOzzvL+gH9mXsI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 505->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkcENwjAMRb84IK6MwAowQMQKZYIgwakSUnuouGV0qFRK/PPtRnLrOIn9
/H26v7rnDsB4+H66PF2HIb9v+3nzyP3l3M+Hx8WAkqz9Ylj8daW/rXfF3rxN
9J7yNbVrq+7UsZqTuQwL2jyF+IpzzvcU8yY/cbqaQtfmGiqn0YNmp/JE2ofv
Nrhc7cRcwv4cjb16Uf8qV6Oh+gc9S16aJc9AxQozOPNRTOwzh8zj9aCWVxet
z1ozhzc7y/oBtnp6yQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 506->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkU0KwkAMhR8upFuP4BX0AINXqCcYwa4KQl2Iuzm6FmrNvHlJA2kzfy9f
kuPt0Q87AM/u++nz6zJN+X3dz4t7Hs+ncT48LA6UVPtvD0u8Wvr7elesq7eJ
3pNek9u6uWP3LCdzVSxodQrxFeec71njWl1+4nR7Cp2bcyhN5rF5lE7U+/Dd
BpfbOzGXsD5obS9fVL/Sanqo/kHNkpdmyTNQe4UZnPkoJo6ZQ+p4NSjz8qKN
udfM4c2uZv0A5IB6ig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 507->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkUsOwjAMREcsEFuOwBXgABFXKCcIEqwqIbWLil2ODpVKcSZjN5LbfGee
7dP91T13AMbD99Pl6ToM+X3bz4tH7i/nfj48LgGUVMdvD8t8Hekf612xrt4m
ek96jbcNc8fuWU7mqljQ6hSPT7A0NWD/LX7idGsK7c0eSpN5rI/SiWofvtvg
cmsn+hLmB63t+UX5K62mhuof5Cx5qZfcA7VXmMHpj2LiOXNIHS8HNTxftHOu
NXN4vatZP/RYekk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 508->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkU0KwkAMhR8uxK1H8Ap6gOIV6glG0FVBqAtxN0fXQq2Zl5d0IO38vvcl
OVwf/X0D4Ln7fvryOo9jeV+20+JWhtNxmA73cwC1a+O3h3m+jO4fy12xbt6y
Buk5bxvmjt2znMzVsMDr1IhPsLgasP8aP3GGNYX2Zg+lyTzWR+lktU/frXCF
tRN9SfOD1o78svyVlquh+ic5S17qJfdA7VVmCPqjmHjOHJGOzEGNyBd+zrVm
jqh3LesHy395yw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 509->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkcENwjAMRb84IK6MwAowQMUKZYIg0VMlpHJA3DI6VCrF+f42kdw6TvL9
bB+u937YAHjsPp++PM/TVF6X7by5lfF0HOfD/WJA7Vr7xrD46+p+tt4V++Yt
a5Cey23N3LExy8lcDQu8To34BIvsAXytIT9xhj2Fzs05lCbz2DxKJ+t9+u4P
V9g7MZe0PmjtKF9Wv9JyPVT/pGbJS7PkGahYZYZgPoqJfeaIdGQNakV54X3u
NXNEs2tZ3/iJeYw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 510->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkcENwjAMRb84IK6MwAowQMUKZYIg0VMlpHJA3DI6VCrF+f42kdw6TvL9
bB+u937YAHjsPp++PM/TVF6X7by5lfF0HOfD/WJA7Vr7xrD46+p+tt4V++Yt
a5Cey23N3LExy8lcDQu8To34BIvsAXytIT9xhj2Fzs05lCbz2DxKJ+t9+u4P
V9g7MZe0PmjtKF9Wv9JyPVT/pGbJS7PkGahYZYZgPoqJfeaIdGQNakV54X1X
B3FEs2tZ3xmYegw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 511->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkcENwjAMRS0OiCsjsAIMULFCmSBI9FQJqRwQt4wOlUqJv/83kdw6TmI/
fx+u937YmNlj9/n05XmepvK6bOfNrYyn4zgf7hczq523b8wWf13dz9a7ZO/e
Yg7IF2q31txpYy0ncjkWi3mq4iMsSgPsVfIDp9TUeG2swXI6PWB2LE+mffru
D5fUjswl7U9orOpl/bNcQUP2T3qmvDBLnAGLVWQQ82FM6CMH69/FsT4uVdei
H/oADjU7x2pvFiV6ig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 512->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRb84oF4ZgRVggIoVygRBglMlpHJA3DI6VCoh/v4OjeQ2cWP7
2b/7y324bQA8us9jSM/TNKXXeTsfrmk8Hsb5424xIPfWvj4s+7L6n5W74mxi
OQflc7Vrq+7UvpqTuQwLfJ4c8QmWaAbca8hPnOFMoWtzDZXTzQiazcWtqMd6
trjC2Qld/vUX/U8yBhTPc27kZ/3Lu9Gzyye0ZA2ULzNDoI9i4j1zqP6Nn+vz
iurC710fxBFpZ1jxBjBhekk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 513->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksENwjAMRb84oF4ZgRVggIoVygRBoqdKSOWAuGV0qFRC/P1NSyS3ieP4
v9jZX25dvwFwb96fLj1O45ie5+20uKbheBimzd1sQG6tfXyY52W0XyuxYm3O
cg7K57Rrq2JqX83JXIYFPk8mvhzsc5xiXuQnzrCm0NqsoXK6GkGzuXMr9Lif
v7jC2om+LOlF70lqg85ynQMe9T7K/w821UvugfJlZgj6o5h4zhzq/sbP+jwi
Xfi5uwdxRL0zrHgB8H97SQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 514->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRT8uxK1H8Ap6gOIV6gki2FVBqAtxl6NrodbMnz8JFqZNJsn8
l/k9XO/9sAHw2H1efXqepym9Ltt5ckvj6TjOi/slgNzZ+OawjNen+8W6V8zN
Wa5B9Zx2GcWeMldyMpdhga+TiS8H67xPMTf5iTPsKbQ2a6iaph/knapT6331
XIMr7J3wpaUX/U9Su3J/5Zfrofr+waa8ZA9ULjND4I9i4jFzqPubPOvzE+nC
j909iCPyzrDiDVGde8k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 515->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRT8uxK1H6BX0AMUrtCdIwa4KQl2IuxxdC23N/PxJMDBtMpnM
vMxPMzy68QDgefp+uvC6zXN498dlcQ/T9TItm+fVgNha23xY5/tof7bHirU5
yzkoX1Y7tSQm9aWczGVYkOeJxBedfY5TzFV+4nR7Cl2ba6icph+kncpT6n3x
XIWrxMu61Op570nWKNxf6ZX1UP3/YFNasgbKF5nB0Ucx8Zw51P2Nn+vzUL0S
vZX3IA5PO8OKD1Fhe4g=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 516->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KhDAMhcMsxO0cwSs4B5C5gp6ggq6EAV3I7Hr0GcGf5vWlxUK0P2ny
Ja9V/2nHh4gs5f/TuvU9z+7bFdticNOrnrbD524ivtF27Mk+P0dz2elL1uou
xoB4Ue7QAp9wL+RELsUicRwPfN44Rz/GnOUHTrOnwnNjDhZT9QO0Y3FSvU/e
y3CleFGXXD7rPdEcifqZXlEP2f8GG9MSNWB7HhkMfRgTzpHDikNrYIP1ivSW
1gEclnaa9QcmzntJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 517->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksENwjAMRS0OiCsjsAIMULFCmSBI9FQJqRwQt4wOlUqxv78dEclt4iT2
y7cP13s/bETksft8+vI8T1N5Xbbz4lbG03GcN/eLidTO2tcny3wd3c/Ws2Rt
7mIMiOdya1NntE9zIpdhER+nAl8N9vEcY27yA2eoqfDcmIPFNHpA7VicTPv0
XoMr48W6tPJF/URzgHZO54AHe8r8/2BjtcQaMJ/mpXWN9hl/wqHj0DewEWkl
fu7eoUbWH0YTeQMLlHuI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 518->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADLF6hnmAF+1UQ6of4t0fXQq3J7GSLgbT7yGYm
kxyu967fAHjsPp8uP8/jmF+X7bS55eF0HKbL/exASd6/Z5jXi6WfL7FiXxK9
iSwJbOsmxp4VhaG4oM7jcODjmEukAdca8ieeoabQ2Iyhcjo9qHcqT0v75rsV
Xi2+3Jc1PDlPEQZpV+kc8OGZcv8/uKlecg/UmeUr+xrdK/4NHjaPrEFZpBXq
dVWHsdZ8OE3wBgRye0k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 519->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbiQbj2CV9ADDF6hnmAEuyoIdSHu5uhaqDWflzSQdj6ZvJeX
HG+PftgBeHbfT19fl2mq7+t+3tzreD6N8+VhcaAV7b8zLOvVyt/XWLJvxbyJ
rBBs6SJGnjWGwbjA51E40HGWS6SBrTXkb3iGmoJjWwyWU+lhesfyZNqn7zZ4
ZXxtXzIP5ynCMNo5nQM+dqbUP6nZ5SO9tD1gZ5Iv7Wt0z/gnPGQeWgOzSCv4
tatDWDYfShN8AAeBe8k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 520->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6VCrFy9i15DZxHHs8
k9P91T13AMbD99PV6ToM9X3bz5tH7S/nfj48Lg60ov0Xw7Jerfx9zSX7Vsyd
yArpLV3kyFhjPRgW+DqqD3SexRJxYGcN8RucIafgvW0PVlPxYbRjdTLu03sb
uDK8VpfMncZbPQx3jucAj31T6p/M7OoRLa0GLCbxUl2jc4Y/wSHr0BmYRVzB
r90cwrL3oTjBB40je4o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 521->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbnk6VCrFy9i15ChxHHs8
k9P91T13AMbDd+nqdB2G+r7t58Oj9pdzP18eFwda0f6LYdmvVv6+5pJzK+ZN
ZIX0li5yZKyxHgwLfB3VBzrPYok4sLOG+A3OkFPw3rYHq6n4MNqxOhn36bsN
XBleq0vmTuOtHoY7x3OAx/4ppUsys6tHtLQasJjES3WN7hn+BIesQ2dgFnEF
v3dzCMv+h+IEHzFYe0s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 522->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKAkEMLDyIV5/gF/QBjV8YX9CCngaE8SDe+uk6MI5ZKulAml6SVKU6
h+tjuG8APHffZaiv8zTV92U7H251PB3H+XG/ONCK9t8dlv1q5e9rLDm3YnIi
KwRbuoiRd41hMC7wdRQOdJzlEmlgew35G56hpuDYFsNpA52regrqZNqneR1e
Xb4BHsOxPaUYRjunc8DHzpTSNOnZ1ZP/SP66+y/QdR0H+874BzNledEemEVa
we9dH8Ky+VD18AEQj3qI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 523->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAMHHoovfYJ/UL7gJAvpC9woT0FCskh5OanJ4E0lUaSbZDxIs2M
ltvr231OAMbLunVpaochzc/zdnmn/nHvt8/rbkButP3esJ+P1fzt8HXuKpYx
CM9wSxM+8k3qZF1KCyxOJn05+Gc/ycO5hvpJZ1hT+NzMYWoDHatyCnBKtS/G
VXRV9QZ80dyU+LnH2bl7fTd9IT+ujTszldngXlf7Ao1rNEjsSH8wU6zLzcFb
ERfs2eQhVmk+FB4WfZh6hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 524->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbgQtx7BK+gBileoJxhBVwWhLsTdHF0LtSYvedNAhslM8vLy
OVwf/X0D4Ln7Hn15ncexvC/bybiV4XQcps/9rEDtvP7eMN8X6f66+Ca2i2UM
wgu5rRof+2Z5Mi/HBRGnEr8q/tkv47zKn3jKniLPzTlCb+BjXU0Cp9X7ZtwK
r1W+Ip/am1Z+nnFN7GzuYS7kx71Jd0btBtmqpoAJjxs4WGzFX+wU80pryETl
QryHOoy09sPh4QOqonpH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 525->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCPYi3fboWak0ms9sGUjbb7GQm
yfH26PodgGfz/XTpdRnH9L7up+CehvNpmH4eZgdy6/13h/m8WPv3JVfE7i1j
EF6obd3k2DvLk3k5Log4mfgpDSpPcV7lTzyLPYWuzTUY2+IqTQqn1vvquxVe
W/iWNKq9qdXnGWcRq7mHuVAe90buTGk3xEyUpoAJjyvxSnsldkFp4frcv2Cl
WojnoMNYbT8cHj7C43pF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 526->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPwQfz2CV9ADFK9QT7CCfhWE+iH+9ehaqDWZnWQXsuwjmUwy
OVwf/X0D4Ln7bn15ncexvC/b+XIrw+k4zJ/7xYCp8/Z7w3JeV/e31VfcXSxj
EF6V25rxsW+WJ/NyXFDjTMRP1aD8FOcmf+IZ9hQ6N+dwmISralI4We/TuAav
jG/W32husvyscaip0KvqIc8JkNZc4VkdhdZNXeBxJV40V1yDjRU4sga1olyI
NYp6EGnn8PABOv16BA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 527->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfEbU+HSWOkjpNWytR2ie3E
PVwf/X0D4Ln7fvryOo9jeV+28+FWhtNxmH/ulwCmro7fHZb9urp/rLniXNUy
BuE5bhsmx95Znayr0gKPM5E+1YPKU5qb+klnOFNobuaoMAlX9aRwstmndQ1d
md5svtG7yfjZ49BT4ZebIb8TIO3Z4VkfhddNX1DjSrzoXXEPtlbgyB7UirgQ
e+R4Efil8PABLfJ5xQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 528->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADJr4wXlAkOE1CGgfEbU+HSWMkjtNWytR2ie3E
PVwf/X0D4Ln7fvryOo9jeV+28+FWhtNxmH/ulwCmzsfvDst+Xd0/1lxxdrWM
QXiB24bJsXdWJ+tyWhBxJtKnelB5SnNTP+lMZwrNzRwOk3BVTwqnNvtqXUNX
OrvGfLN3U+Nnj1NPhV9hhvxOgGrPAc/6KLxu+gKPK/Gyd8U92FqBI3tQK+NC
7lHgReKXwsMHSQF6RQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 529->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADJr4wXlAkdpqENA6IG0+HSWMkjtNWytR2je3E
OVzv/bAB8Nh9P315nqepvC7b+XAr4+k4zj/3SwDvzsfvDst+Xd0/1rfi7HIZ
g/ACtw3zxt5ZnazLaUHE4VxVQ9CTaG7qz7i4p9DczOEwCdfeKW2spVavzGvo
SnvX6G82NzV+9jirX/kVeshzAlRrDnjWR+F10xd4XImXzRXXYHMFjqxBrYwL
uUeBF4lfCg8faT96Bg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 530->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOgzAMHPVQ9don8IXyANQvwAuCVE5ISPRQ9danAxJQe2wnkRwlTjwz
Xqp+aocLgPdt3dr0ec5z+nbX7fJKY/0Yt8f7bsCv0Xb4sJ/P1fzt/OvcVSxj
EJ7hlib+SJ/UybqUFlgcjvVyMHoCzUX9ERfXFD43cyhMwpU+TxtryeXrxhV0
hbUr1Deamxw/9zjK3+uXqSHPCZDN2eBxDPW62BdoXDUX9B7qD2aKcdwcvBVx
wZ651nLlZkXhYQEGTnqG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 531->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz1Cr6AHKF6hPUEK9qsg1A/xz6Nroa27k9kksCGvnZmd
TTM8uvEA4Hn6TV163eY5vfvjsrmn6XqZlsvzGsCn9bGdYV3vo/3H/lbsXS5j
EF7GbcO8sWdWJ+tyWpDjcK6qIdMTaK7qj7jYU2hu5lCYzg/qncIpeV/Mq+gK
vav4G/2bEj/3OKpf9QvMxf8EKNYs8WwO9braF3hc9y/oPtQf5dFe1qBGxIV8
zV7boXyTePgCw1J6RQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 532->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwjAQHPwQfz1Cr6AHKF6hPUEK9qsg1A/xz6Nroa27k9kksCGvnZmd
TTM8uvEA4Hn6TV163eY5vfvjsrmn6XqZlsvzGsCn9bGdYV3vo/3H/lbsXS5j
EF7GbcO8sWdWJ+tyWpDjcK6qIdMTaK7qj7jYU2hu5lCYzg/qncIpeV/Mq+gK
vav4G/2bEj/3OKpf9QvMxf8EKNYs8WwO9braF3hc9y/oPtQf5dFe1qBGxIV8
zV7boXyTPuELwB96Bg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 533->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsEJwzAMPPoo+XaErtAOYLpCOoELzStQSB4lv4yeBNJUPp9sgYLtSLrT
SdfXp+1OAMZm/bTx+xiGOD3P2+Ud+/ut335edgfmkPrvDfv5sPD3I1bck1yu
QfUybOsmxr5Znswr4YK8DueqHjI+Ducqfw+LNYXGZgxVM9GDZqfqlLQv5lV4
udpV9PX2poTPM/b6V/MCY/GeAMWeZT2bQ7OuzoVj7V4EOnv8vTy6yx6UeVjI
z6y1NaWb1AkLQS56hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 534->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPWB+HYEVoABIlYoEwSJviohlQfqr6NDpRKcyzmJ5NZOYt/5
nNP9OYwdgNfx+xni+zrPcbkdtuARp8t52g773YA15Pbbw+6nFf7/dDeUcZbL
NahegW3N3LF7lmfCUFwczjZX9VDwcTg3+XtYQlOFzRiqZqYHzU7VqWlfzWvw
crVr6Ou9mxo+z9jrX80LjMXvBKj2LOvZHJp1cy58176LQL7H38ujWPagloeF
0met7VK6SZ3wATA0ekc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 535->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHPWAuPYJfAEeEPGF8oIg0VMlpHJAvfXpUKkEZzJOLLl1FnvG
45zuz2HsALyO388Q39d5jsvtsC0ecbqcp+2w3x1YQ+6/PexxsvD/p7uhXGe5
XIPqFdjWzR27Z3kmDMXF4WxzVQ8FH4dzk7+HJTRV2IyhamZ60OxUnZr21bwG
L1e7hr7eu6nh84y9/tW8wFj8ToBqz7KezaFZN+fCd+27CBR7/BV3UUf2oMzD
Qhmz1taUblInfACJNHrH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 536->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAESuUCYJEX5WQ2gfi19GhUkmd8yWJ5NZJbN/5
4vPj1Q8HAHP3+/TxfZum+Lkf180zjtfLuF6eNgOWkNv/DJufVtj/KTbse+dD
1KB6DtuaibFnlmfCIPyF8UWPirfkU+Dc5E88a5oqbMZw2iDPtbVcv0KzFl6W
1+BV1K6hr8Lhnmp4tf7Ve4GxeE6Aas+yns2ht26+C8fauQjkl/iLeVB1ZA9q
lbDgfdaaeTCm1AlftTN5xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 537->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFA/TICK8AAESuUCYJEX5WQ2gfi19GhUkmdyyWO5NZJbN/5
4vPj1Q8HAHP3+/TxfZum+Lkf180zjtfLuF6eNgOWkNv/DJufVtj/KTbs+8KH
qEH1CmxrJsaeWZ4Jg/AXxhc9Kt6ST4Wzy594tjRV2IxRaIM819Yq+hWaeXhZ
nsOrqp2jr8Lhnlp4rf7Ve4GxeE6AZs+yns2ht3bfhWPtXATya/zFPKg6sge1
QiVP+Kw182BMqRO+nFh5iA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 538->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmBFWCAiBXKBEGCVyWk9lHx6+hQUVLncnEiuXUS23dn
53R/dc8dgPHw/XRxug5DfN/2y+YR+8u5Xy6PqwFzyO1/htVPK2z/FBu2feFD
1KB6BbY1E2PPLM+EQfgz4wuNirfkU+Hc5E88vZ4qbMYoeoM819Yq9IqetfCy
vAavau8a/VU4rMnD8/SreYGx+J0ArmZZz86XZt2cC8caDhk3j794D6qO1KBW
qOQJn3vNPBiTdf78D05VeUk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 539->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMPPFAfBmhK8AAESuUCYIEr0pI5YH4dfS2ok2dy9WJ5NZJbN+d
nebxbl8HAJ/T9Gnj99b38Xc/zptn7K6Xbr48LwYMIbf1DIufVtj+KTZs+8KH
qEH1CmxrJsaeWZ4Jg/AHxhcaFW/JZ4dzlT/x9HqqsBmj6A3yXFur0Ct6VsPL
8iq8PP5efxUOa/LwPP1qXmAsfieAq1nWs/OlWVfnwrGGQ8bN4y/eg6ojNagV
dvKEz71mHozJOv/+CGNkeck=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 540->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDyIV5/gF/QBg1+ILxjBnAJCPIi3PF2DMemuXuLAJLPW1nO4
3pt2A+Cx+3ya+jz3fX1dtuPkVrvTsRs391MHhqL7bw3TeG5l+c9nyzI3YzgY
hGe4ZRdn5JrUqbQVjRlpHgJs1hJlIPdS/aQzy9TjZg6TDfRdiWX8cmZ/8Kl7
K7oy/Vm+Hg97yvgy/169wFz8ToDUs4sn60u1Xq0LnxUalLZMv/MejBcEHrxG
uFG2nLungznZ53f8BsfWego=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 541->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEuyoIdSHuenQt1pq8fOpA2vlk8j6Z
/eXWdhsA9+b9aevjNAz1ed5Oi2vtj4d+OtzNAYxFx3cP83wZ5fdfcotdq7tc
g+oZbBkiR+5Jnoobcwk4j0Ft5hJ5wFpD/sQz89TDZgzjDfRdWcvoZc/+wON+
Zrwy/pm/0bvJ8LnHkX6vX2AsfidAqtmtJ/tLvV7tC+cKDopbxt95D0YLAg3e
oLqRt+y7x4MxWedn/gLk9HqK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 542->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNksENwjAMRS0OqFdGYAUYIGKFMkGQ4FQJqT0gbh0dKtriPNuBSG6dxLH/
//b+cm9vGxEZmvenzY9T3+fneTttrrk7HrrpcjebyJhKW85k9teVvv81Ntl9
8ZY5kM/U1qZi9JnGWWAjlgDzGOQmlkgDcg3xA2dNU682axhtpHyrcxm+1OyP
euxnDVcNf03faG5q9dlj9pXzF2HhnFEbj7ObT/cXvf7ZF8bquUjwI/zOPBgu
EnDwFvJ6HBafWhMHa5Lnx38BwgN7Cg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 543->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhYML6dYjeAU9wOAV6glG0FVBqAtx16NroY6Zb5LYgbTzk7y8
vGR/ufe3jYg8us+nz8/TOObXeTsfrnk4Hob5cbeYyJRq+97Jsi8r/f7FN7Xn
KpYYwGtya1M++k7zrLiRi8N5crDJxdOAtbr8wTPS1MrNHI02UsdqrKZearYi
H/sZ8Yr4R/p6cxPlZ4/ZV86fx4VzRm2smk083V/0+m9f6KvnImHv8Q94iJGH
+jULmFYN1KnEqWXpZmoib865ewg=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 544->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszigXXkCX4AHVHxhvKBIcJqENA6IW58Ok8ZIXKdsUra2S2LX
zv5y728bAI/u8+rz8zSO+XXeTptrHo6HYfq5mwMoycf3DPN6edLvu+Smeu9q
uQf1q7BtmBx7Znk6bswl4FyC3swl0oDvGvInni1NFTZjVNrA19pe1X1ZsxV4
7GeLV4t/S99oblr47DH7yvMXceE5Y23UnWU/6y95/dcXzrVzkWgteqmZUD5z
TWE8+BqJBa2t1BBaN6kJ3ptKesk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 545->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0OgkAMhV9cGLYewSvoASZcAU8wJLoiMcGFYTdHVxLAzuuPTFKY3/b1
a8/9s3scALya76fL73Yc83Q7zot7Hq6XYT48LQaUVNu6h2W+jfT7b3eTXldv
2Qf5U7GliTtyT+qstLEWR3NxfLMWjwFzcvWTzoipFbuQLsUG9VvpS+XLzHbE
43pGuiL9EV+vb6L4UQ0U50AL9xmzsXI2/cn6Uq3/1oXvyr5INDd8ef2gcoGT
gzW8WLDZmgxhczOZ4AOdwXpL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 546->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADFK+wnqCC+7UgrB/in0fXhS2kk0k0kNJHOplM
crjeh3ED4LH7LkN9nue5vi7b5XCr0+k4LY/71YF36b3dYd03a2+wscWfu7+E
0VkRua2bGHtneVosxwUeh99UDY5PwFlqR255RngKh/WU2qD/a7FcvazZH/m4
nxmvjH+mbzQ3Wf6sB07nhAvPGWujapZ4tr/U65994Vg7F4X2AiuaB1cLghqU
RbmgtZUaQusmNcEHyt96yw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 547->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKAjEMHPwQfz2CV9ADFK+wnqCC+7UgrB/in0fXhS2kk0m0kNJHMplM
crjeh3ED4LH7bkN9nue5vi7b5XKr0+k4LZ/71YB36a29YT231f5gfYu/d7GE
0a0iclszPvbN8rRYjgs8DseqGhyfgLPUjkzmYt4Ch/WU2qCPtViuXtbsj3zc
z4xXxj/TN5qbLH/WA6dzwoXnjLVRNUs821/q9c++sK+di0JngRXNg6sFQQ1q
RbmgtZUaQusmNcEH7Bl6jA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 548->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPIo+WaErtAOYLpCOoEL7StQSB4lv4zeBmKQT6ekAhlblk7S
SefHu381AKb2d/T5cxvHPN9P6+OZh+tlWD+7TYEl1Vps2O5Fyh+sb/LvKpYw
Kkkit1XjY222TovlaoHH4VjVg6snqFlyRypzcd0Ch/mU3KCOtViuX+bsj3x7
djXzkL8DH7U3yi5zE3eO551aeM+YG9WzxLPzpVkfzoV97V4kugusaB9cLwh6
UBLlguZWcgjNm+QEXx83eww=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 549->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHoQrz7BL+gDFr9QX7CCngqFehBvfXotdCGZzK4tpOxmk5lk
kvNj7F8dgPfx9+vz5zZN+Xs/rJdnHq6XYX08bQbMyVvxYTuXr7zBxqZ4d7mE
4b4kuK2ZGOuzdVqsUAsiDueqHlScqllqRya5uG6Bw3pKbeBzLVbol/vZwdfy
q5nX8lr61vZG+SU3aRd0btTCe6b0VL0EPDtfmvXfuXCs3YtEZ4FV2weeM+fM
zAefI7mgtVUalljmlJpgAQJce00=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 550->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHoQr32CX9AHLH6hvmAFPRUK9SDefLoWupBMZrddSOlmk8xk
ktN9Gp4dgNfx/xny+zrP+XM7LJdHHi/ncXnsVwO+yVvxYf0vp7zBxqZ4d7lU
w50ksK2ZGOuzPG2twAWxDueqHlSc4iy1I5NYzFvUYT2lNvC5tlbol/vZgdfy
q5nX8lr61vZG+SU2aRd0bnDhPVN6ql5YbzdfmvXmXDjWzMdxI75b+2DrBF0I
P5waFrS2SsMSy5hSE/wAslJ7Dg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 551->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHHoQrz6hX9AHLH6hvmAL9lQQ6kG8+fRa6EIymV1dSOlmk8lk
kn58DFMH4Hn8fob8ui5Lft8O2+We58t53h5PuwGf5K34sP+XU95gY1O8u1zC
cCeJ2tZMjPVZnhYrcEHE4VzVg4pTnKV2ZLIW8xY4rKfUBj7XYoV+uZ8/6rX8
aua1vJa+tb1RflmbtAs6N7jwnik9VS+st5svzVr1VOPL83HciO+vfbA4QReq
H06tFrS2SkPbL2se8LACPWF7jg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 552->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDefLoubCGZTKqFLts0mclM
erjeh3ED4LH7fob6PM9zfV22y+FWp9NxWi736wbexe8Ww/rfVruDzS3x7GoJ
w60iuO02OTZm+7RYoRdEHK5VGlSe5WCf0v4zLsYUOOyn9Aa+1mIFvaznD75e
XM08q+v5m70bFZfc5F3wudMLvzPlp9LCfrv50qyVpqxfno/rjfr99R4sTvCF
+B0n8yFqYG+Vh1Yvex7w8AEuHnwM
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 553->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQXDyIV5/gF/QBwS/UF0Swp4JQD+LNp2uhgdnZ2TSwpdkkM7Oz
e7o/h3FnZq/D/zPU93We6+e2XzaPOl3O03J4XMPsW3y0nK3/bbUzw7sl7t1b
wnCrCG4MuIM4qBOxghbkFzW6OoWWjIN9SvVnXIwpcNhP6Q37Qb1TOMi7xdfL
q55n73r+ZnOj8pKbvAs+d7TwnCk/VS3st+sv9VrVlOnl/jhtpHdrHhAn+EL8
jpP5LNbA3ioPsV72PODZDzuoe80=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 554->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+LNp2uhgd3Z2TSwpUk2M7Oz
e7o/h3EH4HX4f4b6vs5z/dz2y+ZRp8t5Wi6PawDf4qOdYf1vq93B5pa4d28J
w60iuG2YHItjdVqsoMXyixpdnUJLxsE+pfozLsYUOOyn9Ib9oN4pHMu7xdc7
Vz3P3vX8zeZGnUtu8i743NHCc6b8VLWw366/1GtVU6aX++O0kd6tebA4joc9
gc8NfIg1sFfKQ1svex7w8AMFBntP
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 555->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwzAMEz2MXfuEfWF7QNgXuhdksJ4Kg+4weuvTt0IDtiKnAZfGcSRZ
zuX5HsYOwOf8/wz5e5/nvDxO2+aVp9t12g77PYA1+Sg57P9llTPY2lTv3V3C
cCsJbhumxuJYnRar0mL5RY+uT6El4mCfQv0RF2MKHPZTesN+0OwUjuU94mvl
1cyjey1/o3ej8pKbvKt8bmjhd6b8VL2w326+NGvVU6SX5+O0Uc3Re+A5uzzx
O07ic1yo+2avWQf7pjwBfnAGe88=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 556->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHHoQr32CX9AHBL9QXxBBTwWhHsRbn14LjexOZtNASrPZzMzO
7un+Gp4dgPfx9xny5zpN+Xs7rIdHHi/ncb3stw3Mye8Sw/ZfVrmDzU312b0l
DLeS4Lbb5Fgcq9NiVVosv6jR1Sm0RBzsU6g/4mJMgcN+Sm/YD+qdwrG8e3yt
uOp59K7lbzQ3Ki65ybvK54YWnjPlp6qF/Xb9pV6rmiK93B+njXL25oH77OLE
Xy3CVbPFdf7fkQ72TXkCLFI/e5A=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 557->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwyAQXHooufYJ/UL7AOkXkhdYSE6BQnIovfXprUTD7jhrBEVXnZmd
3evz1U8nEVm7/9LH92NZ4mc4p8MY5/ttTpeXPEW+wc4Sk7wvo9yJfhvqs/kL
GGYEwq2neqNxtE6NVWnR/CRHkyfR4nGgT65+jwsxCQ76Sb1BP6B2DEfzHvG1
4qzm3r+Wv17fsDjlBu8qnxtasM+YnywX9NvUF2rNcvL0Yn2MNnhz1A9YZxMH
/moALustzHP/BzrQN8xz2/8ATwx7UQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 558->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAMFD2UXPuEfqF9gOkX0he40JwCheRQcsvTk9C4SKORY7DxIs+M
Rrq+Pm13EpGxWZc2fx/DkKfneTu8c3+/9dvjZZ8ic7Kz3Mm+L6O8iY5N/mz+
AoYZiXDrqWI0jtapsZwWzU9yNHkSLREH+hTqj7gQk+Cgn9Qb9ANqx3A07xFf
7Z7VPPpX85fGi8eO+NA753NFC/YZ85PlglpNfaHWLKdIL9bHaIOYo37AOpt7
4HcDcFlvYZ7/f6ADfcM8f/sFTht70Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 559->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRYcuxG2P4BX0AMEr1BNE0FWhUBfizqNroZE/P39iAylJM/nz
5k8O12m4d2b22H8/Q36e5zm/Lrtlc8vj6Tguh/06zd7Jz/LP1nUZ5cwwNtV7
d5c03EgiN06IQR3kRK2KBfOLGl2dgiXKwbWG/FEu1jSdm3NU3rAf1Dulg3nl
+QYOxdXib/kr401zKUb2rvK5wcLvTPmpamFW11/qtaop4uX+ODaK+fceUMfd
YU/UIF31ttin3z3iiHrnWT8n+nvP
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 560->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRT8uxK1H8Ap6gOIVxhNUcFYDwrgQdx5dB6aS/PwUCx3aaZr/
8tPD9T6MGwCP3fcz1Od5nuvrsl02tzqdjtNyuF8n8C5+tn9Y1220M9jYEvfu
LuVwowhtO02MzWM5ba7AYvVFja5OwZJpcK0pf6bFOaG1WSN4w35Q71QeqyvP
/+BQXL24nr/SP2guxcjeBZ87LPzOlJ+qFmZ1/aVeq5oyXu6PY6OY9D0kfXZ8
pB8G5VVvi3363SM/st45n/ABOXZ7jg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 561->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kk0KwjAQhR9diNsewSvoAYJXqCeIYFcFoS6kux69FhuYeXmTQErS+fvm
ZS7P9zB2AD7n32fI3/s85+Vx2i+vPN2u027sjw2sye/yD8e5rGKD9U313cVS
DreSqG238eH7ynkVC3ScjVU9KD9bg3sN+YldaWptsn5LG/hYrqPyRNpD1Is4
FFfLr6Wv1A+aSzGydpXODRaeM6Wn6oVZbZw7Bz1FvPw+jo18wnkI3tnxUf1q
UV41W6xTxcz2YA7/5w39GnxL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 562->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kk0KwjAQhR9diNsewSvoAYJXqCeIYFcFoS6kux69FhuYeXmTQErS+fvm
ZS7P9zB2AD7n32fI3/s85+Vx2i+vPN2u027sjw2sye/yD8e5rGKD9U313cVS
DreSqG238eH7ynkVC3ScjVU9KD9bg3sN+YldaWptsn5LG/hYrqPyRNpD1Is4
FFfLr6Wv1A+aSzGydpXODRaeM6Wn6oVZbZw7Bz1FvPw+ji3qkTmCd3Z8lKta
lFfNFutUMbM9mMP/eQNqKXzL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 563->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwkAMfbgQtz2CV7AHGLxCPcEIdlUo1IV016NroSPJm5cJpCSdvOTl
c33Ow3gC8L78PkP+3Jclr4/z7rzy1N+m/bE7FNiS1/IPh12kvMHGptp3WMrh
JInaVk0M+xvnVVygcRarelBxtgb3GvIn7mqm9k3Wb80GHst1VJ7W7KOeWvla
NnOOeqziIXiTbffD+wrvRe2F70TUZjxztThnBz1FfHk/jlvUI/MI9uz4Ua5K
KK+6LZ7TH0fziHbn5oQvnC19DA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 564->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKwkAMRYMLcesRvIIeYPAK9QQj2FVBqAtx16NroZXk9WcGpsx08pOf
/3O6P7t+Z2avw+/T1fd1HOvntp8vjzpczsP8eFy22VTiXv/Zcl7X+mY+tmzv
AYscYRVR228Xw/vEvIqLaZzHqh5UnK/BXlP+4K409W+yfksbi1jWUXla2tO/
jIfi1YpT+rbqsyd6RI/pVzovyhfOiahNPLl6XDgnuIwv/Qncsh7JI/E58EOu
zUJeNVvU6Y+DHpl3QSf7AqQyfEs=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 565->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9kkEKAjEMRT8uxK1H8Ap6gOIVxhNU0NWAMC7EXY+uA1NIfn5a6NBO85Pf
l57ur+m5A/A+/D9T/VyXpX5v+3XzqPPlPK+Hx20CrfjZ/2Fb99HPYGNL3Dst
5XCDNDYfSowJtSlX8AKts1p1BxVna/BdW0n8k3fF1J7J+iM28Fquo/Iw+6xe
ps98jeIU3yE7aD/yvRC7wHnghd+Z4qn8MW+rc+tEl/nl/jhv2R3ZR9Jn1jSO
g9dwL7I1s2YeWe8cJ/wAyrB7ig==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 566->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhPRRv+3QtdCGZTrKQknQzyWSy
l+dneB8AzKf/Z6jLfZrq93Fcg1cdb9dxvTxvBrTirf/D5vfT72Bzyz52WKrh
ThG9rZkcjhvXVVygcRarZlB5tgfPGvIn7kpTeyf7Z9rAY7mPqpNpz/uLeChe
WZ7SN9UOmo/ixtrtdE648DtTeip+rLfFOT/ARXx5P45bNCPzCPbMmMZ58Bje
ReSz1qxHtDunE37LznwK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 567->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UUEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhPRRv+3QtdCGZTrKQkjSZZDK5
PD/D+wBgPv0/Q13u01S/j+MavOp4u45r8rwZ0Iq3/g+b31/PwdaWfeyw1MO9
ImZbMzUcN+6ruEDjLFbtoOrsDN415E/claY2J+dn2sBjeY7qk2nP94t4KF5Z
ndQ/0w6aj+LG2u10DvTjeVbTdBe1m8E5P8BFfPk+jlu0I/MI7syYxnXwGL5F
5LPWrEd0O6cTfkWve8s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 568->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWE9iDe9ula6EoyO9mFlGQ3k0wm
PT9e43QAsA6/z5jft2XJn/txC555vl7m7fG0G1CSt3qH3a+nJO//c5KPHZZq
uJNEb2smh+PCdRUXaBzPwTiVZ3vwrA1/yq13SlP7Jvv3tIHHch9Vp6c97y/i
oXj18qT+vd1D81HcWLtG50A/7mc17c6iZjM45we4iC/vR/1LzYzMI9gzYwrn
wWN4F5HPWrMe0e6cTvgCbJN7TQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 569->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWE9iDe9ula6EoyO9mFlGQ3k0wm
PT9e43QAsA6/z5jft2XJn/txC555vl7m7fG0G1CSt3qH3a+nJO//c5KPHZZq
uJNEb2smh+PCdRUXaBzPwTiVZ3vwrA1/yq13SlP7Jvv3tIHHch9Vp6c97y/i
oXj18nr95O6h+ShurF2jc6Af97OadmdRsxmc8wNcxJf3o/6lZkbmEeyZMYXz
4DG8i8hnrVmPaHdOJ3wBc6J7zQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 570->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwjAQHDxIrz7BL+gDgl+oL4hgTwWhPYi3PF0LjexOZhPYskl2MrOz
PT9e43QAsA6/z5jft2XJn/tx2zzzfL3M2+VpD6AkH/UMe15XST7/1yS/d1h6
w60kuG2YGoXhtxotll/06PoUWiIO7rXRT7X1THlq7yR/zxt4LPOod5SPsq6j
Q+nq1fX45Oyh9Sht7F3jc+Af81lPu72o3gzO5QEu0svzUf9S0yPrCObMmMJ1
8BieRZSz1+xHNDvnE76AMHuO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 571->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAQGzyIV5/gF/QBi1+oL6hgTwWhHsTbPl0LrUzSZBe2zLaTTSbp
6f7shl1EvA6/R9e/r9PUf277+fDox8t5nD8elx1RC+71XSz1umrB+t9T8AxY
ugNWEdx5px6F4bs2WjK/mBHmFFocB89q9ZMXytP8TfK3vAnEMo+6p+U9czgd
Slerr8UnuUPopjrnw3k5XpkL/yeCm/Gb2RIOaoNzejkf0OZmZB0mZ8ZU7gvE
cBauZq/ZD5cd+BRfED97TQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 572->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAQGzyIV5/gF/QBi1+oL1hBTwWhPRRvfboWWpnEZBemzOzubDJJ
T/dX99xFxHj4fro6XYehvm/7pXjU/nLul8PjGhFzwdj2Ys23NRfMf3cK1tBL
b8AqAjtHusM8eC8Ul4wvZoQ5BReHwbNa/qSF0jSfSfyWNqwH4ah3Mq7DU3q0
6pYmTv8mdgjelGd/2C+HK33h/0Rgc//fbKkPctPn+LI/wM3NyDyMz24uuYQX
LmetWQ/nHWr2AWnFe44=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 573->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UksKwjAUfLiQbj2CV9ADBK9QTxBBVwWhXYi7Hl0LrbyZzBhIeW3z5s0n
x9uzf+wiYuq+j76+LuNY39f98nKvw/k0LD8P646YC+7tW6z1tuaC9e9MwXfo
JQxYRczOO53JWJlnxmq45PlCI+gUXNwM1mr5kxfKU9ak8Kw3gb08R+E4LWqG
46F4/Tun/Hdam4zFPeOMOS83V+bC90TM5v5GW+qD2vQ5vioflRVoZB4Ch31i
rGaJLFzNXrMfLjv07AMXLHtN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 574->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgzAMizhMXHnCvrA9oOIL7AWdNE5ISOwwcePpGxpMiWuPSEVpSR3H
7vk+dn1lZs/68+nyq52mPN9O6+aRh+tlWH822zJbUlz7mW35HkuK+a8mxX24
CxghEuntl6vxWJ6nxyq4+P5kRnWP1llZd8gftGCa4kwMT2pjoAf0YThqFtZD
ecx4KU2U/mrWwmPCAT1Gv1Rf6gu+E9Jb6aC8RA+O3tc/f5hXYUbkQXBQJ8Qq
gnihctTaB9MN+X3zN4Xwec0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 575->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgzAMizhMXHnCvrA9oOIL7AWdNE5ISOwwcePpGxpMiWuPSkUpTZ3Y
zvk+dn1lZs/68+nyq52mPN9O6+GRh+tlWC+bbZstKe79n23xvpYU419Oiufw
FjDCSqS23y7HY/k+PVbRi69POKp3NM/KvMP+QQumKXJieFIbAz2gDsNRXFgN
5THrS2mi9FdcGSfsAT1Gv1Rd6gvOCamtdFBeogdH8/XPH+ZV4Ih9EBzUCbGK
BbhsthAP+Rf3Yg6/8RsKpXmO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 576->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOgzAMizhMXHnCvrA9oOIL7AWdNE5ISOwwcePpGxpMiWuPSkUtTZzY
zvk+dn1lZs/68+nyq52mPN9O6+WRh+tlWB+bbZstKe79n23nfS0pnn8xKd5D
LmCElUhtv12Mx/J9eqyiF1+fcFR5NM7KuMP+QQumKXJieFIbAz2gDsNRXFgN
5THrS2mi9Jd8CSfsAT3GfFWX+oJzQmorHZSX6MHRfP3zh3kVOGIfBAd1Qqxi
AS6bLcRD/sW7mMPv+Q0HtHoO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 577->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfEbU+HiQ0lrg2ROrVrY8dO
dudbd10BuG/en64+jsNQn6f1dLjU/rDvp8vtvICx5LX8w7xfYix5/31T8jnl
EkaKIrjjCm8iVqwzYjW1RH7FY/LYC+ZgrbZ+4lKesiaFZ70B+UE8CsdpURyu
x6ou54nz3+oNmthDyYc23/HKvvCc4I8WpQ0ag3ms3h/9Ub1if0B5jMM+MVYT
hKtmi/FYf3Nv5vCzfwFeZ3nN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 578->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1CGgfEbU+HiQ0lrg2RMrVrY8dO
d+dbd10BuG/en64+jsNQn6f1tLnU/rDvp8PtnMBYci7/MK+XGEtef++UvE+1
hJGiCO6Y4U7Ein1GrKaXyK94TB17wRys1fZPXMpT1qTwrDcgP4hH4TgtisPN
WPXlPHH+W71Bk9PDM+Z6xyvnwu8Ef7QobdAYzGP1/piPmlXSyH0IHPaJsZog
XDULxmP9zbl5h5/1C+b9eY4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 579->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDxIrz7BL+gDgl+oL4hgTwWhHsRbn67FVjaTmTaQskmzMzuz
e7w92m4H4Nl8P21+XYYhv6/76XDP/fnUTz8P8wbGVO7lDnO8rDGV8f9NKs9F
LmEUKwnuuMObiBXrjFhVLZFf8Zg89oI5WKutn7iUp6xJ4VlvQH4wj+qL0aI4
XI9VXc4T57/VGzSxh5IPdb7jlX3hOcGGFqUNGoN5rN6V/qhesT+gPMZhnxir
WoQrZwvCh7W5NHP4iz8JWHlN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 580->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDxIrz7BL+gDFr9QX7CCPRWEehBvfboWW8nOzrSBlGx3k8lM
crw92m4H4Nl8P21+XYYhv6/76XDP/fnUT5eH2YExlb78wxwvNqYy/r9J5bnI
pRqFJYEdPbyJtWKfsVbVS8RXOCaPtWAM5mr7JyylKXNS9aw2ID0YR81lRXvG
cDNWfTlNnP6Wb+DEGko81PkOV86F9wQbXBQ36BqMY/ma+UDcVxy5DzNnx0sa
1ZW7BaHD2l6aPfzFH05nec0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 581->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsOwjAMs/hA/HIErgAHqLjCOEGR4GsS0vhA/O3oMLGh1LW7SqnSR+LY
yeH66O4bAM/dd+vy6zwM+X3ZTodb7k/HfnrczwaMqbTlDrO/rDGV/v9PKs9F
LOUoVhLY0cKfmCvWGXNVtUR8hWPiWAvGYK62fsJSmjInlc9qA9KDcVRfGtqr
uNbdms86O45Kb8a1eKjjHa7sC88JVrgobtA5GMfyNf2BeK84ch2mz46XXJRX
zhaEDq25NHP48z+FdnpN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 582->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT9diWzazs2kgYZNNZnZm
c7o/u34H4HX4LV1+X8cxf277afPIw+U8TMnjPIGS6rmcYY6XUVIdr3dSva/e
EkY1kuC209yxWLbO9VzVAo9TVH3J5x0HBP5W/cSlPGVNCi/0BuQH86i+NLxX
7yKtkQ8tnyONym+uJeSDfx/xyr7wP8GGFtFX7qWtoeVpsdyiPxB5p1HoUH2O
dMlBmPJvER7rd/ngH/7jLyiWess=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 583->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkOE1C2g4Ttz4dJjaUOk5XKVO7NHbs
9HR/dc8dgPHw/XR5ug5Dft/28+GR+8u5n5PHJYCS6lj/Ydmvq6R6b+/Yc1VL
GNVKgtuGuWOxbJ///yaKqGGuqr/k844DAn+rf+GR84M0KbzQG5AfzCNwWt6r
ukhr5EPL50ij8pt7Cfng6yNeORd+J9jQIubKs7Q9tDwtllvMByLvNAodas6R
LrkIU74twmP9Lh+8w9/+AxyIeow=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 584->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBxS+sL1hBTwvCehBvfbou7koymXQLKWnTZDKT
Hq6P7r4B8Nx9t65/ncexf1+20+HWD6fjMAX3swG1eFvuMPvLqsX79o09u1yq
4VYR2NbMG1vL9vm/N1ZFDmO5/kqMBwyI+mv9C42CHsRJ1Uu1AenBOKJOS3uV
l3HNdGjpnHFUenMvKR5ifoYr58L/BCtcxFx5lraHlqbVYov5QMQDR8FDzdnx
Ij8sqin/FunE/EM8+Yc//wP4ynpN
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 585->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMfbgQtx7BK+gBilcYT1BBVwPCuBB3PboOzkjy8toWUtLm85KX
HK6P4b4B8Nx9ryG/ztOU35ft/Ljl8XQcZ+N+EaAkL+sfFn09JXnd+ti3i6Uc
7iSBbcX42Fy2zv+/kSJiGMvVl6I9YEDk79UvOAp8UE8qX5UbEB+Eo/K0uLcY
rTpUXS2/Fl6Nb66liocYX8OVc+E9QacXMVeeJc+gu1+V+UDYQ4+iDzVn1xfp
4VBOtVvME/cf7JU9/OkfTeh6zQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 586->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IW58OE9vUuE5WqVPaZnFs
53R/dv0OwOvw+3T5fR3H/Lntp8MjD5fzMD0e5w2UZPdyhzleVkk2XnOSPZt/
qYZZSWDXu8qpa9V9rveqF7R1iuov6XeDgTZvs3/CUpoyJ1XP1QakB+GEfAI8
j1fUl/KfdfY48uwZrbbwAv6MK33hOUHMWfnKXrIHnqalxhb+QLyrupyrfDa8
KG4W1fS0Zd3DuXTm8B9/AeIpecs=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 587->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IW58OE9vUuE5WqVPaZnbs
5HR/dv0OwOvw+3T5fR3H/Lntp8MjD5fzMD0e5w2UZPdyhzleVkk2XnOSPZt/
CcOsJLjrXeXUWHWd672qBS1OUfUl/W440OZt1k9cylPWpPBcb0B+EE+oJ+Dz
dEV1qf6zz55Gnj3j1RZfoJ95ZV94ThBrbvBEL7kHnqel5hb9gXhXuJyr+mx0
UdwswvS8bXyI5tKZw3/8BYs4eks=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 588->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPwQfz2CV9ADLF6hnmAF+1UQ6of4t0fXYls2k8k2kG720Zlk
ktP92fU7AK/D79Pl93Uc8+e2nzaPPFzOw3R5nB0oyfpyhjlerCQbr2+S3Zt/
CcNYEty1V29qrDrP9VzlAo9TVH7J3zsOCPyt/IlLaco1KbxQG5AexKNwWtqr
fka1RjpArC2+SG/OJeRr1M+8si88J2jX7PBEL7kHm/MV9AfiXuHyW9VnUxfF
zggz0tbp0JrLYA7/8RdCVnrL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 589->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMHPwQfz2CV9ADLF6hnmAF+1UQ6of4t0fXYls2k8k2kG720Zlk
ktP92fU7AK/D79Pl93Uc8+e2nzaPPFzOw3R5nB0oyfpyhjlerCQbr2+S3Zt/
CcNYEty1V29qrDrP9VzlAo9TVH7J3zsOCPyt/IlLaco1KbxQG5AexKNwWtqr
fka1RjpArC2+SO8Iz8WN+plX9oXnRHBH2kS95B5szlfQH4h7hctvVZ9NXRQ7
I8xIW6dDay6DOfzHXzdle0s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 590->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB6kV5/gF/QBi1+oL1hBTwWhPYi3fboW27KZzKyBlOxuOpNM
crw9+8fOzKbu++nz6zKO+X3dz4d7Hs6nYX48LG5Wkvf1zpZ4tZJ8vOUkf3b/
AoazRLhrr3JqrLrO7Z7VYhGnQH2sB9QCebBXWb/iQkzj3MgRtDHQA3gYTkv7
lhYKT8VsD1SPTG+FF+JG/8hL54J7QriVNmqWOIO/+yXmY+Sd4WIum7PrC+Jg
gKm0DTq09lLs4S/+APp0e8s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 591->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHigfhmBFWCAiBXKBEGir0pI7QPxy+hQ0Vb25a6N5MhJnPP5
7PPj1XYHMxub39bm920Y8ud+nA7P3F8v/fR4ms2spGjLnc3+skqK/hqT4jn8
BYywEsntzcV4LM9zvWdcrMYpwI/VgFoozrv8VS7A8zUxPKkNcMI8DGdL+y0t
FJ7y2RyoGlVfGF7lG//L8tK+4JyQ3Eob1Uvswe58if4YeWe4GMv6HOoCv1qA
qbStdAA8phvy+/tfQcl7Sw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 592->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKAjEMDH6Ivx7BK+gBildYT1BBvxaE9UP869F1cbs0k5kaSEkfmUwm
PVwfw31jZs/ddxny6zxN+X3ZzptbHk/Hcb7cL25Wkvd6ZktcrSQfr2+S37tc
wHCWSO3WmzctVstzPWdcLOIU4Md6QC0U57/8VS3Aa3tieFIb4IR1GE5P+54W
Ck/F7B+oHtVcGF6IjeeyunQu+E9IbaWNmiXOoKt3zSPzMXIftCV9sDm7viAO
BphK26AD4DHdkN8v/gD6m3sM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 593->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkKwzAMFD2UXvuEfqF5gMkX0he40JwChfRQcvPT20AcpNHIMch4Hc1o
dHu+h/EkIp/Lfxryt5/nvDzO6+aVp+4+rZfXLURKslHPZFvXUZJd72+S3Zu/
gGFGIrl1qDcaS/PczxkX8TgF+DENWIuI8yH/KBfgaU0ML6wNcMI8DEfXK8oX
6WrxYv5jH0QaI18YnlsL/8vyUl+wT0hu9rflJXrQ0o9+GKzAL8ef6NU4rk6k
Zk5HUM/II9Tv7lkfVjz5AQ4Uewo=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 594->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMfbgQtx7BK+gBilcYTzCCrgaEcSHuenQdmEry8lILGdJp+j5J
D9fHcN8AeO6+n2F8ned5fF+2y+Y2TqfjtBzu1wBq8dH+Yc3bqsXnv5ri97aO
MdwqgtuGqbFYVXEoLYg4jgfaA/ci0/xXf8ZFeNaTwkt7Q5qYR+HYfmV8ma+e
rsBDmjI+yY8cL+TQdxWvnAu/E8Gt7vZmyTPo+ed5OKxkXkG/8GtxQp9Ez4KP
pJ/ZjNh/OFfvsOHhAwbyess=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 595->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAUHFyIW4/gFfQAwSvUE1TQVUGoC3GXo2uhkffmzYuBlKQJ883h
+hjuGwDP3fczjK/zPI/vy3bZ3MbpdJyWw/06gVr8bP+wrtuoxa9/d4rf23uM
4UYR3HaaOxarKg6lBRHH8UB74CwyzX/1Z1yEZz0pvDQbUB7Eo3BsXhlf5qun
K/CQpoxP8iPHC+uOf9VX6IXfieDu4okuuYOef+7DYSV9Bf1Cn8UJOYnMgo8k
z6wj9h/O1TtsePgAExp7DA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 596->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwjAQfXQhbnsEr6AHCF6hniCCXRWEupDucvRaaGQ+b9JAyqQZ3m9y
eb6HsQPwOf8+Q/7e5zkvj9N2eOXpdp22y37fQEl613/Y67pK0vW/J+mz7LMY
aiXCLbfokViFcTAt8DiKB9yDzSLSfKg/4jJ40hPDC7OBycPwMByZV8QX+Wrp
cjxGU8RH+RHjubrhn83LzcW+E8LdxCOzVBoO/Nt5KKxgXk4/4ZE4LKfQg+Qm
eUYzsv7dPXuHFQ8ro7p6yw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 597->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUsENwjAMtHggvozQFWCAqCuUCVIJXpWQygP1l9GhokH2+ZxGchXXyd3Z
l258Do+DiLxO38+Q3/085+V2XJN7nq6XaS2etxApyUb9J9u+rpLs/n8m2Vyf
QwyzEuHWoc5oLKcN7hVyB7kcFtFi+iCad/VHXIBXa5S/NRuxd5GH4eh5RXys
3sqp/6Ap4qP8EuO5faN/5pfzBd8J4W7iES+Nhp3+0Q+DFfjl9BMejcPmFPag
uck8I4+wf1cP3sVP2weIwHoK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 598->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKg0AQLHIIXvOEfCF5wOAXzAsmEE9CwByCt3m6SjT0Uj040DJtT1dV
L9fnu+tPAD7N8unytx3HPD3Oq/PKw/02rMHLZkBJ2vZ/2O77KUnf/2+S9uU7
i6FOItzSxBuJ5bSZvEJyLJfCCrQUpp3UGupnXBZTxCh/rTfQuZaH4ch+RXws
XvPp/I2miI/yI8Zz90r9bF5uLnZPCHcVj8xSaTiyX3Y+8LlRj91OEBzWp7AG
yU36Gc3I1u/iwV78tM2r8nnL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 599->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDV0Utz1Cr9AeYPAK9gRTqCuhYBfF3RxdpVqSl5fBgUjGSd57
+Vyf764/icinWT5d/rbjmKfHeb288nC/DevjZTORkqzt/2Tz91OS9f8xyd51
HGKYkwi3NhWjsZw2yCskB7kMVqClMO2kVoartYS6oSbKX+uN2FzkYTiordb/
SAfT5XhIP6Iao7kwPOdX6mfzcnPBPSHcVTwyS6PhyH7hfMTnRj12O0FwWJ/C
GjQ36Wc0I6zfvQd78dM2A+LUeYw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 600->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMtPpA/XYEVoABIlYoEwQJXpWQygPxy+htRYvsy9k0kqukce7O
Zx9vz/7RiMirnT99fl/GMX+uh+Vwz8P5NCyX3RoiJdnY/sm631ZJdv/LSfas
8xDDrES4dagcjVXgHqOQN8hlsBwtpg6i2dWvdFVciKnuKH/kjdi3yMNwUFvk
v6eD6ap4iB+Rb3/nyeML6me8VV9wTsSvi+KRXhoNe+YL+yNwDjypZiLACevC
Ohw/cY/e6MV6inPx1TYBtq16Cg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 601->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS6kW4/gFfQAg1eoJxhBVwWhLsTdHF2LrSQvL7GBlKT5vJdk
9pd7f9uIyKP7fPr6PI1jfZ23k3Otw/EwTMHdrCKtWF3+yWwv0oq1fznF+joP
exgpBFurytG9GsRRG6lBLNMr4GLmIJxD/oqXw8KeKkbxs92IrUUc1ge5ZfuP
eDBeDofsI9vb3/cU4SXzM1x3F3wnEs9F+5FbGg5r3hfeR8BPdqLjrg78dC6c
I9gn2o6HEnZT5P7l9gaGMnnL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 602->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS6kW4/gFfQAg1eoJxjBrgpCXYi7OboWW0nevDd0ICVpPu/l
c7w9+mFnZs/u++nz6zJN+X3dz8Y9j+fTODsPi5iVFGX9Z4u+vpKi/o9J0fZx
WCO8RLC9uBhfq4AfpZAcxAq1BJfQB+Es+TteFRbWdD6K35qNxVzEYXWQm8JT
+YqXymfzV9jNe1J4jf4ZbrUXvBPTfdF6ZJeBw5b7wv0Y2I2ZeH+VB3azL+xD
zBP1iod7bKfI/cftA79Beks=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 603->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3fboWW0lmZ5YupGyaZGY2
yfH26IedmT2776fPr8s05fd1Pzv3PJ5P4xw8LGZWUrT1ny339ZQU7/+cFH2f
hxjhJMLtzeV4rAJxtEJqkCtgCS3hHUSz1O90VVyI6WKUv9Ubi7XIw3BQm+JT
9UqXqmf9V9zNfVJ8jfcz3mouuCemeSgemWXQsGW/cD4GfqMnPl7VgS93Cg9o
V72tMACLzRS1/7R9AGleegw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 604->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3PF2LrWQnkzSQsmmyk0lm
j7dHP+xE5Nl9P319Xaapvq/7ObjX8Xwa5+RhcREtra//ZDmvpqU9/2tKG9s6
xGiskN7WTY3FUsijK7mDvQS5Ei7NHIRzyF8AP9mpzdH+iBPowvogjhJuLh/M
lsVUf7KPbG+b7ynql8zP+tJ9Gh0Qz70DprVwDMQP3xfqIxAnO7F5dw/iSC9n
wD3arcMALKYpcv9x+wCX93lL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 605->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKAjEMRYMLcesRvIIeoHiF8QQVdDUgjAtx16Pr4IwkL8loIKVpmt+f
/O7Ot+66EpH75r109XEchvo8rcfgUvvDvh+T28lFWrE+n8m0n60Vu//eKTbW
94hhLKrTru5orIY8vQU1+py8o7zB+MGZmOQS8sZ8orcdT85GbC3fIY6ZSZZf
6C2LMx3JOcPK+s34UOOs/0ivcJ5KB+K5f0C8QEvD4Z//RX0E8cJMdN7VIc70
cgbu2WwdBrAiTcn9w+0FSwd4yQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 606->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklEKwjAMhoMPsleP4BX0AMUrzBNUcE8DYT6Ibz26DraRfE22BVKapvn7
N3/Oj1fbHUTk3fyXNn9uw5C/9+MYPHN/vfRj8jS5SEnW5zOZ9rOVZPfLnWRj
fY8Yxrw67eqOxirI04tTo8/J28sbjA3OxCQXlzf6471d8WRvxNbyHeKYnkT5
lb9FcaQjOUdY0X8jPtQ4+r+nl9tPpQPxqjkgnqOl4bBnvqiPIF7pic5XdYgj
vSoD96i3FQawtuZjwZMfWgd5SQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 607->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklEKwjAMhoMPsleP4BX0AMUrzBNUcE8DYT6Ibz26DraRfE22BVKaJvn7
N3/Pj1fbHUTk3fyXNn9uw5C/9+MYPHN/vfRj8jS5SEnW5zOZ9rOVZPdLTbKx
riOGMa9Pu6rRWAV5enF69Dl5e3mDscGZmOTi8sZ8vLsrnpyN2F7eQxwzkyi/
wiOKIx3JOcKK3hvxosbR+z293HkqHYhX/QPiOVoaDnv+F/URxCsz0fmqD3Gk
V2XgHs22wgDW1v9Y8OQHkRZ5yQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 608->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklEKwjAMhoMPsleP4BX0AMUrzBNUcE8DYT6Ibz26DraRfE22BVKapvnz
N3/Pj1fbHUTk3fyXNn9uw5C/9+MYPHN/vfRj8jS5SEnW5zOZ9rOVZPfLnWRj
fY8Yxrw67eqOxirI04tTo8/J28sbjA3OxCQXlzfm4/WueHI2YmvZhzhmJlF+
hUcURzpSpwgrem/EixpH7/f6uvNUOhCv+gfEc7Q0HPb8L+ojiFdmovNVHeJI
r8rAPZpthQGsrf+x4MkPCvd5ig==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 609->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksKwkAMhn9ciFuP4BX0AINXqCcYwa4KQl2Iuzm6FtqS/HnUgZSkmXyT
1+n+7PodgNfh9+nq+zqO9XPbT8ajDpfzMDmPswCtaFn+YdaX04rW1ztF2/Ie
M9Tx4qSIO5LVyM8xzYmRb3Henl8xNnJmJpif9JRzNu9nvQHVS+8wR/Uk8ju+
jBfpXs4RK6rX4xk9qd+bl9tPMQfmmT1gnjNLlcM/+8XzAdlJT6TfxJEdzcsc
yj3qrWEQa2s/Vh6+bm15Cg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 610->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADDF6hnmAEXRWEdiHu5uhaaCV5+dSBlElf8pJ5
yfH27B87AFP3/fT1dRnH+r7uZ+deh/NpmMHDYkAr2tZ/WO7raUXffzFF+zKO
OdTx8qSJGMnVCOec5uTIWty3hyuOjZ6ZE8yfaMo9m/qZNqD3Uh3mUZpEuINl
fB4WzTOL39ynqHbyfm9erp5iDsxn9oD5nFmqHv7ZL54PyE80kbjJIz+anTnU
e6St4SCubFcUHz6JfHmK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 611->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBi1+oL6hgTwWhHsTbPl0LrSSzkzSwZdNJJtlJ
TvdnN+wAvA6/T9e/r9PUf2772Xn04+U8zuBxOUAt/qz/sNxXq8Xf/zHF+zaO
OZypPHtMjOWqhHNOFTm2FvetcMex0TNzgvkTTbnnpn6mDei9VId5nCYRLrCM
T2HRPLP4zX2KaifvV/Oy/3jPlJ7NHig+aA7mD/eL5wPyE00s3uSRH82uMeo9
0lbpai3bFceHLyXReUs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 612->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDxIrj7BL+gDxC/EF4ygp4CQHMSbT9eAgerqxQzMMN3VS/Wy
vz76+wbA1H2fvj3P49hel+0s3NpwPAwzuPtd4H2yd9FhuSAd/dmGZbZjf3ci
P83L8ZQbxJ5w9eFcyjvCTYwVnB131Stv6U+U2/EMZmLqlTwax/QkwwOsihdh
WU8q+7/7lOUu6o/mxTrds6ifmW81S8NhzX7pfCBy0RPGnZ/IZV1aR9JP/Tse
dKpdMfHwAe+AeUk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 613->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKwkAQLDwErz7BL+gDxC/EF4xgTgEhHsSbT9eAgerqxQxMSG/VNdW9
v977YQPgsf1++vY8T1N7XbrZuLXxeBjn4O53gffJ3sWH5YJ89M85bHMe17sT
1WlfxlNukHyKaw33Ut5R3GCs4Oy4q195iz5Rb8czmIl5r/RRHKNJFg9iFV4U
yzSp8v/uU9a7eH80L/bpnqmejleGhxhD8dP90vlA7EITjrs6sbPZuSPcM20j
bfhUu2Lw8AGkj3nJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 614->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx6KV5/gF/QB4hfqC1awp4JQD+LNp2vBQjaTWbuwpbOZSbIz
u7/e+2ED4LH9fvryPE9TeV26ObiV8XgYZ3D328D7VO/lDMsGndE/53DMeVwf
lqtTXeZTb5B8wrWGtdS3wyuOFZ6Ddz1X39Ifpx18mplU9xUd5al6kuEGa/E5
LOtJK//ve8q0pXehz8oN443mkM0iu4ebZeXBaIb3pfOBxI2eMB7qJM5mF5Z4
d29L+fT+Lb3Ahw9LhXoI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 615->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx7Eq0/wC/oA8Qv1BRXsqSDUg3jz6VqwkMlkVhe2dDYzSXZm
d5dbN6wA3DefT9c/TtPUP8/rObj242E/zuD2u4HXMe7lDMsGndE/53DMeVyf
lqtTXeZTb5B8wrWGtdS3wwPHH56Tdz1X39Ifp518mpmE+4qO8oSeVLjBWnwO
q3rSyv/5nipt6V3qs3LDeKM5VLOo7uFmGTwYzfS+dD6QuOoJIp7qJK5ml5Z4
d29L+fT+Lb3EhzcaDnnJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 616->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx6kV5/gF/QB4hfqC1bQU0FoD+LNp2vBQiab2bqwpTuZTTIz
u78++vsGwNR9P315nsexvC7b+XArw/EwzODut4H3Ke4lhmWDYvTPOXzmPL5f
LXdPdZlPvUHyCdc7rKW+HR44/vBcede4+pb+OO3Kp5lJqFd0lCf0JMMN1uJz
WNaTVv7qe8q0dSbaZ+WG8UZzyGaR1eFmGTwYzRZv4ErmtZarGPfF9bJa4t29
LeXT+lt6FR8+BDp5CA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 617->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAQCx6KV5/gF/QB4hfqC1awp4JQD+LNp2vBQjaTWbuwpTszm2Qm
u7/e+2ED4LH9fvryPE9TeV26+XAr4/EwzsndbwPvU72XGJYNitE/1/CZ6/h+
WO6e8jKeaoPUU17vMJfqdvkKY4XmoF3jqlvm47iDTuNJ1a/wKE41kyxvci08
l8tm0qr/+54ybvVE56zYMNrIh8yLrA/nZaXBcLZwGSvzy9UGHoOTeReWaHdv
S/G0/xZfwMMHeTp5iA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 618->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAQC34Ufz2CV9ADiFeoJ1jBfhWE+iH+eXQtWMhmMmsXpuy8Mulk
99d7P2wAPLbfT1+e52kqr0s3O7cyHg/jnNz9DHifaltiWAwUozvXsM913B+O
69O5jKfcIPXKBRHH8Xb5CmMF58Bd48pb9uNmB55GE+7VOYpT7STLZ3om9S6X
7aRV//c9ZbNVE92zYsNwIx0yLbL/cFpWHMzMFi5jZXq5WtsnfqZdOMLdvS3F
Czwa8wIePgFCeQg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 619->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/QL+gDil+oL9iCngqFehBvPl0LFmYnk9qFlCabTGYz
afqxu+8APA7fT1eel2kqr+t+dm5lOJ+G+fL4M+Dd1rbEsBgoRv+cwz7ncX04
rk77Mp5yg+QrF0Qcx9vdVxgbOAfuGlfeMh/Xm7HtbFDXah+HwzOz95mef3hl
vK0uyVu39ncas6/7ofMJ3EiHTIvsHU7LioPpuYbLWJleLtfWiZ/ulB7h7nZL
8QKPlX4BDx9yUXmI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 620->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADLF6hnmAF+1UQ6of416Nr0UoymawupCXZzczk
sTtfu34F4LZ5fbp6P45jfZzWs3Opw2E/zJfbjwFT8bbEsBhMDO/Y922J/mRy
bH44Ko95i+d12kDvWQsijtKt7h1GggPxV1qkbsJV3BZb9gY+l3lUvbZniied
5w9dmW45l6TWf/nVjK3P+8H9CdrsfJNZZHWoWToNgrOFa7FsfbIngreFk+4U
H9Kudovxgo4GX8DDEwkyeYY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 621->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3Pl2LVpLJZHUhhaSbmUlm
d+dr168A3DavT1fvx3Gsj9N6Ti51OOyH+ef2E8BUfCw1LAFTw7v2vVtiPpke
2x9OEdzMWzyv0wa6z1oQcZTuTIucQ82qtHOddROu4rbYcjfwvcwj92p2pnhS
P3/oynRLX5JZ/+VXHtuc3wfvJ2iz/iZeZHMoL50GwdnCtVh2PrkTwdvCSd8U
H9Ku3hbjBR0NvoCHJwhQegY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 622->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbiQbj2CV9ADDF6hnmAEuyoI7ULczdG1aCXz8jIdSCHp5H0y
Od4e/bADMHefT5+fl2nKr+t+Se55PJ/G5efhF0BJdaw1rAFTw7f2v5t8XkyP
7XcnCW7mTTVvpQ10n7XA4yjdkRbnI/KqtHOdddN8FHcRfPwmtpd55FyNF8Wz
5THSFeluzS3yu8Wv3tjmvB88H6etsSdq9g6P3rLSIDhbuBbL+pMzEbwtnHCn
+JB2tVuM53Q0+Bwe3jcReoQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 623->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFklEKwjAQRAc/xF+P4BX0AMEr1BNU0K+CUD/Evx5di1Z2Z2fXQApJszNv
Ntmdb911BeC+eX+6/nEcx/55Ws+LSz8c9sP8c/udwNT8XPawTJg9fPZ+Z1tc
T6bG1ofRhDf7Nu/r2KyHYkHUUdwZS8iRZWV2kH7GTZmkf9Ub+Fr2kX0lNpWl
yphxZdxV37K8//zVHdu16zNrQ7BBn5f9U3p0l45BeFa6Vsvmkz0RvpVO+qZ4
ELt6W6wXOAq/oIcXgGl6Bg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 624->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8uxK1H8Ap6gMEr1BOMoKuCUBfirkfXopXk52fsQAqTzvz/
kszufOuuKwD3zfvT1cdxGOrztJ42l9of9v30c/sNYCw+5hzmgMnhk/udLXE/
mjv2flhFeLNv8b6OzXooFkQdxZ2xhDqSWgM7SD/jppqkf6s38HfZZwlbmFs2
zz9cGfeSvmVzyfzVjO3e9Zm1Idigz8v+KT2apWMQni1dq2Xrkz0Rvi2d9E3x
Inb1tlgvcDT8gh5eIYd6hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 625->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KgzAQhR9dFLc9Qq/QHiB4BXuCFOpKKNhFcefRVaxlft5EA5EkZt77
ZibX57tpTwA+1fxp8rfu+zw8zsvmlbv7rVt+Xn4TGJOe2xm2CXGG9ex/N/n9
KGJkvBuJeFvfpH0Vm/RgLPA6jDticXkEuTp2GP2I2+RE/Uu1gY61PkfYXN+i
fu5wRdxH6hb1JfJnPZZ7VWerDcIGfp/Wj+mZXioG4lnSlVoyP1oT4lvSCd+U
HYadvS2r5zgKfpJvXU8eVHpH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 626->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KgzAQhR9dFLc9Qq/QHiB4BXuCFOpKKNhFcefRVaxlft5EAyNJTN77
ZibX57tpTwA+1fxp8rfu+zw8zsvilbv7rVt+Xn4BjEnHtoctIPaw7v3PJr8e
xR15341EvK1v0r6KTXowFngdxh2xqDxA9CN2czbkNjlR/1JtoO9anyNsrm9R
P3e4Im7alyDXo/6sx3Kt6my1QdjAz9P6MT3TS8VAPEu6UkvmR2tCfEs64Zuy
w7Czt2X1HEfBT/Kt8wlKYnoI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 627->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhR8upFuP4BX0AMEr1BNEsKuCUBfirkfXUiszk/fSBlIy02Te
Nz/H26PtdgCezffT5tdlGPL7up+Me+7Pp376efhtYEx+Lz4sG8aH2fe/m0p7
NG/s+2Iloh11k9d1bFaDsaCMw7gVi8sDJL5iD3cld8iJ6tdqA/826mxhK/qm
+rnCpbhpX0SuW/VZj63t6izqR2tSmwPBxnrpGEJc2RebD4KtakJ0a3HkTMUV
2NlsxZwKjoqe5ZvPH4kNecc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 628->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6I254O0yhKnbisUqYlbWrH
7uF67/oNgMfu8+ny8zyO+XXZzsktD6fjMG/uvwFMqY5SQwmYGpba72zy+WR6
bL9bKcBmXL7PcrMYEReLL3CimVgLxuFZHXc6W2qON+q9EL+lDepexlnDzfmm
/PzDS/EOfRGzrsWPPLZ5pbPQL9Sk9Q4Et8jLigPdK32x84BypUmA27pH6seL
uEdvi2dyPBQe4S7/b3XceUk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 629->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszigXXkCX4AHVHxhvKBI7DQJaRwQtz0dplGUOs62SpmWtKkd
u8fbo+12AJ7N99Pm12UY8vu6n5J77s+nfto8/AIYUx2lhhIwNcy1/9nk89H0
2H63ksBmXL7PcrMYiovFD3DUTKwF4/CsjjudLTXHG/WexF/SBnUv42zh5nyL
/FzhFfGWvgSzbsVXHtu80jnQT2pCekr9uCa8rDgQj9AXOw8ojzQRuEv3hPrx
Iu7qbfFMjkeER7jz/wcaEXkK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 630->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6I254O0yhKHWcblTItblM7
Tg/Xe9NuADx2n0+Tn+e+z6/LdkxuuTsdu3Fz/w1gSHUUDCVgMEzY72zy+WBq
bL1bSXAzL99ntVkOpcXyBzyqJ/aCebhXp53OFszpRr0n+ee8QV3LPGu0ubn9
ias9rlvyLZpLxK9mbPPK58A/6Qn5Kf1jTMyy0kA6wrnYfkB55Ingnbsn9I8X
aVdvi3tyOiI+4p3+31MgeYo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 631->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbn66lrmQnk60upDTJJjOZ
7O58664rAPfN+9Plx3EY8vO0npxL7g/7fkpuPwaMqbYSQzGYGObY927y/mhq
bL07SWAzLvez3CyG4mLxAxw1E2vBODyr4053S8zxRp2T+C1tUNcyzi/c3N7+
jKsc1y3pFu0lwlc7tn6lc6Cf1IT0lPotvQ/Tg/s398L9aD6picBt9Qn140Pc
1dvimRyPCI9w5/8X+CB6Cg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 632->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRT8uxK1H8Ap6gOAV6gki2FVBqAtx16NrqZXJnz9pDaQ0k8y8
Pz85XO9NuwHw2H0+TX6e+z6/Lttxccvd6diNm/vvBIZUzjmGecLEMMV+Z5Nf
DybH5ruRBJu5XM9qswylxfAjjuqJvWAO9+q001mrwfkR6FMM5w3KXOas0ebu
7c+42uM8xav1K99TxIZfFz4H/klPyE/p39L7MDW4fvVeuB71Jz0R3Fqd0D8e
pF29Le7J6Yh4xJ3+39BNewo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 633->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAQRT8uxK1H8Ap6gOAV6gki2FVBqAtx16NrqZXJnz9pDaQ0k8y8
Pz85XO9NuwHw2H0+TX6e+z6/Lttxccvd6diNm/vvBIZUzjmGecLEMMV+Z5Nf
DybH5ruRBJu5XM9qswylxfAjjuqJvWAO9+q001mrwfkR6FMM5w3KXOas0ebu
7c+42uM8xav1K99TxIZfFz4H/klPyE/p39L7MDW4fvVeuB71Jz0R3Fqd0D8e
pF29La7ndEQ84k7/b/VNe4o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 634->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBoV+oL4igp4JQD9Jbn96WWtnMzkYMpGS32ZnZ
2Zxuz/axA/A6zJ82v5u+z8N1vwT33F3O3fLz+NnAmMq95bBtmBzW3Pdu8vFo
amy9W0lwMy/jWW2WQ2kx/BGP6om9YB7u1eHSXavB+RHoUxzOG5S1zCN9FX0U
c/szX/OBNUc9RnOJ+NWMbcxzUP5JT8hP6d+v92EwGL86F8aj/qQngreGE/rH
i7Srt8V4TkfER7zreQKSa3wK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 635->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsOwjAMi/hA/HKEXQEOUHGFcYJOYl+TkMYH4m9Hh2kPuY4zoFKnJmts
x2nV3Ot2Z2aPw+dT5+el7/Pruh+DW+7Op278eZy32ZDKveRs2QY5m3Lr3eTj
AWqw3q0kuJmX8VAbcigtwB/xqJ7YC+bhXh0u3UUNzo9An+Jw3lhZyzzSV9FH
Mbc/81s+sOaox2guEb+aMcY8B+Wf9IT8lP59ex+Awfi/4CIW9ic9EbxbOKF/
vEi7eluM53REfMQ7nd8denyK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 636->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBi1+oL6hgTwWhHsRbn66lVmYnE8WFLZs0yUwm
2Z2vTbcCcNu8Pk17Pw5D+zitJ+PS9od9P/3cvi8wlvouPiwX5MPs+8SWaI+U
w/nhFIOtuFqPuTGG40L4GY7rSbVQHO011JVY5hD0SPg5jKAN6lzFsbqaPqq5
/en/poNyznrM5pLhuxmzrXNw+llNRE+r36/9oBpaP90v5oQ63s3Lxdo8sVP9
9Ah3t1taL/DI8AR3fj8B3TB8Sw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 637->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsRbn66lVmZnJysupGzSJJPM
7O58664rAPfN+9Plx3EY8vO0npxL7g/7fvq5/RgwptKWGBYDxTDHvrmp9keq
4frqJIOtuNqPZ2MMNwvhW5xgJ+VCcXRX15dzCyzXs4Xf4ob4cDiWV7NHoduf
8RYPOrPbL9K/he80Zl91cPxZTn7oYHlzWsL3D98Xz4Qy3+nlcm2d+CF/emR2
97a0XzVHhCe48/0F2yZ7yw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 638->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwkAMRYMLcesRvIIeYOgV6glG0FVBqAvprkdvS638+fkTcSClk5nk
JT9zuj3bx87MXof50+Z30/d5uO6XzT13l3O3HB4/Zjam0jafbWbgs9X3vZv8
foQYjHcrCTZzOR/WhgxVC/Alp9ITa8Ec7lXlxbsFS+WM+JE2oIfiSF1FH8Xc
/vRHOnDNqr/a/CO+mjHueQ5KP6nJjzlI3dQszceE7wtrglzq3GlL3ChPVT9e
pI16W5zP1VHjEXf9nwBTy3xJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 639->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMHDwUrz6hX2gfIH7BvmAL7Uko2EPx5tNbsZbsZLLFhYjJmpnJ
xOP10d8rAM/68+jTqxvHNF0OS3JLw/k0LJfNN4C5zWOrYQuYGtba79vW57Pp
sf3uqD7mZTyrzXIoLYbfzWjnJC3sBfOwZodLWjIuhVnij7DJD8UjdYk52P89
9ZIPrFnNF/lX4lc7tnnmc+Cf9OTPHqRvapfwPSEu7cNiqXvnLfGWcEL/+JA3
6t9iPKcj4iPe9f0NHct8CA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 640->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMHDwUrz6hX2gfIH7BvmAL7Uko2EPx5tNbsZbsZLLUhYiJZmYy
2eP10d8rAM/68+jTqxvHNF0OS3JLw/k0LB+bbwBzm8dWwxYwNay137+tz2fT
Y/vdUX3My3hWm+VQWgy/m9HOSVrYC+ZhzQ6XtGRcCrPEH2GTH4pH4ag52P89
9ZIPrFnNF/lX4lc7tnnmc+Bflv+5B+mb2iV8T4hL+7BY0b74XiHqozz0jw95
o+4W4zkdER/xru9vatp8iA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 641->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDFr9QX7CCngpCexBvfboWrSSTSe1CyibdZCaT
7C/39rYBMDTvT1sfp76vz/N2cq61Ox666efua8BYvM0xzAYTwyf2e1uiP5oc
mx+OymNcrme5WQzFxeCHHm2fxIW1YBzmHOoSF4elai7hZ7VJD4Wj6qg+WP9/
PBSv7L2ay5Kl+5RhI/pO50Q/56+cg9SN5uDuK/rnedi9yObFe4Usj/xUPz6k
jdotrhd4ZHhF6IQXOvh9iA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 642->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsTbPl0LFqeTiXUhZbNNMpNJ
dudbd10BuG/en64+jsNQn6f16Fxqf9j348/tx4BW5ja9YTLQG77vHNPIb5TD
+eG4PMXVesyNMRwXwg89KtcSYxQ369XVDRo53qxPhp/VFj0cjqvj+lD9l3g4
Xlm8m0tmdoYLeKpd0PlHfUjc0hysbjKH2f2P/nUevBfZvHSvkOWJn+qnR7Rx
u6X1Ao8Mrxid8AL1gnzH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 643->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAQCx7Eq0/wC/qA4hfqC1awp4JQD+Jtn64Fi2km4y5M2d3OJNnM
HK73ftgAeOw+n748z9NUXpftfLiV8XQc55/7bwC1W8dyhyVAd/jdc06lc6Ua
rg/L1Smv4rE25nBaiD+8UbV2MUd5s7c63OCR083+ZPwZtvjheByOe4f639Lh
dGX5ri9Z2B42+NS74PMffEheqw/WN+nDai+1Flf6wXOR9UvnClmdnFP/dIk3
brYUL+jI+DrjE96IkX1H
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 644->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHDyIV5/QL+gDgl+oL0ihPRWEehBveboWLN3MzprAlmy6OzOZ
TTc8+ukA4Hn6fvr8ui1Lft+PazLm+XqZ15/nXwAl1bGdYQuYM+zntqaYvJge
2++W6mNexrPaLIfSYvjdHVlr8jXMG91V4TqPlG7rT8QfYZMfikfhqHuw/y0d
SldUr+YShZxhyxP4vPL5Dz6orjUH6RvNodpTr8Sledh3Ec2L3xWiPspD/3iR
N+ptMZ7TEfEl4RM+d6B9xw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 645->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fboWLM7OTloXUppskpmd
5HC9d/0GwGP3+XT5eR7H/LpsJ+eWh9NxmC73XwNKqm2OYTZQDL845xTyC9Vw
fXOSwVZc7cfcGMNxIfwIpwiO00Jx9K0h/1RzbXizPhH+kjakh8Nxfdw7qvs/
eDheUb6bS2R2hmuaoPUrnRf6Q/LW5mB1kzlU/1Jr+8o8eC+ieeleIaoTP9RP
j2jjdkv7NTwivGR0wht2vn5H
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 646->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qA4BfqC1awp4JQD+ItT9dKkWR2sm4gZdukmcnM
Hq73YdyIyGP3eQzleZ7n8rpsl5dbmU7HaSnu1xQxjfkNdbkG1kzj2fx3cb1Z
KMFGXJwnrs9jMC4OP8MxwKFaAA7umvLXyLXi7fXJ8FvaOD0YDpvD9gj1Dh6M
V9bPfOnZr2c2867SuTFfoO+fD1Q38CGc4V86F/xAHswv1vsLvB+gC9UPg2lD
tLUWjwxP6xkib/IAfMU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 647->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDgl+oL1jBngqFehBv+3StVMjOTtYGUrbddGYy
yfE29cMOwKP7PPr0vMxzel33y8s9jefTuFwe1gSylfkNc7kG32Urz9l/h6uN
wgQ38zIeXJ3nUFocf8STiUd6QTzca6jfSq2Vbu9PxN/yxvmheBRO5D0EX6RD
6Yrq1Vy29LcFW82u8rmBz3v2bw6qD55DcaZ/w/0Su4LgvsL12l0tz/mnSfrH
obwR3vLegfBau1Lg4Q1QUXyG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 648->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QBwS/UF6xgTwWhHsRbnq6VHrLTyVoDKdtNNjOZ
5HC9d/0GwGP3+XTleR7H8rpsp59bGU7HYQruZwfcav+aBZ+NY2712eM9Qm5m
JrAZl+sh5EUMxSXgZzhOOFILwuFeU/5Wc13wjvpk+C1tgh4KR9XJtIfAW3Pf
0oE5/9Pfmto8O6lzoz7v2a85qD54DtWZ3qb7JXYFSXxRN3IPuTznTFNpShuh
rbd4IMFTs8IbZtZ7xQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 649->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMtHigfhmBFWAAixXKBEGir0pI5YH4ZXQo6uNyOYfWkqs0dnzn
s4+3Rz/szOzZfT99el2mKb2v+/nnnsbzaZyDh8XNspf+M18cjGPZy3PGe4Pc
yFxgo0NOxYMxFBfAj3Ay4UgtCId7Dfl7ybXijfpE+C1tQA+Fo+pE2pvAW3Pf
0oE5b+lvTW2endS5UZ/37N8cVB88h+JMb8P9ErtiQbyqi9whl+ccaSpNaSO0
zS0eFuCpWdkHUex7hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 650->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMREcsEFuOwBXgABFXKCcIEqwqIZUFYpejQ1EXtjNjaslVfs2M
n3O4Pob7BsBz9/0M9XWepvq+bOfJrY6n4zhv7pcEWvH5i7KkibjXih83uw5z
VkUh2jbNmc5H1GBejL7SaUGHsgg6sVbpv3ivnW/LR+lnbAwPpsPuUexB9Nas
Zxyi53/1Ze9JagM5Z8HPzVf2gdUR++DGoqbuf/JWIPa7e613czb2WTGlwdgQ
ti3zAaHHeoUPTvt8Bg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 651->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhR8uxK1H8Ap6gOAV6glG0FVBqAtxN0fXShdJ5r2xgZT5a17y
JYfrY7hvADx3389QXudpKu/Ldt7cyng6jvPlfnGgWvSf2eLO8l21uK7+HO6t
MiPa3t2bJo+swXJx+kqnJh3KIunkWmX+FnNt8vZ8lH6PjePBdFgcxR5Eb815
j0PO+V99vXmS2kCfs+AX9iv7wOrIfQhrUVPzP5mVEE8w8b0Ma9JnxZQaY0PY
5rlDiteblRAPH+Mie4g=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 652->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBwS/UF6ygp4JQD+Jtn66VHpLszNpASnazzSQz
OVwfw30D4Ln7fobyOk9TeV+28+FWxtNxnJP7xYFq0X9mizvLuWoxrv4e7q0y
I9je3Zumj4zBenH4CqcmHMpFwsmzyv4t9tr07flR+IxbwgfDYXUU9yB4a+57
PGQ+/s3X2yeJDfR5FtqE80od2BxZhxCLmZr/hbYsr7QMMdFZcUqNcUO4zXuH
VK+3K6EePk5AfAg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 653->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhR8uxK1H8Ap6gOAV6glG0FVBqAtxN0fXShfJy48NpMxf38t8
mcP1Mdw3AJ6772dor/M0tfdlO09ubTwdx3lzvyTQxeYvZEkVvNfFjjuvw2uY
kMBbpzrj6hCrg6gW5Z/5dPIJWZAP3zWtn1i4ujWfzL9iq3hEPpFOxh6B35r1
igPz+He/6j2l3kDNOemNma/sQ3QP5ql7wj6hLuBr0hrw/0e9NOOoroofhyQJ
z5lZ66jeitHDB7xAfMU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 654->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhR8uxK1H8Ap6gOAV6glG0FVBqAtxN0fXShfJy48NpHRm2ryX
L3O4Pob7BsBz930M7XWepva+bOfFrY2n4zgf7pcEutj8hSypgs+62PfO+/A1
TEigrVN943yIrYPIi9LPdDrphCxIh3tN/RML51vzyfQrtopHpBPVydgj0Fuz
X3FgHv/6q+5Tqg3UnJPZmPXKOUR9ME89E9YJ6wLek64B/380y8xHND/Hj0OS
hOfMrHVUd8XUwwcVT31F
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 655->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwkAMhR8uxK1H8Ap6gOAV6glG0FVBqAtxN0fXShfJy48NpHRm2vcy
X3K4Pob7BsBz930M7XWepva+bOfFrY2n4zgf7pcEutj8hSypgs+62PfO+/Aa
JiTw1qm+cXWI1UFUi/LPfDr5hCzIh++a1k8sXN2aT+ZfsVU8Ip9IJ2OPwG/N
fsWBefy7XzVPqTdQc056Y9Yr+xDdg3nqnrBPqAv4mrQG/P9RL7M6ov45fhzM
MWHLcwfSq2bF6OEDL3x9hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 656->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFyIW4/gFfQAD69QT/AEXRWEuhB37+ha6SJvMokNpPT9ZiaT
HK6P4b4B8Nx9P0N9naepvi/beXGr4+k4zof7JYFW+vxFWdIGnbXS/zfeh8Ag
PMdt09yx0VgbvXN1qBqt1kAL80a1hvrJC6ebPJX8mTfGD8WjcCLvIfjW7Gc+
sOZ/9WXzFHIDuc+Bf916ZR9UHeyn7QnzSFzAa7IY8O9VLyMdqn/OPw72MfCW
5w6El81Kh4cPl0B8hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 657->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOgzAQs3qouPKEfqE8IOoX6AtSqZyQkOBQccvTWyoOE8cTGGkQk8Xj
2HN7Tf1wAbA0v08fP495juvzuhXvOHb3cdts9wRSyPMfYU8btJdC/p94HQKD
8IreNs0Zi8M16F7xDvVGy9XhkmwPCPwj/sS94O1oyniuNkYP1UfheNpD9Duz
XtOBOUt9K74cYbN3UmdHv6yGPu/5KueD6rMasPdgDDEbykuPh/Kv0I+DdXS0
5bkD4dVmJcPDF4CUe8U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 658->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszigXXkCX4AHVHxhvKBIcJqEtB0Qtz4dhnZIXZstUqZlzRzX
zvH27B87AFP3ffT5dRnH/L7u5+Keh/NpmA8PSwIl1fmLtGQMOiupfi/8HQKD
8JrZMUNPxOEa9F9zD3XHyNVwKXEGBP4af+Le8DaaMp7VJuih5igcpz3EPMdD
8XL9ypc13K3Y7J3U2ehX1dD9zle5H1Rv1YC9B2OI3VBeOh7K10Y/DtbRaMt7
B8L7tysVHj6zo3xF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 659->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEQCx7Eq0/wC/qA4hfWF1RwTwvCehBvfbquLDJNE3cHpjB0mkmT
OVzvXb8B8Nh9ji4/z+OYX5ftVNzycDoO0+V+TqCkOr+R5owR7n69qa1Lqntt
JDE7ZuiJOFyD3jX/UH+MXA2XEmdA4C/xJ+4Nb9LU4Vltgh5qjsJx2kPMczwU
L9evfFnCXYvN3kmdjX5VDd3vfJX7QfVaDdh7MIbYDeWl46F8bfTjYB2Ntrx3
ILx/u1Lh4Q3awXzF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 660->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBwS+sL6jgnhaE9SDe+nRdWSSdTmoDKYSkk8kk
h+t9GDcAHrvPM6TneZ7T67JdgluaTsdpSe5XB7KV/jVb3ZvL/WqtjrOVtaGZ
6O3d1XgcjkH/qjnUjJ5rwCX7HhD4//gT94o3aRrhhdo4PVQfhdPSPpqphdfS
gTn34vZi8+6kzoF+RQxdH+1V3gfFvRrw7sEY4jbULiMeMKGZ4i9M3RzrzFrz
/6h3gYc3/gF9Bg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 661->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBwS+sL6jgnhaE9SDe+nRdWSSdTmoDKYSkk8kk
h+t9GDcAHrvPM6TneZ7T67JdgluaTsdpSe5XB7KV/jVb3ZvL/WqtjrOVtaGZ
6O3d1XgcjkH/qjnUjJ5rwCX7HhD4//gT94o3aRrhhdo4PVQfhdPSPpqphdfS
gTn34vZiq91VOgf6FTF0fbRXeR8U92rAuwdjiNtQu4x4wIRmir8wdXN8Z6w1
/496F3h4A9sQfYY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 662->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDgl+oL1jBngqFehBvfbpWimRnJ+sGshA2mUwm
Od6mftgBeHSfp0/Pyzyn13W/Bvc0nk/j+nnYHFgs96/Z5t7c3y/XyngxUaPM
RG/vLsfjcAyqK+ZQMzJXwSWbAwL/H3/iXvAmTSO8UBunh+qjcGraRzPV8Go6
MOdW3FZstbtC50C/LIbOj/Yq74PiVg1492AMcRtqlxEPmNBM8Rembo7vjLXm
+qh3hoc30+59Rw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 663->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB5Krz6hX2gfEPoF+4It1JNQsIfibZ9uLSLJ7GQ1ECHuZnYy
mcvz3fWNiHzOv0+XvvdxTNPjtBSvNNyuw3LYrimS1ec/dE0b5my7q2WdlfSw
UPK2TXPH/svIDfqKOdiMyJVwcXMIwd/jr55rwRs0jfBCbcTPhu8wnJr20Uw1
vJoOyPlI71GNcce2djoH+qGn2P1or9QfUO9pgPzRKxsG8QbbZcRDlGjGMEgw
z6HPUGvsj/bt8GQGdlV8hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 664->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBwS/UF1Swp4JQD+Jtn66VIsnsZG0ghXQ3szOT
HK73btgAeOw+n65/nqepf122c3Hrx9NxnA/3SwLFYn7DlvThzn53ra6LiR4V
Jt726e74f4W5UV+lQ2lkroJL0AGB/4+/Ra4Vb/I0w0u9QdTG7yiclveZphZe
ywfmvKZ3rcc8Y18HnxP/eKfU/Wyucj+oVh5IXJo9GEPshpplxgMmPFMYItTO
8Z5VOqg/m3fAwxskZH2G
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 665->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDgl+oL1jBngqFehBv+3StFMnOTtYGUprdZDI7
yfE29cMOwKP7fPr0vMxzel33S3BP4/k0LpeH1YFspX/NVvfm7n65VsfZRI0y
E729uxx/llUPxQV1jeIdcSl6QOD/4+/PUP4rTSO8UBuQHtRH4bS0j97Uwmvp
wJy31G7VmGfs40LnQD/eKZUfzVXuB8VKA4lLswdjiN1Qs4x4wIRmCkOY2jne
s+odVB/Nu8DDGwuCfgY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 666->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD2I1z7BL+gDgl+oL1jBngpCPYi3fXpbKZKdTGIghe1uJpOZ
nO7PYexE5HVcP0N5X+e5fG6H7fAo0+U8bZf9niJV2/yG7mnD3P3eqj9XJTUs
lPS2ad7Yf5X1AC62ns6IXAmXpodIOGvIH7g0vIimEV6ojYAe0IfhZNpHM2V4
mQ7ImWqf+PIPm3nndA70w51i7yNf6X6AL0wDigveOwyyG8xL9NWdI/2TYDuH
e+bmgPpoVxo8WQCQRnyG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 667->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDB7Eq0/wC/qA4BfqC1awp4JQD+Jtn66VItnJzBpIYbubyWQm
h+t9GDdm9th9PkN5nue5vC7b5XAr0+k4LZf7Nc2qt/kNXzNGuPu99XyuTmpY
OOkdM7yJ/yrrAVxiPZ0RuRIuTQ8zOavkD1waXkRThSe1MdAD+jCcnvZqph5e
TwfkrO6VL/+wmXdJZ6Ef7hR7r3yl+wG+MA0oLnifMMhuMC/R13QWGveC7Rzu
WZoD6tWuNHj2BplVfQY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 668->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBwS/UF6ygp4JQD+Jtn66VItlkZhtIaXaTSXYm
h+tjuG8APHffz1Be52kq78t2Dm5lPB3H+XK/OFCt9Z/Z4t7c3T/XclyN1DAz
0tu7y/FnlfVgsyDXsLnVLE0PEPy1+f0Z2n/GqcKT3CDwEfownB736k09vB4P
cWZ1r3RZw2baJZ4Ff3GnWL7Sle5H0IVxQHGD9gmD7AbTMuqaYsFxz9jOxT1L
7wj1alcaPHwAcHN9hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 669->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMDS6kW4/gFfQAwSvUE4xgVwWhXYi7ObpWquTz3jSQYTKTvCQv
Od4e/bATkbn7HH15XqapvK77xbiX8Xwal8/DqiJVvX5FV7Vi/v6+mu2qIAaJ
gtxWjY99qygHqkVyDKqb1eJyCMDfqt++ib8jThke5UYCHyEnwmlxz3pq4bV4
iDWzfzaXLexfP3FejmfCX9wp5s9i036EuSAOIK9h9gkD7AaaZZxrsgnHLUE7
V8M99RHi2a44PHkDRw19xQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 670->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUssJwzAMFTmUXDNCV2gHEF0hncCF5hQoJIeSm0dPU0IrS+85AhnJ1s/v
6fx49UMjInP7Ofr0vk1TWu6nzXmm8XoZt8duV5GspX5Fd7Vi3n6xGv2sIAeJ
gt5WTYy9y6gHmkViDpqbzVL0EFD/aH57J6WNMGX1KDbi8HA9UZ0a9uxPtXrM
DryxeSq81DC2/Hi+CpwJfn6nWDzLDfvheEEYQFwd96EG2A3Epec1+ARjKmTn
srPDP4wc7cf/jytG0X2E
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 671->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMfbgQtx7BK+gBglcYT1BBVwPCuBB3PbqODJLPSyaQkrZp8vpe
DtfHcN8AeO6+y9Be52lq78t23tzaeDqO8+V+caCL9Z/J4trU3T9X4r4LecNM
SG/tKkefddaDYUF8w3BnWEwPkPpr+PUZbMw4zeql3MDx4XqyOhX32Z+qelXs
MVM8hS4Vx1ofr5fhucACl8fyV//hZkNr4vtQXp32oQaZDaal1zXsE45TS2au
uzj8Q1k1H6YePl3gfgQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 672->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKAjEMfbgQtx7BK+gBglcYT1BBVwPCuBB3PbqODJLPSyaQkrZp8vpe
DtfHcN8AeO6+y9Be52lq78t23tzaeDqO8+V+caCL9Z/J4trU3T9X4r4LecNM
SG/tKkefddaDYUF8w3BnWEwPkPpr+PUZbMw4zeql3MDx4XqyOhX32Z+qelXs
MVM8hS4Vx1ofr5fhucACl8fyV//hZkNr4vtQXp32oQaZDaal1zXsC/6oJTPX
XRz+oayaD1MPH6TgfoQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 673->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEMHDyIV5/gF/QBwS+sL6igpwVhPYi3Pl1XFkmm02wgpWnTZDqT
w/Ux3DcAnrvvMpTXeZrK+7Kdg1sZT8dxvtwvDlSL/jNb3Ju7++daG1cTb5SZ
6O3d5fizqnooLGjfKNw9LKEHRP01/P4Mca847dXrcgPig3qqOhn3vT9l9bI9
Y5Z4El0yjr0+rFfgOcECylP5q/+g2fCacB/JK2nf1BCzobRkXZs44U+a0Im5
lf9wls1HqIcP1eB/BA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 674->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwkAInHgwXn2CX9AHEL9QX7Amempi0h4ab/t0rakNCwMlYQO7LAwM
p/ure+4AjIfv0ZXpOgzlfdvPzqP0l3M/Px4XBaq0+hNZVIt6W2PF+1XIHyZC
amtVMfqushoMC/wfhjvC0tQAyb+FX9+htdlMo3zhbGDmYWqyPNnso56yfJlt
MVM8CS/ZjDU/lq9mzgkWmDgW73Zpaz8UJ7ZOuF9kV9YcpC7j0vLq/KwvJoQn
3dffdn0oyfajyYcPMfp+hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 675->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkkOwjAMHHFAXHkCX4AHWHyhvCBI9FQJqRwQtzwdKrXBdiaOJbdZHHs8
49P9OYw7AK/D7zOk93We0+e2XzaPNF3O03J5XB3IYn07w7ouJv9/iZV6n4W8
YSaktnYVo88yq8GwoH7DcLewmBog+Xv4xfLY47SVr8kNHB+uJssTcd/qKcoX
rT1miifQJeJY6+P1MjwHWODiWHw1S735UJr4Os35IrNScpC6TEuva7WP+mJG
dNJ9beuqD2XRfJh8+AJpGH8G
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 676->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfbgQtx7BK+gBgleoJxhBVwWhLsTdHF0LtWaSl0wgbTKTyee9
HK6P4b4B8Nx9P0N5naepvC/b2bmV8XQc58v9okCVVn9nWOxV5P9fY8X7Vcgb
JkJqa1Ux+qyyGqwX+Des76iXpgZI/l7/0uLYwzTK57A1OehMQZ4M+2imLF9m
WzxoPwkvGcaaH8tXg1HSC0wci3e71NsPxYmtE+5XwG1Ul3FpeXV+NheTYOes
7eZQku1Hkw8f1Cd/hg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 677->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwkAInHgwXn2CX9AHEL9QX7Amempi0h4ab/t0bVIrC8NuSWgXloVh
4HR/dc8dgPHw/XRpug5Det/2s/FI/eXcz5fHRYEspf58WM6ryP+/xoq3s5A3
TITU1qpitC+zGgwL/BuGO8JS1ADJ38IvJY8tTmk++Ho2B+2J4LKc0X43+iMe
WBzrrYZzC8eMH23b/WFYYOJYvNul1n6omdg64X4Fs43qslnauTq71heTYOfs
2fWhpLYfRT58AB3Mf0c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 678->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbgQtx7BK9gDhF6hnmAEuyoU6kK6m6NrodaZ5CXFQNpkPi8v
L3O5j11/APA8fT5derXTlObbcUkeaWiuw7J5Xh3IUvt3DWu8mfz+21mxeRZy
h5mQ2qUXZ8q1zGowLrB3GG+PS1UDBH+Pv9Q67mnq4RltFQbtycGJtPd6ivCi
WOtB+fxRh9aDj6v7pHNR78Tty5kRnSUIF09XhWswSF02Sz1Xk0d9MXP01LHp
o7DofVR4eAM40IBF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 679->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPFAfBmBFegAVlcoEwSJvipVKg/UX0aHSqUk9tkVltzGSXw+
n3O5j11/APA8fT5derXTlObbcQkeaWiuw3J4Xh3IUvt3D+t6M/n9t7ti4ywk
h5mQ2qUXd8q9zGowLrA5jLfHpaoBgr/HX2od9zT18Iy2CoP25OBE2ns9RXhR
jtaD8vmjDq0NH1f3Seei3onXlzcjOksQLp4+CtdgkLpslnquJo76Yuboqdem
j8Kit1Lh4Q1T34DF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 680->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAQC36Ivx7BK+gBBq9QT7CC/SoI9UP826Nrodad2WSLA9PuM8lk
9nC9d/0GwGP3+XTpeR7H9Lpsp8ktDafjMG3u5wSy+fyuYR4vYb//ctbqeTZy
h4UR7jKLM+VaZhxMC+o7TLfS4jhA8Nf0m/dxzVOFJ71B8CNwMpyW96qmFl7r
TtRM9fzBQ7mhcWOdtC/hnai6VI9oL0G0KH8Cruut4GW9jH2t5q26WAg/47iq
o4jWW3F4eANzwX/F
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 681->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADBK9QT7CC/SoI9UP826Nrodbs7GTVQNp9JTOZ
ZHe+dv0KwG3z+nTpfhzH9Ditp80lDYf9MF1uZweylf4+w7xezD7/5a3V+2wi
RpkJbO/ujT/LCkNxQR2jeEdcCgyI/N/4W6kj18GaRvlCbUB6EKbK09I+qqmV
rxXDnCWfP3AkNuK8XKfsC81JVFdYB8+H6wnjSH2o97/Mhuol97XaN/STFujJ
66oOZ61ZKfLhCYrigEM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 682->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADBK9QT7CC/SoI9UP826NrodZNdmaLgbT7ymQy
yeF67/oNgMfu8+nS8zyO6XXZTptbGk7HYbrczw5k8/49w7xezH7/5a3V+2wk
hpmR3KUXb8qzzHIwLqhjGG/FxeUAwV/jb17HNU0VntQGQY+Qk+G0tFc1tfBa
MZEz5fNHHpobGjfWSfsS5kTVJetgvQThovQJvXe9FbPBehn7Wu0b+lETesZ1
VUdhrVlxeHgDyaSABA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 683->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwlAMHFxItx7BK+gBgleoJ3iCrgpCXYi7d3Qt1JrP5EkDad8vmckk
+8u9v20APLrPpy/P0ziW13k7ba5lOB6G6XI3O1DF+vcM83ox+f2XtxL3VUgM
MyHY2tUbfVYZBuOCGMN4Z1wMBkj+f/zF6phqSrgzjKANnB4Ok+VpaZ/V1MrX
ivGcKZ8VOBQbeV5fJ+2Lm5OsrrQO30vVE49D9XFzZXpL7rNe+r6GfaJ5aome
fh3qUNaaFaMT3ja/f4Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 684->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwlAMHFxItx7BK+gBgleoJ3iCrgpCXYi7d3Qt1JrP5EkDad8vyWQm
+8u9v20APLrPpy/P0ziW13k7ba5lOB6G6XI3O1DF+vcM83ox+f2XtxL3VUgM
MyG1tas3+qyyGgwLYgzDnWExNUDy/8MvlseUU4Kd1QjcwPHharI8Le6znlr5
WjEe89q8LY61PrRPoivVxc1J1lfWR9BSaeLr0P7dXBltyX2mpdc17JPZSC3h
069DH8pas2J4whs9zoAE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 685->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwlAMHFxItx7BK+gBgleoJ3iCrgpCXYi7d3Qt1JqXTCINpH2/ZCaT
7C/3/rYB8Og+n748T+NYXufttLmW4XgYpsvd7ECV1r9nmNeLye+/vBW/r0Ji
mAnB1q7e6LPKMBgX+BjGO+LSYIDk/8dfWh1DTQl3huG0gdHDYLI8mfZRTVm+
LMZyXps301j3h9ZJ+kr7YuYkqiuqw/VS9cTi0PrNXNF8gd4MN+pzNBuhBXra
tatDWTYrjU54AwGDf8U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 686->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwlAMHFxItx7BK+gBgleoJ3iCrgpCXYi7d3Qt1JqXTCINpH2/ZDKT
7C/3/rYB8Og+n748T+NYXufttLmW4XgYpsvd7ECV1r9nmNeLye+/vBW/r0Ji
mAnB1q7e6LPKMFgt8DGs7qiWBgMk/7/6pdUx1JTUzjCcNjB6GEyWJ9M+4pTl
y2JszWvzZhrr/lCepK+0L2ZOIl4RD9dL1ROLQ/mbuaL5Ar0ZbtTnkFdkgZ52
7Xgoy2al0QlvToOARQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 687->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAMPPWB+HYEVoABLFYoEwSJviohlQfqL6OXSqU4zjkplpwmruM7
n3O6P7u+AfA6fpYuvK/jGKbbYTk8wnA5D8vPdnUgSurfGNb9ZvL7brmSn6OQ
O8yEYGtXOToWGQbjgvwO4+1xSTBA6tf4S6qjq2mlnqsNjB6FWmwutN+d8ZoO
jPO/dXdpYmab6VzgApPH8mt9ZLNUM7E4tH/7Blg9R2+G683Z7cszi0W0pX0o
K72VRCfMYgeAhg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 688->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMUyM
AcqGA3sEDVdrj8lvsMeiBxuwx2I3MkZSgyzWgM0ObG5hwNSDzd243IJiBwMW
8wm5n9gwJWAezrBhQAsPPGZhixes/iVSnFA4YHMzqeYSFSZocYsRznjcwoCm
Dpt6Qv7AiEukOEG3B6v/0dMANvNwhDc2e3HFM05/4QLodmEJW6z+QAL40gpK
ODEAAPMWgQY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 689->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMbIY
CrBH0HB5e0w+ij50M9DMw7AbGSOpQRbDcBuaPhR5ND3Y3I3LLVj9j8WvON2P
JUwxwgPZHTjMwxk2DGjhgccsbPGC1b9EihMKB2xuJtVcosIELW4xwhmPWxjQ
1GFTT8gfGHGJFCfo9mD1P3oawGYejvDGZi+ueMbpL1wA3S4sYYvVH0gAX1pB
CScGAChDgYY=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 690->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQMU
g9nIwB5BY1PbgE0fuhlo5uGyG90uZLEGbHZgcwsDph6cfsTiFqz+x+JXnO5H
Mwcuj8NMXObhDBsGtPDAYxa2eMHqXyLFCYUDNjeTai5RYYIWtxjhjMctDGjq
sKkn5A+MuESKE3R7sPofPQ1gMw9HeGOzF1c84/QXLoBuF5awxeoPJIAvraCE
EwMACQOBRQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 691->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQMU
g9nIwB5BY1PbgE0fuhlo5uGyG90uZLEGbHZgcwsDph6cfsTiFqz+x+JXnO5H
Mwcuj8NMXOYRihes8jjMwRf2uNyAzzx8etDDg1RziQoTtLjFCGc8bmFAU4dN
PSF/YMQlUpyg24PV/+hpAJt5OMIbm7244hmnv3ABdLuwhC1WfyABfGkFJZwY
AHISgcU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 692->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQMU
g9lIAM7HobYBmz40M1CAPW67GdDsQhZrwGYHNrcwYOrB6UcsbkH3Py6/4nQ/
mjlweRxm4jKPmHhBNhubWdjiBat/iRQnFA7YwoNUc4kKE7S4xQhnPG5hQFOH
TT0hf2DEJVKcoNuD1f/oaQCbeTjCG5u9uOIZp79wAXS7sIQtVn8gAXxpBSWc
GAD0loIG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 693->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQMU
g9lIAM7HobYBmz40M1CAPW67GdDsQhZrwGYHNrcwYOrB6UcsbkH3Py6/4nQ/
mjlweRxm4jKPmHhBNhubWdjiBat/iRQnFA7YwoNUc4kKE7S4xQhnPG5hQFOH
TT0hf2DEJVKcoNuD1f/oaQCbeTjCG8UutHjF4OMJP6wA3S4sYYvVH0gAX1pB
dTsAVaWChg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 694->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQMU
g9lIAM7HobYBmz40M1CAPW67GdDsQhZrwGYHNrcwYOrB6UcsbkH3Py6/4nQ/
mjlweRxm4jIPKxsJoNjNgN0sbPGC1b9EihMKB2zhQaq5RIUJWtxihDMetzCg
qcOmnpA/MOISKU7Q7cHqf/Q0gM08HOGNYhdavGLwiUhH6HZj+IEBk43hDySA
L62guh0AwLSDBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 695->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbgQtx7BK+gBileoJxjBrgpCXYi7ObpWSsnnJaOBDMlMJi8v
yeF674cNgMfuc/TleZ6m8rpsZ+dWxtNxnB/3iwK104pFv7aQ1Q9iK/tncijp
YmwYLHlXGQarBf5PyJHUYvlHXMP6TZ71PcnJ8lFbiMIGr43NpYWX3bf6wPrx
b96sx7avYZ+TWmDiWHyLh5ulmInFofzNDtB8Qb8Vlpmr83/YI4vtOMDbjoeQ
bFd07W890oOG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 696->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsTbPl0rpWwmk90GUpJuNjOT
7On+7IcdgNfh9+nT+zpN6XPbz8kjjZfzOB8eFwdyZx2L/+PC1jyozeoe9TDW
xdggrPJfVhiKC/ydUKPgwvojrSF/6rOeV3qqfjIuzGBDc1N7aeHVvDUHNY8t
eK1czYH3ZeZc4QKqU/UtHW6XxU4YR+qnNyD7BfM2WLRXl294R4ztNMDHTkdh
tbdiuX8BbOGEBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 697->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKg0AMfbgobj1Cr9AeQHoFe4IptCuhoIvibo5uLSKTl482EJk4mbz3
kpwf7+5VARjr76dLn9swpOl+WoJn6q+XfrlsVgdyKx2r/86FbbGTm613VENY
62ODsMp/2cKwuEC/cTUaXFi/wt/jT3W2e67pYDOG0gbNp8Sx6kS99zT9wyvq
xxG8vdjqA89L9DngAsqz8r2difaDZxDqpx0w6zn9Flg0VxUf2CPGVhqgz0pH
YdGuSO4zSfaERw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 698->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbiQbj2CV9ADFK9QTzCCrgpCuxB3c3StlJK8fFoDKZNOJu+9
JMfbs3vsAIzN99OV12UYyvu6n4J76c+nfro8zA7UVjtm/52FLXGQW713VENZ
G2ODsOS/6mF4XGDfhBodLqzf4K/xpzrLPdcMsBnDaIPlI3G8OlnvI03/8Mr6
sQVvLfb6wPNSfU64gPK8/Ghnsv3gGaT6aQfcekG/GUvy5zlv2SPGNhoCLKVD
WLYrqh4+VqyERQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 699->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRT8uxK1H8Ap6gOIV6gki6Kog1IW4y9G1Ukvy+/9kYErSTOb9
mczh+ujvGwDP3ffTp9d5HNP7sp02tzScjsN0uJ8dyF3tmP23LmzZm9is7lGO
yjrPBrHKf1kxlBas79gahRauf8Vv6ac8yznnNOwc8Eqr2NDa1LtIXqDFxYX6
RS8iXmuv+qD6xfOjtIDiVLybmWg++A3C+mkGZD7Tb2aV+vmdXV3WmNXqLdX/
j3XsKh8+oEKEBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 700->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwjAQRT8uxK1H8Ap6gOIV6gki6Kog1IW4y9G1Ukvy+/9kICXTTOb9
mcnh+ujvGwDP3ffTp9d5HNP7sp2cWxpOx2E63M8LyF29MK/fvrDFN7FZ3aMc
lXWeDWKV/7JiKC1Y37E1Ci1c/4rf0k95lnPOadg54JVWsaG1qblIXqDFxYX6
RS8iXstXfVD94vejtIDiVLx7M9H74BmE9TNT5TP9ZlaZi+fs6rLGrFZvqf5/
rGNX+fABH1GEhg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 701->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+KtT9dKLZvpTBpI2TSbzCSz
h+ujvW8APHffT1te574v78t2DG6lOx27MbmfHBia6Jj8d66Mcy4OddQjWOOx
5zr+X/ENGIoLljV2RpHn+d2slj9xmfNJz0U/aLzaAjY0N6WLxEu4uHspf7GL
DG8tVntQ++L3o7iA7mV74TejdKi1HQSO09fpGrglWqp5WWenlzXGWtstzf+/
67BDP3wAADaFBA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 702->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAMHFyIW4/gFfQAxSvUEzzBrgpCXYg7j66VWl6mM2kgpWk+M8n0
cL233QbAY/d9tOV5HobyumzH4Fb607Efk/vJgXcTHZP/3ivjnItDH80I1njs
uY+/V3wDhuKCZY/dUeR5f7er5U9c5nwyczEPGq+2gA3NTeki8RIuri7lL26R
4a3F6g7qXvz/KC6guuwulh9rWWnCOE5fp2vglmip9mWdnV7WGGvttrT/v9Zh
h3n4AK02hYQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 703->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8upFuP4BX0AINXqCcYwa4KQrsQdz26Vqok3/zUQEqnM5P/
8tP95dZ2GwBj83q09X4ahvo4b+fFtfbHQz9v7pYEpuITS77fTfCeWrt7VMNF
0drfe/zd8DqNhO2vHoN97l/1KvmLZ50Mj6r5Uw+xng2njZgtmkuol7Cocyl/
8o9knGseR/6EPicsoHOZL5KPZ2lmwjpqvo4pqic8Yy3Lz3OW/qtgrTVvqf/P
WaXt6uEJC82Eww==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 704->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMfbgQtx7BK+gBilcYT1BBVwPCuBB3PbqOjJI8X9oGMjST33tJ
dufbcF0BuG/enyE/jtOUn6f1bFzyeNiPs3O7KFCSVyz6eRthX2S7PKrhJMW9
f3n83+B1PSrYujgKP/OPuIb4k8daDJ6opqon30Zcb2hsai+tfjVtzUHNoye3
Zas5FGHz/SgsoLjaXEJ8vEuzE+4j69EN8F2oG+FYxZf33HNHzOWPQ222xP8b
G/V29fAC/HuFQQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 705->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1hBTwWhHsTbPl0rRZLZyXYDKUmzSWaS
HK6P4b4B8Nx9P0N+nacpvy/b2bnl8XQc5+B+UaAkr1j0ZxvhWOS7PKrhJMW9
/3n83+B1PRrYujiKOPOPuIb4k8daDJ6opqonbSOuNzQ2tZe1fi1dm4OaR0/u
mq/mUITP96OwgN615hLi412anXAfWY9ugO9C3Qi/VXx5zz13xFwqDqjtioeR
1r5dPXwAIYqFwQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 706->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBBq9QTzCCrgpCXYi7HF0rRTJvXjoTSEk6+b2X
HK6P4b4B8Nx9P0N+nacpvy/b2bnl8XQc58f9ooClUrHoz3by94NYU3lUo5AU
9wb18v9M9Qhm4ZwQo3hn/BHWcP5UzmpunqimqidtJxJTC09HvzVt8aD46Mlt
+YoHEz7fj5oFFKfiW/xUu3Q74T6SH7oBvgt1Ixyr8PKee+6IsVQYUNsVDidr
+y7q4QMGG4VB
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 707->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBBq9QTzCCrgpCXYi7HF0rRTJvXjoTSEk6+byX
5HB9DPcNgOfu+xny6zxN+X3Zzs4tj6fjOD/uFwUslYpFf7aTvx/EmsqjGoWk
uDeol/9nqkeAhXNCjuKd+UdcQ/ypxGoOT1RT1ZO2E8mpxaej35q25qDm0ZPb
8tUcTPh8PwoLKE7Ft+ZT7dLthPvI+dAN8F2oG+FYxZf33HNHzKXigNqueDhZ
23eBHR8C6IUC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 708->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbgQtx7BK+gBBq9QTzCCrgpCXYi7HF0rRTJvXjoTSEk6+byX
5HB9DPcNgOfu+xny6zxN+X3Zzs4tj6fjOD/uFwUslYpFf7aTvx/EmsqjGoWk
uDeol/9nqkeAhXNCjuKd+UdcQ/ypxGoOT1RT1ZO2E8mpxaej35q25qDm0ZPb
8tUcTPh8PwoLKE7Ft+ZT7dLthPvI+dAN8F2oXXGs4st77rkj5lJxQG1XPJys
7bvAjg9x6IWC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 709->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDV2I2x7BK+gBBq9QTzCCrgpCXYi7HL2tFMm8vHQmkJJ08nkv
yen+Gp6diLyPy2fIn+s05e/tsDqPPF7O4/rYbyqiqVTZ9Gcb+ftBrLI8qFFI
insL9LL/lPUIsGBOyJG8I/+Ia4g/lVjV4IlqsnrUNkI51fg09NvT2hzYPFpy
az6bgxIf74dhEYhj8bX5uF2anWAfOh+4AbwLtiuMZXt1fsMdIRfHQbzteBjZ
23eJfQZDZYVD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 710->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOgzAMtDigXnlCv0AfEPEF+oIg0VOkSvRQccvTWcTBGU9ILBl5iBPP
2H5O3/HTiMjvsX9G/x+Wxa/v9gCzD68+HIfd5SLRpX6aji/DsxM7i5N78EZi
jtTWrnmof5HVyHDBO4w348L057Rm+UNPo+KTe5O9R2NlVFNJT0W9Oy/1gfWj
pl4Jsz5EgnF/GBeBPJZf5IuzVDPBOlQ/7ADuBZsV5rK5GlyxR6jFaBAbGx3K
7nYl5b4BNJaFhA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 711->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwMF2GOxGxkjuwNJrAGbHTjcgq4Hm7txuQXd/7j8itP9
aOY0ILkHl5nYzMPKRgJY/YTDHHxhj8tPpLgLX3gQYx8hPrZwQI8vlHDG4xYG
NHXY1BN0L3pcIsUJuj1Y/Y+WBtDTBba4QleLLV4x+ESkI3S/YPiBAZON4Q8k
gC+toLodAOulhgQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 712->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwMF2GOxGxkjuwNJrAGbHTjcgq4Hm7txuQXd/7j8itP9
aOY0ILkHl5nYzMPKRgJY/YTDHHxhj8tPpLgLX3gQYx8hPrZwQI8vlHDG4xYG
NHXY1BN0L3pcIsUJuj1Y/Y+WBrCaRyAuscUrBp+IdIRuN4YfGDDZGP5AAvjS
CqrbAbFShcU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 713->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwMF2GOxGxkjuwNJrAGbHTjcgq4Hm7txuQXd/7j8itP9
aOY0ILkHl5nYzMPKRgJY/YTDHHxhj8tPpLgLX3gQYx8hPrZwQI8vlHDG4xYG
NHXY1BN0L3pcIsUJuj1Y/Y9uJzbzCMQltnjF4BORjtDtxvADAyYb3R/IAF9a
QXU7ADBhhkU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 714->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwMF2GOxGxkjuwNJrAGbHTjcgq4Hm7txuQXd/7j8itP9
aOY0ILkHl5nYzMPKRgJY/YTDHHxhj8tPpLgLX3gQYx8hPrZwQI8vlHDG4xYG
NHXY1BN0L3pcIsUJuj1Y/Y/NjejmEYhLbPGKwSciHaH7BT3M0MMWmz+QAb60
gmIeAwA+34ZD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 715->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwMF2GOxGxkjuwNJrAGbHTjcgq4Hm7txuQXd/7j8im4u
1nBhQBLHYyYu8zDYSACrn3C5C0/Y4/ITKe7CF5/E2EeIjy0c0OMLJZzxuIUB
TR029QTdix6XSHGCKy1g6Ed3I7p5BOISW7xi8IlIR+h+wfADAyYb3R/IAF9a
QTGPAQAI/YdD
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 716->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwMF2GOxGxkjuwNJrAGbHTjcgq4Hm7txuQXd/7j8im4u
1nBhQBLHYyYu8zDYSACrn3C5C0/Y4/ITKe7CF5/E2EeIjy0c0OMLJZzxuIUB
TR029QTdix6XSHGCKy1g6Ed3I7p5hOISzQ3Y4pmYdITVHDR3obPR/YEM8KUV
FPMYAHhvhoQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 717->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwMF2GOxGxkjuwNJrAGbHTjcgq4Hm7txuQXd/7j8im4u
1nBhQBLHYyYu8zDYSACrn3C5C0/Y4/ITKe7CF5+kmksojJHDFWc443ELA5o6
bOoJug89LpHiBFdawNCP7kZ08wjFJZobsMUzMekIqzlo7kJno/sDGeBLKyjm
MQAAe36HBA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 718->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwNFzB6L3cgY2R1IYg3Y7MDhFnQ92NyNyy3o/sflV3Rz
sYYLA5I4HjNxmYfBRgJY/YTLXUj2ErIPHyYUDtjik1RzCYUxcrjiDGc8bmFA
U4dNPUH3occlUpzgSgsY+tHdiG4eEXGJHq8YfCLSEbpfMPzAgMlGD2tkgC+t
oJjHAACKO4cC
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 719->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwNFzB6L3cgY2R1IYg3Y7MDmFgZMPdjcjcst6P7H5Vd0
c7GGCwOSOB4zcZmHwUYCWP2Ey11I9hKyDx8mFA7Y4pNUcwmFMXK44gxnPG5h
QFOHTT1B96HHJVKc4EoLGPrR3YhuHhFxiR6vGHwi0hG6XzD8wIDJRg9rZIAv
raCYxwAAo5WGww==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 720->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwNFzB6L3cgY2R1IYg3Y7MDmFgZMPdjcjcst6P7H5Vd0
czHMR3IDRnjgMAebHejmwQBWP+FyF5K9hOzDhwmFA7b4JNVcQmEM8w96fKGE
ER63MKCpw6aeoPvQ4xIpTrClBQzz0O3EZh4RcYkerxh8POGHFeBIc+hs9LBG
BvjSCop5DABtHYWE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 721->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwNFzB6L3cgY2R1IYg3Y7MDhFnQ92NyNyy3o/sflV3Rz
McxHcgNGeOAwB5sd6ObBAFY/4XIXkr2E7MOHCYUDtvgkVj0h96CYhRa3GOGM
xy0MaOqwqSfoPvS4RIoTbGkBwzy0NIDVPCLiEj1eMfh4wg8rwJHm0NnoYY0M
8KUVFPMYAMulhMM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 722->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMDS6kW4/gFfQAg1eoJxhBVwWhXYi7Hl1bKiQvLxMDGSYzycvL
53h79o+diEzd9+jr6zKO9X3dL8a9DufTsHweNhWZi9VV9H0T/Fvt4m0TBxjm
rZDcWjUP9TazHAEXjGG8Iy5Yf1Qr4jp8xcH1I8BhORDvJ7SmiJfKm+VradYH
Ns9//TM+Bgtm6/rc4CLgx/xTfjhLNRO2Cw4PdoDiZbOEGDbnqK5Qgp3DO/Za
S2tXDJ58AJwmhIQ=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 723->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
s6EAXQ7Mt8fko+hDMwNFzB6L3cgY2R1IYg3Y7MDhFnQ92NyNyy3o/sflV3Rz
McxHcgNGeOAwB5sd6ObBAFY/4XIXkr2E7MOHCYUDtvgk1VxCYQzzD3p8oYQR
HrcwoKnDpp6g+9DjEilOsKUFDPPQ0gBW8wjFJZoebPGMy184AY40h85GD2tk
gC+toJjHAAClNYUE
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 724->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB7Eq0/wC/qAxS/UF6xgTwWhHsRbn64tLSSTSdZAym43mcwk
Od2fXb8Tkdfh9+nq+zqO9XPbz5dHHS7nYX48ri4yFeuL6fNq+Lbci7+bPMAw
Vkht7ZqH+jexGoyL+BzGO+KC+iOtiOvwFQfXjwCH1UC8zaimiFfS+0jTv7yi
uJbGrH7W400Pzsv0KOEiEMfim/xwlmombBccHuwAxWvNEnLYnCNdoQU7h2fs
tbZsVwyefAG+UYSG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 725->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3Pl1bWkgmmbSBlE13M5lJ
cn682u4gIu/m/2nr5zYM9Xs/TsGz9tdLP12eFhcZi/XZ9HkxvJvj4mOTBxjG
SlBbu+ah/o1RjYiL+JyIN+OC+plWxHX4ioPrB8GJaiDeaqEmxivpPdO0lxd7
t6Uxq5/1eNWD8zI9SrgIvMv6QvnhLNVMol1weLADId7WLCEnmjObFzWyc3jG
XmvLdsXgyQ9zYIUG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 726->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3Pl1bWkgmmbSBlE13M5lM
cn682u4gIu/m/2nr5zYM9Xs/TsGz9tdLP12eFhcZi/XZ9HkxvJvj4mOTBxjG
SlBbu+ah/o1RjYiL+JyIN+OC/bNeEdfhKw5OD4IT1UC81cKeGK9Ee9bTXl7s
3VaPWf1M47UfnJfRKOEi8C7ThfLDWaqZRLvg8GAHQrytWUJONGc2L2pk5/CM
WmvLdsXoJD9wLYTH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 727->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMDB6kV5/gF/QBi1+oL1jBngpCPYi3Pl1bWkgmmbSBlE13M5lJ
cn682u4gIu/m/2nr5zYM9Xs/TsGz9tdLP12eFhcZi/XZ9HkxvJvj4mOTBxjG
SlBbu+ah/o1RjYiL+JyIN+OC+plWxHX4ioPrB8GJaiDeaqEmxivpPdO0lxd7
t6Uxq5/1eNWD8zI9SrgIvMv6QvnhLNVMol1weLADId7WLCEnmjObFzWyc3jG
XmvLdsVq/AFtLYRH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 728->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMDB6K1z7BL7QPWPoF+4It1JMg6EF669Ot4EIym4kNRHbdZDKT
pHtN/dCIyNL+Pn1eH/OcP8/Lfnnn8X4b98fr4SLfZL2YPpu7jk313eQBhrHk
1NauYvQ/5CmQZ94hx+PNuKB+phVxK3zFoeoHwfFqIF4xVxPjFfSeafqXF4s7
0xjVj3pc9OC8TI8CLgJxUV8oP5ylmom3CxUe7ICLdzZLyPHmzOZFjewcnrHX
2qJdsRo3VkuECA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 729->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKAkEMLDyIV5/gF/QBjV8YX9CCngaE8SDefLqOOlJdWcZAN51OUqks
m+OlOy8AXFevq6u3/TDU+2E5Kqfa77b9aFx/D/Ao7Znk/VYdn7+fb7E6Y3C8
keLk5kM+/Kc8IXGNXWI83hGXJgcc/IC/wScOph8BjpdD8SZxa4p4Ieae/f/D
K/KbqzHLn/WY61Fd98fjAvHL9iDkp7OkmXi7YPBkB1y8ZJZG1DYzr1CCndO3
9pol25W2xidWAoUG
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 730->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKAjEMfbgQtx7BK+gBilcYT1DBWQ0I40LceXQddeT15aOBlCZNXl7S
bI7nrl8AuKyeR1ev+3Gst8NyMk512G2H6XH9UeBeWp3ldVcbb983tlibMTjf
SHFqs1IM+5QnJK95lxyPd8SlqQEHP+Bv8ImDmUeA49VQvFncniJeiLln/n94
RXG/eszqZzPmftTW/fG4QOKyPQj56V/Sn3i7YPBkB1xJ/jKKNXYyvxRHdk7v
OmuWbFe4DvAAHKuExw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 731->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkKAkEMLDyIV5/gF/QBjV8YX9CCngaE8SDefLoOOFCpLBpI0+lOKpVl
d74N1xWA++ZzDP1xnKb+PK1n49LHw36cP7dfBV7N6iJ8Nzb7Nm+bOMEw0oLc
rOTDb8oTEmf+JSbinXHR+rNaFdfhEwfXjwQnyqF4i4Q1ZbyQc6/e/+GV+f2q
scpf9ZjrUVv3J+IC8av2IOWns6SZRLvg8GQHQilmmfk6u+hfiSM7p3ftNUu1
K5wHeAMHwYSI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 732->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwkAMfbiQbj2CV9ADDF6hnmAEXRWEdiHuPLoWLLy8SWIxkGEyk7y8
fPaXe3/bAJi6z9HXx2kc6/O8nY1rHY6HYf7cfRV4FauL8N3Y7Fta28QJhpHi
5GYlH35TnpA48y8xHu+Ii9Yf1aq4DT5xaPoR4Hg5FG8Rt6aIF2Lu2fsaXpnv
P7i/esz1qK37Y3ZIbfj+q/jpLGkm3i40eLIDriSzjHwbO+lfiiM7p3ftNUu2
K5wHeAMa0IUI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 733->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwkAMfbiQbj2CV9ADDF6hnmAEXRWEdiHuPLoWFF5ekmkxkGEyk7y8
fPaXe3/bAJi6z9HXx2kc6/O8nY1rHY6HYf7cfRV4Fas/4bux2bd428QJhpES
5GYlH35TnpA48y8xEe+Mi9af1aq4Dp84uH4kOFEOVxukH5Iz5IWce+t9La/M
9x/cpR5zPWrr/pgdUhux/yp+OkuaSbQLDk92IJTGLDPfyF7aoxCHa4C/a69Z
WrvCeYA3XTyFSQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 734->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKAjEMfbgQtx7BK+gBilcYT1DBWQ0I40LceXQdUHh5SWoxkNK0ycvL
Z3e+DuMKwG3zPoZ6P85zfZzWi3Gp02E/LZ/bjwLPYvUrfDc2+xZvmzjBMFKC
3Kzkw2/KExJn/iUm4p1x0fqzWhXX4RMH148EJ8rhaoP0Q3KGvJBzb7338sp8
/8Htyi2zdX0OeOiMeE96amnuB80k2gWHJzsQSmOWmW9k/9qjEIdrgL9rr1la
u8J5gBdQS4XJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 735->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKAjEMDS7ErUfwCnqA4hXGE1TQ1YAwLsSdR9dBhZeXl1oMZKZpk5eX
z+Z4Gc4LM7uuXp+h3vbTVO+H5Wyc6rjbjvPj+qNmj+L1K3h2NvqWaLs4wnBS
RG5U8ME75mkU594pRvHOuHD9Wa2MG/CBQ+hHgqNyhNqM+kE5JS/Lubfue3ll
vv/gduWm2YY+Cx48I9yTnlqa+wEzUbsQ8GgHpDRmmfkq+9cemYrDGiyeudco
ga/Ae/+fZEWFxw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 736->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwjAUHFxItx7BK+gBileoJ4igq4LQLsSdR9eiwmTeJMbAa/OSvJl5
n+3pOlxWAObu9RnS7TBN6X5cL845jfvduFxuPgY8+ty+i/eZz2/76GdxgqF4
gZuNuPhMdULisnuJcbo1J1cL5tFcFTfgk4ZQjwKO4wi5SR2V0+pCWXvtvFVX
raf/4jZxS29DnY0O7RHPSUsu1fmgnrhZCHgyA3ZVell66/xfcwQXxzkg7rXW
vIJeg/f+PwFpY4ZH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 737->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPwQfz2CV9ADFK9QT7CCfhWE+iH+eXQtKsxOJmtdSJvsJpPJ
Y3O89OcFgOvq9enLbT+O5X5YTsapDLvtMD2uPwI8ulq+h/XKZt8u2lWcYChe
yM1CufhOeULiqneJcby1JtcLzqO1Km7Az3gbzAwv6KaPmtPyQs69dT+XV2um
/+LOyi2z5fp0rrojEL/WHmT8wixpJm4XAp7sgD2NWWa+zv61R3BxXAOirr3m
E/gavPf/CfRyhsc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 738->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkKAkEMLDyIV5/gF/QBg18YX9CCcxoQxoN48+k6oFCpLI4NaZLupFJZ
dudrP6wA3Dbvq2/34zS1x2k9G5c2Hvbj/Ln9CPDsrHwP68Zm387bJk4wFM/l
ZqFc/KY8IXHmX2Ii3lpT1AvOo7UqrsPPeAeYGZ7Tgz5qzpAXcu7V+1Je1Uz/
xV2UW2bL9elcdUcgftUeZPzcLGkm0S44PNmB8BSzzHwj+9cehThcA7yuveZT
7YqNeQHjq4cI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 739->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKg0AMfXQhbnuEXkEPIF7BnmAKdSUIuhB3PXorVEheklEHMiQzycvL
5/Eau/4GYC5/V5eWdprS+iw2452Guhq2z/tfgE+jZT9SV7b0bayt4giD8Uxu
KSKXfGOeoDj1TzEeb67J64XMw7UyrsGPeDuYEZ7RnT5yTpcXYu6597O8cjO9
insqN81W1sdz5R0B+eX2IOIXnWgXDB7tgHsys4x8Pftoj1wcWQOszr3mHkS7
omO+lqSGyQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 740->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKg0AMfXRRuu0RvEI9gHgFe4IRdCUIdlHc9eitYOHNSzK1AxmSmeTl
5VP1czeeADwun6tLz3ZZ0no/b8aQpvo2bZ/XXYBXk8v3sJ7Z7NtYO4sTDMUz
uVkoF78pT0hc9i8xHm+tyesF59FaFdfgR7wdzAjP6E4fNafLCzH30vtRXqWZ
/ot7KLfMluvTueqOQPxKexDxi060CwZPdsA9hVlGvp79a49cHK4BVtdeaw+i
XeE8wBuTcYaK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 741->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBi19YX1BBTwvCepC97dN3FxSSyaQ2kNK0zWSS
zun+6p87AO/DuvTlcx3HMt32W/Aow+U8bJfHrwNz5/1ndu9i+7aLscsjDMYL
ta2bWvaMeYLy3D3lKN7ck5qFrcO9Mm7Az3gLzAwv7MUcuabkhZx77byVV+1P
m3ATXaS1ofNZP05DQlPqfct8Msu0oPp1nJRV/jJ7q+J/OpI4tgfEPc+aZ5Bp
xdYBFhgmhks=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 742->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfXQh3fYIXkEPULxCPcEIdlUo1IW469FrQSXz8jJOIEMyk8+b
5B1v8zA2AB7t+xjS87Is6XU97M49TefTtD92HwXWPtevWDvzbWzv/SyPanA9
19uq6WXvGCcoL3unHIWb/6RmoWqpHMb7sxVuwGGO6jlbzJF7SlyIsZfua3GV
dlpVN+BF2Bs6n/nD3GJOqfia+UQScUHyi/bjpLDLKFb5/3gk69g/wNs8a55B
xBXbB9gARiyGDA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 743->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPoo/XaErtAOELJCOoEL7StQSB4hv4yeBFqQTqdgg41kS6eT
fLfXt/ucAIyX7ejK1A5DmZ/n3XmX/nHv98frbwNL4/d/Wdv5NraJvssjDMYL
te02tewd8wTl2feFchRv7knNwvbCvTJuwM94A4FzhhdsMUeuKXkh5350X8vr
6E+rcBNdpLWh81k/rC3WlIqvmU+2Mi1IfdH/OD6CU4hFjA1+hY4kju0B0eZZ
8wyy2r7PFXpAhwo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 744->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENgzAMPPWB+HYEVqADRF0BJkgleCFVgkfVH6MXUFucsx3FUiBO7PPZ
uebx7MYLgKXePl183ec5vvtqd4Y43dppv7x+F7CGdP1M7g8L5/8fG7Sf5DGG
MK4r8biWPGOeoDx5v1KOxZt7smYhe+FeGVfhe7wBxdnDU9jGHLmmyQs+99x5
Ca9cbDGuowu3Nux81g9rizVlxZfMxzNPC6a+6H0SPgYnFQsdq/zM/LI4pDne
86x5Bl7ttM8P5ASGCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 745->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHgwXn0CX9AHbPwCvmBJ5ERiggfjjacrBrBMO7hNFna37XS2
naq51+0OwOPw+dT5een7/Lrux8Mtd+dTNzqP0wKGtF6z2f3X0u+/xCZ/XuUx
hjGua/G4lr1jnqA86x8oJ+LNb4p6Yd/Cb2Vch694A46zwnPYQR+5ZsgLmvvW
fQmvrdhiXKELWRtxPuuHtcWaiuJL+qNMaSHUF81nyTcaUbN0xr4/85ImNMd7
7jX3QNW2dYA3WxOGig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 746->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAQszggrjyBL8ADIr5QXlAkeqqEVA6IW58ORSyOM24zUtosM7Yz
8e58bboVgNvm9Wna+3EY2sdpPS0ubX/Y99Ph9jOAMeXjGzx/R/r/f7mpXGd1
ikGhvIynXLynOiF1fD5KTaRb7xT1gnn0ropb4LOWBUyHV2AHfVTOUBe89rn9
Gl1zudW4xheWG3G9+ifzUOCpKL+mPy6cF6L7Zpq4njzi3rIIPVt4LxvGczrX
XmsPHDfzAE+h74ZJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 747->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPWB+HYEVoABoq5QJggSfVVCKg/UX0eHIijOxRdyUtokts/O
2YfLrR8aAPf969PHRzdNcT7v1sM1jqfjuBrbzwKWkK4v7P6N8PtvviE/J3HM
YcB5LR/nsndcJyjO2heK8ermN3la2Dz8VuZ1dYG5L3Aqvozb0RHk49YFXXvp
vqaukm81r5gLmRt+PM9PMkPOTHn+NfoolGYhi6f+bPFmRlQvM7DtT78khJ68
Z61ZA5Xb5gGeGjKGig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 748->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOgzAMHPWAuPYJfIE+IOoX6AuCBCekSnCoeuPpLYjFmdgJlgJJ7PE4
Y1ftu+lvAKby/2n85zmO/vsqlkPnh0c9LM77toDZhWs3uV/Nnf8j1sXnAMc5
hDGvzMdc8o7rBOGkfyaMVje/SdNC8vBbOa+qC8Q9aWBxsy/IregIilHrynCm
asnVlYq9nNeYC5MbOp7nJ5ghZaa0+Cv6WJaahQhP/TnwOP1WLyNjX6Zfphl6
8p61Zg0sbskD/ACdQYcK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 749->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsENwjAQs3igfhmBFWCAiBXKBEGir0pI5YH4dXQogtZx7tJwUtokF58v
jveXW9ttANyb96eNj9MwxOd5Oy2usT8e+im5+w5gDOn4Bc8/EZb/fDbk6wSn
NSiUl+spF+9pnxAc50fBWH3rnSwtmEfvqnVNXUD7ooHHrTmtpzpC+M2+VjhL
vdT0VXrTqrqOL1xu2Hj1T+Ihw1PW+Rp9vCh5IcPL+8x4LHnvLbPQ3B8+8uqw
njpXrVUDj5t5gBcGX4eK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 750->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFAfBmBFWCAiBXKBEGir0pI5YH4dXQogmJfziGW0iZx7LPP
tztfu34F4LZ5fbp8P45jfpzW8+GSh8N+mJ3bzwKm5NfX7P5t6fdf3qbyvNzb
GGGMa/Mxlr3jOkFx1j9RjKqbe1JcWBzulfNKXkC8wN8pbPZxPuYRhC/r+oNZ
q6WlrtpMm/IGugixoeNZP05DQlPqfQs/ThvBXGv9s65cvMkdzbIwUVerjmQe
2wPKPXPNHETYFgd4AnRfiEc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 751->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAESuUCYJEX5WQygPx6+hQBMW+ntNYSpvEsc8+
3/5ya7sNgHvz/rT5cRqG/Dxvp8M198dDPzl33wWMya+f2f3H0v8/v03L83xv
Y4Qxrs3HWPaO6wTFWf9IMapu7klxYXG4V84reQHxAn+nsNnH+ZhHEL6sawWz
VEtNXaWZVuUNdBFiQ8ezfpyGhKbU+xp+nDaCuZb6Z125eJM7muXCRF21Oory
WD55z1wzBxG2xQFeW4SICA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 752->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOwjAMszggrjyBL8ADJr4wXjAkOE1CGgfEbU+HSYAc1ymt1K1pmjhx
vDvf+usKwH3z/vTD4zhNw/O0XozLMB724+LcfjYwd3F/F5+DzW+70v7dg/5m
KS7ng2DxndYJiWP/LDGubu3JccE42qvmtbxAeEG8c9jq03zKIwTf1vUHs1ZL
S121mTblTXSRYsPHq36Choym3PsWfoI2krnW+lddhXjKnc2yWKauVh1leZhP
PRd9CAcZNuMAL6miiQg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 753->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwzAME/0Y/e0RdoXtAGVX6E6QwfpVKLQfZX89+lbYQFbsLAGHvCzZ
is6PeRgbAGv7mYa03ZYlve6nY/NM0/UyHZfdN4C9t/EbvDZ7ftvne5MnGIqX
cXMQF59pnZA8vt8lx6tbe/K0YB7tVXFdXUDnqmnArXeKpzpC+N26/nCWaqmp
q/SnVbiBL0Ju+PnqH+Mhx1Pe+xp9jDeCfy31r74y+YQd/WU2nLpqfRThsJ66
zvoQDSJu5gHeooCIyQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 754->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6jgnhaE9SDefLquKCSTSW2hJW2azCSZ
3fk6jCsAt837GOr9OM/1cVovl0udDvtpcW6/G3gWv3/L2u5u/5Z4d3GUg/MF
bLsNln1jnqA456cYxZtrUr2wOFwr55V9gXnnnibY7Au1UR9B+JLXH8wWlx5e
rZl25U10kWJDx7N+nIaEptT/nv44bSRzbdXPunLxJnc2y7CKrr9HRzIP9ZPt
UEfCJeX+sV/k9YgI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 755->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPyQ/noEr6AHKF6hniCC/SoU6of459G1ojA7uxsTSNg8dmZ2
M/vLPIwbALfuvQzlflqW8jhv1821TMfDtF7uvhN49nb+Bsdmz297vzd5gqF4
jpsncfGZ6oTkmXvJiXRrTVEvmEdrVdywL6Bz7WnCrXeuNukjhD/U9YezpqVF
V+1Pm3ATX6TciPPVP8ZDgaei9y39Md5I/rVWv/rK5BN29pduBLpafZThcD81
dnVEGDXtn/gFumKHyQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 756->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPyQ/noEr6AHKF6hnmAF/SoI7Yf459G1ojCZZOO6kLLJNjOT
x/Z0HS4rAHP3+gzldpimcj+uF+dcxv1uXB43HwMevbXv4bvx+d/e+yZPMBTP
cbMRF8dUJyTPvEtOpFtrinrBPFqr4oZ9AcW1pxVufXO1SR8h/KGuH5yZlhZd
2Uz/xW3iltm6Pgc6dEa8Jy21hPuRzDWrX/fK5BN2bZbuBLpa96iGo/0ExV0d
EUam/X1/Agq8h4g=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 757->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRTYP3S5kMXR3MqDpQ5FH04PN3eh+whYWyPag
+xXdXKzhwoAkjhYGuOxGl8NwM1o4MqDZj9VdWPyByz58mFA44AprUswlym60
uMUIZyzuQI8j5HRCjF+wpg888Yo3vNHiA0U/ktk44xIdYHEXvvjCCdDtQnMr
zI0Y/sBjBla3g9kAQkyGRw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 758->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVks0NwjAMhS0OiCsjsAIMELFCmSBI9FQJqRwQN0aHIn7sL7YBS26aOPZ7
efZqf+z6mYicFvdPV8/bcayX3XzaHOqwWQ9TcPl0kWux/jL9/7DyWd93S7s3
eayhjLi6HrH0GXkK8kwcOR5vvsnTQuPwrazr6iLqHBpE2Iw1nKGjAN/l5bwj
wsv8mw6R1v/U/QkbvW10dniwR3pOvFnJ+JnZCPqa6o1+mHxVO+wlzeGV9Ss0
YoErdfI0yLD1HZEb5nKGCA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 759->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkksOwjAMRC0WiC1H4ApwgIgrlBMEia4qIZUFYsfRoYiP/WK7WHLbNLFn
MuPN8dz1CxG5rJ6Prl7341hvh+W0ONVhtx2mzfU7Re7F5if09yvK7/09W9q1
qWMPFcTV/Yil/5GnoM7so8bjzTt5Wmgc3pV9m/6KA/WI+ngYDWfoSEyXl3OP
CC/LOR0iredq/sGnx/TL6OzwoEd6TrxZyfiZ2Qh8TfWGH6Ze9Q69ZDi8Mr/C
IBa4UidPgwxbnxF5AE5UhQg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 760->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylkksOwjAMRC0WqFuOwBXgAFGvUE4QJLqqhNQuKnYcHYr42C+Ou8CS26aJ
Z+yZ7M/Xrt+IyNQ8H12e23HMt9N2WVzycDwMy+bunSL3ZPMT+vsV6ff+nk3l
2tQRQwV5NR659D/2Kagz+6jx+uZMnhaah7MSt8BXPVCPGo7HUfQMHcnp9uXM
UeOLck2HNdx/+Okx/TI6O/rRI31PvLsSziFlPX0N9YYfpl5hV71kOH1FflWD
XOiVOnkaRNz6jMgDX2OFiA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 761->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylkkEOgkAMRRsXhq1H8Ap6gIlXwBOMiaxITGBh3Hl0xSi0b1pmYZMCQ6f/
t7/dX25ttxGRsXk/2nw/DUN+nLfT4Zr746GfgruvizyT9Z/p74+l5T3fTeXZ
5BFDGXk1Hrn0P9YpyDNx5Hh1sydPC83DXolb4KsaqEeE43EUNUNHcrp1OX1E
fGte06GG+w8/Z8x5GZ0d/TgjvSferqz2EVi0CwUe5mHyZYmHs6QxVplXaORC
rdRpjkGDiFvziLwAJmCFyQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 762->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylkkEOgkAMRRsXhi1H8Ap6gIlXwBOMia5ISHBh3HF0xai0b1pmYZMCQ6f/
t7/dnYfuuhGRW/N6dPl+HMf8OG3nwyX3h30/B9uPi0zJ+tf099vS8v7dTeXZ
5BFDGXk1Hrn0P9YpyDNx5Hh1sydPC83DXolb4KsaqEeE43EUNUNHcrp1OX1E
fGte06GG+w8/Z8x5GZ0d/TgjvSferqz2EVi0CwUe5mHyZYmHs6QxVplXaORy
tHX7gAYRt+YReQJRYIZJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 763->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylkkEOwkAIRYkL49YjeAU9wMQr1BOMia6amNSFcefRtUYtPGC6kIR2ppT/
4cPmeOnOCxG5rl6Prt72w1Dvh+V4OdV+t+3H4PrjIo9i/Wv6/LYyvX//Fn83
ecRQRl6NRy79jXUK8kwcOVHd7CnSQvOwV+I6fFUD9chwIg5XM3QkZ1hX0EfG
1/I5HeZw/+HnjDkvo3OgH2ek9yTalWYfiWW74PAwD5MvUzydJY2xQCfq18TR
PYg/uz6gQbYrmkfkCSq9hgo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 764->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylkkEKwkAMRYML6dYjeAU9wOAV6glGsKuC0C7EnUfXitbkTTJFDKTtNJP/
k59sT5e2W4nI2Dwfbb4ehiHfjuvpcM79ftdPwc3bRe7J+sf098vS9z3fTeXZ
5BFDGXk1Hrn0P9YpyDNx5Hh1sydPC83DXolb4KsaqEeE43EUNUNH8rh1OX1E
fDVf0mEJ9x9+zpjzMjo7+nk7pefyUx+BRbvg7pczV4NdmyWNMUcn6lfFCXaL
Os19QINoVzSPyAOAI4XL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 765->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRTYP3S5kMXR3MqDpQ5FH04PN3eh+whYWyPag
+xXdXAzzkdyAHh64zMFmB4ab0cIR3R6s7sLiD1z24cOEwoEa5hJlN1rcYoQz
lvDDlqaQ44UU9+ECuNIC1vSFJV5RzMYXl+gAXQ5LOKGHH15zcKQt9HCC+wMt
DHClFWR7GBgAhzKGSw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 766->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkKw0AMEz2UXPuEfqF9QMgX0hdMoTkFCumh5JanZ6FQjyxnMThkxh5J
Xq7Pd92cAHyK6VOnb9V1qX+c58MrtfdbOwcvPweGMvfF7D/+dza2xEt/zt4x
hjHmtXjMZe8GxaG0wL9Rurkm1wvi4VoZ1+EbDdyPCEdxOM3UR+aRukQdEd+a
M+9m/l7cgzk8W9fnYLd4p1T+Hn2RRbsg90vMNcNemyUbxzbmFRpzid7KOqgH
jk/oA0Zo7IaK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 767->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhYMLcesRvIIeoHiFeoIR7Kog1IW469G1RTD98tLWQEpnknnv
5edwvdfNxsweu8+nLs9z15XXZTscbqU9HdshuP+6WV9NfTT/b787HxvjVTxP
3hHDGXk9Hrn8Xa84lBaLb5Ru1hR6AR7WStyA7zSwHxmO4gi1oY/kkbpEHRnf
nJN3MX8t7p85nG3oc7Jb3CmVv0ZfZtkuyP3ifAzYc7OkMbYwr9TIJXor60AP
Ap/QZ/YG0/uHCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 768->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhR8upFuP4BX0AMUr1BOMoKuCUBfirkfXFsHMN8nUBlI6k8x7
Lz/7y727bSQ9ms+nS8/TMKTXeTsdrqk/HvopuPu6NLa5z2b/9buzsTnelufs
HTGMkdfikcvejR6Hp0XlG083ayp6AR7WStwC32hgPyIcj6OoDX0kj6vLqSPi
qzl5F/P/xV2ZU6ufc+WOCHm1PYj0RRbtgrtfnI+AXZsljbGFeYVGLqe37HvW
z4jP0Se9AeL3hkk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 769->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhR8uxK1H8Ap6gOIV6glG0FVBqAtx16Nri2D6JZlqIKUzybz3
8rM739rrStJ98/605XHs+/I8rcfDpXSHfTcGtx+Xhmbuk9l/fe9sbIo3/jx7
Rwxj5LV45LJ3Q8QRaZF/E+lmTa4X4GGtxHX4RgP7keFEHK429JE8oa6gjoyv
5uRdzP8V98+cWv2cK3dEyKvtQaYvs2wXwv3ifATs2ixpjC3MKzVyBb1l3wW8
kC/QJ70A1eyGCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 770->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhYMLcesRvIIeoHiFeoIR7Kog1IW469G1RTD98tLWQEpnknnv
5edwvdfNxsweu8+nLs9z15XXZTscbqU9HdshuP+6WV9NfTT/b787HxvjVTxP
3hHDGXk9Hrn8Xa84lBaLb5Ru1hR6AR7WStyA7zSwHxmO4gi1oY/kkbpEHRnf
nJN3MX8t7p85nG3oc7Jb3CmVv0ZfZtkuyP3ifAzYc7OkMbYwr9TIJXor60AP
Ap/QZ/YG0/uHCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 771->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPoh/e0RvIIeoPQK9QQr6FdBqB/Svx5dW4RmJxPXBlK6m8dM
Jnu8Pvp7BeBZfz59enXjmKbLYTnc0nA+DUuw+Towt7mvZv+x3dnYGm/9Oavj
HsYY1/ZjLHs3KwzFBb5G8eaZnBaEw7NyX9ffcGA9oj4Kw81GOjKm5CXmiPB+
OeMW8//tuzOHd+t0FjtXbyrKL/GLLHoLSseMk63HFg93ycaxwr5CYyyhrZyD
NHB4gh/wBsmGhsk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 772->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUsEJwzAMFH2UfjtCVmgGCFkhmcCB5GUopI+SX0ZPYgqVTyenFdjYknx3
klwNz266iMjrtm9deLfzHJb+elzGEOtHPIL3zxJZm3wl02f5+nQsxRt7z94h
hjLk1XjIpX0r42BaxL5hurEm0wvgwVoR1+ArDdgPD4dxmNqgj8hJdZE6PL7S
Qt7T/F9x/8zB2Zo+k5mzP+Xln+nzzPsLrI+ZJlE+dXZniUZwSvNyDblIb2kd
BQyqPZ03PYaFyQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 773->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHHoQr32CX9AHFL9QXxDBngpCPUhvfXptENzMzhpdSNgkm5nZ
SQ7Xez80AB7719Sn53ma0nzZbYtbGk/HcTts3wNYunLksDk+e/Ysn3d+Xdxj
DBPMa/GYy+4tikNpgb+jdHNPzgvi4V4Z1+EbDexHhKM4XG/kI3NKXaKPiO/b
YN5q/a+4f9bw2zqfxZurPxXV1/RFEf0F5WOhCWbP5OFbcggc5VNNP/8jGAwI
PKdZYEjtOV8BhoaGSQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 774->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
sxkQYshyYHl7TD6KPnQzkAC6vcjmoduFLNaAzQ5sbmHA1IPN3eh+wggLNHvQ
/YpuLob5SG5ADw9c5mCzA8NvaOGIbidWd2HxBy778GF0ewmqJ9ZcEtWgxy1G
OGOJc2xpCpd6Qu7DBXClBWzhiOImbABfXOJQi42P03585iD7gQGTjeEPPGZg
dTuYDQBMM4YK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 775->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
sxkQYshyYHl7TD6KPnQzkMTQ7UU2D90uZLEGbHZgcwseuxjQ3YrFLVj9j8Wv
6OZimI/kBvTwwGUONjsw/IZkBjY7cfoHnzwet6CbQ4oeos0lUQ163GKEM5Y4
x5amcKkn5D5cAFdaIBQfWAGuNIZHLTY+oXSE1Rx71PBEZ6OHNT4zsLodzAYA
MYCFyQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 776->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
sxkQYshyYHl7TD6KPnQzkMTQ7UU2D90uZLEGbHZgcwseuxjQ3YrFLVj9j8Wv
6OZimI/kBvTwwGUONjsw/IZkBjY7cfoHnzwet6CbQ4oeos0lUQ163GKEM5Y4
x5amcKkn5D5cAFdaIBQfWAGuNIZHLTY+TvvxmYPsBwZMNnpY4zMDq9vBbAB6
gIZJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 777->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwjAQHPoh/vYIXkEPUHqFeoII9qsg1A/pX4+uDYLbyezWBhL2lZnZ
ZE+3R9dXAJ7Hz9GlVzuOaboeFueehst5WJL1dwNzs955WRu/mM3lfFP6q3uM
YWLMa/GYy8ZmxaG0BFxgrUKL7F/0yrgFvqcbPo7iKHoD4RKn20+UD7Qwzp47
f+PurOG/tW/K/8ozAqpT9Vv6vOXNwtZ/yOXNWFCrfJc/wrE9oLT5rSMMqT3b
bwWehsk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 778->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
sxkQYshyYHl7TD6KPnQzkMTQ7UU2D90uZLEGbHZgcwseuxjQ3YrFLVj9j8Wv
6OZimI/L3Qy4zcFmB4bfGNDMRbMTp3/wyeNxC7o5pOghx1yiwoQBu3709IOe
ttDTFC71hPyBC+BKC4TiAyvAlcbwqMXGx2k/PnOQ/cCAyUYPa3xmYHU7mA0A
ikSGig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 779->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbn64tgulkkrYu7LJJNjOT
bA7Xe91sADx2n6Muz3PXlddlOxi30p6O7RDcfzfQV9M9LnvHz2djY7zy9iSP
MYyPeS0ec1lfrziUloQLrFVokfWLWhnX4Ue6EeMoDlcbCJc4w3qyeKKFcdbk
/IO7qCfQ+Tw/PFs8U9H7uTqiFc3C3H/IFc1Y8lbZIX+GY2uAv3OvuQfuv4Q+
4A2fRIcK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 780->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
sxkQYshyYHl7TD6KPnQzkAC6vcjmoduFLNaAzQ5sbmHA1IPN3eh+wggLNHvQ
/YpuLob5uNzNgNscbHZg+A0tHNHtxOkffPJ43IJuDil6yDGXqDBhwK4fPf2g
py30NIVNPTH+wAVwpQVC8YEV4EpjeNRi4+O0H585yH5gwGSjhzV6GGDEFxb3
MTAAAFQVh0s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 781->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
sxkQYshyYHl7TD6KPnQzkAC6vcjmoduFLNaAzQ5sbmHA1INuF7p/sYYFmj3o
+rGaic7G5m4G3OZgswPDb2jhiG4nTv/gk8fjFnRzSNFDjrlEhQkDdv3o6Qc9
baGnKWzqifEHLoArLRCKD6wAVxrDoxYbH6f9+MxB9gMDJhs9rNHDACO+sLiP
gQEAGzOHyw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 782->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRgg
sxkQYshyYHl7TD6KPnQzkAC6vcjmoduFLNaAzQ5sbmHA1INuF7p/sYYFmj3o
+rGaic7G5m4G3OZgswPDb2jhiGwPXv/gk8fjFnRzSNFDjrlEhQkDdv3o6Qc9
baGnKWzqifEHLoArLRCKD6wAVxrDoxYbH6f9+MzBkbaQzcMIQwZMeZxuB7MB
cJmHjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 783->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRTYP3S5kMXR3MqDpQ5FH04NuVwOaPbjCAtke
dP1YzURnY3M3A25zsNmB4Te0cES2B69/8MnjcQu6OaToIcdcosKEAbt+9PSD
nrbQ0xQ29cT4AxfAlRYIxQdWgCuN4VGLjY/Tfnzm4EhbyOZhhCEDpjxOt4PZ
AFm3h00=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 784->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRTYP3S5kMXR3MqDpQ5FH04NuVwOaPbjCAtke
dP1YzURnY3M3A25zsNmB4Te0cES2B69/8MnjcQu6OaToIdpcEtWgxy2y/9Hj
FT2NMKCpIxQ22NyHC+BKC4TiAyvAlcbQ1CCrRdeLHk6E3M+AbheesMUIQ6Qw
wIgvrHoAKLiHCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 785->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRTYP3S5kMXR3MqDpQ5FH04NuVwOaPbjCAtke
dP1YzURnY3M3A25zsNmB4Te0cES2B69/8MnjcQu6OaToIcdcosKEAbt+9PSD
nrbQ0xQKTYI/cAFcaYFQfGAFuNIYmhpkteh6cYUrToBuF56wxQhDpDDAiC+s
egCtXobL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 786->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRTYP3S5kMXR3MqDpQ5FH04NuVwOaPbjCAtke
dP1YzURnY3M3A25zsNmB4Te0cES2B69/8MnjcQu6OaToIcdcosKEAbt+9PSD
nrbQ0xQ29cT4AxfAlRYIxQdWgCuNoalBVouuF1e44gToduEJW4wwRAoDjPjC
qgcAZm2HSw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 787->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRTYP3S5kMXR3MqDpQ5FH04NuVwOaPbjCAtke
dP1YzURnY3M3A25zsNmB4Te0cES2B69/CNhJDEa3l6B6MswlKkwYsOtHTz/o
aQs9TWFTT4w/cAFcaYFQfGAFuNIYmhpkteh6cYUrToBuF56wxQhDpDDAiC+s
egChfIfL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 788->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRTYP3S5kMXR3MqDpQ5FH04NuVwOaPbjCAtke
dP1YzURnY3M3A25zsNmB4Te0cES3E6d/CNhJDEa3l6B6MswlKkwYsOtHTz/o
aQs9TeFST8gfuACutEAoPrACXGkMTQ2yWnS9uMIVJ0C3C0/YYoQhUhhgxBdW
PQCXB4eK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 789->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRdGPZhcDkhi6OxnsUTGKPJoerHah+QlbWCDb
g64fp/vR/ILNTFzmYLMDw29o4YhuJ07/ELCTGIxuL0H1ZJhLVJgwYNePnn5Q
0hCWNIVLPSF/4AK40gKh+MAKcKUxNDXIatH14gpXnADdLjxhixGGSGGAEV9Y
3MfAAACM8ofL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 790->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwlAMHLoQtz2CV9ADPHqFeoIn6Kog1IV016NrxU8ySUgNpH3tm8zk
tztd+0sD4LZ9Pvp678axTsfN8nGuw2E/LJft24G5aP+YPL+s/N5fbLHfKo45
hLGuiictiH+cJ4p2dU8xrhbV5PVC6kS1m/ypFo9zdjg8PnN2+siaYT2J5hpn
3RS/lvdPDM9W9pTnyjsCwnn4LL/Iol3I5uFatGOEkViO5T5l+fMeQXAYLe6h
6IGZl5Mf8ABlLoeK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 791->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbiQbj2CV9ADDF6hnmAEuyoI7ULc9eja4id5SUgNpDPTeXkv
yWR/ubXdBsDYvD5tvZ+GoT7O2/lwrf3x0M+Xu7cDU9H+MblfrPzWL7bYs4pj
DmGsq+JJC+If54miXd1TjKtFNXm9kDpR7SZ/qsXjnBwOj8/snT6yZlhPornG
WTfFr+X9E8NvK3vK78ozAsJ5+Cy/yKJZyN7DtWjGCCOxHMt9yvLnOYLgAPGZ
HsLeh7kv+yeKLogK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 792->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMHHFAXHkCX4AHRHyhvCBIcKqE1B4qbn06FLHYk3FTLLlxmrHH
2+58a64rAP3m+WnycOy6fD+tp8slt4d9Oz1u3wqMyetHrP2S9Du/2FTenR/H
MMK8zp+4YP5xnkhe3Tv5SC6qSfXC8kS1F/lTLSrmKGKoeIUt+sicYT0VziXK
vFX80rh/Yni2tqc8V94REE7ha/lFEu1CbR5Soh2bwap7yD8Xx9aA0uZecw+K
eYn8gAdbq4fL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 793->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRdGPZhcDkhi6OxnsUTGKPJoerHah+QlbWCDb
g8vvGO5H8ws2MxuwmIHNPAw2lnBEtgeffwjZSQxGt5egemLNJVENetwi+w89
XtHTCAOaOmzqCbkPF8CVFrCmL2S12ACuNIZHLTY+TvvxmYMjbSGbhxGGDJjy
ON0OZgMA+iCIDA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 794->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkkOwjAMtDggrjyBL8ADIr5QXhAkOFVCag8Vtz4diljG40lTLLlJmrHH
nnh3vjXXlZn1m+enycOx6/L9tJ4Ol9we9u10uX272Zi8fwz3L0u/9YtN8ezi
OAcY87p44jL4x3Va8u7uKUZyUU9KC+Qp9R7qp15UzlHkUPnCXuiIPHP91DiX
OPNW8Uvz/onht8X++F15RoxwCl+rr2SlWZDzhVhlpRkjDGI5lnWq1W/MNaNt
0BA0CO8lYx4G5YgK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 795->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRdGPZhcDkhi6OxnsUTGKPJoerHah+QlbWCDb
g8vvGO5H8ws2MxuwmIHNPAw2lnBEtgeffwjZSQxGt5egemLNJVENetwi+w89
XtHTCAOaOnzpAJf7cAFcaQFr+kJWiw3gSmNoapDVoutFDydC7mdAtwtP2GKE
IVIYYMQXVj0Au+WIig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 796->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRdGPZhcDkhi6OxnsUTGKPJoerHah+QlbWCDb
g8vvGO5H8ws2MxuwmIHNPAw2lnBEtgeffwjZSQxGt5egemLNJVENetwi+w89
XtHTCAOaOnzpAJf7cAFcaQFr+kJWiw3gSmN41GLj47Qfnzk40ha6Grg/0MIA
I76w6gEAjWKISw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 797->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRdGPZhcDkhi6OxnsUTGKPJoerHah+QlbWCDb
g64fp/vR/ILNTFzmYLMDw29o4YhsDz7/ELKTGIxuL0H1xJpLohr0uEX2H3q8
oqcRBjR1+NIBLvfhArjSAtb0hawWG8CVxvCoxcbHaT8+c3CkLXQ1cH+ghQFG
fGHVAwAwgIjL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 798->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRdGPZhcDkhi6OxnsUTGKPJoerHah+QlbWCDb
g64fp/vR/ILNTFzmYLMDw29o4YhuJy7/ELKTGIxuL0H1xJpLohr0uEX2H3q8
oqcRBjR1+NIBLvdhpA8s8YqebjD0I6vFBnClMTxqsfFx2o/PHGQ/MGCy0cMa
GWCNL6x6AE0hick=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 799->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMQwg
s8HAHkHD1dpj8lH0oZuBBNDtRdGPZhcDkhi6OxnsUTGKPJoerHah+QlbWCDb
g64fp/vR/ILNTFzmYLMDw29o4YhuJy7/ELKTGIxuL0H1ZJhLVJgwYNePnn5Q
0hCWNIVNPTH+wEgfWOIVPd1g6EdWiw3gSmN41GLj47QfnznIfmDAZKOHNTLA
Gl9Y9QAA0ceJig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 800->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7sbmFAVMPVrvQ/IQ1LBiwmE/I/Wh+
wWYmLnOw2YHhN7RwRLcTp38I2EkMRreXoHoyzCUqTBiw60dPPyhpCEuawqae
GH9gpA8s8YovvNHjAyvAlcbwqMXGx2k/PnOQ/cCAyUYPa2SANb6w6gEAU5qI
ig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 801->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7sbmFAVMPVrvQ/IQ1LLCYhU0PunuR
/YLNTFzmYLMDw29o4YhuJ07/ELCTGEwoHPD5g1hziQoTBuz60dMPShrCkqaw
qSfGH9jSB3q84gtv9PjACnClMTxqsfFx2o/PHGQ/MGCy0cMaGWCNL6x6AIGg
iEs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 802->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7sbmFAVMPVrvQ/IQ1LLCYhU0PunuR
/YLNTFzmYLMDw28MWMzF4zaUMMFjJzGYUDjg8wex5hIVJgzY9aOnH5Q0hCVN
YVNPjD+wpQ/0eMUX3ujxgRXgSmN41GLj47QfnznIfmDAZKOHNTLAGl9Y9QAA
1gqIDA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 803->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7ccmjiWG1C81PWMMCi1nY9KC7H52N
biYuc7DZwYDDXej+xWcmcnjhspMYTCgc8PmDWHOJChMG7PrR0w9KGsKSprCp
J8Yf2NIHerziC2/0+MAKcKUxPGqx8XHaj88cZD8wYLLRwxoZYI0vrHoAJVmH
jg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 804->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7ccmjiWG1C81PWMMCi1nY9KC7H52N
biYuc7DZwYDDXej+xWcmcnjhspMYTCgc8PmDWHOJChMG7PrR0w9KGsKSprCp
J8Yf2NIHerziC28MN2IDuNIYHrXY+Djtx2cOsh8YMNnoYY0MsMYXVj0ApFmI
Dg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 805->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7ccmjiaH7swHNHpxhgcUsbHrQ3Y/O
RjcTlznY7GDA4S50/+IzEzm8cNlJDCYUDvj8Qay5RIUJA3b96OkHJQ1hSVPY
1BPjD2zpAz1e8YU3hhuxAVxpDI9abHyc9uMzB9kPDJhs9LBGBljjC6seAMWT
h88=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 806->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7ccmjiaH7swHNHpxhgcUsbHrQ3Y/O
RjcTlznY7GDA4S50/+IzEzm8cNlJDCYUDvj8Qak69HDAGqdY4hU5naCnKWzq
iXEftvSBHq/4whvDjdgArjSGRy02Pk778ZmD7AeYH7HEP7r/0eUx3I6iBwAV
7YeO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 807->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7ccmjiaH7swHNHpxhgWQPulvxuR+d
jW4mLnOw2cGAw13o/sVnJjZ/kINR7CVGPbHmEqkGOZ1hjVMs8cqArhdNHb50
gMt9GOkDS7ziMxfDjdgArjSGRy02Pk778ZmDHFYwP2KJf3T/o8tjuB1FDwC5
qocO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 808->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7ccmjiaH7swHNHpxhgWQPultxuh/N
Lw1ofLj9OOxGl2PA4S50/+IzE5s/yMHo/iGonlhziVSDnM6wximWeGVA14um
Dl86wOU+jPSBJV4Jpi9c5jFg18tAhFpsfJz24zMHOaxgfsQS/+j+R5fHcDuK
HgBCDoeM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 809->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7ccmjiWG1C81PWMMCyR50/Tjdj+aX
BjQ+TAyX3ehyDDjche5ffGZi8wc5GN0/BNUTay6RapDjDpu70NMPShrCkqbQ
5Yh1H0b6wBKvBNMXLvMYsMijm4tDLTY+TvvxmYNsL3I4MaC5Cc3/6PLobFQ9
ABKbh4o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 810->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwjAQHVxItx7BK+gBileoJ4hgVwWhLsRdjq4FlZc3b2JoYEonM3mf
ZPaX2zBuzOzevT9DepzmOT3P2yW5pul4mJbi7hNmuS/jt/Afc+ztfZ6hz2HA
Yt7iPHEhltQZ1WlPcpEneRfAw+dD/eQlU/7di7i5ZoEu9lvDVD7WBPv529+K
29iDb6d08fwUMyRmimut+tx8iHet4TqNAkt5cNzUq/KQv4aDvHhPRppYs+k7
k3j2ApoziEc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 811->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKgzAQfXRR3HqEXqEeQHoFe4IU6koQdFHc5eit0JbJmxeTwEjGTN5n
MpfHPIwnAGvz+QzhdVuWsN3Pe/IMU3ed9sP2G0Ds0/gvu7e5re19Hk2dwzCL
eZP7xGWxpE6lBf6O5CJPshcQ+CX95CVS/vuX4+Yz5436yP3K+ilw1gT7KdbX
4lbW2LdTunh+khkSM6Xmp0afmw/xrkfYTqPAUh4cN9WqPDsPRziW1/YJpIk1
Q/dM4uEN9r6IBg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 812->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfkNSOowzEAC6Pai6EezC9ksrO7E5hYGTD1Y7ULzE9awYMBiPiH3
o/mlAY0PE8NlN7ocht/QwhE9vHD6h4CdxGB0/xBUT6y5JKpBj1vkMEWPV/Q0
woCmjphwQZfHSB9Y4hWf2RhuxAaw+IGQWmx8nOkBnznI9iKHEwOam9D8jy6P
zkbVAwCjeohH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 813->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAMHPoh/noEr6AHKF6hnmAF/SoU6of4t0evBZXZSfbRQMqmmWSS
2T3epuHRAXjuP58hvC7zHN7X3Rrcw3g+jWvy8HUg9qn/jc8cM7a3cSSc6UGm
vEm9cHEvd05vFtgal0t2crWA0782v+wSJf79y3FrzuwmOqpe2X0qnC2u+1Tx
rX03YvRuWVO9V30jEFyLLpo378O511JvM6Njyo8C1uQyOpX4kjrmZZ0gM8n+
mtdzWrMAFImIxw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 814->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhYMLcesRvIIeoHiFeoIKdlUQ6kLczdG1YCXz5U2nBlImzc/L
S3K43tt+Y2aP3efTds/zOHavy3Yybt1wOg6Tc/9Vs9Tk+hP/9raPbaKdXFyo
4YS4WT6wfC3Zp+rFYo7EAic5CxP1a/2DS4I9/yth0xe4YY6cV5FPBXONkk81
fm3dP2O4Wz9T7pU3YohbuoNSf+E+xF6Jq/Yh62G/4a6U0FeY0xJeludxZ45i
/+RPP995zhu3s4iI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 815->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk0KwkAMhYMLcesRvIIeoHiFeoIRdFUQ6kLczdG1oJL58qZTAymT5ucl
L9mdb/11ZWb3zfvTp8dxHNPztJ6MSxoO+2Fybj9qlrtSf+Lf3vaxXbSziws1
nBC3yAeWryX7VL1YzJFYmElyYaJ+q3/MkmF//9Ww6QuzgUfyVZ2ngblEOU8z
fmndP2O4W88p98obMcTN3UGtv3AfYq/EVfuQ9bDfcFdK6KvwNIdX5Hlci29y
rfrmDmLOC+KziQg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 816->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwkAMfbiQbj2CV9ADFK9QTzCCrgpCuxB3c3QtqGReXmZqIGXS/F5e
sr/ch9sGwNy9P0N6nKYpPc/bxbim8XgYF+fuo0DuS/2JfVvbxvbezibO1TDC
fYt86mVrSZwKC3yO7EUzSS4g6rfw0yyZ7O+/qDf73GzEI/MVztPouUZ5nmb8
2rp/xvBuLae8V74RUFztDiJ87j7EXmt8O4xCwhtTwr6Ap1q/Is/OAP9mrhVu
3oHPeQHawooI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 817->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfkNSOowzEAC6Pai6EezC9ksrO7E5hYGTD1Y7ULzE9awYMBiPiH3
o/mlAY0PE8NlN7ocht/QwhE9vHD6h4CdxGB0/xBUT6y5JKpBj1vkMEWPV/Q0
woCmDl86wOU+jPSBJV7xhTd6fGADeNMYOkA3B0c4YXU/NnPQ7EJno4c1Nnej
xwGmHgCNOYnH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 818->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfkNSOowzEAC6Pai6EezC9ksrO7E5hYGTD1Y7ULzE9awYMBiPiH3
o/mlAY0PE8NlN7ocRtighSN6eOH0DwE7icHo/iGonlhzSVSDHrfIYYoer+hp
hAFNHb50gMt9GOkDS7ziC2/0+MAG8KYxNHsxzCEmPWADOOxCZ+N0BwP2MMPu
dgB6TInF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 819->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMRwg
s5H5yGrtMfl4zUAC6Pai6EeziwFJDKs7sbmFAVMPVrvQ/IQ1LBiwmE/I/Wh+
aUDjw8Rw2Y0uhxE2aOGIHl44/UPATmIwun8IqifWXBLVoMctcpiixyt6GmFA
U4cvHeByH0b6wBKv+MIbPT6wAbxpDM1eDHOISQ/YAA670Nk43cGAPcywux0A
dCaJhg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 820->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/Wh2MSCJYbjTHhWjyKPpwWoXmp9whgUOv+J0P5pf
GtD4MDFcdqPLYYQNWjiihxdO/xCwkxiM7h+C6ok1l0Q16HGLHKbo8YqeRhjQ
1OFLB7jch5E+sMQrvvBGjw9sAG8aQ7MXwxxi0gM2gMMudDZOdzBgDzPsbgcA
XkCJRw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 821->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/Wh2MSCJYbjTHhWjyKPpwWoXmp9whgUOv+J0P5pf
sJmJyxxsdmD4jQGLuXjchhImeOwkBqPYS4x6Ys0lUQ163CKHKXq8oqcRBjR1
+NIBLvdhpA8s8YovvNHjAxvAm8bQ7MUwh5j0gA3gsAudjdMdDNjDDLvbAQYg
iYg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 822->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1C81POMMCh19xuh/N
L9jMxGUONjsw/MaAxVw8bkMJEzx2EoNR7CVGPbHmkqgGPW5R0gtavKKnEQY0
dfjSAS73YaQPLPGKL7zR4wMbwJvG0OzFMIeY9IAN4LALnY3THQzYwwy72wEQ
tolJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 823->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1C81POMMCh19xuh/N
L9jMxGUONjsw/MaAxVw8bkMJEzx2EoNR7CVGPbHmkqgGPW5R0gtavKKnEQY0
dfjSAS73YaQPLPGKL7zR4wMbwJvG0OzFMIeY9IAN4LALnY3hDyzuRo8DTLcD
ADG2ick=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 824->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKwkAQC36Ivx7BK+gBBq9QT7CCfhWE+iH+eXQtiJrMg3Vg2m53NpnZ
ZHO8DOcFgOvq9RjabT9N7X5YzotTG3fbcd5cvxN4GGca9n1/as2vCaPAU146
b1yHn3+uT+OkfTkTcslM6V0ks6b9yywRZoYTcbjZEOAWvdGdFJw9Sbw99b24
f9aotuQX0VU9AqmrfJD15/wR6Frdt+oRRekxDcXp8UMUCZd+uzmCvlUD1Qd4
AgI3iYo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 825->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHHqQXvsEv6APCH6hvmAFPRWE9iC99em1INpMkiUG0u12Z2eS
Zo63Z/9oAEzt+9GX12Ucy3w9bJt7Gc6nYTvsPgksojMM+a1frNi94qjwsa66
LxqH3TdTp+hU53TH1aKewn8R9BrWT714nBGPp2F6g8NbqW2RnGYmlW4Gn+X9
E8OzVX6hubJHQLiaD6L6jD+cubJvzP091omqxziYJ+EHNwItfjd9OHXzDHg+
wApLRooK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 826->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQzEPm1uItQvNTzjDAodfcbofzS/Y
zMRlDjY7MPzGgMVcPG5rsCfOTmIwir3EqCfWXBLVoMctSnpBi1f0NMKApg5f
OsDlPoz0gSVe0dMNhn5ktVgA3jSGDtDNISI9YAU47EJno4c1NnejxwGmHgAq
hInJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 827->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQzEPm1sI2IWuDqccmj3obsXpfjS/
YDMTlznY7MDwGwMWc/G4rcGeODuJwSj2EqOeWHNJVIMetyjpBS1e0dMIA5o6
fOkAl/sw0geWeEVPNxj6kdViAXjTGDpAN4eI9IAV4LALnY0e1tjcjR4HmHoA
75OKSQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 828->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDD1Ir32CX9AHLH6hvmAFPRWE9iC99em1UHQzmawxkLbbncwk
ZI63Z/9oRGRq348+vy7jmOfrYTvc83A+Ddtlt6fIknS6kb7vDzbZs+JgfPs/
1FX1RV2pU9YpPtbLDy3EuXegg726/cMsjNPjYRpmNiG8ld6WFNOMpNKN4KO8
f2Jwt8ovsFf0iACu5gOvP+MPslf0jakvsSSqHsNAnoAfaDha+G3mIH3jDnA/
IisQoorJ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 829->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHHoQrz7BL+gDFr9QX7CCngqFehBvfXotFN3MZmoaSNvtTmYS
Msdb3z4aAM/959Hm12UY8vu6mw/33J1P3Xx5WBIYk00Z6ff+YlN9Nhwe3/KP
dU19UVfqlHWGz+vljxbj5B3pcK+yf5rF41Q8nkY1Gxzeld7GFNOMpNGN4KO8
GzG8W+MX2it7BIRb84HqT4XyguuvEiu4pMc4mCfgBzeEFn9Xczh98w54P8AE
w4yKig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 830->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHHoQrz7BL+gDgl+oL1hBT4VCPYi3Pr0WRDeTZEkX0u02s5NM
M8fb2D86AM/959GX12Wayvu6Ww/3MpxPw5o8fAOYRUe45L//sGLPiqPBx3XV
fdE4VN9Mn6JD5emOW5M0hf8i0Br2T1o8zojHq2G0weFt9DZLrmYmVN0MPsu7
EcOzVX6hubJHQLiWD6L+ohV5wfVXjQ24XI95i3MJPzR5ag2w70aH0zfPgOcD
LJHXigw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 831->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHHoQrz7BL+gDgl+oL1hBT4VCPYi3Pr0WRDeTZEkX0u02s5NJ
M8fb2D86AM/959GX12Wayvu6Ww/3MpxPw5o8fAOYRUe45L//sGLPiqPBx3XV
fdE4VN+MTtGh8nTHrUk9hf8i0Brqp148zojHq2F6g8Pb0DZLrmYmVN0MPsu7
EcOzVX6hmbFHQLiWDyJ90Yq84PqrxgZcrse8xbmEH5o8dQ+w76YPRzfPgOcD
LDz1iow=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 832->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1E81POMMCh1txuh/N
L9jMxGUONjsw/MaAxVw8bmuwJ85OYjCKvcSoJ9ZcEtWgxy2u8EBJQ+h8BlSa
FPfhArjSAtb0hawWh1lY0xg2gC5HRHrAaw6yHxgw2Rj+wOJu9DhANgNCAwAU
BIsM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 833->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1E81POMMCh1txuh/N
L9jMxGUONjsw/MaAxVw8bmuwJ85OYjCKvcSoJ9ZcEtWguwNXeKCkIXQ+AypN
ivtwAVxpAWv6QlaLwyysaQwbQJcjIj3gNQdL2GKEM5o/0N2NHgcYehgAIwCK
Sw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 834->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1E81POMMCh19xuh/N
L9jMxGUONjsw/MaAxVw8bmuwJ85OYjCKvcSoJ9ZcEtWguwODb4/JR48j5HRC
yH50eVwAV1rAFo4obsJhFtY0hg2gyxGRHvCagyVssYYzkj/Q3Y0tHFDDHQDT
eYmK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 835->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1E81POMMCh19xuh/N
L9jMxGUONjsw/MaAxVw8bmuwJ85OYjCKvcSoJ9ZcEtWgxy26u9DDDyNe0NIJ
IfvR5XEBXGkBWziiuAmHWVjTGDaALkdEesBrDrIfGDDZ2PyB7m5s4YAa7gDR
iIqK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 836->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1E81POMMCh1txuh/N
L9jMxGUONjsw/MaAxVw8bmuwJ85OYjCKvcSoJ9ZcEtWgxy26u9DDDyNe0NIJ
Ifsx0gAOgCstYAtHFDfhMAtrGsMG0OWISA94zUH2AwMmG5s/0N2NLRxQwx0A
fKaLCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 837->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQzEPm1sI2IWuDqccA3Y12PSguB/N
L9jMxGUONjsw/MaAxVw8bmuwJ85OYjCKvcSoJ9ZcEtWgxy26u9DDDyNe0NIJ
Ifsx0gAOgCstYAtHFDfhMAtrGmNA0o/ERpcjlB6wAnS70NIOsrsY0PyB7m5s
4YAa7gCLY4sI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 838->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDxIrz7BL+gDFr9QX7CCngpCexBvfboWiiazE3cNpO02ycxk
k/3l3t82AKbu/ejz4zSO+XneLodrHo6HYQnuVgfm5D209H1/clN5dhgKb/3H
vK7e1FkeW+fwlJYKF+eFMegcVeP0Uy8KM8JRHEVvELg/tM2pjbPFHW9Lfivu
nzk8W9bF91fMhfakxl/sQGDRLqh7dJoCLLljMPXmm2O1fZDGXLQ7VheoD9bN
Myhq8AKYY4uI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 839->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQzEPm1sI2IWuDqccA3Y12PSguB/N
L9jMxGUONjsw/MaA3Vx8ZhJjJzEYxV5i1BNrLolq0OMW3V3o4YcRL2jphGBa
wZc+cMQrujsw9COrxWEW1jTGgKQfiY0uRyg9YAXodqGlHWR3MaD5A93d6HGA
oYcBAJH+iwo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 840->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQzEPm1sI2IWuDqccA3Y12PSguB/N
L9jMxGUONjsw/MaA3Vx8ZhJjJzEYxV5i1BNrLolq0OMW3V3o4YcRL2jphGBa
wZc+cMQrujsw9COrxWEW1jTGgKQfiY0uRyg9YAXodqGlHWR3YQtDdHkMt6Po
AQCE84rL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 841->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1E81POMMCh1txuh/N
L9jMxGUONjsw/MaA3Vx8ZhJjJzEYxV5i1BNrLolq0OMW3V3o4YcRL2jphGBa
wZc+cMQrujsw9COrxWEW1jTGgKQfiY0uRyg9YAXodqGlHWR3YQtDdHkMt6Po
AQCEtYqM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 842->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1E81POMMCh1txuh/N
L9jMxGUONjsw/MaA3Vx8ZhJjJzEYxV5i1BNrLolq0OMW3V3o4YcRL2jphGBa
wZc+cMQrujsw9COrxWEW1jTGgKQfiY0uRyg9YAXodqGlHXR3YbiDAXuYoZsH
oQGltYsM
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 843->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWa4/JRzGDgHkYdiObi2wvkhiGO+1RMYo8mh6sdqL5CWdY4HArTvej+QWb
mbjMwWYHht8YsJuLz0xi7CQGo9hLjHpizSVRDXrcorsLPfww4gUtnRBMK/jS
B454RXcHhn5ktTjMwprGGJD0I7HR5QilB6wA3S60tIPuLgx3MGAPM3TzIDQA
0tOLjA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 844->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWa4/JRzGDgHkYdiObi2wvkhiGO+1RMYo8Fjdj9S8+OQbsarDpQXE/ml+w
mYnLHGx2YPiNAbu5+MzEJo/PfnxhRpJ6KqpDDwdc7sJID9jihYR0gs19uACu
tIA1fSGrxWEW1jTGgKQfiY0uRyg9YAXodqGlHXR3YbiDAXuYoZsHoQE/j4tL

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 845->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWa4/JRzGDgHkYdiObi2wvkhiGO+1RMYo8Fjdj9S8+OQbsarDpQXE/ml+w
mYnLHGx2YPiNAbu5+Mwkxk5iMK74I8YflKpDDwdc7sJID9jihYR0gs19uACu
tIA1fSGrxWEW1jTGgKQfiY0uRyg9YAXodqGlHXR3YbiDAXuYoZsHoQGAnovL

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 846->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWa4/JRzEDm3n2CPMw7EY2F9lee0x9KOZhcwuy/VjsQleHU44BuxpselDc
j+YXbGbiMgebHRh+Y8BuLj4zibGTGIwr/ojxB6Xq0MMBl7sw0gO2eCEhnWBz
Hy6AKy1gTV/IanGYhTWNMSDpR2KjyxGbjlAAul1oaQfZXRhhyIApj+F2FD0A
FtyLCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 847->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWa4/JRzEDm3n2CPMw7EY2F9lee0x9KOZhcwuy/VjsQleHU44BuxpselDc
j+YXbGbiMgebHRh+Y8BuLj4zibGTGIwr/ojxB6Xq0MMBl7sw0gO2eCEhnWBz
Hy6AKy1gTV8EzMOZxhgQ+pHZ6HLEpiMUgG4XWtpBdhdGGDJgymO4HUUPAJXc
i4o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 848->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQzEPm1twuBmrf/HJMWBXg00PivvR
/ILNTFzmYLMDW9hgMxefmcTYSQzGFX/E+INSdehxjMtdGOkBW7yQkE6wuQ8X
wJUWsKYvAubhTGMMCP3IbHQ5XOkIn/vR9cHsQGejpEdc6RKb21H0AAD/oIqK

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 849->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+KUeTR9GC1E81POMMCh1txuh/N
L9jMxGUONjuwhQ02c/GZSYydxGBCYYrPH5SqQ49jXO7CSA/Y4gUtnRCyHyMN
4AC40gLW9EXAPJxpjAGhH5mNLocrHeFzP7o+mB3obJT0iCtdYnM7ih4AzoCK
yw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 850->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+K0d2Gyy4Uc/DJMWBXg00PA5rd
DVjcgB4GuOxGl8MWNtjMxWcmMXYSgwmFKTH+IKSOKLMYcLsLZ3rAkj6QaWLt
xkgfOOIV3R0Y+pHV4jALaxpjQNKPxEaXwxf+OAGONIfORkmPuNIlNrej6AEA
LReKCg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 851->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxDDcaY+K0d2Gyy4Uc/DJMWBXg00PA5rd
DVjcgB4GuOxGl8MWNtjMxWcmMXYSgwmFKTH+IKSOKLMYcLsLZ3rAkj6QaWLt
xkgfOOIV3R0Y+pHV4jALaxpjQNKPxEaXwxf+OAGONIfORkmPONIlVrej6AEA
PheKig==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 852->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdiSKPxW247EIxB58cA3Y12PQwoNnd
gMUN6GGAy250OWxhgy88cPmHkJ3EYEJhSow/CKkjyiwG3O7CmR6wpA9kmli7
MdIHjnhFdweGfmS1OMzCmsYYkPQjsdHl8IU/ToAjzaGzUdIjjnSJ1e0oegAf
NYsK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 853->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdiSKPxW247EIxB58cA3Y12PQwoNnd
gMUN6GGAy250OQYc7sIVHrj8Q8hOYjChMMXnD0rVoYcDLnfhTA9Y0gcyTYr7
cAFcaQFr+kJWi8MsrGmMAUk/Ehtdjth0hALQ7UJLO8juwghDHO7GZh6EBgCR
U4wK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 854->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdiSKP7g80PVjtRPMTzrDA4Vac7kfz
CzYzcZmDzQ4MvzFgNxefmcTYSQwmFKb4/EGpOvRwwOUujPSALV7Q0gkh+zHS
AA6AKy1gTV/IanGYhTWNMSDpR2KjyxGbjlAAul1oaQfZXRhhiMPd2MyD0ACq
rYvL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 855->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdiSKP7g80PVjtRPMTzrDA4Vac7kfz
CzYzcZmDzQ4MvzFgNxefmcTYSQwmFKb4/EGpOvRwwOUujPSALV7Q0gkh+zHS
AA6AKy1gTV/IanGYhTWNMSDpR2KjyxFKD1gBul1oaQfZXRhhiMPd2MyD0ADz
rYxL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 856->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdiSKP7g80PVjtRPMTzrDA4Vac7kfz
CzYzcZmDzQ4MvzFgNxefmcTYSQwmFKb4/EGpOvRwwOUujPSALV7Q0gkh+zHS
AA6AKy1gTV/IanGYhTWNYQPocgTCFSdAtwst7SC7CyMMcbgbm3kQGgDELowM

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 857->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdiSKP7g80PVjtRPMTzrDA4VZc7kcJ
IyzuRnY7TrfhYmMJR2LMJMZOYjChMMXnD0rVoYcDLndhpAc0MeQ0hUyT4j5c
AD0t4E1fyGpxmIU1jWED6HIEwhUnQLcLLe0guwsjDHG4G5t5EBoAWUyMjA==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 858->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdia4PRR5ND1Y70fyEMyxwuBWX+1HC
CIu70d2OLzyw+o0Bi7l43NZgT5ydxGBCYYrPH5SqQw8HXO5iQFeLJoacppBp
UtyHnj6wxSu6OzD0I6vFAnCmMWwAXY6I9IDXHGQ/MGCykfkMaObhCz9UPQAu
C42K
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 859->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdia4PRR5ND1Y70fyEMyxwuBWX+1HC
CIu70d2OLzyw+o0Bi7l43NZgT5ydxGBCYYrPH5SqQw8HXO5iQFeLJoacppBp
UtyHC6CnBXzxgeImHGZhTWPYALocEekBrznIfmDAZCPzGdDMwxd+qHoA4PWN
Sw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 860->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDdia4PRR5ND1Y70fyEMyxwuBWX+1HC
CIu70d2OLzyw+o0Bi7l43NZgT5ydxGBCYYrPH5SqQw8HXO5iQFeLJoacppBp
UtyHC6CnBXzxgeImHGZhTWPYALocEekBrznIfmDAZCPzGdDMI5T+EHoA28qN
DA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 861->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh8jLHC4FZf7
UcIIi7vxuR2bHQw43IXNH/j8Q8hOYjChMMXnD0rVoYcDLncxoKtFE0NOU8g0
Ke7DBdDTAr74QHETDrOwpjFsAF2OiPSA1xxkPzBgspH5DGjmEUp/CD0AtuiN
jA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 862->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh8jLHC4FZf7
UcIIi7vxuR2bHQw43EVseDTYE2cnMZhQmOLzB6Xq0MMBl7sY0NWiiSGnKWSa
FPfhAuhpAW/6Qo4XHGZhTWPYALocgXDFCdDtQks7yO7CCEMc7kZPfwg9AM4L
jQ4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 863->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3EWMmcTYSQwmFKbEhBW56tDDAZe7GNDVookhpylkmhT3
4QLoaQFv+kKOFxxmYU1j2AC6HIFwxQnQ7UJLO8juwghDHO5GT38IPQB7KY2O

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 864->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3EWMmcTYSQwmFKbEhBXZduNxB0p4YIsHtDiCxQ0yTYo/
cAH0tIA3fSHHCw6zsKYxbABdjkD44wTodqGlHWR3YYQhDnejpz+EHgB2OI4O

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 865->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3EWMmcTYSQwmFKbEhBXZduNxB0p4YIsHtDiCxQ0yTYo/
cAH0tIA3fSHHCw6zsKYxbABdjkD44wTodqGlHXR3IfsDl7vR0x9CDwCXOI6O

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 866->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3EWMmcTYSQwmFKbEhBXZduNxB0p4YIsHtDiCxQ0yTYo/
cAH0tIA3fSHHCw6zsKYxbABdjkD44wMYfmDAZGPzBy53o6c/hB4AfGWOTw==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 867->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3EWMmcTYSQwmFKbEhBXZduNxB0p4YIsHtDiCxQ0yTYo/
cAH0tIA3fSHHCw6zsKYxbABdjkD44wTodqGlHXR3IfsDl7vR0x9CDwCXOI6O

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 868->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3EWMmcTYSQwmFKbEhBXZduNxB0p44Ag/BjR55HRCyJ3o
8rgANntwpi/keMFhFtY0hg2gyxEIf5wAW1gxYLKx+QOXu9HTH0IPAGJHjw4=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 869->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3EWMmcTYSQwmFKbEhBXZduNxB0p44Ag/BjR55HRCyJ3o
8rgANnuISV+4zMKaxrABdDkC4Y8TYAsrBkw2ijk40iWu9IfQAwAjCI7P
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 870->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3EWMmcTYSQwmFKbEhBXZduNxB0p44Ag/BjR55HRCMK3g
SR+44hXdHfjSFy6zsKYxbABdjkD44wTYwooBk41iDo50iSv9IfQAAMcujpA=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 871->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IUvXJHVELKTGEzIHmLCimy78bgDJTxwhB8DmjxyOiEY
fnjSB654RXcHvvSFyyysaQwbQJcjEP44AbawYsBko5iDI13iSn8IPQAeTI8Q

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 872->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQ5fH6g88dqGrwynHgN0MrHZikcPl
bnxux2YHAwF34XInun8I2UkMJmQPMWFFtt143IESHjjCjwFNHjmdEHInujwu
gM0eYtIXCsARzgzoetHY6HL4wh8nwBZWDJhsZD4DFv/gS38IPQDCK4+M
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 873->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQ5fH6g88dqGrwynHgN0MrHZikcPl
bnxux2YHAwF34XInun8I2UkMJmQPMWFFtt143IESHjjCjwFNHjmdEHInujwu
gM0eYtIXLrOwpjEYQGOjy+ELf5wAW1gxYLKR+QxY/IMv/SH0AACI1I9N
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 874->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+ShmYDMPKoZuL4p+JH3I9iDrQ5fH6g88dqGrwynHgN0MrHZikcPl
bnxux2YHAwF34XInun8I2UkMJmQPMWFFtt143IESHjjCjwFNHjmdEHInujwu
gM0eYtIXLrOwpjEYQGOjy+ELf5wAW1gxYLJRzMGRLnGlP4QeAKnUj80=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 875->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IUvXJHVELKTGEzIHmLCimy78bgDJTxwhB8DmjxyOiHk
TnR5XACbPcSkL1xmYU1jMIDGRpfDF/44AbawYsBko5iDI13iSn8IPQCplo+O

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 876->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IXPH8hqCNlJDCYUpsSEFdl243EHSnjgCD8GNHnkdEIw
/PCkDwYkPjZ7cIUjih4sAF8aQ7eXAd1cAuGPE+CwC52N0x1Y3I2e/hB6ALGu
j8s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 877->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IXPH8hqCNlJDCYUpsSEFdl243EHSnjgCD8GNHnkdEIw
/PCkD1zxiu4OXPpxmYcvjaG4Hcn9GHwi7EcBOOxCZ+N0BxZ3o6c/hB4AZKeP
jA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 878->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IXPH8hqCNlJDCYUpsSEFdl243EHSngQiBvkNIVMk+IP
XACbPbjCEUUPDrNw+QPF7Ujux+ATYT8KwGEXOhunO7C4Gz39IfQAADe2kAw=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 879->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IXPH8hqCNlJDCYUpsSEFdl243EHSngQiBvkNIVMk+IP
XACbPbjCEUUPDrNwuQXF7Ujux+ATYT8KwBZWDJhsnO7A4W50MyA0AKC2kIw=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 880->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IXPH8hqCNlJDCYUpsSEFdl243EHSngQiBvkNIVMk+IP
XACbPbjCEUUPDrNwuQUDoJtLIPxxAmxhxYDJRnEHjnSJK/0h9AAAcTeQTQ==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 881->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IXPH8hqCNlJDCYUprTE6OGAy13ofkSPG+Q0hUwTazd6
POCKVwYs+nCmBRxmEdILB+hyONxNyP1Yw4oBk43MZ8DiH3zpD6EHAE7PkI4=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 882->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6Dhau0x+Shm4DEP3V4U/fao6hiQxNDd2YDmBhR5ND1Y7WTArh89LHC5FZf7
UcIIi7vxuR2bHQwE3IXPH8hqCNlJDCYUprTE6OGAy13ofkSPG+Q0BacJpRU8
6QNXvDJg0YczLeAwi5BeOECXw+FuQu7HGlYMmGxkPgMW/+BLfwg9APL1kE8=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 883->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWa4/JRzGDgHkYdiObi2wvkhi6OxvQ3IAij6YHq50M2PWjhwUut+JyP0oY
YXE3Prdjs4OBgLvw+QNZDSE7icGEwpSWGD0ccLkL3Y/ocYOcpuA0obSCJ33g
ilcGLPpwpgUcZhHSCwfocjjcTcj9WMOKAZONzGfA4h986Q+hBwAgIpDP
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 884->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWi64X3QwC5mHYjUSj2Iskhu5ObO5Adisuu9DV4ZTD4V6sdmKRw+VufG7H
ZgcDAXfh8weyGkJ2EoMJhSktMXo44HIXuh/R4wY5TcFpQmkFT/rAFa8MWPTh
TAs4zCKkFw7Q5XC4m5D7sYYVAyYbmc+AxT/40h9CDwBBQJFP
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 885->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWi64X3QwC5mHYjUSj2Iskhu5ObO5Adisuu9DV4ZTD4V6sdmKRw+Vu5DDF
6TZcbCzuwucPZDW43E4KJhSmtMTo4YDLXeh+RI8b5DQFpwmlFTzpAyNe0ewh
Jn3hMouQXjhAl8PhbkLuxxpWDJhsZD4DFv/gTH8MyHoAgL+Q0Q==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 886->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l0NWi64X3QwC5mHYjUSj2Iskhu5ObO5Adisuu9DV4ZTD4V6sduIKFyzuRg5T
nG7DxcbiLnz+QHcHIXWEMKEwpSVGDwec4UwgbpDTFJwmlFbwpA+MeEWzh5j0
hcssQnrhAF0Oh7sJuR9rWDFgspH5DFj8gzP9MSDrAQAR3ZFR
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 887->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e1H026OqY0ASQ3cnNnc0ILkVl13o6nDK4XAvVjtxhQsW
d8Pdjsd92MIaPUyJ8Qe6OwipI4QJhSktMUqYoLkDJTwIxA1ymkIOU2LtRo9L
jHhFs4eY9IXLLEJ64QBdDoe7Cbkfa1gxYLJR0iOOdIk1/TEg6wEAe6GQUQ==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 888->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e1H026OqY0ASQ3cnNnc0ILkVl13o6nDK4XAvVjtxhQsW
d8Pdjsd92MIaPUyJ8Qe6OwipI4QJhSktMUqYoLkDJTwIxA1ymkIOU2LtRo9L
jHhFs4eY9IUet3jTBjaALofD3YTcjxFGaGkH2V3YwhCXuzH8CaYBih+QTw==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 889->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GFCxZ3
w92Ox33Ywho9TInxB7o7CKkjhAmFKS0xSpiguQMlPAjEDXKaQg5TYu1Gj0uM
eEWzh5j0hR63eNMGNoAuh8PdhNyPEUZoaQfZXdjCEJe7MfwJpgGSvZAQ
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 890->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GFCxZ3
w92Ox33Ywho9TInxB7o7CKkjhAmFKS0xSpiguQMlPAjEDXKaQqaJtRs9LjHi
Fc0eYtIXCiCUNrABdDkc7ibkfowwQks7yO7CCEMGVHlc6Q+hBwDrlJBP
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 891->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO7DFtboYUqMP9DdQUgdIUwoTGmJUcIEzR0o4YErbSGHI1o6IRh+eNIHRryi
2UNM+kIBhNIGNoAuh8PdhNyPEUZoaQfZXRhhyIAqjyv9IfQAAIKykM8=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 892->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO7DFtboYUqMP9DdQUgdIUwoTGmJUcIEzR0o4YErbSGHI1o6IZhW8KQPjHhF
s4eY9IUCCKUNbABdDoe7CbkfI4zQ0g6yu7CFIS53o5sBoQEm55CQ
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 893->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO7DFtboYUqMP9DdQUgdIUwoTGmJUcIEzR0o4YErbSGHI1o6IZhW8KQPjHhF
s4eY9IUCCKUNbABdDoe7Cbkfa1gxYLJR0iOOdIkr/SH0AABX55EQ
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 894->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO7DFtboYUqMP9DdQUgdIUwoTGmJUcIEzR0o4YErbSGHI1o6IZhW8KQPjHhF
s4eY9IXLLEJ64QBdDoe7Cbkfa1gxYLJR0iOOdIkr/SH0AAAekJDR
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 895->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO7DFdbY3IXPH+juIKSOECYUprTE6OGAM5xxpS0kGpY+4DShtIInfWDEK5o9
xKQvXGYR0os1LSClB2LsRwHYwooBk43MZ8DiH3zpD6EHAOKfkdE=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 896->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO7DFdbY3IXPH+juIKSOECYUpvTC6O5ACQ9caQuJhqUPOE0oreBJHxjximYP
MekLl1mE9GJNC0jpgRj7UQC2sGLAZCPzGbD4B1/6Q+gBAMuuklE=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 897->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO7DFdbY3IUvXNHdgcudxGJC9tALo7sDJTxwpS0kGpY+4DSh8MOTPjDiFc0e
YtIXLrMI6cWVFtD9TIwZ2PTBwgedjcxnwOIffOkPoQcAISOSEg==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 898->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO4jxV34whXdHbjMJRYTsodeGN0dKOGBK20h0bD0AacJhR+eeMCIVzR7iIlH
XGYR0osrLaD7mRgzsOmDhQ86G5nPgMU/+NIfQg8AjjKSkg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 899->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8zCcCcWd+DSg9VOBuz6sbkDm1sJiTWguQHD
b3jcR4q78IUrujtwmUssJmQPvTC6O1DCA1fawpI+kGm89uGJB4x4RbOHmHjE
ZRYhvbjSArqfiTEDmz5Y+KCzkfkMWPyDM/0xIOsBAOxSklE=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 900->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2d+DSg9VOBuz6sbkDm1sJiTWguQHD
b3jcR4q78IUrujtwmUssJmQPvTC6O1DCA1fawpI+kGm89uGJB4x4RbOHmHjE
ZRYhvbjSArqfiTEDmz5Y+KCzkfkMWPyDM/0xIOsBAM1wktE=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 901->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2d+DSg9VOBuz6sbkDm1uJEcPmbrjb
8biPFHfhC1dkNfjMJRYTsoegfgrtx+UOlPDAlbawpA9kmhR34wLY7CEmHnGZ
RUgvrrSA7mdizMCmDxY+6GxkPgMW/+BMfwzIegA1UpHR
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 902->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2d+DSg9VOBuz6sbkDm1uJEcPmbrjb
8biPFHfhC1dkNfjMJRYTsodeGN0dKOGBK21hSR/INF778MQDRryi2UNMPOIy
i5BeXGkB3c/EmIFNHyx80NnIfAYs/sGZ/hiQ9QAAPGGSUQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 903->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2d+DSg9VOBuz6sbkDm1sJiTWguQHD
b3jcR4q78IUrujtwmUssJmQPvTC6O1DCA1fawpI+kGm89uGJB4x4RbOHmHjE
ZRYhvbjSArqfiTEDmz5Y+KCzkfkMWPyDM/0xIOsBAM1wktE=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 904->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO4jxV34whXdHbjMJRYTsodeGN0dKOGBK20h0bD0AacJhR+eeMCIVzR7iIlH
XGYR0osrLaD7mRgzsOmDhQ86G5nPgMU/ONMfA7IeAIr/klM=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 905->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2d+DSg9VOBuz6sbkDm1uJEcPmbrjb
8biPFHfhC1dkNfjMJRYTsodeGN0dKOGBK21hSR9wmlD44YkHjHhFs4eYeMRl
FiG9uNICup+JMQObPlj4oLOR+QxY/IMz/TEg6wEA4IeSEg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 906->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GIYXM3
3O143EeKu/CFK7IafOYSiwnZQy+M7g6U8MCVtpDjBS2dEAw/PPGAEa9o9hAT
j7jMIqQXV1pA9zMxZmDTBwsfdDYynwGLf3CmPwZkPQD54ZHT
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 907->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GIYXM3
3O143EeKu/CFK7IafOYSiwnZQy+M7g6U8MCVtpDjBS2dEAw/PPGAEa9o9hAT
j7jMIqQXV1pA9zMxZuD0AwMmG5nPgMU/ONMfA7IeAN8OkZQ=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 908->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GIYXM3
3O34/ECCu/CFK7IafOYSiwnZQy+M7g6U8MCVtpDjBS2dEAoXDDNxAGz2EBOP
uMwipBdXWkD3MwYbD8DwAwMmG8UcHOkSa/pjQNYDAJXKkVM=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 909->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GIYXM3
3O34/ECCu/CFK7IafOYSiwnZQy+M7g6U8MCVtpDjBS2dEAoXDDNxAGz2EBOP
uMwipBdXWkD3MzFm4PQDAyYbxRwc6RJr+mNA1gMA3sqR0w==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 910->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBzTyoGLq9WPUzIMTR9aHLY/UHHrvQ1eGUY8BuBlY7cYhhczfc
7fj8QIK7cLkTXR8+c4nFhOyhF0Z3B0p44EpbyPGClk4IhQuGmTgANnuIiUdc
ZhHSiystoPsZg40HYPiBAZONzGfA4h+c6Y8BWQ8AdQiREg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 911->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBzTyoGLq9WPUzIMTR9aHLY/UHHrvQ1eGUY8BuBlY7cYhhczfc
7fj8QIK7cLkTXR8+c4nFhOyhF0Z3B0p44EpbyPGClk4Ihh+eeMCIVzR7iIlH
XGYR0osrLaD7GYONB2D4gQGTjcxnwOIfnOmPAVkPABk9kNM=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 912->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBzTyoGLq9WPUzIMTR9aHLY/UHHrvQ1eGUY8BuBlY7cYhhczfc
7fj8gMc8dHfhcie6f3CZSwomZA+9MLo7UMIDV9pCDke0dEIw/PCkD4x4RbOH
mPSFyyxCenGlBQYs9jMQ4X6sfmDAZKOkRxzpElf6Q+gBAGJSkBI=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 913->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBzTyoGLq9WPUzIMTR9aHLY/UHHrvQ1eGUY8BuBlY7cYhhczfc
7fj8gMc8dHfh8weyGlzmkoIJhSm9MLo7UMIDV9pCDke0dEIwreBJH+hmoNtD
TPrCBvD5HZdaZDehu5uBgBk4/cCAyUZJjzjSJa70h9ADAKrzkRA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 914->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GIYXM3
3O34/IDHPHR34fMHshpc5pKCCYUpvTC6O1DCA1faQg5HtHRCMK3gSR/oZqDb
Q0z6wgbw+R2XWmQ3obubgYAZOP3AgMlGSY840iWu9IfQAwCqtZDR
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 915->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GIYXM3
3O143IfPPHR34fMHshpc5pKCCYUpvTC6O1DCA1faQg5HtHRCMK3gSR/oZqDb
Q0z6wgbw+R2XWmQ3obubgYAZOP3AgMlGSY840iWu9IfQAwAn05FR
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 916->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GIYXM3
3O143IfPPHR34fMHshpc5pKCCYUpvTC6O1DCA1faQg5HtHRCMK3gSR8Y8Ypm
DzHpC5dZhPRiTQtI6YEBhx/wAQw/MGCyUdIjjnSJK/0h9AAA2r2REg==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 917->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO3GIYXM3
3O143IfPPHR34fMHshpc5pKCCYUpvTC6O1DCA1faQg5HtHRCMK3gSR8Y8Ypm
DzHpC5dZhPRiTQtI6YEY+wn6gQGTjZIecaRLXOkPoQcAI8yRkg==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 918->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRWXXejqcMrhcC9WO/GYg8tM
fO4jxV34/IHuDkLqCGFCYUovjO4OlPDAlbaQaFj6gNOE0gqeeMCIVzR7iIlH
XGYR0os1LSClB2LsJ+gHBkw2Mp8Bi3/wpT+EHgAd+ZKS
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 919->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j8Bwteh60c3AYx66vVj1MyDEYWahuxObO+DyaHqw2smAXT82d2BzKyGxBjQ3
YPgNj/twmmeP6S58/kB3ByF1hDChMKUXRncHSnjgSlvIYYiWTgimFTzpAyNe
0ewhJn3hMouQXqxpASk9EGM/CsAWVgyYbJS0iMU/+NIfQg8A+jmTTw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 920->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j8Bwteh60c3AYx66vVj1MyDEYWahuxObO+DyaHqw2smAXT82d2BzKyGxBjQ3
YPgNj/tIcRc+f6C7g5A6QphQmNILo7sDJTxwpS0kGpY+4DShtIInHjDiFc0e
YuIRl1mE9GJNC0jpgRj7UQC2sGLAZCPzGbD4B1/6Q+gBAEnGkxA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 921->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j8Bwteh60c3AYx66vVj1MyDEYWahuxObO+DyaHqw2smAXT82d2BzKyGxBjQ3
YPgNj/tIcRc+f6C7g5A6QphQmNILo7sDJTxwpS0kGpY+4DShtIInHjDiFc0e
YuIRl1mE9GJNC0jpgRj7UQC2sGLAZCPzGbD4B2f6Y0DWAwBGk5LR
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 922->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRXdzbjU4ZTD4V6sduIxB5eZ
uMKCkHno7iLkT2S78MUhMRifm+mJ0d2BEh640hYSjZw+iAo/PPGAEa9o9hAT
j7jMIqQXa1pA8g8x9qMAbGHFgMlG5jNg8Q/O9MeArAcAgTeR0Q==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 923->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRXdzbjU4ZTD4V6sduIQw+Zu
uNtxhAUh89DdRcifyHbhi0NiMD430xOjuwMlPHClLeRwJCGdYDUTB8BmDzHp
C5dZhPRiTQtI/iHGfhSALawYMNko6RFHusSa/hiQ9QAAhwqQ0Q==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 924->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRXdzbjU4ZTD4V6sduIQw+Zu
uNtxhAUh89DdRcifyHYRUkcI43MzPTG6O1DCA1faQg5HEtIJVjNxAGz2EJO+
cJlFSC/WtIDkH2LsRwHYwooBk42SHnGkS6zpjwFZDwDIGZFR
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 925->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRXdzbjU4ZTD4V6sduIQw+Zu
uNtxhAUh89DdRcifyHYRUkcI43MzPTG6O1DCg0BYIqcpYtIJVjNwAGS1DFj0
4UsL2MwipBdrWkDyDzH2owB7LH5gwGSjpEcc6RJr+mNA1gMAkSiR0Q==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 926->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DhatH1opuBxzx0e7HqZ0CIw8xCdyc2dzQguRXdzbjU4ZTD4V6sduIQw+Zu
fG4nxjx0dxHyZ4M9cXYSg3HFH70xujtQwoNAWCKnKWLSCVYzcABktQxY9OFM
CzjMIqQXa1pA8g8uN+AE9lj8wIDJRkmPONIl1vTHgKwHAAF2kZA=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 927->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmNSCxkflY/UGMm/HI43MvVjtxiCHrx+Y3QuGJ
zTx0dxHyZ4M9cXYSJY8j/uiN0d2BEh4E/IScpohJJ1jNwAGQ1TJg0YczLeAw
i5BerGkByT+43IAT2GPxAwMmGyU94kiXuNIfQg8ACZqRTw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 928->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmNSCxkflY/UGMm/HI43MvVjtxiCHrx+Y3QuGJ
zTx0dxHyZ4M9cXYSJY8j/uiN0d2BEh4E/IScpohJJ1jNwAGQ1TJg0YczLeAw
i5BerGkByT+43IAT4Ehz6GyU9IgjXeJKfwg9ADyakc8=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 929->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmNSCxkflY/UGMm/HI43MvVjtxiCHrx+Y3QuGJ
zTx0dxHyZ4M9cXYSg3HFH70xujtQwoNAWCKnKWLSCVYzcABktQxY9OFMCzjM
IqQXa1pA8g8uN+AEONIcOhslPeJIl7jSH0IPAHOpkk8=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 930->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmNSCxkflY/UGMm/HI43MvVjtxiCHrx+Y3QuGJ
zTx0dxHyZ4M9cXYSg3HFH70xujtQwoNAWCKnKWLSCVYzcABktQxY9OFMCzjM
IqQXa1pA8g8x9qMAHGkOnY2SHnGkS1zpD6EHAMCpks8=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 931->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmNSCxkflY/UGMm/HI43MvVjtxiCHrx+Y3XG7D
FUbY3IUvXJHVkGMnLnMGGqO7AyU8CMQNcpoiJp1gNQMHQFbLgEUfzrSAwyxC
enGlBQYc7ibkfqxhxYDJRkmPONIlrvSH0AMAiS2TEA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 932->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmNSCxkflY/UGMm/HI43MvVjtxiCHrx+Y3XG7D
62YG7OYS0keundjMGWiM7g6U8CAQN8hpiph0gtUMHABZLQMWfTjTAg6zCOnF
lRYYcLibkPuxhhUDJhuZz4DFP/jSH0IPAPI8k5A=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 933->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmNSCxkflY/YGkB6eb8fgJn3ux2olDDFk/Nr/h
cx+x7sIXrshqyLUTmzkDjdHdgRIeBOIGOU0h03jtwxMPuOKVAYs+nGkBh1mE
9OJKCww43E3I/VjDigGTjcxnwOIffOkPoQcAwVqUEA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 934->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFm4ZLH6g8kPTjdjMdP+NyL1U4cYsj6iXE7IYzN
XfjCFVkNuXZiM2egMbo7UMKDQNwgpylkGq99eOIBV7wyYNGHMy3gMIuQXlxp
gQGHuwm5H2tYMWCykfkMWPyDL/0h9AAA0diT0Q==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 935->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj5/wuRernTjEsLkbn9sJ
YWzuwheuyGrItRObOQON0d2BEh4E4gY5TSHTeO3DEw+44pUBiz6caQGHWYT0
4koLDDjcTcj9WMOKAZONzGfA4h986Q+hBwCoeJSQ
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 936->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj5/wuRernTjEsLkbn9sJ
YWzuIhQ3DfaU2YnNnIHG6O5ACQ8CcYOcppBpvPbhiQcGJD6yWgYs+nCmBSyA
mDSANS0g+YcY+/HZCfMbOhuZz4DFP/jSH0IPANcZlY4=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 937->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj5/wuRernTjEsLkbn9sJ
YWzuIhQ3DfaU2YnNnIHG6O5ACQ8S4gaZxmsfnnhgQOIjq2XAE94YaQELICYN
YE0LSP4hxn58dsL8hs7GGoZ43I1uBoQGAJwolg4=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 938->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj5/wuRernTjEsLkbn9sJ
YWzuIhQ3DfaU2YnNnIHG6O5ACQ8S4gaZxmsfnnhgQOIjq8VnJkZawAKI0Ys1
LSD5B5cbcAFc4YTOxhqGeNyNbgaEBgArN5aO
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 939->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj5/wuRernTjEsLkbn9sJ
YWzuIhQ3DfaU2YnNnIHG6O5ACQ8S4gaZxmsfnnjAFa/4zMTQg8MsQnqxpgUk
/+ByAz73YwsndDbWMMTjbnQzIDQA3iGWTw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 940->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj5/wuRernTjEsLkbn9sJ
YWzuIhQ3DfaU2YnNnIHG6O5ACQ8S4gaZxmsfnnjAFa/4zMTQg8MsQnqxpgUk
/+ByAz73YwsndDZ62iPkbnQzIDQA/yGWzw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 941->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj5/wuRernXjMwWUmvvDE
62YGLOYSoY9cO3H5ZyAxujtQwoPI+EJOJwTDD0884IpXfGZi6MFhFiG9WNMC
kn9wuQGf+7GFEzobPe0RcjeGP8FsAI0MlxA=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 942->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l7PH1APXi24GAfMI6mdAiMPMQncnsj4Mf6DpwWonHj/hcy9WO/GYg8tMfOGJ
180MWMwlQh+5duLyz0BidHeghAeR8YWcTgiGH554wBWv+MzE0IPDLEJ6saYF
JP/gcgM+92MLJ3Q2etoj5G4Mf4LZALoql5A=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 943->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l7PH1APXi24GAfMI6mdAiMPMQncnsj4Mf6DpwWonHj/hcy9WO/GYg8tMfOGJ
180MWMwlQh+5duLyz0BiFP9j4RMTX8jphGD44YkHXPGKz0wMPTjMIqQXa1pA
8g8uN+BzP7ZwwhXOMLsY7HGbgZL+kNzHwAAAySaWzw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 944->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l7PH1APXi24GAfMI6mdAiMPMQncnsj4Mf6DpwWonHj/hcy9WO/GYg8tMfOGJ
180MWMwlQh+5duLyz0BidHeghAeR8YWcTgiGH554wBWv+MzE0IPDLEJ6saYF
JP/gcgM+92MLJ3Q2Rhja4zYDJf0huY+BAQCmNZdP
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 945->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMS4A
l7PH1APXi24GAfMI6mdAiMPMQncnsj50s9D1YLUTj5/wuReXnVjdgcXd+NxO
CGNzF6G4abCnzE5s5gw0RncHSniQEDfINF778MQDrnjFZyaGHhxmEdKLNS0g
+QeXG/C5H1s4obOxhiEed2P4E8wGAO6yls8=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 946->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0/43IvLTqzuwOJudL/h
cyMx7iIUNw32qHaSYh8ucwYao7sDJTxIiBtkGq99eOIBW7wSCms4wGMeMWkA
a1pANpcEM7DZCQsfdDbWMMTjbrgZDMh6AIDIlg4=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 947->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0/43IvLTqzuwOJudL/h
cyMx7iIUNw32qHaSYh8ucwYao7sDJTxIiBtkGq99eOIBW7wSCmsMPTjMIqQX
a1pA8g8uN+BzP7ZwQmdjDUM87sbwJ5gNAEKFlc8=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 948->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0/43MuAhY3THVjcje43
fG4kxl2E4qbBHtVOUuzDZc5AY3R3oIQHnvhCjxtkGq99eOIBW7wSCmsMPTjM
IqQXa1pA8g8uN+BzP7ofkP2FrgZmFyF3o5sBoQFzmpUO
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 949->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0/43MuAhY3THVjcje43
fG4kxl2E4qbBHtVOUuzDZc5AY3R3oIQHnvhCjxtkGq99eOIBW7wSCmsMPTjM
IqQXa1pA8g8uN+BzP7ofkP2F7i6YXYTcjW4GhAYAlJqVjg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 950->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0/43MuAhY3PHFxmMuDR
h9fNDFjMJUIfPneSYj8l+qmF0d2BEh544gsljTAwEJW2sZqJAxCTJrCmBRxm
EdKLNS0g+QeXG/C5H1s4obPR0x4hd6ObAaEBWLiWjg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 951->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0/43MuAhY3PHFxmMuDR
h9fNDNjNJaQPnztJsZ8S/dTC6O5ACQ888YWSRhgYiErbWM3EAYhJE1jTAg6z
COnFlRYIuQGf+7GFEzobxRwc6RJX+kPoAQCuHpZP
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 952->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0+E3Ivhbjzm4DKTAY8+
vG5mwG4uIX343EmK/ZTopxZGdwdKeOCII4w0wsBAVNrGaiYOQEyawJoWcJhF
SC+utEDIDfjcjy2c0Nko5uBIl7jSH0IPAFM8ls8=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 953->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0+E3Ivhbjzm4DKTAY8+
vG5mwG4uIX343EmK/ZTopxZGdwdKeOCII4w0wsCAkk6JiWds8YAtXgmFNYYe
HGYR0osrLRByAz73YwsndDaKOTjSJa70h9ADAPdilpA=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 954->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0+E3Ivhbjzm4DKTAY8+
vG5mwG4uIX3Y3EmO/aSopxVGdwdKeBDhR1j6gNNExjO2eMAWr4TCFkMPDrMI
6cWVFgi5ASfAEU7obBRzcKRLXOkPoQcAgVOVkA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 955->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0+E3Ivhbjzm4DKTAY8+
vG5mwG4uIX343EmK/ZTopxZGdwdKeOCII4w0wsCAkk6JiWds8YAtXgmFNYYe
HGYR0osrLRByA06AI5zQ2Sjm4EiXuNIfQg8AwGKWEA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 956->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+6Weh6sNqJx0+E3IvhblzuwOJudL/h
M58YdxHlTjzhRar9lOinFkZ3B74wxRc3cJrIeMYWD9jilVBYY+iBASLcg8te
dHPwuQEnwBFO6GwUc3CkS5zxA9cDAJKXlU8=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 957->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuRfD3TjksLkb3W/4
zCfGXUS5E094kWo/JfqphdHdgS9M8cUNnCYynrHFA7Z4JRTWGHpggAj34LIX
3Rx8bsAJcIQTOhvFHBzpEmf8wPUAAKvxlRA=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 958->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuReX+9HFsLkb3W/E
mI/PXcS4E194kWo/JfqphdHdgS9M8cUNnCYUfnjiAVu8EgprDD0wQIR7cNmL
bg4+N+AEOMIJnY1iDo50iTN+4HoASw+VkA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 959->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuReX+9HFsLkbn9sJ
2oPFXcS4kxI7sZkz0BjdHSjhQULcwGlC4YcnHnDFK76wxtADA0S4B5e96Obg
cwNOgCOc0Nko5uBIl7jSH0IPAKEtlpA=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 960->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuReX+9HFsLkb3e34
wpUYdxHjTnzhRQomNjxojdHdgRIeJMQNMk1K/OICxMYrhh4YICI+cdmLbg66
GxiIcD+2sEP2F7q70N2My93oZkBoADbplc8=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 961->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuReX+9HFsLkb3e34
wpUYdxHjTnzhRQomNjxojdHdgRIeJMQNMk1K/OICxMYrhh4cZhHSiystYHMD
AxHuxxZ2yP5CdxdMDyF3o5sBoQH8h5WQ
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 962->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuReX+9HFsLkb3e34
wpUYdxHjTnzhRQomNjxojdHdgRIeJMQNMk1K/OICxMYrhh4cZhHSiystEHID
ToAjnNDZKObgSJe40h9CDwBFlpYQ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 963->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuReX+9HFsLkb3e34
wpUYdxHjTnzhRQomNjxojdHdgRIeJMQNMk1K/OICxMYrhh4cZhHSiystEHID
PvdjCyd0Noo5ONIlrvSH0AMAfJaWkA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 964->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GRDi6PrQ5bH6A49d6OpwyjEQNgPd/ehi2NyN7nZ8
4UqMu4hxJ77wIgUTGx60xujuQAkPEuKGmHSC1UwcgNh4xdCDwyxCenGlBWxu
YCDS/djCCZ2NLQzxuRvdDAgNAM3Ulk8=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 965->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GRDi6PrQ5bH6A49d6OpwyjEQNgPd/ehi2NyN7nZ8
4UqMu4hxJ77wIgUTGx60xujuQAkPEuKGmHSC1UwcgNh4xdCDwyxCenGlBWxu
YCDS/djCCZ2NYg6OdIkr/SH0AADu1JbP
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 966->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GRDi6PrQ5bH6A49d6OpwyjEQNgPd/ehi2NyNz+0E
7cHiLmLcSYmd2MwZaIzuDpTwICFuiEknWM3EAZDV4gtrDD04zCKkF1dawOYG
BiLdjy2c0Nko5uBIl7jSH0IPAGvyl08=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 967->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GRDi6PrQ5bH6A49d6OpwyjEQNgPd/ehi2NyNz+0E
7cHiLmLcSYmd2MwZaIzuDpTwICFuiEknWM3EAZDV4gtrDD04zCKkF1daIOQG
fO7HFk7obBRzcKRLXOkPoQcAtPKXzw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 968->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuReX+9HFsLkbn9sJ
2oPFXcS4kxI7sZkz0BjdHSjhQULcEJNOCMUDrnjFF9YYenCYRazdGHIE3IDP
/djCCZ2NYg6OdIkr/SH0AABfw5gQ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 969->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DMgxGFmobsTWR+GP9D0YLUTj58IuZcYjMvd+NxO0Ews
7iLGnZTYic2cgcbo7kAJDxxpC1vcEJNOCMUDrnjFF9YYenCYRazdGHIE3IDP
/djCCZ2NYg6OdIkr/SH0AAD60piQ
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 970->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GRDi6PrQ5bH6A49d6OpwyjEQNgOv+Tjcjc/tBM3E
4i5i3EmJndjMGWiM7g6U8MCRtrDFDTHphFA84IpXfGGNoQeHWXj1Yol7ZDl8
bsDnfmzhhM7GFob43I1uBoQGAAmemI4=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 971->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GRDiDEjyyGoa0MRR5PHYha4OpxwDYTPwmo/mBuRw
wOV2gmZicRcx7sQXXqTaT4l+amF0d6CEB460hS1ukGly4wFbmiUU1hh6cJiF
Vy+WuEeWw+cGfO7HFk7obKxhiMfd6GZAaAD/QJiM
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 972->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GRDiDEjyyGoa0MRR5PHYha4OpxwDYTPwmo/mBuRw
wOV2gmZicRcx7sQXXqTaT4l+amF0d6CEB460hS1ukGly4wFbmiU1HnGZhVcv
lrhHlsPnFnzuxxZO6GysYYjH3ehmQGgAkE+ZDA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 973->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GRDiDEjyyGoa0MRR5PHYha4OpxwDYTPwmo/mBuRw
wOV2gmZicRcx7sQXXqTaT4l+amF0d+BzF9Y0gpZOSA0XXIDYMMbQg8MsYu0m
NY3hcz+2cEJnYw1DPO5GNwNCAwA135lN
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 974->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GdDEsbgTXRxFHo9d6OpwyjEQNgOv+WhuQA4HXG4n
aCYWdxHjTnzhRar9lOinFkZ3Bz53YU0jaOmE1HDBBYgNYww9OMwi1m5S0xg+
92MLJ3Q21jDE4250MyA0ACL9mc0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 975->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GdDEsbgTXRxFHo9d6OpwyjEQNgOv+WhuwOU3kszE
4i5i3EmJndjMGWiM7g587sKaRtDSCanhggsQG8YYenCYRazdGHJ4/E7I/djC
CZ2NNQzxuBvdDAgNAGO3mY4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 976->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GdDEsbgTXRxFHo9d6OpwyjEQNgOv+WhuwOU3kszE
4i5i3EmJndjMGWiM7g587sKaRkhIJ4TigZx4xdCDwyxi7caQw+N3Qu7HFk7o
bGxhiM/d6GZAaAAexpoO
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 977->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBzTyoGFH6GbDLI6tBF0eRx2MXujqccljcQQpGdwO6mfjCE6+b
GbCYS4Q+cu3EZs5AY4z0gcddWNMICemEUDwwIPGJDWOMtIAFEGU3trSAlB5w
uQUXwBVO6GxsYYjP3ehmQGgABYWbDA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 978->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DNgl0dWgy6OIm+P2y50dTjl8LiXGIzuBnQz8YUnXjcz
YDGXCH3k2onNnIHGGOkDj7uwphES0gmheGBA4hMbxhhpAQsgym5saQEpPeBy
Cy6AK5zQ2djCEJ+70c2A0AAFR5rN
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 979->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1opuBxzyi9DNgl0dWgy6OIm+P2y50dTjl8LiXGIzuBnQz8YUnXjcz
YDGXCH3k2onNnIHGGOkDj7uwphES0gmheGBA4hMbxhhpAQsgym5saQEpPeBy
Cy6AK5yQ9eAKQ3zuRg4bhB4A8Umajg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 980->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU5g
j6DR9cD1EjIDCRCrH5s8shp0cRR5e9x2oavDKYfHvcRgdDegm4kvPPG6mQGL
uUToI9dObOYMNMZIH3jchTWNkJBOCMUDAxKf2DDGSAtYAFF2Y0sLSOkBl1tw
AVzhhKwHVxjiczdy2CD0AADsH5pP
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 981->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU4A
lUNXj6KXkBlIgFj92OSR1aCLo8gT42YG7PrxuYMUjO4GdDNx2U3QzQxYzCVC
H7l2YjNnoDFG+sDjLqxphIR0QigeGJD4xIYxRlrAAoiyG1taQEoPuNyCC+AK
J2Q9uMIQn7uRwwahBwAVTJrP
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 982->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU4A
lUNXj6KXkBlIgFj9OO1CkmfAJU+Mmxmw6yfWHYQwuhvQzcRlN0E3M2Axlwh9
5NqJzZyBxujuwJte8MQNMemEUDyQE68YenCYRazdGHJ4/E7I/djCCVkPrjDE
527ksEHoAQCzVJsQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 983->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU4A
lUNXj6KXkBlIgFj9OO1CkmfAJU+Mmxmw6yfWHYQwuhvQzcRlN0E3M2Axlwh9
5NqJzZyBxujuwJte8IUjmX7CBYgNYww9OMwi1m5s/sLnFnzuRw87dDeiyzFg
8Q++9IfQAwBTmZrR
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 984->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU4A
lUNXj6KXkBlIgFj9OO1CkmfAJU+Mmxmw6yfWHYQwuhvQzcRlN0E3M2Axlwh9
5NqJzZyBxujuwJteCIQjOX7CBYgNYww9OMwi1m4MOTx+J+R+9LBDdyO6HAMW
/+BLfwg9APXHmpI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 985->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU4A
lUNXj6KXkBlIgFj9OO1CkmfAJU+Mmxmw6yfWHYQwuhvQzcRlN0E3M2Axlwh9
5NqJzZyBxujuwJteCIQjOX7CBYgNYww9OMwi1m4MOTx+J+R+nGkH3S6ktEe0
GSh6ACTWmxI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 986->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU4A
lUNXj6KXkBlIgFj9OO1CkmfAJU+Mmxmw6yfWHYQwun50M3HZTYyZGOYSoY9c
O7GZM9AY3R140wuBcCTHT7gAsWGMoQeHWcTajSGHx++E3I8z7aDbhZT2iDYD
RQ8AX6ia0w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 987->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU4A
lUNXj6KXkBlIgFj9OO1CkmfAJU+Mmxmw6yfWHYQwun50M3HZTYyZGOYSoY9c
O7GZM9AY3R2kuouYNEmKflLjFUMPDrOItRtDzh6/W/C5H2faQbcLKe0Ra0YD
ih4AM7eb0w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 988->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMU4A
lUNXj6KXkBlIgFj9OO1CkmfAJU+Mm4mwg5AZhMxH1o9uJja3E2smhrlE6CPX
TmLDjJ4Y3R2kuouYNEmKflLjFUMPDrOItRtDzh6/W/C5H2faQbcLKe0Ra0YD
ih4A8sacUw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 989->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh5FL5Fm4DIHm36cdiHJM+CStyfCzUTYQcgMQuYj60c3E5vbiTUTw1wi9JFr
J7FhRk+M7g5S3UVMmiRFP6nxiqEHh1nE2o0hZ4/fLfjcjzPtoNuFlPaINaMB
RQ8A4NCcFA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 990->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh5FL5Fm4DIHm36cdhEjb0+Em4mwg5AZhMxH1o9uJgMFZmKYS4Q+cu0kNszo
idHdQaq7iEmTpOgnNV4x9OAwi1i7MeTs8bsFn/txph10u5DSHrFmNKDoAQC/
7pyU
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 991->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh5FL5Fm4DIHm36cdhEjb0+Em4mwg5AZhMxH1o9uJgMFZqKbS4w+cu0kNszo
idHdQaq7iEmTpOgnNV4x9OAwi1i7MeTs8bsFn/txph08dhFrBlwfmAYACw2c
1Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 992->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh5FL5Fm4DIHm36cdhEjb0+Em4mwg5AZhMxH1o9uJgMFZqKbS4w+cu0kNszo
idHdQaq7iEmTpOgnNV4x9OAwi1i7SU1j+NyPM+3gsgtHusQVPwg9AOJjnJY=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 993->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh5FL5Fm4DIHm36cdhEjb0+Em4mwg5AZhMxH1o9uJgMFZqKbS4w+cu0kNszo
idHdQaq7iEmTpOgnNV4x9OAwi1i7SU1j+NyPM+3gsgtHusQVPwgAAOEonFc=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 994->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgZg1YdFPyE78MrbE3YzMXYQ629i3IluJgMFZqKbS4w+cu0kNszoidHd
Qaq7iEmTpOgnNV4x9OAwi1i7SU1j+NyPM+3gsgtHusQVPwgAAPxGnNc=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 995->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgZg1YdFPyE7iHEDIbdSagYxYYHLTAYKzEQ3lxh95NpJbJjRE6O7g1R3
EZMmSdFParxi6MFhFrF2k5rG8LkfZ9rBZReOdIkrfhAAABarnJg=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 996->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgZg1YdFPyE7iHEDIbdSagYxYYHLTAYKzEQ3lxh95PqDFuZQ2x2kuouY
NEmKflLjFUMPDrOItRtf+iDV/bjCGqddRNiL3Y0ArLqdmA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 997->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgZg1YdFPyE7iHEDIbdSagYxYYHLTAYKzEQ3lxh95PqDFuZQ2x2kuouY
NEmKflLNwUgLJJiFTy2xbiHF/ehuxDCDCHuxuxEAQcmeGA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 998->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgZg1YdFPyE7iHEDIbdSagYxYUELM9HNJUYfuXbSwhxqu4NUdxGTJknR
T6o56HpIMQufWmLdQor70d2IYQYR9mJ3IwDC2J6Y
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 999->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgYQq5+QGkrMgKmj1Axi/EILM9HNJUYfuXbSwhxqu4NUd5GSJonRT6o5
6HpIMQufWmLdQor70d2IYQYR9mJ3IwC99p8Y
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 1000->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuxRMSGA
rh4bJgYQq5+QGkrMgKmj1Axi/EILM9HNJUYfuXbSwhxqu4NUd5GSJonRT6o5
6HpIMQufWmLdQor70d1IiRmo+gCv757Z
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False]}, Dynamic[$CellContext`i26$$],
                Alignment->Automatic,
                BaseStyle->"ListAnimateCore",
                ImageSize->All,
                TransitionDirection->Horizontal,
                TransitionDuration->0.5,
                TransitionEffect->Automatic],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
        GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}}], If[
        And[
         CurrentValue["NotebookSelected"], 
         CurrentValue["SelectionOver"]], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i26$$, \
$CellContext`i26$40850800$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 1000, 1}, 1000, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{309., {82.884033203125, 88.615966796875}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.7736056007330847`*^9, 3.773605745327199*^9},
 CellLabel->
  "Out[285]=",ExpressionUUID->"7efeed36-cab7-4705-85a3-a128f64c9e6b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Self-healing Membranes", "Section",
 CellChangeTimes->{{3.682883960591103*^9, 3.682883967305956*^9}, {
  3.773598763545928*^9, 3.773598768239665*^9}, {3.773607560147758*^9, 
  3.773607566892798*^9}},ExpressionUUID->"2dd66fc1-dd27-43b9-8a4f-\
8e36ee97a6b4"],

Cell["\<\
Associative memories epitomize the case where there are just a few solutions \
-- the intended memories -- despite the exponentially large space of possible \
states.  Constraints incarnated as Boolean formulae need not have that \
character:  they can also be meaningful even when there are an astounding \
number of solutions, a situation we might refer to as entropic patterns?  All \
the solutions satisfy the same constraints and thus might look like \
\[OpenCurlyDoubleQuote]the same kind of pattern\[CloseCurlyDoubleQuote].  For \
example, staying within the framework of variables that represent pixel \
positions, we can consider a \[OpenCurlyDoubleQuote]connected membrane\
\[CloseCurlyDoubleQuote] where the constraints ensure that corners are \
connected by black lines, but are otherwise agnostic as to how the connection \
is made (and whether there are addition closed loops in other areas).   \
Specifically, here we will make images where the outside has black only in \
the corners, and all interior cells are either white or have exactly two \
von-Neumann black neighbors.\
\>", "Text",
 CellChangeTimes->{{3.683224502613168*^9, 3.683224542566287*^9}, {
   3.683224585063489*^9, 3.683224600759535*^9}, {3.6832246471913033`*^9, 
   3.683224704354827*^9}, {3.683224754384179*^9, 3.683224766384227*^9}, {
   3.683225703380989*^9, 3.68322570424437*^9}, {3.683225939963592*^9, 
   3.683225948099937*^9}, {3.683227667006626*^9, 3.68322767610086*^9}, {
   3.68322884914076*^9, 3.683228851796751*^9}, 3.683230612502606*^9, {
   3.773607579983191*^9, 3.7736076317337008`*^9}, {3.773607670465179*^9, 
   3.77360773654235*^9}, {3.773607773858426*^9, 3.773607875131447*^9}, {
   3.773607951899206*^9, 3.773607972609044*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"01ec5b9b-42b6-4115-8819-6bac339afe89"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CornerMembrane", "[", 
   RowBox[{"width_", ",", "height_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"And", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"!", 
        RowBox[{"ImageVar", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", "1"}], "}"}], "]"}]}], " ", "&&", " ", 
       RowBox[{"!", 
        RowBox[{"ImageVar", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", "2"}], "}"}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"And", "@@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ImageVar", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "n"}], "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", 
           RowBox[{"height", "-", "2"}]}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"ImageVar", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"height", "-", "1"}]}], "}"}], "]"}]}], "&&", 
       RowBox[{"!", 
        RowBox[{"ImageVar", "[", 
         RowBox[{"{", 
          RowBox[{"2", ",", 
           RowBox[{"height", "-", "1"}]}], "}"}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"And", "@@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ImageVar", "[", 
          RowBox[{"{", 
           RowBox[{"n", ",", "height"}], "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "1", ",", 
           RowBox[{"width", "-", "2"}]}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"ImageVar", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"width", "-", "1"}], ",", "height"}], "}"}], "]"}]}], "&&", 
       RowBox[{"!", 
        RowBox[{"ImageVar", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"width", "-", "1"}], ",", 
           RowBox[{"height", "-", "1"}]}], "}"}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"And", "@@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ImageVar", "[", 
          RowBox[{"{", 
           RowBox[{"width", ",", "n"}], "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "3", ",", "height"}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"ImageVar", "[", 
         RowBox[{"{", 
          RowBox[{"width", ",", "2"}], "}"}], "]"}]}], "&&", 
       RowBox[{"!", 
        RowBox[{"ImageVar", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"width", "-", "1"}], ",", "2"}], "}"}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"And", "@@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ImageVar", "[", 
          RowBox[{"{", 
           RowBox[{"n", ",", "1"}], "}"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "3", ",", "width"}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"And", "@@", 
       RowBox[{"Flatten", "[", 
        RowBox[{
         RowBox[{"Table", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"With", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "=", 
                RowBox[{"ImageVar", "[", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "j"}], "}"}], "]"}]}], ",", 
               RowBox[{"a", "=", 
                RowBox[{"ImageVar", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"i", "-", "1"}], ",", "j"}], "}"}], "]"}]}], ",", 
               RowBox[{"b", "=", 
                RowBox[{"ImageVar", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"i", "+", "1"}], ",", "j"}], "}"}], "]"}]}], ",", 
               RowBox[{"c", "=", 
                RowBox[{"ImageVar", "[", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{"j", "+", "1"}]}], "}"}], "]"}]}], ",", 
               RowBox[{"d", "=", 
                RowBox[{"ImageVar", "[", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{"j", "-", "1"}]}], "}"}], "]"}]}]}], "}"}], ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"a", "||", "b", "||", "c", "||", "x"}], ")"}], "&&", 
              RowBox[{"(", 
               RowBox[{"a", "||", "b", "||", "d", "||", "x"}], ")"}], "&&", 
              RowBox[{"(", 
               RowBox[{"a", "||", "c", "||", "d", "||", "x"}], ")"}], "&&", 
              RowBox[{"(", 
               RowBox[{"b", "||", "c", "||", "d", "||", "x"}], ")"}], "&&", 
              RowBox[{"(", 
               RowBox[{"x", "||", 
                RowBox[{"!", "a"}], "||", 
                RowBox[{"!", "b"}], "||", 
                RowBox[{"!", "c"}]}], ")"}], "&&", 
              RowBox[{"(", 
               RowBox[{"x", "||", 
                RowBox[{"!", "a"}], "||", 
                RowBox[{"!", "b"}], "||", 
                RowBox[{"!", "d"}]}], ")"}], "&&", 
              RowBox[{"(", 
               RowBox[{"x", "||", 
                RowBox[{"!", "a"}], "||", 
                RowBox[{"!", "c"}], "||", 
                RowBox[{"!", "d"}]}], ")"}], "&&", 
              RowBox[{"(", 
               RowBox[{"x", "||", 
                RowBox[{"!", "b"}], "||", 
                RowBox[{"!", "c"}], "||", 
                RowBox[{"!", "d"}]}], ")"}]}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"i", ",", "2", ",", 
             RowBox[{"width", "-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "2", ",", 
             RowBox[{"height", "-", "1"}]}], "}"}]}], "\[IndentingNewLine]", 
          "]"}], ",", "1"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.683224624011496*^9, 3.6832246438314*^9}, {
   3.683224773317997*^9, 3.683224788828412*^9}, {3.683224860727188*^9, 
   3.683225072944334*^9}, {3.683225198699018*^9, 3.68322524551303*^9}, {
   3.6832253474288*^9, 3.683225515009305*^9}, {3.683225684855328*^9, 
   3.683225697374363*^9}, {3.683225799145752*^9, 3.683225818296988*^9}, {
   3.683225958738749*^9, 3.683225987042583*^9}, {3.683226047577368*^9, 
   3.6832260705579977`*^9}, {3.683226235056451*^9, 3.683226263444654*^9}, {
   3.6832263346868677`*^9, 3.683226379696711*^9}, {3.6832272447615128`*^9, 
   3.6832273065552187`*^9}, {3.683227701216446*^9, 3.683227767646196*^9}, {
   3.683227887611739*^9, 3.683227888137129*^9}, {3.683227979004722*^9, 
   3.6832281068479548`*^9}, {3.683228770199181*^9, 3.683228773125284*^9}, 
   3.683230621950902*^9},
 CellLabel->
  "In[307]:=",ExpressionUUID->"91ad4aa3-f839-4517-93d1-a79b4f9cd7be"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ropes", "=", 
  RowBox[{"CornerMembrane", "[", 
   RowBox[{"6", ",", "6"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.683225045495026*^9, 3.6832250524747*^9}, {
   3.683225086195566*^9, 3.683225087786372*^9}, {3.683225548463438*^9, 
   3.683225551132901*^9}, {3.683227336435286*^9, 3.6832273658028727`*^9}, {
   3.683227478569496*^9, 3.683227480185129*^9}, {3.683227894168249*^9, 
   3.68322789513592*^9}, 3.683228140642571*^9},
 CellLabel->
  "In[308]:=",ExpressionUUID->"8c598de3-b3c0-4e8e-ba22-341c0c4dd13b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"!", "pix2v1"}], "&&", 
  RowBox[{"!", "pix2v2"}], "&&", "pix1v1", "&&", "pix1v2", "&&", "pix1v3", "&&",
   "pix1v4", "&&", 
  RowBox[{"!", "pix1v5"}], "&&", 
  RowBox[{"!", "pix2v5"}], "&&", "pix1v6", "&&", "pix2v6", "&&", "pix3v6", "&&",
   "pix4v6", "&&", 
  RowBox[{"!", "pix5v6"}], "&&", 
  RowBox[{"!", "pix5v5"}], "&&", "pix6v3", "&&", "pix6v4", "&&", "pix6v5", "&&",
   "pix6v6", "&&", 
  RowBox[{"!", "pix6v2"}], "&&", 
  RowBox[{"!", "pix5v2"}], "&&", "pix3v1", "&&", "pix4v1", "&&", "pix5v1", "&&",
   "pix6v1", "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v2", "||", "pix3v2", "||", "pix2v3", "||", "pix2v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v2", "||", "pix3v2", "||", "pix2v1", "||", "pix2v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v2", "||", "pix2v3", "||", "pix2v1", "||", "pix2v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v2", "||", "pix2v3", "||", "pix2v1", "||", "pix2v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v2", "||", 
    RowBox[{"!", "pix1v2"}], "||", 
    RowBox[{"!", "pix3v2"}], "||", 
    RowBox[{"!", "pix2v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v2", "||", 
    RowBox[{"!", "pix1v2"}], "||", 
    RowBox[{"!", "pix3v2"}], "||", 
    RowBox[{"!", "pix2v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v2", "||", 
    RowBox[{"!", "pix1v2"}], "||", 
    RowBox[{"!", "pix2v3"}], "||", 
    RowBox[{"!", "pix2v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v2", "||", 
    RowBox[{"!", "pix3v2"}], "||", 
    RowBox[{"!", "pix2v3"}], "||", 
    RowBox[{"!", "pix2v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v3", "||", "pix3v3", "||", "pix2v4", "||", "pix2v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v3", "||", "pix3v3", "||", "pix2v2", "||", "pix2v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v3", "||", "pix2v4", "||", "pix2v2", "||", "pix2v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v3", "||", "pix2v4", "||", "pix2v2", "||", "pix2v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v3", "||", 
    RowBox[{"!", "pix1v3"}], "||", 
    RowBox[{"!", "pix3v3"}], "||", 
    RowBox[{"!", "pix2v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v3", "||", 
    RowBox[{"!", "pix1v3"}], "||", 
    RowBox[{"!", "pix3v3"}], "||", 
    RowBox[{"!", "pix2v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v3", "||", 
    RowBox[{"!", "pix1v3"}], "||", 
    RowBox[{"!", "pix2v4"}], "||", 
    RowBox[{"!", "pix2v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v3", "||", 
    RowBox[{"!", "pix3v3"}], "||", 
    RowBox[{"!", "pix2v4"}], "||", 
    RowBox[{"!", "pix2v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v4", "||", "pix3v4", "||", "pix2v5", "||", "pix2v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v4", "||", "pix3v4", "||", "pix2v3", "||", "pix2v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v4", "||", "pix2v5", "||", "pix2v3", "||", "pix2v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v4", "||", "pix2v5", "||", "pix2v3", "||", "pix2v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v4", "||", 
    RowBox[{"!", "pix1v4"}], "||", 
    RowBox[{"!", "pix3v4"}], "||", 
    RowBox[{"!", "pix2v5"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v4", "||", 
    RowBox[{"!", "pix1v4"}], "||", 
    RowBox[{"!", "pix3v4"}], "||", 
    RowBox[{"!", "pix2v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v4", "||", 
    RowBox[{"!", "pix1v4"}], "||", 
    RowBox[{"!", "pix2v5"}], "||", 
    RowBox[{"!", "pix2v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v4", "||", 
    RowBox[{"!", "pix3v4"}], "||", 
    RowBox[{"!", "pix2v5"}], "||", 
    RowBox[{"!", "pix2v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v5", "||", "pix3v5", "||", "pix2v6", "||", "pix2v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v5", "||", "pix3v5", "||", "pix2v4", "||", "pix2v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix1v5", "||", "pix2v6", "||", "pix2v4", "||", "pix2v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v5", "||", "pix2v6", "||", "pix2v4", "||", "pix2v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v5", "||", 
    RowBox[{"!", "pix1v5"}], "||", 
    RowBox[{"!", "pix3v5"}], "||", 
    RowBox[{"!", "pix2v6"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v5", "||", 
    RowBox[{"!", "pix1v5"}], "||", 
    RowBox[{"!", "pix3v5"}], "||", 
    RowBox[{"!", "pix2v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v5", "||", 
    RowBox[{"!", "pix1v5"}], "||", 
    RowBox[{"!", "pix2v6"}], "||", 
    RowBox[{"!", "pix2v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v5", "||", 
    RowBox[{"!", "pix3v5"}], "||", 
    RowBox[{"!", "pix2v6"}], "||", 
    RowBox[{"!", "pix2v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v2", "||", "pix4v2", "||", "pix3v3", "||", "pix3v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v2", "||", "pix4v2", "||", "pix3v1", "||", "pix3v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v2", "||", "pix3v3", "||", "pix3v1", "||", "pix3v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v2", "||", "pix3v3", "||", "pix3v1", "||", "pix3v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v2", "||", 
    RowBox[{"!", "pix2v2"}], "||", 
    RowBox[{"!", "pix4v2"}], "||", 
    RowBox[{"!", "pix3v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v2", "||", 
    RowBox[{"!", "pix2v2"}], "||", 
    RowBox[{"!", "pix4v2"}], "||", 
    RowBox[{"!", "pix3v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v2", "||", 
    RowBox[{"!", "pix2v2"}], "||", 
    RowBox[{"!", "pix3v3"}], "||", 
    RowBox[{"!", "pix3v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v2", "||", 
    RowBox[{"!", "pix4v2"}], "||", 
    RowBox[{"!", "pix3v3"}], "||", 
    RowBox[{"!", "pix3v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v3", "||", "pix4v3", "||", "pix3v4", "||", "pix3v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v3", "||", "pix4v3", "||", "pix3v2", "||", "pix3v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v3", "||", "pix3v4", "||", "pix3v2", "||", "pix3v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v3", "||", "pix3v4", "||", "pix3v2", "||", "pix3v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v3", "||", 
    RowBox[{"!", "pix2v3"}], "||", 
    RowBox[{"!", "pix4v3"}], "||", 
    RowBox[{"!", "pix3v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v3", "||", 
    RowBox[{"!", "pix2v3"}], "||", 
    RowBox[{"!", "pix4v3"}], "||", 
    RowBox[{"!", "pix3v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v3", "||", 
    RowBox[{"!", "pix2v3"}], "||", 
    RowBox[{"!", "pix3v4"}], "||", 
    RowBox[{"!", "pix3v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v3", "||", 
    RowBox[{"!", "pix4v3"}], "||", 
    RowBox[{"!", "pix3v4"}], "||", 
    RowBox[{"!", "pix3v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v4", "||", "pix4v4", "||", "pix3v5", "||", "pix3v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v4", "||", "pix4v4", "||", "pix3v3", "||", "pix3v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v4", "||", "pix3v5", "||", "pix3v3", "||", "pix3v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v4", "||", "pix3v5", "||", "pix3v3", "||", "pix3v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v4", "||", 
    RowBox[{"!", "pix2v4"}], "||", 
    RowBox[{"!", "pix4v4"}], "||", 
    RowBox[{"!", "pix3v5"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v4", "||", 
    RowBox[{"!", "pix2v4"}], "||", 
    RowBox[{"!", "pix4v4"}], "||", 
    RowBox[{"!", "pix3v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v4", "||", 
    RowBox[{"!", "pix2v4"}], "||", 
    RowBox[{"!", "pix3v5"}], "||", 
    RowBox[{"!", "pix3v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v4", "||", 
    RowBox[{"!", "pix4v4"}], "||", 
    RowBox[{"!", "pix3v5"}], "||", 
    RowBox[{"!", "pix3v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v5", "||", "pix4v5", "||", "pix3v6", "||", "pix3v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v5", "||", "pix4v5", "||", "pix3v4", "||", "pix3v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix2v5", "||", "pix3v6", "||", "pix3v4", "||", "pix3v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v5", "||", "pix3v6", "||", "pix3v4", "||", "pix3v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v5", "||", 
    RowBox[{"!", "pix2v5"}], "||", 
    RowBox[{"!", "pix4v5"}], "||", 
    RowBox[{"!", "pix3v6"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v5", "||", 
    RowBox[{"!", "pix2v5"}], "||", 
    RowBox[{"!", "pix4v5"}], "||", 
    RowBox[{"!", "pix3v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v5", "||", 
    RowBox[{"!", "pix2v5"}], "||", 
    RowBox[{"!", "pix3v6"}], "||", 
    RowBox[{"!", "pix3v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v5", "||", 
    RowBox[{"!", "pix4v5"}], "||", 
    RowBox[{"!", "pix3v6"}], "||", 
    RowBox[{"!", "pix3v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v2", "||", "pix5v2", "||", "pix4v3", "||", "pix4v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v2", "||", "pix5v2", "||", "pix4v1", "||", "pix4v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v2", "||", "pix4v3", "||", "pix4v1", "||", "pix4v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v2", "||", "pix4v3", "||", "pix4v1", "||", "pix4v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v2", "||", 
    RowBox[{"!", "pix3v2"}], "||", 
    RowBox[{"!", "pix5v2"}], "||", 
    RowBox[{"!", "pix4v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v2", "||", 
    RowBox[{"!", "pix3v2"}], "||", 
    RowBox[{"!", "pix5v2"}], "||", 
    RowBox[{"!", "pix4v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v2", "||", 
    RowBox[{"!", "pix3v2"}], "||", 
    RowBox[{"!", "pix4v3"}], "||", 
    RowBox[{"!", "pix4v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v2", "||", 
    RowBox[{"!", "pix5v2"}], "||", 
    RowBox[{"!", "pix4v3"}], "||", 
    RowBox[{"!", "pix4v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v3", "||", "pix5v3", "||", "pix4v4", "||", "pix4v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v3", "||", "pix5v3", "||", "pix4v2", "||", "pix4v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v3", "||", "pix4v4", "||", "pix4v2", "||", "pix4v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v3", "||", "pix4v4", "||", "pix4v2", "||", "pix4v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v3", "||", 
    RowBox[{"!", "pix3v3"}], "||", 
    RowBox[{"!", "pix5v3"}], "||", 
    RowBox[{"!", "pix4v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v3", "||", 
    RowBox[{"!", "pix3v3"}], "||", 
    RowBox[{"!", "pix5v3"}], "||", 
    RowBox[{"!", "pix4v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v3", "||", 
    RowBox[{"!", "pix3v3"}], "||", 
    RowBox[{"!", "pix4v4"}], "||", 
    RowBox[{"!", "pix4v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v3", "||", 
    RowBox[{"!", "pix5v3"}], "||", 
    RowBox[{"!", "pix4v4"}], "||", 
    RowBox[{"!", "pix4v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v4", "||", "pix5v4", "||", "pix4v5", "||", "pix4v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v4", "||", "pix5v4", "||", "pix4v3", "||", "pix4v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v4", "||", "pix4v5", "||", "pix4v3", "||", "pix4v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v4", "||", "pix4v5", "||", "pix4v3", "||", "pix4v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v4", "||", 
    RowBox[{"!", "pix3v4"}], "||", 
    RowBox[{"!", "pix5v4"}], "||", 
    RowBox[{"!", "pix4v5"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v4", "||", 
    RowBox[{"!", "pix3v4"}], "||", 
    RowBox[{"!", "pix5v4"}], "||", 
    RowBox[{"!", "pix4v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v4", "||", 
    RowBox[{"!", "pix3v4"}], "||", 
    RowBox[{"!", "pix4v5"}], "||", 
    RowBox[{"!", "pix4v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v4", "||", 
    RowBox[{"!", "pix5v4"}], "||", 
    RowBox[{"!", "pix4v5"}], "||", 
    RowBox[{"!", "pix4v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v5", "||", "pix5v5", "||", "pix4v6", "||", "pix4v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v5", "||", "pix5v5", "||", "pix4v4", "||", "pix4v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix3v5", "||", "pix4v6", "||", "pix4v4", "||", "pix4v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v5", "||", "pix4v6", "||", "pix4v4", "||", "pix4v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v5", "||", 
    RowBox[{"!", "pix3v5"}], "||", 
    RowBox[{"!", "pix5v5"}], "||", 
    RowBox[{"!", "pix4v6"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v5", "||", 
    RowBox[{"!", "pix3v5"}], "||", 
    RowBox[{"!", "pix5v5"}], "||", 
    RowBox[{"!", "pix4v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v5", "||", 
    RowBox[{"!", "pix3v5"}], "||", 
    RowBox[{"!", "pix4v6"}], "||", 
    RowBox[{"!", "pix4v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v5", "||", 
    RowBox[{"!", "pix5v5"}], "||", 
    RowBox[{"!", "pix4v6"}], "||", 
    RowBox[{"!", "pix4v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v2", "||", "pix6v2", "||", "pix5v3", "||", "pix5v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v2", "||", "pix6v2", "||", "pix5v1", "||", "pix5v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v2", "||", "pix5v3", "||", "pix5v1", "||", "pix5v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix6v2", "||", "pix5v3", "||", "pix5v1", "||", "pix5v2"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v2", "||", 
    RowBox[{"!", "pix4v2"}], "||", 
    RowBox[{"!", "pix6v2"}], "||", 
    RowBox[{"!", "pix5v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v2", "||", 
    RowBox[{"!", "pix4v2"}], "||", 
    RowBox[{"!", "pix6v2"}], "||", 
    RowBox[{"!", "pix5v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v2", "||", 
    RowBox[{"!", "pix4v2"}], "||", 
    RowBox[{"!", "pix5v3"}], "||", 
    RowBox[{"!", "pix5v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v2", "||", 
    RowBox[{"!", "pix6v2"}], "||", 
    RowBox[{"!", "pix5v3"}], "||", 
    RowBox[{"!", "pix5v1"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v3", "||", "pix6v3", "||", "pix5v4", "||", "pix5v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v3", "||", "pix6v3", "||", "pix5v2", "||", "pix5v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v3", "||", "pix5v4", "||", "pix5v2", "||", "pix5v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix6v3", "||", "pix5v4", "||", "pix5v2", "||", "pix5v3"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v3", "||", 
    RowBox[{"!", "pix4v3"}], "||", 
    RowBox[{"!", "pix6v3"}], "||", 
    RowBox[{"!", "pix5v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v3", "||", 
    RowBox[{"!", "pix4v3"}], "||", 
    RowBox[{"!", "pix6v3"}], "||", 
    RowBox[{"!", "pix5v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v3", "||", 
    RowBox[{"!", "pix4v3"}], "||", 
    RowBox[{"!", "pix5v4"}], "||", 
    RowBox[{"!", "pix5v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v3", "||", 
    RowBox[{"!", "pix6v3"}], "||", 
    RowBox[{"!", "pix5v4"}], "||", 
    RowBox[{"!", "pix5v2"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v4", "||", "pix6v4", "||", "pix5v5", "||", "pix5v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v4", "||", "pix6v4", "||", "pix5v3", "||", "pix5v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v4", "||", "pix5v5", "||", "pix5v3", "||", "pix5v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix6v4", "||", "pix5v5", "||", "pix5v3", "||", "pix5v4"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v4", "||", 
    RowBox[{"!", "pix4v4"}], "||", 
    RowBox[{"!", "pix6v4"}], "||", 
    RowBox[{"!", "pix5v5"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v4", "||", 
    RowBox[{"!", "pix4v4"}], "||", 
    RowBox[{"!", "pix6v4"}], "||", 
    RowBox[{"!", "pix5v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v4", "||", 
    RowBox[{"!", "pix4v4"}], "||", 
    RowBox[{"!", "pix5v5"}], "||", 
    RowBox[{"!", "pix5v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v4", "||", 
    RowBox[{"!", "pix6v4"}], "||", 
    RowBox[{"!", "pix5v5"}], "||", 
    RowBox[{"!", "pix5v3"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v5", "||", "pix6v5", "||", "pix5v6", "||", "pix5v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v5", "||", "pix6v5", "||", "pix5v4", "||", "pix5v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix4v5", "||", "pix5v6", "||", "pix5v4", "||", "pix5v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix6v5", "||", "pix5v6", "||", "pix5v4", "||", "pix5v5"}], ")"}], 
  "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v5", "||", 
    RowBox[{"!", "pix4v5"}], "||", 
    RowBox[{"!", "pix6v5"}], "||", 
    RowBox[{"!", "pix5v6"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v5", "||", 
    RowBox[{"!", "pix4v5"}], "||", 
    RowBox[{"!", "pix6v5"}], "||", 
    RowBox[{"!", "pix5v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v5", "||", 
    RowBox[{"!", "pix4v5"}], "||", 
    RowBox[{"!", "pix5v6"}], "||", 
    RowBox[{"!", "pix5v4"}]}], ")"}], "&&", 
  RowBox[{"(", 
   RowBox[{"pix5v5", "||", 
    RowBox[{"!", "pix6v5"}], "||", 
    RowBox[{"!", "pix5v6"}], "||", 
    RowBox[{"!", "pix5v4"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.773606937393517*^9},
 CellLabel->
  "Out[308]=",ExpressionUUID->"2f322b1d-4d08-4bdd-8427-91a6e4e453b4"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"SatisfiabilityImages", "[", 
   RowBox[{"ropes", ",", "100"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6832255563248*^9, 3.683225564852481*^9}, {
  3.683227319251843*^9, 3.683227320145241*^9}, {3.683227354195279*^9, 
  3.683227369746913*^9}, {3.6832274822973013`*^9, 3.683227483713231*^9}, {
  3.683227783468841*^9, 3.6832277891564417`*^9}, {3.773606948730075*^9, 
  3.773606958968235*^9}},
 CellLabel->
  "In[310]:=",ExpressionUUID->"85463176-d96d-4dda-8514-fb0bb8e8ed81"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 0., 0., 0., 
        0.}, {1., 1., 1., 1., 1., 1.}, {1., 1., 1., 1., 1., 1.}, {0., 0., 0., 
        0., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 0., 0., 0., 
        0.}, {1., 1., 1., 1., 1., 1.}, {1., 1., 0., 0., 0., 1.}, {0., 0., 0., 
        1., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 0., 1., 0., 
        0.}, {1., 1., 0., 0., 0., 1.}, {1., 1., 1., 1., 1., 1.}, {0., 0., 0., 
        0., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 0., 1., 0., 
        0.}, {1., 1., 0., 1., 0., 1.}, {1., 1., 0., 1., 0., 1.}, {0., 0., 0., 
        1., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 0., 0., 0., 
        0.}, {1., 1., 1., 1., 1., 1.}, {1., 0., 0., 0., 0., 1.}, {0., 0., 1., 
        1., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 0., 0., 0., 
        0.}, {1., 1., 1., 1., 1., 1.}, {1., 0., 0., 0., 1., 1.}, {0., 0., 1., 
        0., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 0., 1., 0., 
        0.}, {1., 1., 0., 1., 0., 1.}, {1., 0., 0., 1., 0., 1.}, {0., 0., 1., 
        1., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 1., 1., 0., 
        0.}, {1., 0., 0., 0., 0., 1.}, {1., 1., 1., 1., 1., 1.}, {0., 0., 0., 
        0., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 1., 0., 0., 
        0.}, {1., 0., 0., 0., 1., 1.}, {1., 1., 1., 1., 1., 1.}, {0., 0., 0., 
        0., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 1., 1., 0., 
        0.}, {1., 0., 0., 1., 0., 1.}, {1., 1., 0., 1., 0., 1.}, {0., 0., 0., 
        1., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 1., 1., 0., 
        0.}, {1., 0., 1., 1., 0., 1.}, {1., 0., 1., 1., 0., 1.}, {0., 0., 1., 
        1., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 1., 1., 0., 
        0.}, {1., 0., 1., 0., 0., 1.}, {1., 0., 1., 0., 1., 1.}, {0., 0., 1., 
        0., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 1., 0., 0., 
        0.}, {1., 0., 1., 0., 1., 1.}, {1., 0., 1., 0., 0., 1.}, {0., 0., 1., 
        1., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[
      RasterBox[
       RawArray["Real32",{{1., 0., 1., 1., 1., 1.}, {1., 0., 1., 0., 0., 
        0.}, {1., 0., 1., 0., 1., 1.}, {1., 0., 1., 0., 1., 1.}, {0., 0., 1., 
        0., 0., 1.}, {1., 1., 1., 1., 0., 1.}}], {{0, 6}, {6, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{6, 6},
     PlotRange->{{0, 6}, {0, 6}}],
    StripOnInput->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.7736069510536413`*^9, 3.773606959582582*^9}},
 CellLabel->
  "Out[310]=",ExpressionUUID->"61435ffb-639a-4581-a8b2-f09c53a01ccf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"RunWalkSATCRN", "[", "ropes", "]"}]}], ";", " ", 
  RowBox[{"ropes", "/.", "sol"}]}]], "Input",
 CellChangeTimes->{{3.6828853321486807`*^9, 3.682885373829384*^9}, {
  3.682895498786302*^9, 3.682895508473031*^9}, {3.6828956392906313`*^9, 
  3.6828956418029633`*^9}, {3.683228883455316*^9, 3.683228887478694*^9}, {
  3.773606978197034*^9, 3.773606980474711*^9}},
 CellLabel->
  "In[311]:=",ExpressionUUID->"d0229289-220e-4315-8530-21b788c3183c"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.682895652923731*^9, 3.6828995710001993`*^9, 
  3.682943531352207*^9, 3.682994257807015*^9, 3.6830691591064987`*^9, 
  3.683165192331099*^9, 3.683221729483575*^9, 3.683222271057686*^9, 
  3.683228931352107*^9, 3.773606983824901*^9},
 CellLabel->
  "Out[311]=",ExpressionUUID->"fb410bb9-bf40-4152-b0ad-5e25ded48b79"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ropes", "=", 
   RowBox[{"CornerMembrane", "[", 
    RowBox[{"17", ",", "17"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.683225045495026*^9, 3.6832250524747*^9}, {
   3.683225086195566*^9, 3.683225087786372*^9}, {3.683225548463438*^9, 
   3.683225551132901*^9}, {3.683227336435286*^9, 3.6832273658028727`*^9}, {
   3.683227478569496*^9, 3.683227480185129*^9}, {3.683227894168249*^9, 
   3.68322789513592*^9}, 3.683228140642571*^9, {3.773607008771453*^9, 
   3.773607013940501*^9}},
 CellLabel->
  "In[312]:=",ExpressionUUID->"fc7aed5c-643c-497f-b387-d5070c6c1738"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"RunWalkSATCRN", "[", "ropes", "]"}]}], ";", " ", 
  RowBox[{"ropes", "/.", "sol"}]}]], "Input",
 CellChangeTimes->{{3.6828853321486807`*^9, 3.682885373829384*^9}, {
  3.682895498786302*^9, 3.682895508473031*^9}, {3.6828956392906313`*^9, 
  3.6828956418029633`*^9}, {3.683228883455316*^9, 3.683228887478694*^9}, {
  3.773606978197034*^9, 3.773606980474711*^9}},
 CellLabel->
  "In[313]:=",ExpressionUUID->"617d67ae-24ba-46c8-afde-06185424c335"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.77360706524004*^9},
 CellLabel->
  "Out[313]=",ExpressionUUID->"d70f3433-771e-49af-b542-3e879e627163"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AssignmentImage", "[", "sol", "]"}]], "Input",
 CellChangeTimes->{{3.773607071806995*^9, 3.7736071074276648`*^9}},
 CellLabel->
  "In[314]:=",ExpressionUUID->"504cf3f4-27df-4f9d-9d1a-a200487b925f"],

Cell[BoxData[
 FrameBox[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GJ8ZyACfODZ12NQQYy+6Gfj04HMbIXli3UYojAmFET53Y9OHKzzQ1ZLjRlzu
IsYduOwk1h+E/ENqmsUX5uSYi66XkDm4AL4wI5R2iYk/SvxJSZhj+gkAC8qc
nA==
     "], {{0, 17}, {17, 0}}, {0., 1.},
     ColorFunction->GrayLevel],
    BoxForm`ImageTag["Real32", ColorSpace -> Automatic, Interleaving -> None],
    
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->Tiny,
   ImageSizeRaw->{17, 17},
   PlotRange->{{0, 17}, {0, 17}}],
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.773607108835093*^9},
 CellLabel->
  "Out[314]=",ExpressionUUID->"8f0daf41-6396-4a2e-8dc6-f6ba8c1af1b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"AssignmentImage", "[", 
    RowBox[{"RunWalkSATCRN", "[", "ropes", "]"}], "]"}], ",", "10"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6828853321486807`*^9, 3.682885373829384*^9}, {
  3.682895498786302*^9, 3.682895508473031*^9}, {3.6828956392906313`*^9, 
  3.6828956418029633`*^9}, {3.683228883455316*^9, 3.683228887478694*^9}, {
  3.6832297553986607`*^9, 3.683229773701606*^9}, {3.773607137701159*^9, 
  3.773607164829008*^9}},
 CellLabel->
  "In[315]:=",ExpressionUUID->"9db32e0c-2e23-46de-abe4-563faafd6d9b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GB0gi6HLY9OHzTxsZuAyF587sJlLyE3E+pWQGmLDjdhwxeU/Qv7GZz4x4vjC
EyaObj8pZuCKd3zuw2UXsWFAyC50eXLjjxx16ICUuCQlzHDZhQ8Qk0eIdy8A
d6WNsA==
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GNkMbACbOLIYNjOwmY9NDT670cWJMYNYP2KzkxgziLUTF0B3Nz5zsMnhCwdy
3UFqOOAKE0LuQbcbn/3kmEGpX8jFuOzDFe6kpCtcfHxmE7KXGuECMQMAl8+T
qA==
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAaIUYOsFl0fuhnYADY5dD34+MT6h5AZuOwn1gx84YBPjFK/U+puQnFLiRnY
aFq4AxsgJS0QCnts7sAX3tjMxKYXlx2EzMYVvvj8TUq4koMhZgAA1RiYIg==

       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GJsZMIDOxqeGVDPQxZABJW4nNVxwuQuX29DlcfmN2HAmFH7o7sDmHkJ+xmUG
vjgjZAaxagn5CV8YE4o3UsKAkB+pbQYx5hDyNzHhSMguUsOVWDc32AMAaeGZ
oA==
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GNkMZIAuhk0fNnfgEsNlBi7zCNmLKwxw6SPHHmLCDJ8dlJpBjN9JtQNbuBET
3vjCj5jwR9dHKLzwmUOsPYTCAN1ubH7D5S5s5pKSBonRQ8gN5NiLT55YDDED
AA/ulSY=
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
mBAgpIdY87HZRchcXHoJ2YdOkxpOuOwixyx84UENdfjUo4th8xeu8CYmfMkN
Y3S9xPgHl9tJNQOX/bgAsemZ1HgkFF64/E+svfjSBCXpF2EGAGSnmCI=
       "], {{0, 
       17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAaIkcMGkOUImYHPLmLk0e3BpR7dPnxuxWcGIf9TGvbExAsuvxDjDmS9hOKI
GDMIhRUxcUZOuiDWDFLDFJ88Oe4hNVyJCUt8agj5g1bpFmIGAC7cnho=
       "], {{0, 
       17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GBvAJo9LPT4zsfFx6cNnNzZxQvbicwOxYUfITcT6n5J4oTR+ccUxLn/g8zOx
7sVlBqXxQk0zKAl/UsIHmzipYUzIv/ROUxAzAAtMnho=
       "], {{0, 17}, {17, 0}}, {
       0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GN0MQgBdHS4ziLEPl3nEmEGM3YTCh5C/sPHJCVNS3EKJO7CpIRQe6ICY8CZk
Bz5zCPkP2R5S0is2NYTsINaPuNjEpilcZuByH6F0RcitxJhBCYaYAQDH85mg

       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False], ",", 
   FrameBox[
    GraphicsBox[
     TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwieOyA10Om3p0d2IDuMxGt4MUP2PTR4oZuPyBzy+EwpSQv7Gpxxc/hPxK
iRno/sXlXlL9gw0QSk+UpGdy9BNK/8T6A5/dhMIL2f3EhBUpcUJJmKC6DwDa
rJIq
       "], {{0, 17}, {17, 0}}, {0., 1.},
       ColorFunction->GrayLevel],
      BoxForm`ImageTag[
      "Real32", ColorSpace -> Automatic, Interleaving -> None],
      Selectable->False],
     DefaultBaseStyle->"ImageGraphics",
     ImageSize->Tiny,
     ImageSizeRaw->{17, 17},
     PlotRange->{{0, 17}, {0, 17}}],
    StripOnInput->False]}], "}"}]], "Output",
 CellChangeTimes->{3.682895652923731*^9, 3.6828995710001993`*^9, 
  3.682943531352207*^9, 3.682994257807015*^9, 3.6830691591064987`*^9, 
  3.683165192331099*^9, 3.683221729483575*^9, 3.683222271057686*^9, 
  3.683228931352107*^9, 3.683229739886231*^9, 3.683230145163266*^9, 
  3.7736073948243647`*^9},
 CellLabel->
  "Out[315]=",ExpressionUUID->"44c4759f-7d44-4791-b050-ca33450db3a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"WatchImageWalkSATCRN", "[", 
  RowBox[{"ropes", ",", 
   RowBox[{"{", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773608003372048*^9, 3.773608070520596*^9}},
 CellLabel->
  "In[318]:=",ExpressionUUID->"0cbaae70-1efa-4b18-a33b-b96e849cbccf"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i28$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i28$$ = 1}, 
     "\"max\"" :> {$CellContext`i28$$ = 1000}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i28$$], 1, ""}, 1, 1000, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i28$44530065$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            TagBox[
             StyleBox[GridBox[{
                {"\<\"\"\>", 
                 AnimatorBox[Dynamic[$CellContext`i28$$], {1, 1000, 1},
                  AnimationRate->Automatic,
                  AnimationRepetitions->1,
                  AnimationRunTime->0.,
                  AnimationRunning->False,
                  AnimationTimeIndex->5.,
                  
                  AppearanceElements->{
                   "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons",
                     "DirectionButton"},
                  AutoAction->False,
                  DisplayAllSteps->True]}
               },
               AutoDelete->False,
               
               GridBoxAlignment->{
                "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "ListAnimateLabel",
              StripOnInput->False],
             {"ControlArea", Top}],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhGJmN
i4+uHlkMG41NHpeZ6PpwsdHNxYZJcQs28wi5BZtebGbiMo8Yd2DzHz4xXPpx
0fjiGBfAF8aEwoRQOiPGnYT8QKrZ2NyKSw2+9IIrbgild2z244sLYsIHl5m4
7MFnJj4/YnMTMfka0wwAWTp1EQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 2->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhGJmN
i4+uHg7skTADpjw289DNhJuDLobFPHS3YDMXncblFmzm4bMfm/ux6cdnHlZ3
YLEPl7+w+hUJ4woDbH7H6h+0+MTld7xmMCDcQihdEetOQn4g1Wx0gE8N3vSC
Fvb40iUuu8EAT9oiJgxw6cHlbnS3Y1OPK+4w/ILHn/jyGQMDAFN1c0Y=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 3->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwhGJmN
i4+uHg7skTADpjw289DNRNeHi41uLoaZaGYRcguGHJpfsLkFaxhgMRM9LPG6
A0d44IsTFLORMLqd2GiccYwjDLCpJcYMQn7A6U4i1BDjH0I0uv9wqcGVXrCF
PS6Mbg8GwJO2YPLo+QzDrXjUYLUHl3o84YnVL3j8iTPcwAAAtohzPA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 4->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUlsKwkAMDP2Q/noEr6AHWLxCPcEK9qsgtB/Svx69torEycxuIPsg2clM
Nqf7s+sbM5va99Ll13Uc83w7bJdHHi7nYQsev262pI/7s7pj/s+Sc4txhoeY
+E6dETdgAlaNS4iBFsaF9oBgKjzKQ/SD6WL/5OugdrbLP0bOnnfimkoYQUMC
HMWTaaxoYFxqu7dSjpoXpks51mH11WztJvr+h1nI8TiMe9BEOEktBZ2yb/u7
FYh3cHc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 5->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMDD1Ir32CX9AHLH6hvmAFPRWE9iC99elaFUknM3Eh7W6ymcxk
s7/c+1tjZlP7+vT1cRrHOp936+Fah+NhWIPd18yW8jG/V2e8/1tl+8c4w0NM
zFN7xA2YgOV9jEvg6Y34GX/kI/EyHkkMdbF3MuAYeiC0Bz0JZyu8RxlG0FAA
x3TtoPGPBt8Lmkf8fqlaWCP4hF4672J2PJ6Kq75vuCZ3PA7jHjQRTnTGERNi
sm/vvCchSHBx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 6->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAMHPwQfz2CV9ADFK9QT7CC/SoI9UP869G1umB2dmY1kJLNY5JJ
sztf+2EF4LZ5ffp0P05TepzWy+OSxsN+XILbrMDcfTTa7s35b+myoqyLovAY
k+uczbhz7h/tCtP0kjyixhrqI2dSvFqYqOdWMeZV+ITGnVS7IO6c29oDVF+e
iTDcvOpfKR7/cnB8fvmjuF7co/IZvvLe3e1A5LKYvRezNnIijrwh5iRmYjzm
pWLqvr91T0gPbyw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 7->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk0KwjAQhYcupNsewSvoAYpXqCeIoKuC0C6kux69VgNOXt5LHJgySefv
m8zx9hwejZnN7fszhNdlmsJyPeyHexjPp3H/2UU1W/uvelud0f8jfVRL47yw
fJgT45SNeddY39tZTlGLcnj1MaJOIoxL5DTIWeoRuZI7on4m2SyAHX1LczBW
F3sibKxf9laK4x+GGo+aSSKEK2N3UuLCXff91Pa5upeKWzBk+6p2iPhjT9gf
csk3g5hf3AZ3Nmyk
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 8->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkkOwjAMHHFAXHkCX4AHVHyhvCBIcKqEVA6IW58OLQWS8QzBkpu48TJj
e3O8tOcFgOvq+WnTbd/36X5YjsYpdbttNz6uZwWG5qX5fbIbsoHgP8ns+377
nJmq/CEHYh11z0VhtVgQ/zMGxl3EmDqFiF7B5Az9+YGReQ0Kq8hX9MBwZ1+Z
U/FzmAQ3xutm5Xj8w6HGx/WkEOIs9yMTNQfeR9Wb2j5zXTeT0HPDIexrZYfs
vnFNCF5uZhTzjXsAPHJsoA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 9->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwkAMs3ggvozACjBAxQplgkOir0pI5YH43ejQUlDiOIVI17s0qWO7
tztf224F4LZ5PdpyPw5DeZzWY3Ip/WHfj8XtvIDavJc9T3lDORD6p5h7P7Xv
ThiMHzAQ56izDcU15YL4njlY3uGbZI4L4RUSTBDmEkfWVRVXgec8SLRzr8RU
+jJOpia5QmtSs50vGcafeqraOcSMJe3qP/B9VN44HBOhV3iSefDTJ6Elu0Pp
feOZELqEfzzf834Cs5VtHA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 10->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwlAMHFyIW4/gFfQAxSvUEzzBrgpCXYi7d3RtFZnOm7w2kL5fMplJ
c7je224D4LH7fNr0PA9Del224+GW+tOxHx/3Pwdy83XeT+dGzkARP5nk/1fB
UHzF4Pzans1xVSy+03urg51zgjozM71CgAnBrHFUXdlxNXj2v4h2jbWYTl/E
id4sV3hNiln0JcJYqSe7Vc3UKLRHs2Dw1W0PyYpY5VTpwWKfjJZohsJ5MzWz
y3PzR/XnGG/WZG5Z
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 11->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsOgkAMnPhB/PUIXkEPQLwCnmBN5IvEBD+Mf3t0xQfpTqcLTcpuoZ1O
h+4vt67fALhv348uPU7jmJ7nZgquaTgehunj7udAbr9u75+4pRhlDv7vqH4+
RX0OMEH1tbs1xZWxCq7wXCyHOVfVBH0kH1HHmCDMGkeeKyuuAk/+F+LJuRKL
NbJ5zAlwWhVcoWdiTKdLhLFynqxONtHDzR7tgsBnlxoac7nMqaLBok4Ls0T7
yJzkLFyn9s/0LzFegLVvmA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 12->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAQCx7Eq0/wC/oA8Qv1BRXsqSDUg3jbp2txi5lsRgem7DKzmSSd
3eXWDSsA98370/WP0zT1z/N6vlz78bAf5+K2JlCOn0RNvhe+1wj9+PYtZxis
pV4STFCd57gzh+OqWIErWi7MoQj/8CaZE8J4pZ4EzYTJfkI4qi79Z1kGDxLt
RXozjEZfxglovApc4TUppvqSYvzTI1i2Tn06w2HYXTD4mtZDiqZXOf3woNmf
xOtMS7aPyslq0Xdu/2h+xHgBC9Jtlg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 13->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UkEKwkAMHDyIV5/gF/QBxS/UF6ygp4JQD+Jtn67FLSaTyS6k7JJ0MjPJ
4foY7xsAz933M5bXeZ7L+7JdHrcynY7Tkty3AOrwC7Sw72rf7bh6/OvWOwTW
mq8JJkze9lF3exRXxnJcEblYDqzL/ZP0cUd4xZ44zQbT9VX+CQ8DtvA/eEHa
wzwSDNaXcgJy/tyf5672ivt1NNi6bLYyb+q4h8KQuyDwOdhD3qFQy5w6Hqj9
CTUdLUF3MlupZdCYalcixgcN/m4Y
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 14->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJx9UsENwjAMPPFAfBmBFWCAihXKBEGCVyWk9lHxy+hQkQjnfI4lV0nt3Nln
n+6v8bkDsBy+nzGt13lO79t+uzzSdDlPW/BYHMjDz1Hc3rO9F2vy8c+rZwis
Gs8BJkzc8qizNcazdVlOCCxVA+c2b4Q+zoRWrIniYz2lfkJDhy30d1pQ724e
AQb3F9YExPUzP89d7RXzdXqwedFsZdzkMUc1pXn0j3tnbZp+4Tm49t5cHVZH
J6WH2s/ebGUvg8ZUu+IxPq1Ub9k=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 15->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsTbPl2LW0xmJ2sX0m7YMJOZ
5HC998MGwGP3+fTpeZ6m9Lps5+SWxtNxnB/3JYDcfQMlbJ5tXo6rx69uuUNg
Le+5gWn/rbs9jGf7cpgBl8NlXcSj/KmO0sUh+NhP6Z/wsMIW/ldekPZqHgEG
6wt7AuL+mZ/nrvaK+RoabF00W/lu6phDYchdEPjRrNbss+xJzNV5hz81Skuk
O5gtc2buK9o/04PHeAOrlG+a
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 16->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwkAMs3ggvozACjAAYoUywSHBqxJSeSB+HR0qWsjZTuGk9O7a1LGd
bE7X5rIAcFu9Hk25H7quPI7L4XIu7W7bDh/XYwD9/h0YI957uks+vnnTGQar
p3/ju+l93OfOcTEe8/zsSa0Kl3VRHeePLKeLw9RjP61/xkPBNr0UL0i79MPh
GX0pJyDnn8yQ1CZ/xMtEQ8xzvHm2ZZkaop34sb6In/Xqn3m2nExfK+/wI2dG
i+hOess1nXY7f4FDjfEELsRxGg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 17->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsENwjAMPPFA/TICK8AAFSuUCYJEX5WQygPxy+hQ0YJzPqdESmInzuXO
9v5y6/oNgHvzXrr0OI1jep63k3NNw/EwTJe7eQK5/UzM0/qZfBePX9xiQ2Bl
emvPlnO712w7GI95fvfgrwJX8CreiPy4Eegq8sKxIp8qh5z/3PpYVM4j7a4e
Cg/6TnICHPeseAheRY5UPVUfClvxZi6ypyJegk+kz+JHtfqnnyUneu90r8TX
tMj6kE7+k/st0lngOYwXn3huGA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 18->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbnq7VFrKTie1CupvsdjKT
5HC9t90GwGP3+bTleR6G8rpsR+dW+tOxHy/3kwHW/AyTed/IV+/nd98l4ubu
TcTmOFRMnP1iPM7lsRmLOUDwYn5cn4xP4O3rQvnAeEkNuf7cAzAWW6I99CPr
rbiTnIDA3RQPwauqkdCtcqqz4s1c5Ew19a4wmB/r8/hZr9bMc8Up+T/oXnj/
T4vsD+nknDxvmc4KL2C8AcA2b1c=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 19->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEOwjAMszggrjyBL8ADKr4wXlAkdpqENA6IW58OgyElxh6VsrVJ6thJ
d+dr168A3DavT1fvx3Gsj9N6OlzqcNgPU3A7G9DKxzBbPHNM5X/z3kv4VW6L
d5DrJZ/Yx9WKtninBe7sT7jMi/UpTYYP60pG9cB4rlfEW2Iv+J32n3m42YqY
5AR4/jwT4pV6JPou36HYK97MRb6pkv8Kg/mxvojvZiVrqz4CsudW95/8JS1y
PqSTayq9jqfDQ3kCyZ9wkA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 20->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEOwjAMBFccEFeewBfgARFfKC8IEpwqIZUD4panQ6GgdDtuI7lpYsfe
XXt3vjXXlaT75v1p8uPYdfl5WveHS24P+7Z3bgeTSvqaBqvP7qP4X9xnwT3F
lvqNxvX+y/2wSmIjLJ7LMSh6r1ifCI/zIhxKxhtwF6g3uaNeBHWJ+5Juk54E
eSkHYnVdFGvuuqMf/gm3Y8GZSuPdY7xPxK/OH/UKa5OOEmoe8l6Idz1o5uZ4
ek3iS7M4l0/pBedIb5A=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 21->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwlAQCy6kW4/gFfQAxSvUEzzBrgpCXYi7Hl2rFeZlEvtgWt58Mpm8
2V9uXb8BcG/en648TuNYnuftfLmW4XgY5uBuMWBqv4bF4p1jKv+X9znCL3Nj
DbQPHOdDPaIpLozFc8HVw+tjY8gx5pG0aLVf9VO6sr6q70QYCU/olt7E4CoM
yVVoX9WhxpRzmRkiNvNmLnanwp9z1Ds5nmknnaaEzztk31jNvZLPekDV/JmT
e6p51S5WeAnjBQMnb80=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 22->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPwQfz2CV9ADBK9QTxDBfhWE+iH+9ehaNLiZnU0bSLvZx+zO
JIfrves3AB67z6fLz/M45tdlOx9ueTgdhzm4/21gSt+N9Lf5jLIhfOUM7Ze5
psbWWR84zkvMPFkM6stYzAtRPeVWnKIYfIzncFok7Vf9lK6sL9vMne1IN3cn
gk+EIWcV2ld1qDFbXCI+WDFL+KbMP3q7JUfxU3cnccRyOgJe7xbvhXyLyVzk
/RBP7qn4Kr1aeEhvGQdyiA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 23->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEOgkAMnHAwXH2CX9AHbPwCvmBN5ERiAgfjjacDBmJ3OkU36cK22+nO
tKf7s2krAEM9b01+Xfs+v2+H5fDI3eXcLcHjasCY5m210Rjo/2MQvu0M7Y98
W47Nsz5wnJfAK3CpLmMxL0T5gUa7MfgYvwOJeCftV/WUrmCsoHcWw+EJ3VxP
An0Uhnyr0L7IQ4m5xyXigz/eEs6U+arZVfOi5sHNZKSpWU5HlHmc73j/uG8x
mYvsD/HkmmpWlV7K/8WYAAklckk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 24->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/QL+gDFr9QX7AFeyoI9SDe+nRbaWl2MqlayNJNNpNM
JlVzr9sdgMdhPOr8vPR9fl330+WWu/Opm4LH2YAhjcdsgzHQ/8cgfMsd2s/v
Cx/KPOsDx/kTeAUu9cJYzAtRfjCjf2PcBxLxTtqvMJUGYKxAO4vh8MTcnCbB
fBSG7FXMvsgD9bjBJeKDH3qRO2Vqu74Cnbb0ibSKars5Ak4Pm+94f3lvMZmL
1Id4ck21q2oXlX/FeAN7u3OK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 25->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKgzAQHHooXvuEfqF9QPAL+oIU6kko6EG85ekqKM2Os2oggexmJzOz
+/z8quYGoC/mo4pD2XVxrO/L5Rvb96tdko91AynMx7pTttV9e5/XbO8YS9Zz
DLYuj4HztBRHg0tcGCtxzqt3PDrMYZ9jHgikO+i457/EFl7vdMDyPPNN6hH+
KAzJVXhv6mAxj7R4enCBi5opo5N5OX1SPZcz6XjK/zKe22Ol++R9jil7yf0h
nfynmlU1iyr+x5gApd10jA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 26->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwjAQHPyQ/noEr6AHCF6hniCCfhWE9kP8y9FtoZXN7Gy0sKHJPmdn
jrdn/9gBmLr56PPrMo75fd0vl3sezqdhcR5WA0qaj9WKMXXf4m3OFse1ZD6/
oc6zb2A/fSXF9s23RrUYF6L8YEdNH7yP50Ai3Em//7N/x4X4Z+yKJ7U3iUfs
R9VQ/Lv+oDzUNVtYHJegnTZmUTxXOHmuhl4UP06TwU65L2so5Fjh/hFvayou
nT4IJ/dUWlVabOvtA0Q/dYg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 27->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwkAMfbgQtx7BK+gBSq/QnmAEXRWEupDu5uhtoS3Tl5eIDqQwzSR5
n1zur+Z5APA+TZ8mfeq+T0N7nC+P1N2u3Zw8LwHkavoskYtQ9/V9WROFqed/
gMGwHc7TyZUfW73ou+aZF7x6R6Nfc4pfqTPj+Fd/xmN4CFyRbtInoY/qofw3
80F12PeMuBgvQZoGWNTMHU/GFeyL8sfspKMpz82c9zxWvL+8L3sqL81+EE+e
6e6qyPn7NgKROHSI
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 28->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB7Eq0/wC/qA4hfqC1bQU0GoB/GWp9vCWuJkZosLWbrN7mQy
mcP10d83ZvbcTVtfXudxLO/Ldj7cynA6DnNyX8PMu2mr4SHY+Xvf67eF/9bl
aOEtGMBhWZiHhVgJF/kAFvZl6r3Q6N8c6y/qgjxW9ReBfFIfhFdLNzonok/E
kPxZfYPa9ouJmjAfqtqRJ/OiWs54NfzC5pM8KTTFuo55NWPW98r9iMlmmfwB
fWJN6VWS0377AMUgdIw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 29->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDgl+oL4igp4LQHsRbnm6LsWxnZwMGNjTZ7czs
ZI+3Z//YAZi6eevz6zKO+X3dL4d7Hs6nYUkeagAlzVuNYkKdf/WlfsPcI/lo
4a0Y2ObXxXlajOVwWQ9hcV+I/g88+jfHOpCo76TvQ/+DYD2uD6Gr5Zt6J+WP
xQj1K34QN7aY7InzCTG31Sm1iLlyPhFG9E6s281k4CnzFs5H76r6NvVNPtEL
43KfijOcVeWPmJdv3QfwpXPN
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 30->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUlsKAjEMHPwQfz2CV9ADFK+wnqCCfi0I64f4l6O7C7VkJw+xkNI27cxk
0sP1Mdw3AJ67eRrq6zxN9X3ZLptbHU/HcUnuWwBS5qmFqPD23/vS1lDnKDYy
vI6Bdb4PzhMHYxlc1uNw6boQvQ88+jfHOlCo7uKfh/4HwXpMHawLuW9enzx/
NEaoP+HvmFhjsifGJ8TcWqerRfdDDfF0/egT6zZ/MvCUeYXzSV9N3ep+ypdx
wK/T8zr8q54/gW6UDyQNdUk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 31->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAURAcX4tYjeAU9QPEK9QQR7Kog1IW4y9FtJYY4f6Zg4YcmP3l/
Mj+H670fNgAeu3no0/M8Tel12S6TWxpPx3FJ7ksAuZuHErkJNf/uz+UfzTq6
GGu8ysBvvn6cpxrMCtxWC4gl7gV33nj0by5oIV9YR+Cx/yZYj6pvmeyb6onx
p2XY97NSvzKhNfEZUD1Vu9UptdDbCPcUDNcn1m176LwWPsrahu2YoYdqjRjq
nsprpcXlpO7PvjceQnNF
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 32->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkEKwjAURAcX0q1H8Ap6gOAV6gki2FWhUBfiLke3lSjDz0zBwk+b/ObN
5Ocfb1M/7AA8umXo8/Myz/l13a+Tex7Pp3FNHmoAJS1DjUKh5t//S/3+PIne
IbZ4zOB8wwWtG7bkKiZaL+xf7Xc1+jfHPNaD8dHwYv1NRD9K3zJheAg5UR9m
2P7Z0P8xoT3FPQh6Spt9Si+hN5pzql4y+tG3vUNXa1FHqW3YjtncoVoLDHVO
VWvlxeXcfSG9AY8Zcwg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 33->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBwS/UF0Swp4JQD+ItT7eVFLaTGdSFTZtsMzM7
28P13vUbAI/dtHT5eR7H/Lps580tD6fjMBf3NYGSpqVmCan2y/elvn8ihSdl
+ZJLRL4GF+H8R2yLiba3qN/1pjz6t4bIFfhgdDR47L9J1qP4LSYMHqgGfV95
73po9sFvpYnvgPjs3NX/oeYRQ3DZOWHtEfMozsZrdZe0qLkyj9O+wlNnhKH6
VF4rLa7m5oX0Bis7dAo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 34->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDxIrz7BL+gDil+oL4hgTwWhHsTbPt22RNxMZi0NbEiyyczs
bI63R9fvADybaerS6zKO6X3dz5t7Gs6nYU4ecgDWTlMOc6H23/uW18twObRl
2EowRnWGHyfjr+GawkRdm9cudQUebc0VPjk+BDoqPPY/CNaj+I20FHUrPFCO
1v+8j2qo9s5vpYnfgPjCvqv/ofrhh+AK+4TSI+ZRnJXX6i1pUX1lnkh7gafO
CEPVqbxWWqKc1L3c+wCSfnOK
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 35->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBi1+oL1jBngpCPYi3fbottDI7mZUuZNkkzcwk
6en+7PodgNdhurr8vo5j/tz2s/PIw+U8zMnjYkBJ07VYIXP++j37cG9T72w9
zPc7muf4BlyLidgba1ddECxXtzVXzYn40NAR8Nz8hRsp6nH8RbRUfTtcmb2+
/82+1UPwad5Ok9Y4Ho1xrdXi9qIzIN/uCXVceRxnmDVMrWhxe1WelvYKz8UE
w/XJObeXoN38k25fSF8S5nVH
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 36->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwkAMfbiQbj2CV9ADFK9QTzCCXRWEdiHu5ui20krm5WVoIMNkXpKX
z5wfr64/AJia+ejS+zaO6XM/LsYzDdfLsICnVYHczseq2aiyN39rQ91FvNJN
LN9fGLfvO/LKnPC92dq5LlAuFbcXK+Zk+BDU4fKp+RM3Wl+P8wHxgfoOYgqM
7tHsaz0428xbzY5jrE917+K/KLwQ5qrtCeW74on2oHqWfzDYa7UfUafNGXJA
92mxzLl5vgKTdf/8viRAdIg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 37->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDxC/UF6xgTwWhPYi3Pt126SGZTGwLWzaZZDaT
5Px8t90BwNjMv7Z87sNQvo/jYrxKf730C3haDzDd5t96JnPYrj54vH7qnuQr
PluD9YFxeGyLV3IiarO1c10gLpW3F3N9Mu8hqSPwUf+ZO3BlMYg6nZ3kOIzu
We//aQi26bfqHefYmM25834ovfDxSqucE7xfvZPNQWmWO5jMdZce5lM+sR+s
U+6OqCXDZN017gd6yHVL
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 38->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwjAQHDyIV5/gF/QBxS/UF0TQU0GoB/HWp9uGCpPJbK2BhGQ3mZ3Z
yeH6aO8bAM/duLTpde779L5sp8MtdadjNyX38wSGZlzmOdDUc46h3Ofxfc/7
4L3DY8wKl/LFWIHLGnioNuYecXA9+jdX9InqIeBR4Un/FbvCiu6g1hl6usZr
5bTUE9cXUA31PNIid376rv+jkZrmfzmt1ieUcVcn8sFpjrxwvq7So3guZv7H
krdcS7lEPC3vjPEBDCR2DA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 39->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3fbq7UiWdZLoaaGmTdjKZ
ZHe+ddcVgPtm2rr8OA5Dfp7W8+WS+8O+n4PbsoAxTVtZo1l8Z9/XPv/tWfx3
eMUiHyhe2Q+4lq81V0fymMwh0ujfWKWTyQfBw+EZTOePsNQb+DplTxs9kZwW
NHG6wORQb7g+erPYd56PRDmD+ar8rT4h1lL2sKEp6xjmFtiyHsaLfMF8tHpr
czEXxTPk/cZ7AaTudo4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 40->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMDB6kV5/gF/QBi1+oL1hBTwWhPYi3fbptqTidTLa4kIWdZCfJ
JMfbs33szGxoxqvNr0vf5/d1Pz3uuTufusl5WMyspPFarIDxm7H5wF/mUv8d
n/14FPY9K5ziI16sF4/rI3lOrkFp9K8PdcJ8FtTh+IDT4YpLYIU4UBPXt9JP
xXBNG5o4XQxyRDGiB4zZnDvvR6KcYr9WeG1OprUMZ1jRlHWUuQPusB/mU5jY
j9psMRfXEvlk3TPfBxIDdw4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 41->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDyIV5/gF/QB0i+0L1hBTwWhHqS3Pr2ttJCdTHYxkKWbpElm
Zi+Pd/s6APiclqNN32YY0tgd18sz9bdrvybPmwPTfTk2n4zznWNgh4/z/67f
bkFstyxO9VFfu681iaOyg+Lo35zlyc5DsIfkGl6PmnZuDjxOiVvw577VTkHO
6ck8oVAjMNiaqu4BPxlW5PVZvKST4CXSQXHKmCMt+J1JjRUe7qdi4n2UtLWz
eJcoJ/f+9ZsBmSp5Dg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 42->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMFH2UfDtCV2gHMFkhmcCF5hUIpI+Sn0dPAi7Ip5NdgUwsxafT
SffXMkwXEfl0xzHEb7+ucRuv5+Ud5+djPpO37CIpHEf2pBzvGBPt2TCO7w3e
z5xYgSv8fw9X89VG+2hwYBphDnVieghgFxwDjyd4a+o0ZmfqiO2T9k30M9+M
k5Nz90TjNnaJ8vln7o4+Ra/KkB9y0JhMF28OTFPs2ZtFbeeq/SAei5H9qM1W
10IuXs7bvxR2qph5UQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 43->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
IGF0ProYAzKGAnRxdP0Y5sEADjEUcxlwqMdhLrIcMsDnD1xuwBZGpMqhhxWG
G2Fy+MKaATM+CMUdunnIZiC7A8PfWMIPg43NTTjkcKYTZHMJpCWs7iEm3nGE
D4pfkQC6+9DdgGwmtnDBFQ/YwhTdz7jiAlu6Iso/6OYxYNqBLX3gi1tku9Dd
gksOm1qIeQDTJnmQ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 44->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHHoovfYJ/UL7APEL+oIt1JNQ0IN426ersIXs7KRrIAtJTJyZ
5PH+dsMFwHzbny4s7TSFtb8ewSeMr+d4FO/JgdjsT/JonGPOwXoyznN/Me9n
Ti6bC+d7Z66tWVOcGC9jUBr9rTl6QGABzbNxgRF17KqXtVA4C95CP8mNMVVq
hS52buWWJJ4ze3f0ybgaY3yMwc5Uunh7UJoyZ28X6uYUnwwj4eT/MN8z+8t6
BU+v5t1fbDY0EXqS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 45->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUkEKwkAMHDwUrz7BL9QHFL9QX7AFeyoI9SDe9um2sIXsZILVQJZu0sxm
JjkPj348AHgel6NPr+s8p/etWS/3NF3aaU2eigO5W47i2TjfOQbrxTjO9Q5v
syBW4SL4P8C1OWuKE/fLPSiN/slB9OJykdai/0hrpY/VgnlK3kI/9014rL3K
sS4V7pddkv3smXugT8XVGPcnZ8hvmtq9c1Cco1movVJ83J4xHvwbv8yvqhU8
o1y0f7n7AJ3bfBI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 46->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEQCx7Eq0/wC/qAxS+sL6igpwVhPYi3Pt1dqLLNJF0LU+hkZkgy
PVwf/X0D4Lmbrj69zuOY3pft/Lil4XQcZnBfAsjddJXIi+A357CMcjjP/WHe
95hcNZdOkydqTPUpHY6D9chgrg+CS8Cc14K/85q1VLWIOqVu5Z/SxpxWMJ7/
qweCzsBD8HZa3f8KeGMvoBq5J2gv1Q4dN9lLXql/pfSs7rZR88/+ql6h02GO
Y+4+app70w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 47->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBi19YX1BBTwvCehBvfbq7UCWdTlIDKbTppJOZ
Hq6P8b4B8Nwty5he53lO78t23dzSdDpOa3FfEsjDspTMJnnPZ7BZgs8Z3/T7
hnNW9aUIeaKuRTjFlzkojSCyqgkcBBf1boRjPyLvFMdKA9bEzi30k7Mxp06N
+//uA82cDQ+HT9d3Tx/LxUQmftILftNg1d/0ZnC9Ja2U9mqerrfBnX/8q7Bi
Tq/mcczDB6yLehI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 48->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBi19YX1DBPS0I60G89enuQoVkOk0NpNBMk0wy
Pd2f47QD8Dqsx5je12VJn9t+uzzSfDnPG3gsDuRhPYpn43znGKwX4zjnV/V+
1oi5umQhT3gsylN8mYPaEYQ7TORBcFF9ozzWI9KOccuL+1U7FvuTszGnDmZr
u7oQMTGP4tPVvbUfwcXxpzeZYq6nyVV/s9KCZ+/sSv05Nc+/2kZ9e9ra3fGc
LazFMQ9fTft50w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 49->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
IGF0ProYAzKGAnRxdP0Y5sEADjEUc9EAXncyoMrh04fNvehuwBVGOPXj0MeA
xS3Y7MWnj5DdxPgNm33Ywhg9/LD6Dd1NBOTg4YotfrHYhZXGE35Y4x1X+GBx
C4r7sZlpj2omivvR/YsnrjD8TiCs0M1AN5ukuMWhhpj4QzEPiz9xyeFyY4M9
APhge5Q=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 50->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
IGF0ProYAzpmwBRH149hHgzgEIMBFHEkMZzuZECVw6cPm3vR3YArjHDqx6GP
AYtbsNmLoQ+L+/GFNYM94bBBtw9bGKPbj9Vv6G4iIAcPV2zxi8UurDSe8MMa
77jCB4tbUNyPzUx7VDNR3I/uXzxxheF3XGGFbBeeOCcpbnGoISb+UMzDkc6w
yaGHF4INABbdfNU=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 51->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFkkEKwkAMRT8upFuP4BX0AMUr1BOMYFcFoS7EXY9uiy3MJC/TQIZO0p/8
/Mz58er6g6R3Mx9d+tzGMX3vx+XyTMP1MizJ0+rS1M7H6lPm9m5jsi4ft3hX
b7MgtlkRz2IhT5W5Go74Wg6RRiE+wAm4UF+HA/41re1spI3tRxqH+4Vv0t7q
7erm8wpiMA/x3t17pA9wKfhTTeAdcXJvIpgBsbnBPvEtyuOr9YK+e7vNtSMu
lKN///V+F9p8lA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 52->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKwkAMHDxIrz7BL+gDil+oL1hBTwWhHsRbn24LK24mk6CB7HYTJjs7
0/3lPtw2AB7dsgzleZqm8jpv18O1jMfDuDZ3NYG5X5aac5N85hrarMF1xrt5
nwhqZi5FyhO2l+EUX+YQaRTiAxwEF3Wvwwn+v2rtfIW+T2nMvLNvpT3rbXRV
/goN5C60SH0PNFFcDH8x0/mEmJP7J4I3SGwbNEP5+pe3iY7m/UGv1Y7rrhfs
X9wbggF+Fg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 53->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKAjEQCx7Eq0/wC/oA8QvrCyroaUFYD+Jtn+4uVJimyTgw3W3LZDJJ
D7fn8NgAeO2WZSjvyzSVz3W7bu5lPB3H9XJfE5jPy1JzDsl7PkPMGnzH9R3e
L8xZxOVIeaK9U3VqDschm0nWx7owHwQX1Zf7Of6qd+ZZ1Ib7KY2Zd/avtG+w
WVflr9BAfoUWqe9GE8Wl4S8wO5/gOXVvwswga2MQhvUamqPFM33/edu9a8U9
8a7F+wL74H8Y
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 54->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwjAQHHoQr32CX9AHiF+oL4igp4JQD9Jbn94WUtlOZuLCpiTp7szs
5PR4d68GwOe4LF363oYhjffDunmm/nLu18s2JzBdlyXnFJL3fIaYOfiO64t+
W5iz2JejyhP7O1WndDgONU2yPtYFfRBcFC7jOf4Ku+ZZnA3jqRkzt0Ib9XP/
sXalacNTsym+YhZV381MfpjGF9YqfYLnVLwJo0HWxqAe1mtojrafwf3nrXrX
6l067/b9ZsvdgFc=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 55->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKg0AMDV0Utz1Cr9AeQLyCnmAKdSUU7KK48+gqaEleXuJAZpiESd5n
7q9P219E5FutW1t+zTiWqbtul3cZno9hK972EJnrddtjVoF3zAmG+Bq+d/2O
FeSOZfIqF+IUW2PvGI8IQ8YJdfjnNG7IG144l/UL8DPsET7URvd1vBX/zGv0
HbU3vRM/DXeijTuJFqnvwT/GmTgbuTLdkA+bw7xiWiAXxH/qtXCMYb9g7pm3
7F877Il3tt8CAAR+Fg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 56->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUkEKwkAMHDyIV5/gF/QBxS/UF1TQU0GoB/HWp9tCK9nJzHYhu+yEJDNJ
TvdX+9wBeB+mq+0+12Hovrf9/Hl0/eXcz87jYsDYTNdiYzD+MwY2ZB/Hp3zr
Mdh6CjxglidKn4pTOhyHmibuwx+LvAm3XGDymRjF3fHj3sS8SXfQzzlST5iT
8dXmWWiPWGPeSv/k3M0ec02uzVpV31iPqqNmpXqRdoH4b84amqPNZ+puzTbt
teJemV2Z7wedH37X
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 57->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwjAQRT8upFuP4BX0AOIV6gki6KogtAtx16PbQiOZn/+DA5OSmebP
5GWO91f/3AGYumXp0/s6julz26+bRxrOp2FNHjYH5suybD4XznuOgR11js9X
GtlMLFuI51yrT8RcadwHRL9ct3Un5vCLQWiZXkJdwdCdaXF2/wQGzIRN9WLu
ptgzb+Za7QUv+W3wk+9uZpBrcm0ITTsfioWZE6VRnS3tz/cuNVhT6pm66v2k
voirOWbmUe8LD2V+mA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 58->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QB4hfqC1awp4JQD+KtT7eFLiSTydpAlibpzmQn
OT1eXb8D8D7MR1c+t3Es3/t+CZ5luJyHpXhcHZiu87H6ZJxjzoEdscb3A0a1
JFfN5Wut1Sd8zRr3AdGv4/3zJqWB+0bMcy+OV/BZPRS30jn7x2nAmrCpXpK3
Be2F3k4LiLihvZrn5rknO8iczM0zlfvR0iLZE4UR7lrbOG+LwZgSL+HlOaf4
Iq/2mDX3eD9FiX6Y
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 59->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKg0AMHDwUr31Cv9A+QPoF+4It1JNQ0EPpzaeroGUzmWwNZNlNNslk
ksvz3XYVgLFejjZ97sOQvo/T+nil/nbtV+d5U2BqlmPTKVN+sw2s8D6Odzl2
CWy7GHtmC3HC+mQcfB+MweQocMIcmDu8nbGYuqJezoeqrXiO/jAH6v0ThSXo
zfHKuQvz5B5Vn2qeh+ce7CDXNHjETOV+lLgI9kTlcLHw9n/zNn85NpcCj6b/
wOd2VWGPZufyzcKdf9k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 60->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyFUksKwkAMfXQhbnsEr6AHKL1CPcEIdlUQ6kK669FtoeDk5SUOZD7JJC95
yeXxGsYGwPu8bUP59PNclvtpfzzLdLtOu7E9BFi7bTtkrYTfrAMLvI39Xbxq
OV1nbbzSPGFtEQ7XwTmYGAknzIG5w+s5F4Mr8Go+FHbKsahN1WlwGJ/vojbJ
KygPeF/zjmLymfAn+x7MMWOafERP5XxkXARzomI4X3j9v36bv+yragxwVf9k
fKFX86LOn98XC4aBFg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 61->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJwzAMPPIo/WaErtAOELJCOoELzStQSB8lv4zeBAK1Tie7BtmWhM66
sy6P1zA2AN7nbRvSp5/ntNxPu/NM0+067cn2MGDttu2wNTP2OQY2+BzXO7xs
uVhnc7yKfcLmoneYB/dgMCIOQgNzj/gh0ENoGNX8o7Pipng67Ym7uQfcnK6g
PuBrjR9h8lnQj89cU4dHb5p+xJ/K+ShpEcyJwnC1qGNG/GtzV3tX/Z/EF3E1
L+r81X0B9cyB2Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 62->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUlsKwkAQC36Ivx7BK+gBileoJ1hBvwpC/RD/enRbqNDJJNsuzLKzwzyS
yen+ap87AO/DeLXlc+378r3tJ+dRusu5m4LH2YChGa/ZhoWxz39gQ45xfqq3
OOmviTE+1TkRY64P4+AZQg2HQXAQ3g4fPB+MzeVs4Vlhs/3+h/LS22BLvBKW
wCuyb2saPuzeuUdNf0ZbaqdSHxvmVjpTXCgt1Go6/Gu6W+ur9ifri3+lF95d
rPcDb3uC2w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 63->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
IGF0ProYAzpmwK8XG0YGGGL2qHLoAK87GVDlcNmD7g90N6CYgcsPuMKAAdMs
XG7BZi8h9+OKN1zuQ3cXIbch68OIdxx+wwhXBkx96HqR+TjNxBEeOOMd3Q58
6Q9H2kKWwwgDEt2NLZ1hCwtCeQNfOiQpbgnYiy3+sJqPw03Y0g4DDjMa7AFm
EIQc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 64->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKAjEMHDyIV5/gF/QBxS+sL6igpwVhPYi3Pt1d2EN2MkktpCVtM0lm
crq/hucOwPswb0P9XKepfm/7xXnU8XIel8fjakAr87ZaM8Y+34ENeawyu9xd
2b7xSuvEf3m4D/5v8bOeJAfwWFEtKu8mdxCjdMs0Y26y2iy20z3ozfEKH8ex
1g8xAz4i3V2ObP7sybHUj5wP+h9xz3OmuOjNbHcOoWt02nbyKv0kfjRjSrMA
o5UfLgeGWQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 65->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbiQbj2CV9ADBK9QTxBBVwWhXYi7HN0Wupi+edMxMAlJ3vze
vPPj3b8OAKZu3vr6uY1j/d6Py+VZh+tlWD5PqwGtzNtqzRjf+Q1s8PjM7HJv
ZfvHy+JV3H/ycB+Mtz0rPhwXKn7UX1D3Bpv4qLntzYy52avNxnZzD3pzvML7
sa/NxRjHQ1C34py1FOqPT/g/xwHhLD7innWmuMg0m+oQukbHd5JXzU/GjzSm
ZhbEaOUHfvWFmg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 66->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDyIV5/gF/QBxS/UF6xgTwWhHsRbn24LLWwnM7sNZGE3yWQz
mcvz3XYHAJ/TdLTpex+G9Hsc58sr9bdrPwfPiwNjMx2Lj5nznd/Ajphf89zC
W7ONseX5CndPH56D8/OZFR+BC4UPje3+vcEQXKu+RY4L3FjuV3N7h65X+FzH
tWsfiBzFg+vLnLOWrP6MtvJY4IDyLBdKIwYj1KKO6ebfs9va/ljPEr+gsbAz
q48/Jr6GGg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 67->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKwjAQfbgQtx7BK+gBgleoJ4hgVwWhLsRdjm4LXUzevEkamEAyk8n7
zOX5HsYDgM9p2Yb8vc9z/j2O6+GVp9t1WpPnLYCSlm2LYoLPfAcO+Ppe2OXu
Up3jZetV39Y/CjtEveXc0kNpUOHucFb/yv7if4Wr5aPSWmGzuJ3v0O8r3oSv
6Sd7Ac0RAW6lOc9SOH/BbNmc04DqQi2EV4qDfIt+z4j/Hm93+RfkeK7VjDnP
gh4l/QFsVYNZ
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 68->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkEKwkAMRT8uxK1H8Ap6gOIV6glG0FVBaBfFXY9uCxUyP/lpA5lhJplM
8pLL89O+DwCG07y0Zbz3ffk+jsvhVbrbtVuM51WBqZmXVSejfOY7sML7b6kV
d9fUNhbrH8XN/olyR+Bva454OBZBXiq2yruKIXb+N2WcsJHs/6L6jvh9VTfl
l/WTGTIDxyHh59ibOkLeYraszTEgP8kimhERw73FdkxV/57e7uqfsPFch7mr
GQbH+wFsjoSa
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 69->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKwkAMHDxIrz7BL+gDil+oL1jBngpCPYi3Pt0WVkgnmbSBbNndZDqZ
2fPj1fUHAO9mXrryuY1j+d6Py+ZZhutlWC5PNYGpnZeak0ne8xls1uD6rbTh
zgiXw9ZHuNl/EPEP6u3MkR5Oi4CXwla8Vxjim3mUecbaSO3/oXxH3L+aW/Rx
L9eHnFiHRD+nvenP6h0f0KzqfWRaRG9EYLhebGOqefZ4u8s/ced8ibirNwzG
+wEeSoWc
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 70->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUksKg0AMDS6KW4/QK7QHkF7BnmAK7Uoo6KK4m6OrMIX45r20gYwk5vte
zo/38GrMbG63Z0if2zSl5X7ajWcar5dx/9kVNcv99hTNTtFGn3ktgvG/1Evl
g7ooPp7VjfoYm5/E+50ZHogLm0vVVnMfaohvxFHEGZuRYv8Vxbvx/MPeIg9z
K07YTARnhV+FvcuX8dDf9/Ux9D4iLHB/sQPNNe4PuUbciP1PX+RZ1g9uTN0u
4pj7FU3+h9c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 71->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUkEKhDAMDB7Eq0/YL7gPEL/gvqDC7kkQ9CDe+nQVimQnk2ohlcRkMp3k
NUz9rxCRpTquPqzdPIftU57ON4zvZjx/1slEYntcyaIy9DEm2tLB/DvTx8QA
F4/OZ7i5Phe+5k/y9ZuZHkYLwsvDNhwZhvN9OiPqE60ZN83bzF14/d+7nTqs
RZ0oJ9SB9EXNcZe8/UNujI/RAPJcLdh8HQxTKzyeM6Mb8Z/0xTm7+Jkd83YX
dYztDoBjhZo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 72->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUkEKg0AMDD2I1z6hX7APkH7BvmAFexIEPUhvPr0KlsaZidWFrCabTGYn
e6u76nUxsyGftyqNj75P72e2OE1q70W7HF5XM5vKeVttcoY+xgzNOP+f+UWx
cnuGy+cr3L0+m/+vL/L9nZUepIXgFWETR4WBWCdnJH2hteLmedPchY5076AO
a1EnyUnogX1Rc3xL0ftDbooPaQB5oRZqvgEG1ZqO7xnpJvwjfXHOIb6I4+yj
76/uA7drhds=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 73->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNUsEJhEAMDD4Ov5ZwLdwVILbgVbCC9xIEfYg/S1dBMTuZrAaymmwyyU7y
bvr6n4nImG9HHaZqGML8e+1GG7rvp9svi0NFlnI7Dl2Uoo0+QRUbf6dajK+M
71B0PMNN1Yn+T5vE6zczPpAb1peHbXpkGIj1YEapmSE3jMtIvLkTHik+ycNc
5In2RPjAusg57pK3f95u6X7MWyDO5YLtiINhcoX7k7NG3oj9pC7bZ4pP/Oad
zvfKWwHz5Iec
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 74->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUkEKgzAQHDyUXn1Cv9A+QPyCfUEK7Uko2EPx5tOrYO06OxulgU3IZjPZ
mcnp9mweBYDXcZya9K67LvXXw7S5p/ZybqfDcg5gqMZpjsEE7zkHDvj6rbDD
5ar12ZLjPsS7nON3uN8vNtdbzkoP1oYxc9iuR4XBWDs8ynnG2oTaGw+k76D6
CF/cc3cB949cT0IP1o81j/qT9UL/pS8ILsRD+Rz5pTgoPnZsefyPt7l31X+W
+Ht4BusP7wM16ImS
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 75->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydkk0Kg0AMhR9dlG57hF6hPYB4BT3BFNqVUNCFuJujq1RLfPMySgMZmEwm
P19ye36q9wlAd5mOKvRl24ahPs+XV2ge92Z+vC4KxGI6Fo1G+c42sCL131Mr
ia3YvilbdPKyjfPInMLf9qwYqRxcg41tWSU1Co7gWGw/wjjDxmW/ijd34sjs
3H0RM1j/e2xUHYofM/fqk/6C/68uiF6oD7VDkr3Tg+rHyt6M/5ltLi/P2Y1/
pM/Mzn7jjc8Dh1U=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 76->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUkEKgzAQXHooXvuEfqE+QPoFfUEK9SQIepDefLpKtYyT2Shd2Eg2m8nO
jPdXW9YXM+uzeSnD8Oy68Kmuy+YdmvzRLIe3Nc3GYl7WHCF5zzWD7xbcf5QY
UY1wVW2rK9zUOxEGc8Nep0dpwxg4N/YovfAs0ljM4nmU8oy1cbUHD5TvrKPi
7d2L7tpeOzmT0IP1Y829+WS/0P83lwkuxIPndLV3OCg+GEce/+Nt6l322cU/
wzPxz37xJlMgiNM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 77->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydUksKwlAMHLqQbnsEr6AHKL1CPcETdFUQ6kK669FtpWo6mTyLgbwPbzIv
mWR/vrXXAsC9nJY2PZq+T8NpN18uqTseuvmxWhwY62lZfDTOd3aY/W05vOSA
j/0Y8bJZvOLN/eM4qN4VNsAoPZhDcUV62TenMWjf2COFUVornV4mOED5WJzj
F3EuFppzlZPQg/WTOon8JF7o7/KK5gM+z1D7oAZVj7VfPf6nt7l/uc8h/5Y6
g1n+np+VoogY
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 78->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksKwlAMHLqQbnsEr6AHEK9QT/AEXRWEdiHdvaO3haphMqmvgbwPSSbJ
JMf7q31WAIZ6Ptr0vvZ9Gm+H5fNI3fnULcZmVSBf5mPVvENh7o/sic8mzsZ+
hXBZrL/C3cojcwp/1+cfPhhDYUV8WZvjGHSTvWROihvJgxWBAapHcadyb80z
4otng6BuxXlUn/SP6hOcu5nC1xnuYdCD6of5KVHHm/iX5OU5h/jRjokd5V3+
vSdKF4hb
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 79->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
kIAZkGgYIEV/A5I+ZL1wgGYuOkBWj81cfPZgtROLegx/EggPdDOwmYXND8j6
UdyFjrG4idh4whY2WMMBGWAxA8UdaOowzMeiD0MvA6o+rG5CT3NYwg/dDFzu
w6oel/uwhDlGnDJguhNnOsThB2z+QQ8fYjBGuGHhE2MvejzjNB9XGsOSRrGm
JbB5AGNNh5o=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 80->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
kIAZkGgYIEV/A5I+ZL1wgGYuOkBWj81cfPZgtROLegx/EggPdDMwzMLhB1zh
CA8HJHl0NxEbT9jCBqt9yACLGSjuQFOHYT4e/6GHA7bwQo8bBhzuxhbmuNyH
Sz0292ALc2xxii0NYU2HOPyAzT/o7iEGY4QbFj4x9qLHM07zcaUxLGkUa1oC
mwcAdcWGXw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 81->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
kIAZkGgYIEV/A5I+ZL1wgGYuOkBWj81cfPZgtROLehR/EvAjgz2mmRhm4fAD
rnBECQdkM9HigJh4whY2WO1DBljMQHEHmjoM8/H4Dz0csIUXetwQigtcZuEK
J2xuQRHDEubY4hRbGsKaDnH4AZt/0N1DDMYINyx8YuzFlp6xmo8rjWFJo1jT
Etg8AFJYhWM=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 82->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
kIAZkGgYIEV/A5I+ZL1wgGYuOkBWj81cDHuQxLHaicVdGP4kEB7Y3EWMH7DZ
i+5udPMbCLgHlxoM87Hw4QCLGdjCET3ssNmNLz5xhRd63DDgcDe2MMflPlzq
8bkHwy+43E0oHeLwAzb/oLuHGIwRblj4xNiLLT1jNR9XGrPHlMOalsDmAQBx
K4eg
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 83->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
kIAZkGgYIEV/A5I+ZL1wgGYuXAzNrdjsRRdDNg/Zzejy6G5oQNdDIDzQzcRm
FjY/Y7MXq7vR/UVCPGELG6z2IQMsZqC7B1vYYbMba3yi8fGFAUqawxN+2MzC
FU7Y3ILNDAy/4HI3MekQiz+x+QfdPcRgjHDDwifGXmzpGav5uNKYPaYcAw4z
GuwBLv+IIA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 84->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksEJwzAMRUUOpdeM0BXaAURXSCZwoT0FCumh9ObRk0AKjvQUHIMcHNn/
f33p8nh3r0ZEPud569L3Po7p15+WwzMNt+uwJNs1RLLO2xr5QIhu3/6xDmEU
y/3Tba78isEgXMdjMSwn6NrjJT8sJmFRzcQb6aYe1PSJvEG+cgEG+Rj1g96R
F5Ff1ncJdJPnkb7o/p4eV0uku2YOoU6qx+qpCecbnGt4aZ4RP5ox9TkJMLJO
gfmIIg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 85->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
kIAZ7FH1wszCpxZDHAlgiNmjyiHbw4BmBjZzMexBEsdqJxZ3NaDrIRAe6GZi
Mwubn7HZi8vdxIQrPjUY5mPhwwE2PVj8his+GOwx9WELC1zhhR7uDDjcjS3M
cbkPl3qc7kHCBNMHAw7zcegjpBeXP3HGNXq4YeETYy+29IzVfFxpzB5TDmta
ArMBsgaGIg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 86->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBBBQ3
kIAZkGgYIKQWQ5wBUy8coJnLgMMubPaiiyGb14DDDAYs7mpA10MgPLC5C90s
bH7GZi8udxMTrvjUYJiPhQ8H2PTgCUdsatH1YQsLXOGFHu4MONyNLczR0xKu
9IcrXuA0EiaYPnCEBQM2v2AJC0J5g2Bco4cbFj4x9mJLz1jNx5XG7DHlsKmF
mAcAHe6Gog==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 87->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQEgthjgDpl44QDOXAYdd2OxF9xeyeQ04zGDA5i50ewmEBzZ3ofgB
DeAKD3R3IesnJlzxqcEwHwsf2f8YevCEIza16PqwhQWu8MIWN7jsRTcDPR5x
pT9c8QKnkTA2+4kNC3S/YAsLQnmDYFyjhxsWPjH2YkvPWM3HlcbsMeWwpiUw
GwBwj4ai
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 88->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64QDNXAYcdmGzF91f6PZgtRObu+wxaXzhgc1d2OzFFV64
3IWsH1scEBNP2MILq33IAJseHH7Daj6W8MEWFrjCC1vc4LIX3Qz0eMSV/nDF
C4ocul+IcDfW+EJyC7awIJQ3CMY1erhh4RNjL7b0jNV8YvyJTjOgmwcAVxSF
5w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 89->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64QDNXAYcdmGzF91f6PZgtROLu5Dl0NVgCw9s7sJmL67w
wuUuZP3Y4oCYeMIWXljtQwbY9ODwG1bzsYQPtrDAFV7Y4gaXvehmoKclXOkP
JW3hMANfuKHYhSes0dVgCwtCeYNgXONwI660h8tebOkZq/m4/IkU9xg0A7p5
ANHNh+M=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 90->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINFgzECGGUgAQ8weVY4Bj3ps5qK4EU0fVjuxuAtZDl0NLr9guAGLvehq
8ZnBgGYWtjggJp6whRdW+5ABNj04/IbVfHtMfVjDAi0dYQsDfOGELczR0xKu
OENJwzjMwBduKHbhCWt0NdjCglDeIBjXONyIK+3hshc9nnGaj8ufSHGPi0bo
AwCmtoci
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 91->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINFgzECGGUgAQ8weVY4BDSOrx2YuihsZsJiFbicWdyHLoavB5RcMN6Cb
hcXP+MxgQDMLWxwQE0/YwgurfcgAmx4cfsNqvj2mPqxhgZaOsIUBvnDCFubo
aQlXnGFLJyhhjyu9YLMLT1ijq8EWFoTyBsG4xuFGXGkPl73Y8ghW83H5EzlM
cdAIfQCt94ee
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 92->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64QDNXAY0jKwem7kobmTAYha6nVjchSyHrgaXXzDcgG4W
Fj/jM4MBzSxscUBMPGELL6z2IQNsenD4Dav59pj6sIUFRjhjCQN84YQtzNHT
Eq44w5ZOsMU7hptw2IUrLND9gi0sCOUNgnGNw4240h4+N6P7Gav5uPyJHKbo
NAO6eQB+hYbj
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 93->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64cAeQcPtQRODqcdmLj43YrUTi7uQ5RjsGfCGEzYzsZqF
xc/4zGBAMwtbHBATT9jCC6t9yACbHhx+w2q+PaY+bGGB7ldsYYAvnLCFOXpa
whVneOMKSxxgU0dMWKD7BVtYEMobBOMahxtxpT18bkb3M1bzcfkTKe4xaAZ0
8wD7iYbj
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 94->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64cAeTRzZLjQzsJmL7i9ke7DaiU8tkv2E/ILhBiz24gov
XO5C1o8tDoiJJ2zhhdU+ZIBNDw6/YTUfT1xj5RMRN7jsRQ9zfOqIUY/iHjzh
RmxYoPsFW1gQyhsE4xqHG3GlPXxuRvczVvNxpTF7TDlsaiHmAQAZ34ii
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 95->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64cAeTRzZLjQzsJmL7i9ke7DaiU8tkv2E/ILhBjT/YPMz
PjMY8LiBmHhDV4MtrLHFB3KYoKjB4jec5uOJa6x8IuIGp71o7sKlDms6wWI3
Njlc6QM9nnGlTWR5bGFBKG8QjGscbsQWt4TiD93PWM3Hk8bQ5bCphZgHAN3d
hiI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 96->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64cAeTRzZLjQzsJmL7i9ke7DaiU8tkv2E/ILhBiz24gov
XO5Cp9HjgJh4whZeWO1DBtj04PAbVvPxxDVWPh434QsnbO7CpQ5rOsFiNy4a
W5yip1tcaRNZHltYEMobBOMaT7ihA0Lxx4DD/Vj9gi0d45LDMA8A/x6HJA==

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 97->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwgE0erxkMmHrhwB6BG5DY2NRjM7cBXT+SPqx2YnEXshyyWfj8guEG
LPZiCy987kKnSQpjHGGD0z5kgE0PDr9hNR9PXGPl43ETvnDCFub41BGjHheN
Tx3MD7jSJrI8trAglDcIxjWecEMHhOKPAYf7cfkFpz8JuLHBHgC0mIYm
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 98->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwgE0erxkMmHrhAM0MuBgW9djMhbsNzVx0NrLZ6G5AsZeAn3C5C5u9
2MILn7vQaZLCGEfY4LQPGWDTg8NvWM3HE9dY+UTEDS570cMcnzpi1MPdg+Zn
bOrQ0y2utIksjy0sCOUNgnGNw4240h4ue9HjGaf5xPiTgBsb7AEdgoXl
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 99->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwgE0erxkMmHrhAM0MuBgW9djMhbsNzVx0NrLZ6G5AsZeAn3C5C5u9
2MILn7vQaVLDGBcfq33IAJseHH7Daj6euMbKJyJucNmLHub41BGjHtk9+MIN
wz8Ewp6Y9Igrb5AS11jDEc1MXPaixzNO83H5E0/axAwfAPA3huU=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 100->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwgE0erxkMmHrhAM0MdIAsjs1cuNvQ9KOz4XwsdiHLobsHl18w3IDF
Xmzhhc9d6G4hNYxx8bHahwyw6cHhN6zm44lrrHwi4gaXvehhjk8dMeqR3YMv
3DD8QyDsiUmPuPIGsXGNMxzRzMRpL1o840w7ONIhvvyCGT4A2c+F5Q==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 101->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwgE0erxkMmHrhAM0MdIAsjs1cuNvQ9KOz4XwsdiHLobsHl18w3IDF
Xmzhhc9dDLjcSWQYN6CZgdc+ZIBNDw6/YYsPXPGHk09E3GCEKTa/4nEfhjk4
7EYWwxduGP7BERbofsEWFoTyBilxja4XHeC1l5i4RfYLujvw5BfM8AEAyC6D
5Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 102->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwgE0erxkMmHrhAM0MdIAsjs1cuNvQ9KOz4XwsdiHLMeCwC5seFDdg
sRdbeOE1A5c7iQxjdDPw2YcCsOnB4Tds8YHLbJx8IuIGI0yx+RWP+zDMwWE3
shi+cMPwD46wQPcLtrAglDeIjWti4havvUTGLbb0AU8jONInZvgAACg0hCg=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 103->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64QDNXegAWRybuXC3oelHZ8P5WOxClmPAYRc2PShuwGIv
rvDCZwZWdxIZxijxhe5vLHw4wBHG2PyGLT5wmY2LT0zcYIQpDnfhch+GOeg0
FjPwhRuGf3CEBbpfsIUFobxBbFwTE7d47SUybuF+QXcHEsZwI4Z5AG8Qhig=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 104->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64QDNXegAWRybuXC3oelHZ6Orw6oWyZ94/YLNDVjsxRVe
uPyG7hb0OCAUxijxxYDfPhSAI4xxhSM283HFNTY+TjfhCSdcYY7LfdjiDIXG
Yga+cMPwD46wQPcLtrAglDeIjWti4havvUTGLc70gYQJubHBHgAByoYo
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 105->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuyBhD2E
JgUzINEwQLIZDJh64QDNXegAWRybuXC3oelHZ6Orw6qWiDCCqcNwA7JZyBiH
u7H5Dd0t6HFAyF24+NjsQwEEzEDXj818XHGNjY/TTXjCCVeYo6clfGEDU4PT
PQTSEi67sIUNMekRV94gJa7R9aIDvPYSGbc40wdaeKHLoZoHAACjh6I=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 106->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQp
mAGJZiDXDCSAIYZkB7padPXYzEV2G7J+dDacj8UuZDkGIv2C4QZkswiEFz4z
sLqTyDDGxccaDsiAgBno6rCZjyuu0e1BDhcMfXjCCZvd+NyH0x9Y4h09/nGl
JWLCAt0v2MKCUN4gJa7R9aIDvPbikcPlFxR1aOGFLodqHgCuEYXj
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 107->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQp
mAGJZiDXDCSAIYZuBwNu9djMRXEbmhux2onFXchyyO7B5xcMNyCbhcPPxJiB
1Z1EhjEuPtZwQAYEzMDmD2zuxxbXGHy08MEVN9jCFG94YdGP1R9Y4h1X/ONU
h2YXtrDBZQZWtVjEiY1rdL3oAK+9RMYtzvSBJ79ghg8AxBqFJA==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 108->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQp
mAGJhgGSzWDA1AsHOOzAph6buXB9yJgB1Q4UO7G4C1kO2T34/ILhBmSzcPiZ
GDOwupPIMMbFxxoOyICAGdj8gc392OIaHx9DH4FwwhteWPRj9QeWeMcV/zjV
odmF7kZkeWx+J5Q3SIlrrOGIZiZOe4mMW7hf0N2BJ21ihg8AxHmFpg==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 109->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQp
mAGJhgGSzWDA1AsHOOzAph6buXB9WNyI1U4s7kKWQ3YPPr9guAHZLBx+JsYM
rO4kMoxx8bGGAxb34TIDmz9w6UM3Fx8fQx+ecEKPN2zuwxVOMDlcaQRdDa70
gcsuZH+g+wWb3wnlDVLiGms4opmJ014i4xbuF3R34EmbmOEDAHuVhaY=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 110->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGqnxwzkAGGGNRsdDuwqcdmLlwfFjditROLu5DlkN2Dzy8YbkA2C4ef8ZmB
4Qcs/iQUxjC70fVgtQ+L+9DtwRWO2MzHFdf4+NjCAFc4YQsPDDMJhQ1UDbp7
0OMAV/rAZReyP7CmKyxsfHmD2LgmNm5x2ktk3MLTFLo78OQVzPABAJtthKg=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 111->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGGyTADGWCIQc1tQDKfwR5VHJfb4f5Ccx+KOLqdWNzVgMdeXH7BcAMWe9HV
EjQDLQzw+R1fWKDrwWYfNveh24PNb9jU4jKbEB9DH4FwwuYu9LSEN2ygatDd
gx7/uNIHLrvQ3Ygsj83vhPIGsXFNbNzitJfIuIX7Bd0dePIKZvgAAO0IhyI=

                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 112->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGqnxwzkAGGGNRsFDuQ2MjqsZkL14fFjdjMYMDirgZ0e4nwC4YbsNiLK7zw
moHDncSEcQOS2zH8jYWPyx34/IZNLS6zCfEx9BEIJ2zuQk9LeMMGi3/wmYFX
HQ7/o/sFm98J5Q1i45rYuMVpL5FxC/cLujvw5BXM9AsAWh+GZw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 113->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGqnxwzkAGGGNRsFDuQ2MjqsZkL14fFjVjtxOKuBnR7ifALhhuQzcLhZ2LM
wOVOYsIYFx9rOGBxHy4zsPkDlz50c/HxMfQRCCe84YVFPyH1hMzAqw6H/7Gm
KyxsfHmDlLjG5hZ0M3HaS2TcwsIEW/jiDHMM8wAIW4dp
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 114->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGGyTADGWCIQc1tQDKfwR67emzmorgNTR9WO7G4C1kO2T34/ILhBmSzcPgZ
nxkYfsDiT0JhDLMbXQ9W+7C4D90eXOGIzXxccY2Pjy0McIUTtvDAMBNfnOFI
W/jMwKuOAbv/saYrLGx8eYPYuCY2bnHaS2TcYktTcHlcbsQwDwA99YRp
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 115->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGqnxwzkAGGGNRsFDuw2IXNXri/kDGSPkJmYKhFMoeQXzDcgGwWDj/jMwPD
71j8SSiMG5DcjmE+Fj4x4YNNPzbzccU1Pj62MMAZPzjchZ6WcMYZjrSFzwy8
6hiw+x9rusLCxpc3iI1rYuMWp71Exi22NAWXx+VGDPMAO4+Eaw==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 116->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGqnxwzkAGGGNRsFDuw2IXNXri/kDGSPgwzcLirAdleLOowwgGbG5DNwuFn
9LBEcQcWGp/f8YUFuh5sYYnNfej24ApHbObjimusfBzhiDd+CPgVXxjB7cTi
H1zuJFUd3nSFhY0vbxAb18TGLSF7sclhixdsbsSVVzDjCwBbz4bl
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 117->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGqnxwzkAGGGNRsFDuw2IXNXri/kDGSPgwzcLirAdleLOowwgGbG5DNwuFn
bG5HsRvNLfj8ji8ssJqPhU8ojHGFIzbzccU1Vj6OcCQUP/j8ijfOGHD7B9ks
rG7CoReX/7GmKyxsfHmD2LgmNm4J2YtNDlu8YHMjrnDHTL8A/tSJIg==
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 118->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGqnxwzkAGGGNRsFDuw2IXNXri/kDGSPgwzcLirAdleLOpw6UFxA7JZOPyM
ze3oZiC7BZ/f8YUFNvOx8XH5BZ/f8LkfW1zj5KOFM7qfscUPseGFM2yw+AdO
Y4l7rOrQ/IMr3HDZhUstujgxcU1s3BKyF5sctnjB5kZc4Y6ZfgH11Yim
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 119->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGGyTADGWCIQc1tQDKfwR67emzmorgNTR8hM7CpRXYPPr9guAHZLBx+xghL
LGbAzcLiT2zmYAsLdD3Y3IzNfdjCB5t+bObjimucfCzuRw93dH3Y3IVLLy5/
4DIXp5tw6MXlf3T3YPM7obxBCKPbjY1Pir3Y5HD5BV8axJ82Aa2VhyY=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 120->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ5
mAGGyTADGWCIQc1tQDKfwR67emzmYnMfsn/xmYFNLbJ78PkF3UwUs3D4GcOt
WMwgxt3I5mC4A1vYYDEPm/uwhQ82/djMxxXXOPnY9OEJa2z2oZhJIM5wxhWa
GehhiksvLv/jSlf4whGbOKH8RErcErIXmxy2eMHmRlzhjhk+AA6Ehqo=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 121->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DS5
mIFMM5ABhhjUXGTzGeyxq8dmLorb0PQRMgObWmT34PMLupkoZuHwM4ZbsZhB
jLuRzcFwB7awwWIeNvdhCx9s+rGZjyuu8fEx9OEJa2z2oZhJIM5wxhUOd5Kq
jlC6wheO2MQJ5SdS4paQvdjksMULNjfiCnfM8AEACnqGbQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 122->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DS5
mIFMM5ABhhjUXGTzGeyxq8dmLorb0PQRMgObWmT34PMLupkoZuHwM3o4MmAx
gxh3I5uD4Q5sYYPFPGzuwxY+2PRjMx9XXCPHCyG7sdmB7i+c4UUgznDGFRZ3
4Uof+NQRSleE/IguTig/kRK3hOzFJoeiDk86xBXumPEFAE3ohus=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 123->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DS5
mIFMM5ABhhjUXGTzGeyxq8dmLorb0PQRMgObWgYi/YJuJlaz0NRimIPFDGLc
jexnfH7D52Zs7sNlBjZ/4NKHbi5yvBCyG5sdyOZgcxd6WOIKa3xxRSiNEqMO
X9xisxdf3iAmP5ESt4TsxSaHL50S5UYM8wBXKIjr
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 124->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
mBwzkAGGmD0EN0BpuBgW9fjcgk0fITOwqWUg0i/oZmI1C00thjlYzCDG3cTE
C0bYYOETEz7Y9GMzH1dcw+IXxSwkcVxuxAhTbO7CoxeXP7DFFaE0Sow6fHGL
zV58eYOUuMblZlLsxSaHL50S5UYM8wBapopp
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 125->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DS5
mAEJk6QPCcDNgQEk8+Di9qjqcbkdXR5dHyEzsKkl5DdcZmI1C00thjlYzCDG
3bjMwxs2WPjEhA82/djMxxnX2PhY0hEuO+D6CPgVXxgh240trrC5k1R1+OIW
m724wovY/ERK3BKyF5scvnRKlBsxzAMABvCJKg==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 126->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
mAGKSdKDBOBmwACaeXAxJPW43I4uj2EPATOwqSXkN1xmYjULTS2GOVjMIMbd
uMwjFDb4wgqfGdj8gUsfurlY+VjSES470MOGUDziCxts/sHlTlLV4YtbbPbi
Ci9i8xMpcUvIXmxyWP1CpPvQ1ULMAwDR74nr
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 127->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
mAGKSdKDBDDE0MyDi2FRj81cbHYg+xefGdjUEvIbLjOxmoWmFsMcbH4m0u+4
woIBix5s5mFzH7bwwaYfm/m44honH1u8Y7EDWR/eeCQmbLD4B05jSdtY1aH5
h9h0RciP6OLExDWxcUvIXmxyWNMpke5DVwsxDwBLrolp
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 128->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
mAGKSdKDBDDE0MyDi2FRj81cbHYg+xefGdjUEvIbLjOxmoWmFj0MGewx/UyM
u5HNwXAHnrDBF1a4wgebfmzm44prXHxs7sdmB7I+vPFIIM7wxRW2OMGpDs0/
hNyDy+/48gYx+YmUuCVkLzY5rH4h0n3Y0yYA3CyJ5w==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 129->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
mIEMc5ABhhjUTGxq0dVjMxefPkJmYFPLQKRf0M3EahaaWpQwRPI3PByIdDey
ORjuwBM2pIYxLvdgMx9XXOPiE3IjIbX44gRXOsHnBnic4HATLv/gdA+eNEYo
bxCTn0iJW0L2YpPD6hci3Yc9bQIArLCIrA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 130->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRibWnT12MzFp4+QGdjUMhDpF3QzsZqFI6wYkDBcPQ6ziI03
uF48YUNqGGP1Gw7zccU1Tj4BN2ILUxRxEtIkuhnYzIXHCQ434fIPsemKkB/x
uZ+YdE9KPiCURnH5jVDeQE/jqGYAAOpNh64=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 131->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRibWnT12MzFp4+QGdjUMhDpF3QzsZqFI6yw+hmHWcTGG1wv
nrAhNYyx+g2H+bjiGicfmz48YY3NPgYc/sMZNtjcgIyxhAdOvTj8jyst4HIn
NvOIjWti45aQvdjksLKJdB+6WogZAHGzh20=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 132->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRibWnT12MzFp4+QGdjUMhDpF3QzsZqFI6wYsLkdh1nExhs2
v+FzMzb34TIDmz9w6UM3FycfRxjgix8MdxGZJtHNwABIcYLNL7j0kpKu8IUj
IfcTk+5JyQeE0iguv5HkRgzzAGDGh3E=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 133->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRhF3B67ODZzsdmB7F90Nbj8guweUvyPzS5sbkExA81/cD8T
6W5kc/D5DZ+bsbkPlxnY/IFLH7q5OPnY9OEJa2z2MeDwH650gs1NcLfgCSdc
evGmKzxpjFDeICY/kRK3hOzFJkeITdCNGOYBAGCgh6w=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 134->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRhFHCqGrh6budjsQPYvPjOwqWUg0i/oZmI1C0dYwfzGYI/m
ZyLdjWwOPr/hczM29+EyA5s/cOlDNxcnH5s+PGGNzT4GHP7DlU6wugE9TrD4
BateZHXY3I0njRHKG8TkJ1LilpC92OQIsUl1Y4M9AGF0iCw=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 135->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRhFHCqGrh6budjsQPYvPjOwqWUg0i/oZmI1C0dYwfzGYI/F
z0S4G9kcDHfgCRt8YYUrfHDFOS596OYi+wsj3tH14QlrQn7FFUbo/sCV9nCF
O069OPyP7hd0M7CqJeB+YtI9KfmAUBrF5TdCeQO/GQAO74hn
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 136->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRirOJp6bOZiswPZv/jMwKaWgUi/oJuJ1SwcYYXNbwzoNAG/
w8zBcAeesMEXVrjCB1ec49KHbi7cT0TEL3rYo5hDwK+4wgjdH7jSHq7wwKkX
h/9xpQV84UjI/cSke1LyAaE0istvhPIGfjMAxb6HrA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 137->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRibWnT12MzFp4+QGdjUMhDpF3QzsZqFI6wYsLkdnSbgd3xh
gStsSA1jbH7DZT6uuIb7CVu8YwkDnPGDzV1Epklkt+BKe7jCA6deHP7HlRbw
hSMh9xOT7knJB4TSKC6/Ecob+M0AAHltiG0=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 138->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRibWnT12MzFp4+QGdjUMhDpF3QzsZqFI6wYsLkdh1nExhs2
v+FzMzb34TIDmz9w6UM3lwEJY8Q7ljDAGT/Y3EVkmkT2B660hys8cOrF4X9c
aQFfOBJyPzHpnpR8QCiN4vIbobyB3wwAZsKJLA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 139->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRibWnT12MzFp4+QGdjUMhDpF3QzsZqFI6wYsLkdh1nExhs2
v+FzMzb34TIDmz9w6UM3lwFNPxzgCAOc8YPNXXj04vIHLjcwIGFc6QNfWsZw
N540RihvkBLX2NyCbiYhe7HJYWUT6T7s8QUAwBeJ6Q==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 140->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRhF3B67ODZzsdkB9y8WNbj8guweUvyPrh+XW1DMwOZ2JD/j
soOQu2Bm4wobfGGFK3xwxTkufejm4uTjCAOc8UPAr/jiDdluXG7AleZw6sXh
f3T3YPM7obxBbFwTG7eE7MUmh5VNpPuwmwEA5yOJpg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 141->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDw7sIRhZvMEetzi6udjsQDGDAbcZKGqR3EOK/9H143ILihnY3I7k
X1x2EHJXA5oZ+NyMzX3YwgdXnOPSh24uTj4BN2ILU3x+xRdv6GZgcwOcT8B+
dP/gTFd40hihvEFsXBMbt4TsxSZHiE2qGxvsAfV9iao=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 142->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyhHQg6wPBSDpR8fI6rGZi9U8BiTzGHCbgaIWzS3E+h9dPy63oIcThtuR
/IvLDkLuakAzA5+bsbkPW/jginNc+tDNxckn4EZsYYrPr/jiDd0MbG5AFsNn
P7p/iE1XhPyILk5MXBMbt4TsxSaHlU2k+7CbAQB+JIfr
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 143->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyhHQg6wPDNDcxIAFI6vHZx86gJvHgNsMFLUwQKL/0fXjcgu6u7GaQcAO
Qu5CNwOfm7G5D1v44IpzXPrQzcXJJ+BGbGGKN7yICRs8bsAVHjj14vA/rrRA
yI/o4sTENbFxS8hebHJY2US6D7sZAGxuiSo=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 144->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyhHQg6wPDNDcxIAsjsUMbOZiswPuXyxqcPkFDkj0P7p+XG5BDyesZhCw
g5C7CIUNvrDCZwY2f+DSh24uTj4BN2ILU7zhRUTY4HMDrvDAqReH/9Hdg83v
hPIGKXGNy82k2ItNDiubSPdhNwMACcGJ6w==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 145->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyhHQg6wPDNDcxIAsjsUMbOZiswPZv+hqcPkFDkj0Pza7sLkFPZywmkHA
DkLuIhQ2+MIKnxnY/IFLH7q5OPnY9OEJa4LhRUTY4HMDrvDAqReH/9Hdg83v
hPIGKXGNy82k2ItNjhCboBsxzAMAlI6J6w==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 146->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyhHQg6wPDLC4CQWgiWMzF6s+BjQxHGbgU4vLX9j8gdMsHGGF7m+4PgJ2
EIoXQmGDL6zwmYHNH7j0oZuLk49NH560RjC8iAgbfG7AFR449eLwP7p7sPmd
UN4gJa5xuZkUe7HJEWITdCOGeQBUaYht
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 147->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsERibWnRxbOZi1ceAJobDDHxqUdTh8T+6flxuQTcPqxkE7CAU
xoTCBl9Y4TMDmz9w6UM3FyefgBuxhSmx4YUrbPC5AVd44NSLxT3oaRtXuiCU
N0iJa1xuJsVebHKE2ATdiGEeAIq+iC4=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 148->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIRiXWgY0cWzmYtXHgCaGwwx8aon1P7p+XG5BMQOL22Hi+Owg
5C5CYYMvrPCZgc0fuPShm8uAhNHDGZ8bMcIUm7vQ0hKhsEH3DwM2s/CkD3xp
GcPdeNIYobxBSlxjcwu6mYTsxSZHiE3QjRjmAQAkroum
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 149->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS8c4DADn1pi/Y+uH5dbUMzA4naYOD47CLmL
UNjgCyt8ZmDzBy596OYyIGH0cMbnRowwxeYutLSEN86Q3YLFDbjswZAnMtyw
xSU+P6KLExvX2NyCbiYhe7HJYWUT6T7s8QUAo5WLZQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 150->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS8c4DADn1pi/Y+uH5dbUMzA4nZcZhEbb/jC
C5t52NyHywxs/sClD91cMMBiFrYwwGYHXB82d6GlJbxxhq4ei7uw2YMhj+Y/
nOkKTxojJr0TG9fY3IJuJiF7sclhZRPpPuzxBQCtrYso
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 151->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS8c4DADn1pi/Y+uH5dbUMzA5nZ7JIzDDkLu
gpmNK2zwhRWu8MEV57j0oZuLk0/AjRhhSsCv+MIIbh+6G9H8iC+ucfmH2HRF
yI/43E9MuicmH+CyF5scVjaR7sMeXwC6y4mq
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 152->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS8c4DADn1pi/Y+uH5dbCLm9ASkscNlByF2E
wgZfWOEzA5s/cOlDNxcnn4AbMcIUm7uITJPo9mFzAzb96O7Gl5YJpStCfsTn
fmLSPTH5AJe92OSwsol0H3YzAP8kiyw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 153->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS8c4DADn1pi/Y+uH5dbUMxAwuhm4LMDmzm4
1GALG3xhhc8MbP7ApQ/dXJx8ZPPx2IHN78j68KUljLSGzw0MmPrR3Y0vLRNK
V/jCEZc/8aVBUuKWkL3Y5LCyiXQf9rQJAJWTiSo=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 154->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS8c4DADn1pi/Y+uH5dbUMxAwhhm4LEDmzkY
7sATNvjCClf44IpzXPrQzcXHR3YzLjuw+R2bX7GlJYy0hu4GLGGPL33gS8uE
0hW+cMTlT3xpkJS4JWQvNjmsbCLdhz1tAgBhF4fr
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 155->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS8c4DADn1pi/Y+uH5dbUMxA8zeKPjx2EHJX
A5K52MIGX1jhCh9ccY5LH7q5+PjIbsZlBza/Y/MrtrSEkdbQ3YAt7PGkD3xp
GT1u0dXjC0es4kTENbFxS8hebHK4/EYoHWJTCzEDANBRh6o=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 156->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS8c4DADn1pi/Y+uH5dbMMzB4g94mOCwg5C7
CIUNvrDCZwY2f+DSh24uPj4+N+JLa3CzCKQlbP5Aj2sUMSzxglMvLv/DMAN2
M3D5EUOcyLjG5hZ0MwnZi02OEJuU9AhhAwA5aoks
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 157->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS82O3H5BQ5I9D82u7C5BcMcdDPRaTzuxuUu
ZHOxhQ2+sMIVPrjiHJc+dHPx8fG5EV9aw+ZXbGkJmz/Q4xpFDFu84NKLy/8w
zIDdDFx+xBAnIq6JjVtC9mKTI8QmmB4xzAMAQoqI6w==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 158->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS82O3H5BQ5I9D82u7C5hZDbcZlFbLzhCy9s
5mFzHy4zsPkDlz50c/HxMfQRmdbgZhFIS4TClwFdDM0MdHfjS8twNgwzYDcD
3T/YzCMlrrGGI5qZhOzFJkeITdCNGOYBAJLaius=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 159->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIRiXWgY0cWzmYtXHgN0OdDMw1KLZCVeHx//o+nG5Bd08XGbg
s4OQuwiFDb6wwmcGNn/g0oduLj4+hj4i0xrcLAJpiVD4MqCL4YlrXP7B8D9a
/GLzO6G8QUx+IiVuCdmLTQ6X34h2I4Z5AGEriOk=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 160->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS+6HdjMRFHLgOmeBjQ3YvMHTrNwhBUDNrfb
I2EcdhAKY2S3YgsbfGGFK3xwxTkufejm4uNjCwNi0ho2v2JLS9j8gR7XKGJ4
4hqXfzD8jxa/2PxOTHonJq6JjVtC9mKTI8Qm1Y0N9gAVXIgq
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 161->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsDwzsIZiQWlxuxzAPTS82O3H5BQ6wuR+P/7HZhc0t6OZhDQtkGo+7
cYUxsluxhQ2+sMIVPrjiHJc+dHPx8bGFATFpDZtfsaUlbP5Aj2tsYrjSB760
jBK36G5jwO0fbOYRG9fExi0he7HJEWITdCOGeQA2vYhr
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 162->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD+4mItTicju6eeh6cdmJzS9wgM39SO7E6Q9sZiGLoZuHywwi3I0r
jBvQ3IkrzrC5D1f44IpzXPow/I2Hj6GPyLSGza/IcYRTPbobcIjhSh+E0jJy
WsGWXrD5B5t5xMY1sXFLyF5scoTYBN2IYR4AfL2Iaw==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 163->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD+4mItTicju6eeh6cdmJzS9wgM39SO7E6Q9sZiGLEXA7LrOIjTd0
e7CFDb6wwhU+uOIclz4Mf+PhE/Ijij48aQEMsIQxNnkGtLjGcBee9EEoLSOn
FWzpBV0fvvROTFwTG7eE7MUmh8tvRLsRwzwAOLCJaQ==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 164->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD+4mItTicju6eeh6cdmJzS9wgM39SO7E6Q9sZqGJ4XM7LrOIjTe4
Xjxhgy+s8LkRXR0u92OLP3x8Qn5E0YcnLWBzH4Y8Fv/gEsOVPgilZeS0gi29
YHMnNvOIjWti45aQvdjkcPmNaDdimAcAQw+JrA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 165->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD+4mItTicju6eeh6cdmJzS9wgMP9uPyPzS5cboHrQcLoZhDjbmRz
cIUnITejuw9X+OCKc1z6sPmbUNjgi19c4qSkSWS70eMamxiu9EEoLeOKW3S9
xKR3QvmJlLglZC82OVx+I9eNDfYAJCWJbQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 166->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD+4mItTicju6eeh6cdmJzS9wgMP9uPyPzS5cboHrwWImLrPwxRsD
FjcyEOlmdPfhCh9ccY5LHzZ/EwwbJIwzfvCkBTjAl/6Q7UFSj+EuPOmDUFrG
5hdsficmvRPKT6TELSF7scnh8hvRbsQwDwCp64dr
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 167->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLlxuwWcmLrPwhhWe8CHk
ZnT34TMDXR0u92OLP3x8uBgSxhk/BPwKBnjSH7IZyOoJ+RFZnpi0jO4XbH4n
Jr0Tyk+kxC0he7HJ4fIb0W7EMA8AklSKaw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 168->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLgxgj8C4zMRlFoo4urvw
hA8hNyMDQmagq8Plfmzxh4+P7C9cdqCL4YtHbHGHLfyQ1RPyI7I8MWkZPa6x
+Z2Y9E4oP5ESt4TsxSaHy2/kurHBHgDfZojt
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 169->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLgxgj6BxmYnLLLxhhSd8
CLkZGRAyA10dLvdjiz98fHxuxJfWcKnDFnf4wpeBCD/i1IvD/7B4YcBhBk63
Y/EnvvxEStwSshebHCE2qW5ssAcAlH+JsA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 170->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLgxgj6BxmYnLLGLjDV94
YTMPGRAyA10dLvdjiz98fAx9eNIarrAjFHfIZsMxknpCfkSWJzYtMyC5F5vf
iUnvxMY11nBEM5OQvdjksLKJdB/2+AIActeJrA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 171->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLpxugelBwuhmEOPuBiRz
8PkNn5vR3YfPDHR12MzHFX/4+Bj6iExr2NyCTT82sxnQ1BPyI7I8sWkZPW6J
sQObP/HlJ1LilpC92OSwsol0H3YzAAH3iaw=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 172->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLpxuQTbTHsFHVkOMu3GF
GyluRncfPjPQ1WEzH1f84eNj6CMyrWFzCzb9uMzG5gZcfkSWJzYto8ctMXZg
8ycxcY01HEnwGy45rGwi3YfdDAA3UYrt
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 173->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLlxuQTHTHmEXzF44JuBu
XOHWgGYmPjejuw9X+OCKc1z6sPmbUNjgi19c4ljTDL70hyONEfIjsjwpaZkB
hxk43Y7FDEJxTWzcErIXmxwhNqlubLAHAKqiiu0=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 174->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLgxgj8BwfejuwBPGcHMJ
hDGyGkJuRg8rXOGDK85x6UM3Fx8fn9340ho2t2BTR0g9NnfhSx+kpGUGHGbg
cwsp+YmUuCVkLzY5QmxS3dhgDwDp/4ws
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 175->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLgxgj8BwfXj8RmxY4Qsf
Qm5GDyt8ZqCrw2Y+rvjDxyfkR2z2oocdMWkSw+3ImIAfkeVJScsMOMzAZQc+
95OaHtHNJGQvNjlCbIJuxDAPAIeAjuc=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 176->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLqxusUc1mwGP34gNK3zh
Q8jN6O7DZwa6Omzm44o/fHxCfsRmLzHhRax6BiL8iCxPSlpmwGEGTrfgcT+p
6RHdTEL2YpMjJe1hdSOGeQAWbY9p
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 177->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/I/NLpxuQTYTj9+IDSt84UPI
zejuw2cGujps5uOKP3x8FH1oYYIvreEKL2xxh1c9FnfhSx+kpGUGHGbgcwsp
+YmUuCVkLzY5UtIeMW5ssAcAs16N6w==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 178->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCARqbGHtQ+PYIM/C5BZ+ZDfYIuwm5G1e4
keRmBuzi2MxAV4fL/djiDx8fQx+RaQ2bW7DpJxS+2NyFy36Y+QxY1GJ1Iy4z
cLkdixnExDXWcCTBb7jkSEl7xLixwR4AAZqL6w==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 179->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCARqbGHvQ5RiQ2Tjcgs9MmBnEuBtXuJHi
ZnT34TMDXR0u92OLP3x8DH1EpjVc6rDFHdbwRYovQn5EliclLWOLS3x2YDOD
mLjGGo5oZhKyF5scKWmPGDc22AMACOWNaQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 180->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnZiU8uAw024/A/Xb4/FLDTz8ZkJM4MYd+MK
N1LcjO4+fGagq8Plfmzxh49PyI/Y7EUOJww7iQ0bPO7Clz5IScvY4hKfHdjM
ICausbmFFL/hkiMl7WF1I4Z5ABNyjuk=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 181->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5BntMs+DAHoFxmdmAJE9sWOEL
H0JuRg8rfGZgCxtc+tDNxcdH9jd6+OCLE1zq0MUJxTs2d+FLH6SkZWxxic8O
bGYQE9fY3EKK33DJkZL2sLoRwzwAtBiNqA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 182->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGbBgT0C4zKzAUme2LDCFz6E
3IweVvjMwBY2uPShm4uPj+xvbH7EZi9yOGHYSSBs0MMXm7vwpg8S0jK2uMTm
TmzmkRLX2NxCit9wyZGS9rC6EcM8AI58jCo=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 183->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGbBgT0E4zOzAUkNsWGFL3wI
uRk9rPCZgS1scOlDNxcfn5AfsdmLHE6E0gyh8MXmLnzpg5S0jC0u8dmBy+3k
pEdS/IZLjpS0R4wbG+wBsNeNrA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 184->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahAAJmgmkCdhAKY1LcjB5W
+MzAFja49KGbi49PyI/Y7EUOJ2Q+A4E0hS180d2Fz35c/sGpl8g0hs08gv5l
wO5GvPkAzRxs6gjGLYE0iN8MACSHjWk=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 185->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGZhcxNYHgkTchfesMITPoTc
jNVdOMzAFja49KGbi49PyI/Y7MUZXgTSFHJ4YXMDIftx+QenXiLTGDbz8MUz
OXELBzjsxeYmrGwc7iMmzzTYAwBTdous
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 186->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHhW+PMAObWzD0QDG6+Qx47CDG
XSS5GZu7cJiBLWxw6UM3Fx+fkB+x2YscThhxQCCcGJD0o8c5Iftx+QenXhxm
oKvFZh4x/iUlbuEAh73Y3ISVjcN9xKVNAFQJi2k=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 187->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5BntMs7C5Ca4Wi/kMBOwg5C5S
3IzVXTjMwBY2uPShm4uPT8iP2OxFDids7iQUTshxhe4ufPbj8g9OvUSmMWzm
EetfYuMWDnDYi81NWNk43EfIzRAzANOljWk=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 188->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGZhcxNYHooxzCBgB4a78IQP
ITeDAZFmYAsbdP/gij98fEJ+xGYvun3o7iQUf/DwRwb2CBpf+iCUlhmwuBGb
34lJ78T4F2/cYrEXVzxhcxOheCaEMc0AAHmvjGc=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 189->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2CNhZD1QjGEGLjtwhSue
8CHkZmQ3EjIDW9jgch8yIMRHdxOxaQ09PJDNxhd/cBpLGKCHBbY4RdeLK/5w
xSWyfYTSOzH+JRi3RNqLbjc2v+ELX3xhjmADAHNMi+U=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 190->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2CNhdLuxmM+Ayw5c4Yon
fAi5GdmNhMzAFja43IcMCPHR3YQvraHYgSN+sJkBNwctLtDDAD0ssMUpobSM
zY1Y/U5EescVzyTFLQN2NfjiAZv5+OIIp5sx9AEAgy6LJg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 191->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2CNhdLuxmM+Ayw5c4Yon
fAi5GdmNhMzAFja43IcMCPHR3YQvraHYgSN+sJkBNwcpHrC5AT0ssMUpobSM
LUyw+p2I9I4Po9uNjY/NXmx+wyVHiE3QjRjmAQD6c4vn
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 192->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2CNhdLvx+A3DDlzhSsAM
fG5GdiMhM7CFDa5wRQaE+LjMIJTW0MMD2Wx88ceAjtHdhcd+DPcTsJ8Bhxno
bsQWFoQwerhh45NiLzY5QmyCbsQwDwBeE46k
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 193->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGaBAQ6zGfD4jeiwImAGPvOQ
3UfIDKzux+E+ZECIT8iP2OxF9zdcnT0C44o/BnSM7i4sYYosj+J+HOGE7kZs
ficmvePD6OGGjU+KvdjkCLFJdWODPQBHYoxn
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 194->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGaBAQ6zGfD4jeiwImAGPvPQ
wwqfGVjdj0Mfurn4+IT8iM1edH/D1eGQQ/EHMsbiLmxhiiEPA1jsZ0DSz4DD
DHT/YLgDRx6iJG4J2YtNDiubCLfhNgMAnNOL5w==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 195->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGaBAQ6zGfD4jeiwImAGPvPQ
wwqfGVjdj0Mfurn4+IT8iM1egn4lFH8wjMVd+OzHcD+2NItkPwMOM7C5HUUN
gbxETtwSshebHLFhS6wbG+wBJ0eM6Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 196->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGZhcxNcHx6/EXI3sWbgMw+b
u3CZgdX9OPShm4uPT8iP2OzFsA8Jo4cJXvVY3IXPfgz322N3A7o7sPkda3rH
435S0yM2v+G0F4ccITapbmywBwDhI4xn
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 197->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHhS+PRQzYHcLVv9gMZ8Bjx1Y3YUn
fAi6GYu7cJmB1f049KGbi49PyI/Y7MWwDwmjhwle9Vjchc9+DPfb4zATzR3Y
/I41veNxP0npEc09BO3FIUeITaobG+wBzAKMJA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 198->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHhS+PRSjmQUXx2Y3FvMZcNmBK1zx
hA9BNzNgF8dmBrawwaUP3Vx8fHx244sTbGGJK4zQwxc5PtDdhc9+FDMYUO1j
wCKOLS7hAFt6JxDXRMctmv/wxR96GBATt4TchlsfAEm2jSA=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 199->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5BntMsxjskTAe/yCbgdUOXOGK
J3wIuRk9rPCZgS1scOlDNxcfH9nfDGj+wRcnGG7BoR9rHCHFB7q78KV1FDMY
UO1iwCKOLS7hAI8fcfmB6LhF8x+++EMPA4JxS4TbcJsBAGi6jN8=
                    
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 200->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGaBgT0U4/EPXB8BOwi5ixQ3
o4cVPjOwhQ0ufejm4uMj+xuGiUlr2NyCTT+28EWOD3R34UvrKGYwoNqFLY6x
xSUc4PEjLj8QHbdo/sMXf+hhQDBuiXAbbjMAsZKMJA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 201->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGaBgT0U4/EPXB8BOwi5ixQ3
I7uNkBnYwgbFPDzxh4+P7G90t+CLE2xuwaYfW/gixwe6u/CldRQzGND8jCWO
scUlNv+gi+HyA0lxS4K9uOQIxTNBN2KYBwDC/Y1h
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 202->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGaBgT0U4/EPXB8BOwi5ixQ3
I7uPkBnYwgbFPDzxh4+P7G8GNHPwxQk2t2DTjy18keMD3V340jqKGejhhidM
sPkdnx+xuYPU9MhAgr245IhJY6S4scEeAHKRjOU=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 203->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGbBAQ67iXEXobDCZwY+85Dd
RsgMbGGDYh6e+MPHh4vBMIFwwBteaO7A6g8kNdjchS+to5iBHm54wgSb38mJ
a7Lilgh7cckRk8bwuhHDPABHio1n
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 204->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGbBAQ67iXEXobDCZwY+85Dd
RsgMbGGDYh6e+MPHh4shYWLSGtbwwqIfwx9IarC5C19aRzEDze8MWNyFbg++
cMRlBi6MYg8Dwgxi8wEudYTSFa7wJS5tAgBCHIzl
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 205->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGZhcxMuM/GFMVa/I2FcZuAz
Dw7whDG+sEExD0/84eOjiKGZgy9OsIYXFv0Y/kALL3Q34EvruMICVxyg24Mv
HPHFI7HpEZu/CNrLgFuOUDwTdCOGeQC+BYum
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 206->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGZhcxMuM/GFMVa/E2EGPvPg
AE8Y4wsbFPPwxB8+PooYmjn44gRreGHRj+EPJDXY3IAvreMNCzxhgs3vWNM7
gXxBMN2TkA9wqSOUNolxG6400WAPALgji+k=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 207->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHXY4BmY0D4DMTZgYx7ka3D5ff
8LkZ2e+EzCDofjzxh4+PIUZkWsPmFgZ7TP3ExhG+9IUujy8ssIUJNn/iSoP4
8gVZcUuMvXj8g49N0I0Y5gEAkNSK6w==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 208->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHXQ6bvXCzcdhNyF1wPjY3EWEG
Pjcju4+QGdjCBpf7kAEhPoYYkWkNa3jhCCcUf2DxEzIfX1onJiywhQk2f+JK
g/jyBVlxS4y9ePyDL54JuhHDPAB10owo
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 209->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGaBgT0U4/EPPnfh9DsRZuAz
D9l9hMzAFjYo5uGJP3x8DDEi0xo+d+KLPwYsfsKnF5s8vrDAFibY/Ik1vWMJ
S3z5CWfcImNi7MXjH3zxTKobG+wBhQuNZw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 210->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGZhcxMuM/GFMVa/E2EGPvPg
AE8Y4wsbFPPwxB8+PoYYkWkN3W44xqKWmDjCl77Q5fGFBbYwwWYn1vSOJSzx
5SeccYslPPDai8c/+OKZVDc22AMAa0SL6Q==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 211->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHhS+PRQzYHcLIf/A9eGxA8NNOMwg
2s0wgCeM8YUNinl44g8fH0OMyLSGbjd6+ONST8hd+NI6MWGBLUyw2Yk1vWMJ
S3z5CWfc4glzrPbi8Q8+NkE3YpgHANsIiqo=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 212->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGZhcxMuM8E0ATtQ9OMwg1g3
wwGeMMYXNijm4Yk/fHwMMSLTGoZbsIQHIX9gcwO+tE5MWGALE2x2Yk3vBPIF
0XGLJ8xx5TNc/sHHJtWNDfYARHGK7Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 213->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGZhcxMuM8E0ATvwxQMh87Hx
8enB5Tes5uOJP3x8DDEi0xqGW2AYi1pi4oiYMCYmLLCFCTY7saZ3AvmC6LjF
E+a48hku/+BjE3QjhnkA1BGLbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 214->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2CNhPP7B564GqH5C8UDI
fFxhhS+M8YUNLvehm42PjyFGZFrDGl4E0hTOOGLAbiY29YTCAluYYLMTa3on
kC/IiVui7MXjH2Ldg9WNGOYBANAujSo=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 215->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2EMwLruJcRc+vxMyA59a
bP7FxSeklgGLuzDCAgsfQ4zItIbNLQwE0hTOOGLAbiY29YTCAluYYLMTa3rH
Epb48hPeuCXFXjz+wRUuxGD0NNFgDwD+1I3p
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 216->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18Y4/I7ITPwqcXm
X1x8QmoZ8MQfPj4Y2KOyiUlr6HbDMRa1xMQRMWFMTFhgCxNsdmJN7wTyBUlx
S4q9ePxDrHuIcWODPQDjQows
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 217->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18Y4/I7ITPwqcXm
X1x8QmoZ8MQfPj6GGJFpDcMtMIxFLTFxREwYExMW2MIEm51Y0zuBfEFO3BJl
Lx7/EOseYtzYYA8AiLWM7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 218->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHhW+PMAObWxiQ1OEys8EeIY/L
3ej6CfkNr5ux+BcXnxi1uMzGx8cQIzKtYbgFLfxxqSfkLnxpnZiwQBbHFpe4
9CL7HZcfyIlbFHtxpB98/sHlJ2IwphkADCqJ6w==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 219->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHXY4BmY0O7BE0LjPxhTGyHYTU
EOtmbP7FxSdGLS6z8fExxIhMa9jcwkDATejmYXMDvrROTFggizPgMAOr2xlQ
1ROTn4iJWxR78cQTLv8Q6x5i3NhgDwAEvIus
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 220->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGbBAQ67iXEXih1EqCHWzdj8
i4tPjFpcZuPjY4gRmdawuQWXWmLiCF/6QpfHFxbI4gw4zMDpdjR9hPITzrhF
xkT4DZ9/8MUzqW5ssAcA74SNqg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 221->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18Yw80gQg2xbsbm
X1x8YtTiMhsfH9lfYEBkWsNwCxLGF3+E3IUvrRMTFsjiDDjMwKYX2e/Y3EFq
eoSHBwOqGK54wuUfYt1DjBsb7AGB244o
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 222->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18Yw82AYmL9htWf
JIQxvrDBF1a4wgJn2MDEiUxrGG5BCxtc6gm5C19aJyYskMWxxRMuvch+x+YO
UtMjNr/hClt8/iHWPcS4scEeAJ9UjKo=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 223->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHhY8mjsst+MwE03jsQJYn1m/Y
1DKguQ9fGKP7h1B8YIs/fHwMNxGZ1jDcgkbjUk/IXfjSOjFhgSyOLS5x6UX2
OzZ3kJweSfAbPv8Q6x6sbsQwDwBdZYzp
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 224->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18Yw80gQg0hNzOQ
EMb4wgZfWOEKC5xhAxMnMq1huAWNxqWekLvwpXViwgJZnAGHGdj0Ivsdlx+I
To/IGNlePPGEyz/44pmgGzHMAwB1GI7l
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 225->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18YYzODGL9h9ScJ
YYwvbPCFFa6wwBk2MHEi0xqGW9BoXOoJuQtfWicmLJDFGXCYgU0vst9x+YHo
9Eii3/D5B188E3QjhnkAwSyOqA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 226->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18YYzODGL9h9ScJ
YYwvbPCFFa6wwBk2MHEi0xpOd+JJf/jiCF/6QpfHFxbI4gw4zMCmF9nvuPxA
dHok0W9Y9aO5n5B7sLoRw70AGHyNqA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 227->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHhS+PRQz4HcLPjMboGbgczchdxDj
ZgY09+ELY3xhgy+s0P2Ni4/hJiLTGorf0DC++CPkLnxpnZiwQHcXMWkMDkjM
TzjTAa4wxxNPGPrR3E+su1DMx3AvAMj6jCY=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 228->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE0wTYQchdxDrZmz+
xcUnRi0us/Hxkf0NBkSmNRS/oGF88UfIXfjSOjFhge4uYtIYHJCYn3DGLYl+
w+omNPcT6y50M1DdCwBCCI3n
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 229->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE0wTYQchdxDrZmz+
xcUnRi0us/HxMcSITGsofrHHrpeQP7C5AV9aJxQWDFjcRUwaQ/c7Pn8QFbck
+g2rm9DcT8g9WN2I4V4ANAOM6Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 230->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE5dZ2OSJ9Rs+tdj8
i4tPjFpcZuPjY4gRmdZQ/GKPXS8hf2BzA760TigsGLC4i5g0Row7SEqPJPoN
q5vQ3E/IPVjdiOFeABLLjCw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 231->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE5dZcL49AhPrN6z+
JCGM8YUNvrDCFRaE4okBh1n44gM5fPClP3xxhC99ocvjCwtkcWzxhEsvIXeQ
kh5J9RtW/WjuJ+QerG7EcC8AdzCMaw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 232->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE5dZcD6R7iDWzdj8
i4tPjFpcZuPj41JDKK1hVUcg/eGLI3zpC10eX1ggizPgMAOXH/G5g5T0SKrf
sOonIp4JuhHDDAAYaI1t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 233->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE0zjsYOBWHcQ6WZs
/sXFJ0YtLrPx8THEiExr2NyCrpeQP7C5AV9aJyYskMWxxSUuvYTcQUp6xBnm
eOIJQz8R8UzQjRhmAAC0H4zr
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 234->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+E10x6CcdnBQKQ7iHUz
Nv/i4hOjFpfZ+PgYYkSmNWxuQddLyB/Y3IAvrRMTFsSYgdXtBNxBSnrEGeZ4
4glDPxHxTNCNGGYAABkujWs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 235->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18YgwGR7iDWzdj8
i4tPjFpcZuPj4zOfkDiGOgLpD18c4Utf6PL4woIYM7C6nYA7SEmPOMMcTzxh
6Ccingm6EcMMAOhbjus=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 236->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHXY4BmY3DLfjMxBfGyG4k5A5i
3YzNv7j4xKjFZTY+PooYCWkNm1sY7LGbgcsf2NyAz35iwoIYM7C6nYA7SEmP
OMMcTzxh6Ccingm6EcMMAKHKjmk=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 237->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHhW+PMAOfW/CZ2QA1A68dBNxB
kpux+BcXnxi1uMzGx8dnPiFxDHVI4YdLPSF34bOfmLAgxgysbifgDlLSI6l+
w6qfiHgm6EYMMwBqPo2q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 238->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5BntMs9DNx2cmvjAGA3sEJtZv
WP1JQhjjCxt8YYXub1x8fOYTEsdQhxQ2uNQTchc++4kJC2LMwOp2Au4gJT3i
DHM88YShn4h4JuhGDDMA8N+N6Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 239->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18Yo5hLQA2xbsbm
X1x8YtTiMhsfH5/5hMQx1NkjwgaXekLuwmc/MWFBjBlY3U7AHaSkR1L9hlU/
EfFM0I0YZgAAXluO6w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 240->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHhY8mjsst+MwE03jsQLaLWL/h
dTMW/+LiE6MWl9n4+PjMJySOoQ4p/HCpJ+QufPYTExbEmIHV7QTcQUp6xBnm
eOIJQz8R8UwKhpgBAHEQjWs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 241->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18YYzODGL/hU4vN
v7j4xKjFZTY+Pj7zCYljqLOHYHzxR8hd+OwnJiyIMQOr2wm4g5T0SKrfsOon
Ip5JwRAzAMRqj+s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 242->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHhW+PMAOfW/CZ2QA1A68dBNxB
kpux+BcXnxi1uMzGx8dnPiFxDHVI4YdLPSF34bOfmLAgxgysbifgDlLSI84w
xxNPGPqJiGdSMMQMADI+jao=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 243->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18YgwGR7iDWzdj8
i4tPjFpcZuPj4zOfkDhWO/GkP3xxhC99ocvjCwtizMDpdjxmkJIecYY5nnjC
0E9EPJOCIWYAALutjqw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 244->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHhQ+DrPQxfCZiS+Mke3Ap4YkN2Px
Ly4+MWpxmY2Pj898QuKkpEls9mBzAz77iQkLYszA5XZ8ZpCSHnGGOZ54wtBP
RDyTgiFmAAD3no6s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 245->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18Yw80gQg0hNzOQ
EMb4wgZfWOEKC2LjiVBaw+YWXO4hJo7wpS90eXxhQYwZuNyOzwxS0iO+MMel
BkOOiHgmBUPMAAA7j48s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 246->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHhY8mjsst+MwE03jsQJYn1m94
3YzFv7j4xKjFZTY+PooYmv/wpTVsboGZgS/+CLkLX1onJiyIMQOn2/GYQUp6
xBfmuNRgyBERz6RgiBkAe6ONaw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 247->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18Yw80gQg2xbsbm
X1x8YtTiMhsfH0OMyLSGzS243ENMHOFLX+jy+MKCGDNwuR2vGSSkR5xhjiP9
YNWPyy4c4UsIQ8wAAOg/jes=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 248->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbCAQF/YbMHhW+PMAOfW/CZ2QA1g6AdeNQQ
42YGNPfhC2N0/xCKD2zxh4+PIUZkWsPmFlzuweUPbG7Al9aJCQtizMDldnxm
kJIe8YY5DjUY+nHZRcBd+N0LAEA2i2s=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 249->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE18YgwESTazfsPqT
hDDGFzb4wgpXWBCKJwYcZuGLD2LSJDZ/YHMDvrROTFgQYwYut+Mzg5T0iC/M
canBkMNlFwF34XcvAMLBjO0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 250->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5BntMs9DNx2cmzAy8djAQVkPI
zQxo7sMXxvjCBl9YofsbFx9DjMi0hs0tuNyDyx/Y3IAvrRMTFsSYgcvt+Mwg
JT3iC3NcajDkiIhnUjDEDACY742s
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 251->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+EzE5dZ2OSJ9RtWf5IQ
xvjCBp2PK/7w8THEiExr2NyCyz3ExBG+9IUujy8siDEDl9vxmkFCesQX5rjU
YMjhsgtH+BLCEDMA+l6Mrg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 252->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+E10x4J47GDoDuIdDM2
/+LiE1LLYI/bbHx8FDE0c/DFCTa3YFNHbBzhS1/o8vjCghgzcLkdrxkkpEd8
YY5LDYYcEfFMCoaYAQAkAous
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 253->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahi+E1E4dZ6HYQdAeRbsbm
X1x8QmoZ7HGbjY+Pz3xC4qSkSWz2YHMDPvuJCQtizMDldnxmkJIe8YU5LjUY
cgTyHakYYgYA10+NLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 254->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahixHjdlx2MNgjMLF+w+pP
EsIYX9igmI8n/vDxUcTQzMEXJ9jcAjMDX/wRche+tE5MWBBjBk634zGDlPRI
THrCFQ+44pOQe4hzLwDYlott
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 255->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahixHjdlx2MNgjMLF+w+dm
bP7FxSdGLSG/YONjiBGZ1rC5BZd7iIkjfOkLXR5fWBBjBi634zWDhPSIM8zR
zEEHuOxDsQtH+BLCEDMA4BSLbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 256->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1noYjjNJOAWMECi8bmDKDcz
YIrhcyMxanGZjY+PIUZkWsPmFlzuweUPbG7Al9aJCQtizMDldrxmkBC3+MIc
lxoMOSLimRQMMQMAlQGMrA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 257->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahixHjdlx2MCDRWNWQ6GZs
/sXFJ6SWwZ6wX7DxUcRw+AHdXnzxiK6f2DjCl77Q5fGFBTFm4HQ7HjNISY/E
pCdc8YArPgm5hzj3AgAO0Ivt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 258->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahixHjdoJ24HIHiW7G5l9c
fGLUEvILNj42fxGT1rC5BZcZxMQRvvSFLo8vLIgxA6fb8ZhBSnrEGeZ44glD
Py67CLgLv3sBcryNLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 259->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahixHjdkJ2EHIHsW7G5l9c
fGLUEvILNj6KGAlpDZtbcLmHmDjCl77Q5fGFBTFm4HI7PjNISY84wxxPPGHo
x2UXAXfhdy8A+SyN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 260->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1noYjjNhGE87mZAUofPHYTc
zIDmPnxhjC9s8IUVrrDAG08kpDVsbsHlHlz+wOYGfPYTExbEmIHL7fjMICU9
4gxztDSCDlD040mnhNyG270ARB+NKA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 261->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1noYjjNhGEC7ibGHYTczIDm
PnxhjC9scNmNzd/EhA0DDj+g24svHtH14/MHNjfgS+vEhAUxZuB0Ox4zSEmP
OMMcTzxh6CcinknBEDMAhI2MaQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 262->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1noYjjNhGEC7sbrDnzmY1GL
zb+4+ITUMtjjNhsfH5/5hMRJSZPY7MHmBnz2ExMWxJiBy+34zCAlPeIMczz5
DEM/EfFMCoaYAQCirY3r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 263->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1noYjjNJOAWOMBhH0Hzkc0m
IYzxhQ22MMAWf/j4+MwnJE5KmsRmDzY34LOfmLAgxgxcbsdnBinpEV+Y41KD
IUcg35GKIWYAAPBIjG0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 264->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGahixHjdlx2gAGeeCDGfDCb
hDDG5R4M8/HEHz4+PvMJiZOSJrHZg80N+OwnJiyIMQOX2/GaQUJ6xBnmePIZ
hn4i4pkUDDEDAG2Vi64=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 265->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGaBAR67cfkZww4YJsIdOM0n
I4zxhQ2+sMIVFnjjyR7VjfjiBJtb0P1IyB/Y3IAvrRMTFsSYgdPt+MwgIT3i
DHM88YShH5ddOMKXEIaYAQCCjoyq
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 266->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1noYjjNhGFc7kaTx+cOnG4m
I4zxhQ2+sMIVFoTiCZsfsNmDzS243IPLH9jcgC+tExMWxJiBy+14zSAhPeIM
czzxhKGfiHgmBUPMAAATlY4o
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 267->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnzhgsstOM2EYTzuZiDgDrzmYzMP
iz9w8YlRi8tsfHxcaogJa1LSJDZ/YHMDoTglFBbEmIHL7XjNIDE9kuI3rPqJ
iGdSMMQMAIJKjiw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 268->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NRiU89gj2keul5CdiKbgc9f2OxBNgNdHJdbcJpJwC1gQMgd
+MzHZh4W/+LiE6MWl9n4+LjUEEprxKrD5w9sbsCX1okJC2LMwOV2fGaQkh5J
9RtW/UTEMykYYgYATv+N6w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 269->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnYy2ONWS8geZDPQxVEALrvRzcTjFgY0txLl
NyzmkxrG+MIGX1jhCgtC8cSAwyx88UFMmsTmD2xuwJfWiQkLYszA5XZ8ZpCS
HnGGOZ54wtBPRDyTgiFmAACxpY6o
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 270->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiVUvAHnQ5bGYxIJmDzz/43M2AjIlwB07z
yQhjXGFDSvzh42OIEZnWsLkFl3sIxhEDbv9gk8cXFsSYgcvt+MwgJt0TjAM8
8YShn4h4JgVDzAAAD1ONKg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 271->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2EMwLrvhbBjGZhaSHF53
EHIzGWGML2zwhRXWsMDCxxAjMq1hcwsu9xCMIwbc/sEmjy8siDEDl9vxmUFK
esQZ5njiCUM/EfFMCoaYAQAcWo4o
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 272->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2EMwLrtx+RmDjcNeQn5D
UUtGGOMLG3xhhTUssPBxqSGU1ohVR1QcMeD2DzZ5fGFBjBm43I7PDFLSI84w
xxNPGPqJiGdSMMQMAOXrjO0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 273->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYxoMkT43acZmGxl5DfUNSS
EcbY3ENq/OHjY4gRmdawuQWXewjGEQNu/2CTxxcWxJiBy+14zSAhPeINcxxq
MPTjsgtH+BLCEDMADM6K7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 274->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYxoMkT43YMs2AYi72E/AZn
QzGpYYwvbPCFFdawwMLHpYZQWiNWHVFxxIDbP9jk8YUFMWbgcjs+M0hJj4TS
E778gpxecKUjQm7D7V4ANjaMbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 275->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYx2CNhPP7B525k/cS4A6f5
ZIQxvrDBF1ZYwwILH0OMyLSGzS243EMwjhhw+webPL6wIMYMXG7HZwYp6ZFQ
esKXX+ByuOwi4C787gUASQaMLA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 276->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1kM9kgYj38Y8LiFAYs8Pnfg
dDMZYYwvbPCFFdawwMLHpYZQWiNWHT5/YHMDvrROTFgQYwYut+Mzg5T0iC/M
canBkCMinknBEDMAFdKNKg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 277->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1kMaPLEuB3DLBjG4hdCfkNR
S0YY4wsbfGGFNSyw8HGpIZTWiFWHzx/Y3IAvrRMTFsSYgcvt+MwgJT0SSk/4
8gt6mibWPcS5FwA82I0s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 278->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHnQ5bGYxwNTgsBuXn1HYyJgId+A0
3x7JPQyY+vGZQYxaQn7BxselhlBaI1YdUXHEgNs/2OTxhQUxZuByOz4zSEmP
hNITvvwClyMinknBEDMA5iKMrA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 279->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0vIHjgfj1nY5LCaCcNY3IIsh9cd+Mxn
QJhDShjjCxt8YYU1LLDwMcSITGvY3ILLPbj8gc0N+NI6MWFBjBm43I7PDFLS
I74wx6UGQ46IeCYFQ8wAACK6jSo=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 280->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDo//GfCYxYCkhgGf2/G4hQFZHpfb
kdTgDBssbsUWHtj4xKjFFX/4+BhiRKY1bG7B5R5c/sDmBnxpnZiwIMYMXG7H
awYR6Z5gHOBIx1j140mnuMIYH4aYAQAg/4um
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 281->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0us/7HphwOYGnsEG6vb8biFAVkel9sJ
+BWmlwFNL7bwwMYnRi2u+MPHxxAjMq1hcwsu9xCMIwbc/sEmjy8siDEDl9vx
mUFMuicqDnCowdCPJ50Schtu9wIAmoqL6Q==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 282->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZKMAev3p089DtIWQGhlpcbsLjf2z60d3PgGYGKW6B6cXmF2z+
xxk2SG5ADyd8bsIVNjjDCs1sfHwMMSLTGja34HIPwThiwO0fbPL4woIYM3C5
HZ8ZxKR7YuIAlxoMOSLimRQMMQMAE1CNKA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 283->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZKMAev3p089DtIWQGhlpcbsLjf2z60d3PgGYGhtvxuIUBWZ6A
O7C5CzkcGNDUYgsPbHxi1OKKa3x8DDEi0xo2t+ByD8E4YsDtH2zy+MKCGDNw
uR2vGUSke4JxgCMdY9WPJ53iCmN8GGIGAP7ii2c=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 284->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDo//semHAyT9DHjcjs8tML341BPy
K8wtDGhqsZmJjU+MWlzxh4+PIUZkWiMUFrjUE3IXvrROTFgQYwYutxMyg1C6
JyoOcKjB0I/LLhzhSwhDzAAAiS2MKg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 285->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDpceZIzFLAZ7VHU43Y7HLcjm44sH
fH6FuYUBTS02M7HxiVGLK/7w8XGpIZTWiFWHzx/Y3IAvrRMTFljNwBLuhMIL
X/rDle6JigMcajD0ExHPpGCIGQAOoYvn
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 286->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDpceJDlsZmFTR6pbwICAekJ+hZtB
YhjjCxucYYXudzx8XGoIpTVi1eHzBzY34EvrxIQFTjPwuJModxCR7omKAxxq
MPQTEc+kYIgZAGPPjCo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 287->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDo//senHcAeaGaS4BZ3G5w5cfgUD
JDeguw+fm3CFDc6wQvc7Hj6GGJFpjVBY4FJPyF340joxYUGMGbjcjtcMItI9
MXGASw2GHBHxTAqGmAEACw2Naw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 288->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDo//senHcAeaGaS4BZ3G5w5cfkV2
BylhjC9scIYVut/x8DHEiExrhMICl3pC7sIW7+jy+MICpxl43EmsOwile2Li
AJcaDDki4pkUDDEDAB+Qjqg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 289->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDpceJDlsZqHw8bkdj1tgehnwuIOQ
X5HdS0oY4wsbnGGFze84+BhiRKY1bG7B5R5c/sDmBmzxji6PLyxwmoHHnUS5
A4d9pJiJTw2GHBHxTAqGmAEA2RaMqA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 290->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDpceJDlsZuEzm1i3gAESjSse8PkV
2b2khDEp7scVf/j4GGJEpjVsbsHlHlz+wOYGbPGOLo8vLHCagcedRLkDh32k
mIlPDYYcEfFMCoaYAQDhWIyq
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 291->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU4uiDpcee+z6CbmDFLeAAQ6/EOITsosY
NxHrflxm4+PjUkMorRGrDp8/sLkBX1onJixwmoHHncS6g1C6JyYOcKnBkCMi
nknBEDMApCKL7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 292->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0us/7HpJ+QOUtyCzy+E+ITsIsZNxLof
l9n4+LjUEEprxKojNY7wxTUxYUGMGbjcTsgMQumemDjApQabnYTimRQMMQMA
LDKNsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 293->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0us/xnwmIXPbGLdgs8vhPiE7CLGTcS6
H5fZ+Pi41BBKa8Sqw+cPbG7A0GePKY8vLHCagcedRLkDh32kmIlPDTY7CcUz
KRhiBgDGvY6s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 294->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0us/xnwmIXPbGLdgs8vhPiE7CLGTcS6
H5fZ+PgYYkSmNVz+wRdnxMQRvrgmJixwmoHHncS6g1C6JyYOcKnBZieheCYF
Q8wAAKj2jm0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 295->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZKMAev3p089DtQTcH3QxsarG6CY//GfCYhc9sYt2Cywxi+ITs
IsZNxLofl9n4+LjUEEprxKrD5w9sbsAW7+jy+MICpxl43EmUO3DYR4qZ+NRg
s5NQPJOCIWYAAHlyjSw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 296->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeOMBhBja15Pofq714zCbWLbjMIIZPyC5i3ESs
+3GZjY+PSw0xYU1KmsTmD2xuIBSnhMICpxl43EmsOwile2LiAJcabHYSimdS
MMQMAAWTji4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 297->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NRiU89gj2keul58djLY41dLqv+xmYXPbGx8bOrx+YUQn5Bd
xLiJWPfjMhsfH5caYsKalDSJzR/Y3EAoTgmFBTFm4HI7ITNw8Yk1E58abHYS
imdSMMQMAPYrjW8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 298->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NRiU89gj2keul58djLY41eLbhch/2MzC5/Z2PjY1OPzCyE+
IbuIcROx7sdlNj4+LjXEhDUpaRKbP7C5AVu8o8vjCwucYYLHncS6A5f/iTUT
nxpiwo4SDDEDANwLjms=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 299->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZKMAev3p089DtgZnBgE29PRa1uNxEhP+xmYXPbGx8bOpxmUEM
n5BdxLiJWPfjMhsfH0OMyLSGyz/40h8xcYQt3tHl8YUFzjDB406i3IHDPlLM
xKcGl7vx+YkUDDEDAC6qjio=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 300->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZKMAev3p089DtIWQnPrWk+h+bWfjMJtYt+PxCiE/ILmLcRKz7
cZmNj48hRkJYk5ImsfkDmxsIxSmhsMAXJvj0EuMOQumemDjAmc9wuBufn0jB
EDMA3PKO7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 301->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0uq/7GZhc9sYt2Czy+E+ITsIsZNxLof
l9n4+LjUEBPWpKRJbP7A5gZCcUooLLCaQYReotxBIN0TEwe41GCzk1A8k4Ih
ZgAAaJ6OLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 302->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ2NTiUo9uHrpeQnbiU0uq/7GZhc9sYt2Czy+E+ITsIsZNxLof
l9n4+LjUEBPWhNRh8z8hdxGKU0J2YTODGL1EuYNAuicmDnCpweVufH4iBUPM
AADB4I3v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 303->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ6ACfenR5dH2EzMCnllT/YzMLn9nEugWfXwjxCdlFjJuIdT8u
s/HxcakhJqwJqcPmf0LuIhSnhOzCZgYxeolyB4F0T0wcEJPPCIU1ORhiBgDr
QI0w
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 304->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZYGAPxXjUY5NHtwefGeh2EOsvDH9gEcdwBxazsfGxqcdlBjF8
QnYR4yZi3Y/LbHx8DDE8YUps2CHHOwMef2BzA764JiYssJlBjF6i3IHD/8Sa
iU8NLnfj8xMpGGIGAFXWi2s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 305->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGCPXz02eXR78NnJYI9fLbH+Z8AiTsgdWP2DQz0+vxDiE7KL
GDcR635cZuPj41RDIK3h8g++tEFMHOGLa2xmYDMfV5jg00uUO3D4n1gz8anB
5W58fiIFQ8wAAP5Viu8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 306->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsj4GQWjT3otvJgGYGOsDmVnT7YfaQ4i9c/sBmLy53YPUPDvX4/EKI
T8guYtxErPtxmY2Pj0sNobRGjDps/ifkLnxxTUxYYDODGL2kuAOb34gxE58a
XO7G5ydSMMQMADvajG0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 307->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ6ACfenR5dH34zGCwx6+WWP8zYBEn5A5s/sGlHp9fCPEJ2UWM
m4h1Py6z8fFxqiGQ1nD5ByVu0cwhJo7wxTUxYYHNDGL0kuIOXOmemDggJp8R
CmtyMMQMAFMlirA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 308->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZKMAev3p089DtYcCiBs5G8wux/sLwBxZxDHdgMRsbH5t6XGYQ
wydkFzFuItb9uMzGx8cQwxOmxIYdStzi8Qc2N+CLa2LCApsZxOglxR240j0x
cYAzn+FwNz4/kYIhZgAANR2LLg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 309->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ6ACfenR5dH34zGCwx6+WVP9jMwuf2dj42NTj8wshPiG7iHET
se7HZTY+PoYYUtwQCmtCcYJiHhZ/YHMDoTglFBbYzCBGLynuwJXuiYkDYvIZ
obAmB0PMAADF94uw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 310->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ6ACXegZ7THl0faSYQay/MMzEIk7IHVjdgkM9Pr8Q4hOyixg3
Eet+XGbj4+NSQyitEaMODPD4A5sb8MU1NjOwhROuMMHrThLcgS1uiTETnxpc
7sbnJ1IwxAwAXmeLsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 311->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZYGCPwPjUo5uHbg8DFjUo+pHEiPUXhj+wiGO4A4vZ2PjY1OMy
gxg+IbuIcROx7sdlNj4+hhiRaQ2Xf/ClDWLiCF9cExMW2MwgRi8p7sCV7omJ
A1xqcLkbn59IwRAzACUzjes=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 312->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGCPXz02eXR78JnBgCZPrL8w/IFFHMMdWMzGxsemHpcZxPAJ
2UWMm4h1Py6z8fExxIhMa7j8g0sNNn9gcwO+uCYmLLCZQYxeUtyBzW/EmIlP
DS534/MTKRhiBgCx+4xt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 313->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ6ACXegZ7THl0ffjMYLDHr5ZU/2MzC5/Z2PjY1OPzCyE+IbuI
cROx7sdlNj4+TjVEhDW+OGFAwrj8gc0NhOKUUFhgM4MYvaS4A1vcEmMmPjW4
3I3PT6RgiBkADyWKsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 314->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uHbg8DFjVwNppfiPUXLnXYzMJnNjY+NvW4zCCG
T8guYtxErPtxmY2Pj0sNMWGNTx08bvH4A5sbCMUpobDAZgYxeklxB650T0wc
4FKDy934/EQKhpgBADBWjC4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 315->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ6ACfenR5dH0MWNTg8gux/sKlDptZ+Mwm1i24zCCGT8guYtxE
rPtxmY2PjyFGQlgTUoduPjFxRChOCYUFNjOI0UuKO3Cle2LigJh8RiisycEQ
MwDoJIyw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 316->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZ6ACXegZ7THl0ffjMYLDHr5ZY/zNgESfkDqz+waEen18I8QnZ
RYybiHU/LrPx8XGpIZTWiFEHBnj8gc0NGPbY4zcDWzhhDRNC7iTkDjR96Gxi
zMSnBpe78fmJFAwxAwCwm4uu
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 317->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZYGAPweji2NRiswPuXyxq4Gw0vxDrL1zqsJmFz2xsfGzqcZlB
DJ+QXcS4iVj34zIbHx+XGmLCmpA6MMDjD2xuwLDHHr8Z2MKJ1LRDlDvQ9KGz
iTETnxp87ibkJ2IwxAwAOjGOqg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 318->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZYABj2+NXj24euj0wsxiwqbfHohaXm4jwPzaz8JmNjY9NPS4z
iOETsosYNxHrflxm4+NjiBGZ1nD5B2c6wuIPbG7AFu/4zMAWTvjSD053EnIH
WtggqyHWTGxmoKvDFZ+45IjFEDMAt9uNKA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 319->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uHAuxRMYZ6NL/g8hcDDvfhCxd0/2LTg42PTT0u
M4jhE7KLGDcR635cZuPj41JDTFgTUgcGePyBzQ3Y4h6fGdjCCWuYEHInIXcg
+QVXuicmDnCpweVufH4iBUPMAAC7hIxp
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 320->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uHbg8hM1DUEukvXOqwmYXPbGLdgssMYviE7CLG
TcS6H5fZ+PgYYiSENSF1yOZh8wc2N2DYY4/fDGzhhDVMCLmTkDvQ9KGziTET
nxpc7sbnJ1IwxAwA69GOaQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 321->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uHbg8hM1DUEukvXP7AZhY+s4l1Cy4ziOETsosY
NxHrflxm4+NjiBGZ1nD5B0OMxDjCsMcevxnYwglrmBByJyF3oOlDZxNjJj41
uNyNz0+kYIgZAI+cjao=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 322->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uHbg8hM1DUEukvDPOx6MdwBxaziXULLjOI4ROy
ixg3Eet+XGbj4+NSQyitEaMO3Xxi4gjDHqT0Q0xYYDOjAc0MXO7E6w40fehs
YszEpwaXu/H5iRQMMQMAIWiMrA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 323->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uHbg8hM1DUEukvDH/gMQuf2cS6BZcZxPAJ2UWM
m4h1Py6z8fFxqSGU1ohRh24+MXGEYQ9a/BIKC2xm4Eoj+MKLYJpjwC1HSvpD
V4crPgnlCWLyTIM9AH+djWs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 324->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uHbg8hM1DUEukvDPMZkGgG7P7FZjaK2/G4BZcZ
xPAJ+Rufm/DZTVT8EQgLfGqwhQkhd2IVQzIHV3wj87H6hYSwwGYGzC943UmM
Oxgw7SPFTHxqcLkbn59IwRAzAHzdiqw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 325->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uHbg8hM1DUEukvDPOx6MdwBxazUdyOxy24zCCG
T8jf+NyEz26i4o9AWGAVQzYHT5zg8g+GGB5/YHMDVr+QEBY4w4SQO4lxBwOm
faSYiU8NLnfj8xMpGGIGAEpti+s=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 326->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uH1R48ZiCrJdZfKHrssetHdwc2s4l1Cy4ziOET
sosYNxHrflxm4+PjUoMcttjsweUfDDE8/sDmBqx+ISEssJlBjF6i3MGAaR4p
ZuJTg8vd+PxECoaYAQDO7Yxt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 327->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uH1R48ZiCrJdZfKHqQMRaz8JmN7kZc6nGZQQyf
kL/xuQmf3UTFH4GwwCpGZFrD5R98cYsrvtHVYJhBQlhgM4MYvUS5gwHTPFLM
xKcGl7vx+YkUDDEDAIyljCw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 328->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uH1R48ZiCrJdZfKHqQzMdmFj6ziXULLjOI4ROy
ixg3Eet+XGbj4+NSQyitEaMO3Xxi4ghFP5b4JRQWWN1KhF587iAmbokxE58a
bHYSimdSMMQMAEFTjCw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 329->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcGAPwfjUo5uH1R48ZiCrJdZfKHrssetHdwc2s4l1Cy4ziOET
sosYNxHrflxm4+NjiBGZ1nD5B194EhNHhNIXobDAZgYxeolxBza3kGImPjW4
3I3PT6RgiBkAcLuNbQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 330->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcIBFHJtabHbgMxuXX4j1F4oee+z60d2BzWxi3YLLDGL4hOwi
xk3Euh+X2fj4uNQQSmvEqEM3n5g4wuoXEsICqxlI5uBzJ0F3MGDaR8jvhNyM
ro6YPEMOhpgBAPxnjK4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 331->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZuMwnJIYOcJmNyy5i/YXLH9jMwmc2sW7BZQYxfEJ2EeMmYt2P
y2x8fAwxMtMCLvchm09MHBFKX4TCApsZxOglxh3Y3EKKmfjU4HI3Pj+RgiFm
AACdJI9t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 332->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZuMwnJIYOcJmNyy5i/YWiB8bHYRY+s1HcjsctuMwghk/I3/jc
hM9uYuKPUFhgFSMzLeByH7L5uOIbXQ2GGSSEBVYzkDEedxJ0BwOmfYT8TsjN
6OqIyTPkYIgZAJUFjKw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 333->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZuMwnJIYOcJmNyy5i/YWiB4pxmYXPbBS343ELLjOI4RPyNz43
4bObmPgjFBZYxchMC7jch2w+MXGE1S8khAVWM3CkEXzhRShPoLOJMROfGmx2
EopnUjDEDABwSY3r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 334->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6wPlxlggMUcbOrRzUMBOMzG5RdC/sLlfwY8ZuEzG90MXOpxmUEM
n5C/8bkJn90E44+IsMAqRmRaw+UffHFLTBwRSl+EwgKbGcToJcYd2NxCipn4
1OByNz4/kYIhZgAAI1uN6w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 335->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZcIBFHJtabHZg04/NDGQ3EesvXP7AZhY+s4l1Cy4ziOETsosY
NxHrflxm4+PjUkMorRGjDt18YuIIRT8SJjYssLqVCL343EFM3BJjJj412Owk
FM+kYIgZAPRajO0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 336->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5cZuMwnJIYBcJiNyy5i/YWiBxljMQuf2Shux+MWXGYQwyfkb3xu
wmc3MfFHKCzwqSE1LRDSi80f2NyAoR8aN8SGBVa3EqEXnzuIiVtizMSnBpud
hOKZFAwxAwC0ZIvt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 337->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6wPlxlggMUcbOrRzUMBOMzG5RdC/sLlfwY8ZuEzm1i34DKDGD4h
u4hxE7Hux2U2Pj4uNYTSGjHq0M0nJo7wpUNsZmALJ1xhQsid+MxA14fOJsZM
fGpwuRufn0jBEDMA0e2NLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 338->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6wPlxlggEMcnxgGIMIMZDcR8hcu/2PTj+5fbGYT6xZcZhDDJ2QX
MW4i1v24zMbHx6WGUFojRh26+cTEEXo6RhbDZgY2OVxhQsid+MxA14fOJsZM
fGpwuRufn0jBEDMAmfCN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 339->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6wPlxmkiKObh80efGYgqyXkL6x6kPyLzSx8ZhPrFlxmEMMnZBcx
biLW/bjMxsfHpYZQWiNGHbr5xMQRejpGFsNmBjY5fOkOnzvxmYGuD51NjJn4
1OByNz4/kYIhZgAAfjSOrA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 340->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyuGwAxkgi2HTj0yjm4FPDB3gcjsuv+DTh1MPMsZiFj6zUdyOxy24zCCG
T8jf+NyEz258aQmX37HxcakhlNaIUYduPq74RleDKy1jMwObHL50h8+d+MxA
14fOJsZMfGpwuRufn0jBEDMAbAuMrA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 341->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyuGwAxkgi5FqLz4xdECMGchq8enDqQeKcZmFz2xi3YLLDGL4hOwixk3E
uh+X2fj4GGJEpjVc/sEXnsTEEb60TExYYHMrMXrxuYOYuCXGTHxqcLkbn59I
wRAzAMHXjus=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 342->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyiFhbHqQ9ZHqFmzq0c3DZg8+M5DV4tOHz/8MeMzCZzaxbsFlBjF8QnYR
4yZi3Y/LbHx8DDEi0xou/+ALT2LiCKs/SAgLrG5FxnjcidcMNH3obGLMxKcG
m52E4pkUDDEDAJI7jao=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 343->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6wPlxnY9ONSj24eHBBpBrKbMNxHpP+x6Uf3L7YwI9YtON1HBJ+Q
XcS4iVj34zIbHx9DjMi0hss/+MKTmDjC6g8SwgKrW5ExHnfiNQNNHzqbGDPx
qcFmJ6F4JgVDzAAAMN6Nqg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 344->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6wPlxnY9ONSj24eHBBpBrKbMNxHhP8ZkNRhMwuX2aS4Baf7iOAT
sosYNxHrflxm4+NjiBGZ1nD5B194EhNH+MzEZgY2OXxpGp878ZmByy2kmIlP
DS534/MTKRhiBgAMBI7p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 345->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6wPlxnY9ONSj24eHBBpBrKbMNxHhP8ZkNRhMwuX2aS4Baf7iOAT
sosYNxHrflxm4+PjUkMorRGjDt18YuIIPR0ii2EzA5scqXmHkDuIiVtizMSn
Bp+7CfmJGAwxAwBskI9p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 346->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6yPVLdgU49uHhwQaQaymzDcR4T/Geyx60f3L7YwI9YtON1HBJ+Q
XcS4iVj34zIbHx+XGkJpjRh16OYTE0fo6RgMSAgLbG4l1p34zEDXh84mxkx8
avC5m5CfiMEQMwDteY8q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 347->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6yPVLdgU49uHkG3MWB3FzH+wuV/bPrR3YLNbGLdgssMYviE7CLG
TcS6H5fZ+Pj4zCckTkgduvnExBF6OgYDEsICm1uJdSc+M9D1obOJMROfGnzu
JuQnYjDEDABdRZFp
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 348->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6yPVLdgU49uHhiQYAaym1DYRPqfAUktNrOwmU2yW3CYQQyfkF3E
uIlY9+MyGx8fn/mExAmpQzefmDhCT8dgQEJYYHMrse7EZwa6PnQ2MWbiU4PP
3YT8RAyGmAEAxOWQ5w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 349->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6yPVLdgU49uHkG3MWB3FzY2sf5nwGMWNrPJdQu28CPEJ2QXMW4i
xv0MeMzGx0cRIyGt4fQPnvAkJo7Q0zGymcSEBTa3EvIPIXcQE7fEmIlPDT53
E/ITMRhiBgA7o5Ao
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 350->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6yPVLdgU49uHkG3MWB3FzY2sf5nwGYWEsYVZqS6BVv4EeITsosY
NxFyP7I/sZmNjw8GWMwglNZw+QdfeOIKY3Q1yPEKcx/RYYHFrcS6E58Z6PrQ
2cSYiU8NPncT8hMxGGIGALuakKQ=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 351->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6yPVLdgU49uHkG3MWB3FzY2sf7HpZ8BKSywuYtUt2CzlxCfkF3E
uIkY92NzB7pebHwwsGdACSti0hou/+ALT1xhjK4GOR3D3EdsWGBzK3KewOdO
fGYghxWu8CZkJrJ+bPFAbJ4hB0PMAACfH47n
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 352->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuPRg6yPVLdgU49uHkG3MWB3FzY2Mf5nQMZYzMJmNla3E+EWbOFHiE/I
3/jchM9ufObj8js2PlyMQLohJR5xxS2u+EZXgxEnJIQFNrci5wl87sRnBro+
dDYxZiL7BVc8EJNnyMEQMwCbmI4o
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 353->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdhE+p8BSS02cWxyJLsFixixfEJ2EeMmYtyP
zR3oerHxUcRISGu4/IMvPHGFMboauH40dxETFtjcipye8LkTnxno+tDZxJiJ
Tw0ud+PzEykYYgYAjC2Q5Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 354->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdhE+p/BHrd+XGaT7BYcZhDDJ2QXMW4i5H4G
JIzNbHx8FDES0hou/+ALT1xhjK4Grh/NXUSFBRa3IqcnfO7EZwa6PnQ2MWbi
U4PL3fj8RAqGmAEApJOPZw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 355->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq0dnE+J/BHrd+XGaT6xZs4UeIT8guYtxEjPsZ
8JiNj4/PfELihNShm09MHKHoJzIe0OWwphki3InPDHR96GxizMSnBpe7CeUF
YjHEDABvJ49r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 356->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdhE+p8BGWPRz4BFD1a343MLFjFi+YT8jc9N
+OzGZz662fj4+MwnJE5IHbr5uOIbXQ2+OCEUFtjcSkw6wOcOYuKWGDPxqcHl
bnx+IgVDzAAAR7mP5w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 357->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdhQTIz/GXCZhWQONncR7RYsYsTyCdlFjJtw
xTk+u7D5BRsfn/mExAmpQzcfVxijq0GOV0JmYAsnrGmGCHfiMwNdHzqbGDPx
qcHlbnx+IgVDzAAAa3+PqA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 358->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqMdhE+p8Bl1k45MhxC1Z7ieATsgvdn7jciM/9
DEgYWzzg4+Mzn5A4IXXo5uMKY3Q1yPFKyAxs4YQ1zRDhTnxmgAGaOcT4HcOv
uNIADnfj8xMpGGIGANwBjec=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 359->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqMdhE+p8Bl1k45MhxC1Z7ieATsgvdn7jcSMj9
6GZg8ws2Pj7zCYkTUoduPq4wRleD7CdCZmALJ6xphgh34jMDXR86mxgz8anB
5W58fiIFQ8wAAHCvj6g=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 360->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqMdhE+J/BHqEOm35sZpPjFmxmEMMnZBcxbiLG
/Qx4zMbHx2c+IXFC6tDNxxXG6GqQ/UTIDGzhhDXNEOFOfGag60NnE2MmPjW4
3I3PT6RgiBkATm2PaQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 361->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqMdhE+J/BHqEOm35sZpPjFmxmEMMnZBcxbiLG
/Qx4zMbHx2c+IXFC6tDNxxXG6GqQ/UTIDGzhhDXNEOFOfGag60NnE2MmPjW4
3I3PT6RgiBkATm2PaQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 362->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq4cAeQRPyP4M9Qh2KfnuEObjCjBi3NOAxgxg+
IbvQ/YnLjYTcjzUcGAjz8ZlPSJyQOnTzccY3Aw4ziYwHdDlS8w4hdxATt8SY
iU8NPncT8hMxGGIGABNcjig=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 363->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqMdhE+J/BHqEOmzg2s8lxCzYziOETsosYNxHj
fuTwQjcbHx+f+YTECalDNx9XGKOrIcUMbOFEat4h1R240j0hM/GpweduQn4i
BkPMAACkfY/p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 364->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqMdhE+J/BHqEOXT86jc1uOJuAW7CZQQyfkL/x
uYkk9yOFF7rZ+Pj4zCckTkgduvm44htdDSlmYAsnUvMOqe7Ale4JmYlPDT53
E/ITMRhiBgD4Q4+q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 365->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq4cAeQRPyP4M9Dv045Eh1SwMeM4jhE7KLGDcR
436Yv7GZjY+Pz3xC4oTUoZuPM74ZsJtJbDygy5Gad4h2BzRN4Ur3hMyEmYFN
DT53E/ITMRhiBgA0qY3p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 366->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq0dnE+J/BHod+PGaT6xZs4UeIT8guYtxEjPux
uZ0YPj7zCYkTUoduPjHuxBvXeNyKzwxi3UmMOxgIhD0+M5H144oHYvMdqRhi
BgChCY6s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 367->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdgk+B+XfgYkc7C5i2i3YBEjlk/ILmLcRIz7
sbmdGD4+8wmJE1KHbj4x7sRnPz634jODWHcS4w5saog1E58afO4m5CdiMMQM
AJwPkCo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 368->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdhE+p8BSS2GWfZofCx2E+UWHGYQwydkFzFu
Isb9MP9iMxsfH5/5hMQJqUM3H1cYo6shxQxs4URq3iHFHdjUEGsmPjX43E3I
T8RgiBkAz8mPqg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 369->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdhE+p8BGaObZY/Gx2I3UW7BYQYxfEJ2EeMm
YtyPze3E8PGZT0ickDp084lxJ964xuNWfGYQ605i3IFNDbFm4lODz92E/EQM
hpgBALaMjus=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 370->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqifUXih577PrBAIccqW7BZQYxfEJ2EeMmYtyP
ze3E8PGZT0ickDp084lxJ964xuNWfGbA1RBwJ9HuwBP2+MxE1o8rHojNd6Ri
iBkAoBaO6w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 371->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqifUXih4oxmUWPrOJdQsuM4jhE7KLGDcR435i
/I6Nj898QuKE1KGbT4w78cY1HrfiMwOuhoA7iXYHnrDHZyY+NXjdjUeOWAwx
AwDi/o9r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 372->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCcGB3jMQTcD2U0obCL9j2wXNrOwmU2yW3CYQQyfkF3E
uIkY9xPjd2x8fOYTEiekDt18YtyJN67xuBWfGchpGwwI5A2C7kBLn/j8jtfN
eNIBvrAmB0PMAADmCo7n
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 373->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdgk+J8Bj1nYzCbZLTjMIIZPyC5i3ESM+4nx
OzY+PvMJiRNSh24+Me7EZz8+t+IzAzmdgAGBvEHQHXjCHp+Z+NTgdTceOWIx
xAwADFSPqg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 374->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqifUXLn9gMwuf2cS6BZcZxPAJ2UWMm4hxPxjg
MBsfH5/5hMQJqUM3n5g4wmc/PrfiMwMsjiWccMUFTnfYI2EG7G7EZya63eiA
lHxHKoaYAQAF6o9p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 375->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqifUXhj/wmIXPbGLdgssMYviE7CLGTcS4H5s7
CIUFLv8Sk9Zw+QdfeBITR/jsx+dWfGZgpBECeQOnO+yRMAN2NxKKA1xqcLkb
n59IwRAzAB0fkKg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 376->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCcGB3jMQTcD2U0obBL8z4DHLGxmk+wWHGYQwydkFzFu
IuR+BiSMz+/Y+PjMJyROSB26+cTEET778bkVnxkY5hHIG/jcAQ9rBuxuxGcm
PjX43E3IT8RgiBkATwiO5w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 377->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8InBgT0EE2MGsptQ2ET6H9kubGZhMxur2/G5BYcZxPAJ+Ruf
m/DZjc39uMzGx8dnPiFxQurQzScmjvDGNR634jMDwzwCeQOfO2DpDVkNPr8T
cjO6OmLyDDkYYgYAWhePZw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 378->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqifUXih4CZuEzG8XteNyCywxi+IT8jc9N+OzG
Zz4uv2Pj4zOfkDghdejmExNHeOMaj1vxmYFhHoG8gc8dDEhphRi/E3Izujpi
8x2pGGIGAPuCkGk=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 379->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8IlhswOvejS/EOsvDH9gEUd3CzazsfGxqcdlBjF8QnaBAQE3
EXI/AxLG53dsfHzmExInpA7dfGLiCJ/9+NyKzwwM8wjkDXzugIc1A3Y34jMT
nxp87ibkJ2IwxAwA43CPKA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 380->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCcGB3jMwaqeAZVPjDtQzMEijs9sXP7B6RYcZhDDJ2QX
MW4i5H4GmDyBcMXGx2c+IXFC6tDNJyaO8NmPz634zCAmDRPrDljaRlaDz++E
3Iyujlg3k4ohZgAAsvGOaQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 381->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCcGB0Sage4mFDYJ/seqH4/ZuPyD0y04zCCGT8guYtxE
yP0MRIYrNj4+8wmJE1KHbj4xcYTPfnxuxWcGMWmYVHcgq8Hnd0JuRldHrJtJ
xRAzAPlxj2s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 382->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8InBAZFmoLsJhU2C/xmwiOMzG5d/cLoFhxnE8AnZRYybiHE/
NncQCgtc/iUmreHyD77wJCaO8NmPz634zCAmDZPqDmQ1+PxOyM3o6oh1M6kY
YgYAxMSQqg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 383->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8InBAZFmMKD5BZ1NrP8ZsIij+xdbmGHj43MLtvAjxCdkFzFu
IuR+eDjiMBsfH5/5hMQJqUM3n5g4wmc/PrfiM4OYNEyqO5DV4PM7ITejqyPW
zaRiiBkApYqPqg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 384->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8IlhswOvejS/oLBJ8D8DFnEGJIwrzLDxsboFixixfEJ2EeMm
YtwPBjjMxsfHZz4hcULq0M3HFcboakgxA1s4YU0zBNIwqe5AVoPP7xh+xaEG
l7vx+YkUDDEDACuIj+c=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 385->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8IlhswOvejS/oLOJ9T8DFnFsfkU3Exsfn1sImYmNT8guYtxE
jPvBAIfZ+Pj4zCckTkgduvm4whhdDSlmYAsnctIwqe5AVoPP7xh+xaEGn7sJ
+YkYDDEDAOA0kCo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 386->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8IlhswOvejS/oLOJ9T8DFnFsfkU3Exsfn1sImYmNT8guMCDg
JkLuZ0DC2OIBHx+f+YTECalDNx9XGKOrIcUMbOGENc0QSMPEuANbmiXkd0Ju
RldHKM+QiyFmAAAKv4+o
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 387->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8IlhswOvejS/oLOJ9T8DFnFsfkU3Exsfn1sImYmNT8guMCDg
JkLuZ7DHNAObX7Dx8ZlPSJyQOnTzcYUxuhpSzMAWTljTDIE0jM8d8HSKJx/h
8jshN2Mzj5h8RyqGmAEAJzyO6Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 388->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8IlhswOvejS/oLOJ9T8DFnFsfkU3Exsfn1sImYmNT8guMCDg
JkLuZ0DC2OIBHx+f+YTECalDNx9XGKOrIcUMbOFEThomyh148hEuvxNyMzbz
iHEzqRhiBgD+LY9p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 389->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8IlhswOvejS/oLOJ9T8DFnE4wBNm2PhY3YLLXiL4hOwixk2E
3M+A5EZsZuPj4zOfkDghdejm44wjBuxmEmMGtnAiJw0T5Q48+QiX3wm5GZt5
xLiZVAwxAwBswpAo
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 390->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq0dnE+p8Bj1nYzCbZLbjsJYJPyC5i3ESM+7G5
g1BY4PIvMWkNl3/whScxcYTPfnxuxWcGMWmYKHfYo2Ji/E7IzejqiHUzqRhi
BgB8J5Fn
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 391->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdgk+J8Bm1lIGFeYEe0WLGLE8gnZBQYE3ESM
+7H5FV0vNj4+8wmJE1KHbj6uMEZXQ4oZ2MKJnDRMlDtg4QxlE+N3Qm5GV0es
m0nFEDMA9byRJA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 392->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq0dnE+p8Bj1nY5Mh1C7bwI8QnZBcxbiLG/Qx4
zMbHx2c+IXFC6tDNxxlHDNjNJDYe0OXIScNEuQMazjA2MX4n5GZ0dcS6mVQM
MQMA5neRZw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 393->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq0dnE+p8Bl1k45Mh1C7bwI8QnZBcxbiLG/Qx4
zMbHx2c+IXFC6tDNxxXG6GpIMQNbOJGThol1BxwQ6XdCbkZXR6ybScUQMwBJ
s5Eo
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 394->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq0dnE+h+Xflxmk+sWbPYS4hOyixg3EeN+bO4g
FBa4/EtMWsPlH3zhSUwc4bMfn1vxmUFMGibWHehqCfmdkJuxmUeMm0nFEDMA
TWeP7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 395->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjq0dnE+J8BinGZhc1sct2CLfwI8QnZBQYE3ESM
+9HNICYscPmXmLSGyz/4wpOYOMIb13jcis8MYtIwse5AV0vI74TcjM08YtxM
KoaYAQDPe49r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 396->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqUdhk+B9dPwOSOdj0EO0WLGLE8gnZRYybiHE/
Nneg68XGx2c+IXFC6tDNxxXG6GpIMQNbOJGThol1B7paQn4n5GZs5hHjZlIx
xAwAv0GRqA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 397->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwzUPj2mOYRchuKejQzkPUykOB/BiziYIDDbJz+QdePFmfYwo8Q
n5BdxLiJGPdjcwe6Xmx8fOYTEiekDt18XGGMroYUM7CFE940TETewOcOMMAR
3oTMxKcGn7sJ+YkYDDEDAFk1kGc=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 398->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwzUPj2mOYRchuGGUjqUdgk+B+rfgbsfLLcgsMMYviE7CLGTcS4
H5s7CIUFLv8Sk9Zw+QdfeBITR/jsx+dWfGagp1lCeQOfO9DVEvI7ITdjM49Q
WJODIWYAAISGj+s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 399->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwzUPj2mOYRchuGGUjqifUXih4oxmUWPrOJdQsuM4jhE7ILDAi4
iZD7GZAwPr9j4+Mzn5A4IXXo5hMTR3jjGo9b8ZmBz92kugNdLSG/E3IzNvOI
cTOpGGIGAE1Xjqo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 400->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCcGB3jMQTcD2U0obBL8z4DHLGxmk+wWHGYQwydkFzFu
Isb9yGGOy+/Y+PjMJyROSB26+cTEET778bkVnxnEpGFi3YGulpDfCbkZm3nE
uJlUDDEDAIUNj2k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 401->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8InBAQlmILuJWH/h8gc2s/CZTaxbcJlBDJ+QXcS4iRj3M+Ax
Gx8fn/mExAmpQzefmDjCZz8+t+Izg5g0TKw70NUS8jshN2Mzjxg3k4ohZgAA
NFCRKg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 402->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCeGzQ5CZiCrJ9ZfuPyBzSx8ZhPrFlxmEMMnZBcxbiLG
/djcQSgscPmXmLSGyz/4wpOYOMJnPz634jODmDRMrDvQ1RLyOyE3YzOPGDeT
iiFmAADbUpAs
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 403->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqifUXih577PrR3YLNbGLdgssMYviE7CLGTcS4
H5s7CIUFLv8Sk9Zw+QdfeBITR3jjGo9b8ZlBTBom1h3oagn5nZCbsZlHjJtJ
xRAzADNhkCw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 404->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCeGAog0A9lNxPoLRY89dv3o/sVmNrFuwWUGMXxCdoEB
ATcR435kc3D5HRsfn/mExAmpQzefmDjCG9d43IrPDGLSMLHuQFdLyO+E3IzN
PGLcTCqGmAEAMweOLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 405->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCeGzQ5CZiCrJ9ZfKHrssetHdws2s4l1Cy4ziOETsosY
NxHjfmzuIBQWuPxLTFrD5R984UlMHOGNazxuxWcGofRNijsYsJiBz++E3Iyu
jpg8Qw6GmAEAZiqRKA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 406->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCcGB3jMQTcD2U0obBL8j1U/A3Y+WW7BYQYxfEJ2EeMm
YtyPzR2EwgKXf4lJa7j8gy88iYkjfPbjcys+M4hJw8S6g5A/CcUBsWYScjOp
GGIGAM9mkCo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 407->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCeGzQ5CZiCrR2GT4H8GPGZhMxur2/G5BYcZxPAJ+Ruf
m/DZjc98XH7HxsdnPiFxQurQzScmjvDZj8+t+MwgJg0T6w5C/iQUB8SaScjN
pGKIGQAL5ZAq
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 408->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCeGzQ5CZiCrJ9ZfuNRhMwuf2Shux+MWXGYQwyfkb3xu
wmc3ihxavOHyOzY+PvMJiRNSh24+MXFEKE4JhgUWM4hJw8S6Aw6I9DsuN8Pi
DF0dsW5GNodQfkGYAQAs7Y+o
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 409->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCeGzQ5CZiCrJ9ZfuNRhMwuf2cS6BZcZxPAJ2UWMm4hx
PzZ3EAoLXP4lNqwJqUM3n5g4IhSnhMICmxnEpGFi3UHIn4TiADmfMZCZZ8jB
EDMAn/CRaQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 410->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwzUPj2mOYRchs+M4j1Fy51yOLobsGmBxsfm3pcZhDDJ2QXMW4i
xv3Y3EEoLHD5l9iwJqQO3Xxi4ohQnBIKC2xm4HM3qe4g5E9CcUCsmYTcTCqG
mAEArQOR6Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 411->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8Ilhs4OQGcjqifUXLnXYzMJnNrFuwWUGMXxCdhHjJmLcj80d
hMICl3+JDWtC6tDNJyaOCMUpobDAZgYxaZhYdxDyJ6E4gMsTMJOQm5HNIZRf
EGYAAFw/kSo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 412->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsjxwz8IlhswOvehhmQNVPqv8ZsIijuwWb2dj42NTjMoMYPiG7iHET
Me7H5g5CYYHLv8SkNVz+wReexMQRPvvxuRWfGcSkYWLdAQdE+h2Xm5HTPjb9
hNyMnvaJyTMN9gCmtJAo
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 413->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDATMwCcGB3j8iaIezS8obDL8j80sbGbj8g9Ot+Awgxg+IbuI
cRMx7sfmDkJhgcu/xIY1IXXo5hMTR4TilFBYYDODmDRMrDsI+ZNQHKCkfTzp
gJCbScUQMwBxoY/p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 414->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDFCMywx8YigAhznoZiC7CYVNwB243IJuFjazSXYLDjOI4ROy
CxZW+NQRcj8DEsbnd2x8fOYTEiekDt18YuKIUJwSDAssZhCThol1ByF/4jMT
Qw0WdcS6mVQMMQMAMWaOKA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 415->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDHjciFU9A3Y7GPC4A5dfUNhk+B+bWdjMJtktOMwghk/ILmLc
RIz7GZDCDJffsfHxmU9InJA6dPOJiSNCcUooLLCZQUwaJtYdhPyJz0x8avC5
m5CfiMEQMwDfbI+q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 416->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDHjciFU9A3Y7GPC4A5dfUNhk+B+bWdjMJtktOMwghk/ILmLc
RIz7GfCYjY+Pz3xC4oTUoZtPTBwRilNCYYHNDGLSMLHuIORPQnFArJmE3Iwt
3gn7GwDZe4+q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 417->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbI0YOsD5sZDHjciFU9A3Y7GPC4A5dfiPUXLn9gMwuf2cS6BZcZxPAJ2UWM
m4hxPwMes/Hx8ZlPSJyQOnTziYkjfPbjcys+M4hJw8S6g5A/CcUBsWYScjO2
eCfsbwAoZI9r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 418->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyhHQg6wPmxkMSBibGfjE0AEud+DyCz59OPUgYyxm4TMbxe143ILLDGL4
hPyNz0347MZnPi6/Y+PjM5+QOCF16Objim90NaSYgS2cCKUdQnmDkBpS/E7I
zbjMJORm5HRLKL8gzAAA4ZWM6w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 419->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyeHTgyyPUy0UE2M2unnY7MFnBrJafPpw6oHxcZiFz2xi3YLLDGL4hOyC
uR2fOkLuZ0DC+PyOjY/PfELihNShm48rjNHVkGIGtnAilHYI5Q1CakjxOyE3
4zKTkJtJxRAzALxnjKw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 420->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyeHTgyyPUy0UE2M2unnY7MFnBrJafPrw+R+bfnR3YDObWLfgMoMYPiG7
iHETMe5HjjNcfsfGx2c+IXFC6tDNJyaO8NmPz634zCAmDRPrDjgg0u+43AyL
L3R1xLoZ2RxC+QVhBgCfgY1r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 421->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyeHTgyxPjhn4xNABMWYgq8WnD6ceKMZlFj6zUdyOxy24zCCGT8jf+NyE
z26s7sdhNj4+PvMJiRNSh24+MXGEN67xuBWfGcSkYWLdAQdE+h2vm/GkA0Ju
JhVDzAAApyKN6w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 422->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyeHTgyxPjhn4xNABMWYgq8WnD6cee+z60d2BzWxi3YLLDGL4hOwixk3E
uB+bOwiFBS7/EpPWcPkHX3gSE0d44xqPW/GZQUwaJtYdcECk3wm5GV0dsW4m
FUPMAADBMI4u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 423->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawykExLj3I+nCaQYI4unnY7MFnBrJafPrw+R+bfnR3YDObWLfgMoMYPiG7
iHETMe7H5g5CYYHLv8SkNVz+wReexMQRPvvxuRWfGcSkYWLdQcifhOKAWDMJ
uZlUDDEDAKliju0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 424->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ2
zIBDHEMdA3ZzGJAwLj3I+nC5hRRxdPOw2YPPDGS1+PTh8z82/ejuwGY2sW7B
ZQYxfEJ2gQEBNxHjfnQziAkLXP4lKq3h8A++8CQmjvDZj8+t+MwgJg0T6w5C
/iQUB8SaScjNpGKIGQC5Mo2s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 425->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ2
zIBDHEMdA3ZzGPCYjwyQxXCpJVYc3Txs9uAzA1ktPn34/M+Axyx8ZqObgUs9
LjOI4RPyNxgQCB9i3Y8rrvHx8ZlPSJyQOnTziYkjfPbjcys+M4hJw8S6g5A/
CcUBsWYScjOpGGIGABc1jaw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 426->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ2
zIBDHEMdA25z8Imj6yPHDHxi6IAYM5DV4tOHz//Y9KO7A5vZKGbgcQsuM4jh
E/I3Pjfhsxub+3GZjY+Pz3xC4oTUoZtPTBzhsx+fW/GZQUwaJtYdhPxJKA5Q
1OBJB4TcjC3eCfsbAJsLjiw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 427->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ2
zIBDHEMdA25z8Imj6yPHDHxi6IAYM5DV4tOHz//Y9KO7A5vZuNyOzSxc9hLi
E/I3PjfhsxvDfDxm4+OjiGFJg9jsxesfPHFLTBzhi2tiwgKbGcSkYWLdgctu
nOFBwM24zCTkZlIxxAwAmCKNbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 428->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAYwxJEwLj3I+nC5hRRxdPOw2YPPDGS1+PTh8z8DHrPwmY1uBoM9dvW4zCCG
T8jf+NyEz25C8URMWGCIYUk72OzF6x88cUtMHOGLa2LCApsZxKRhYt2By26c
4UHAzbjMJCaeScEQMwD0NI5p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 429->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbs5DDA5LOYgA2QxnObjEMcnhg5wmY3LL/j04fM/Nv3o7sBmNooZ
SOGHzSxc9hLiE/I3Pjfhs5tg/BERFljFiE1ruPyDJ26JiSN8cY3NDGzhRCjt
EBNe+NTg8jsxcUCsmcTEMykYYgYAjiOMLA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 430->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YIDFHGSALIbLDGLF0c3DZg8+M5DV4tOHz//Y9KO7A5vZuNyO
zSxc9hLiE/I3Pjfhs5tQPBETFrj8S0xaw+UffHFLTBzhs5+YsMBmBjFpmFh3
EPInMemJlPxCjJ+IwRAzANylja4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 431->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YIBHD7I+fGYQK45uHjZ78JmBrBafPnz+x6Yf3R3YzMZwO1L4
o+vFZS82M3CZTyg+cKkjxv34zMbHx2c+IXFC6tDNJyaO8NlPTFhgM4OYNEys
Owj5k1AcwOVhGIeZxMQzzBxC+QVhBgDAFY4q
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 432->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZIkUMGyGK4zCBWHN08bPbgMwNZLT59+PyITT+6O7CZjeF2ewjGZhYue7GZ
gct8QvGBSx1R7sdjNj4+ihiJ6Qmrf/DELTFxhM9+YsICmxnEpGFi3YHLbpzh
gc/NeNIBITeTiiFmAADTTY6q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 433->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5uOSQAbIYqWbgE0MHuMzGZRc+ffjch00/ujuwmY3hdqTwR9eL
y15sZuAyn1B84FJHlPvxmI2Pj898UtICHOCJW2LiCJ/9+NyKzwxi0jCx7sBl
N87wwOdmPOmAkJtJxRAzAFE4jSw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 434->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5uOSQAbIYqWbgE0MHuMzGZRc+ffjch00/ujuwmY3LDGxm4bIX
g0/AfHzxgUsdUe7HYzY+Pj7zSUkLcIAnbomJI3z243MrPjOIScPEuoOQPwnF
AYoaPOmAkJuxxTthfwMAm9WMbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 435->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5DDjsQAbIYjjNwGEvPjF0gMvtuPyCTx8+/2PTj+4ObGZjuB3J
7+h6cdmLywxs5hOKD1zqiHU/LrPx8fGZT0gcq3/wxC0xcYTPfnxuxWcGMWmY
WHcQ8iehOMBnJiluJhVDzAAAgDSL6w==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 436->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5DEgYmx5kfTjNYMDuDmzq0c3DZg8+M5DV4tOHz//Y9KO7A5vZ
GG5HCjd0vbjsJWQGIX/jcxM+u/GZj8vv2Pj4zCckjtU/eOKWmDjCZz8+t+Iz
g5g0TKw7CPmTUBzgM5MUN5OKIWYAAPHli+s=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 437->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
TEgepgaXOgYYZsCuB1kcpxkMEDOIcRu6edjswWcGslp8+vD5H5t+dHdgMxvD
7XjMwmUvNnfgMp9QfOAzgxj34zIbHx+f+YTECalDN5+YOMJnPz634jODmDRM
rDvggEi/E3Izujpi3UwqhpgBAJSDjK4=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 438->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
TEgepgaXOgYc8siAkF1gQKTb0M3DZg8+M5DV4tOHz//Y9KO7A1eYoPsZl1m4
7MXmDlzmE4oPfGYQdD8U4/M7Nj4+8wmJE1KHbj4xcYTPfnxuxWcGMWmYWHcQ
8ic+M/GpweduQn4iBkPMAABjaIyu
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 439->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
TEgepgaXOgYc8siAkF1gQKTb0M3DZg8+M5DV4tOHz//Y9KO7A1eYYDMDm1m4
7MVmBj7z8cUHPjOIcT8DDrPx8fGZT0ickDp084mJI3z243MrPjOIScPEugMO
iPQ7ITejqyPWzaRiiBkA8k2Mbw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 440->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5DDB5NLOQAbIYTvOxuAWbenTzsNmDzwxktfj04fM/Nv3o7sBm
Nobb7ZEwml5c9mJ1Bw7zsfkBn5vw2Y3PfFx+x8bHZz4hcULq0M0nJo7w2Y/P
rfjMICYNE+sOOCDS74TcjK6OWDeTiiFmAACugoss
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 441->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5DDB5NLOQAbIYTvOxuAWbenTzsNmDzwxktfj04fM/Nv3o7sBm
Nobb8ZiFy15s7sBlPjY/wOwlZAZB9yPFFy6/Y+PjM5+QOCF16OYTE0f47Mfn
VnxmEJOGiXUHIX/iMxOfGnzuJuQnYjDEDABQSYus
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 442->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawysHkoWx0Pcj6cJqBRT8u9ejmYbMHnxnIavHpw+d/bPrR3YHNbAy34zEL
l73Y3IHLfGx+wKcHn9243I/P79j4+MwnJE5IHbr5xMQRPvvxuRWfGcSkYWLd
Qcif+MxEVgPLX7jMJORmZHMI5ReEGQD3G4us
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 443->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAawyiHJM2DRg6wPpxkkiKObh80efGYgq8WnD5//selHdwc2szHcjscsXPZi
cwcu87H5AZ8efHbjcj8+v2Pj4zOfkDghdejmExNH+OzH51Z8ZhCThol1ByF/
4jMTWQ0DATMJuZlUDDEDAMVOjK4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 444->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
NrNw2YvNDHzm44sPfGYQ6358fsfGx2c+IXFC6tDNJyaO8NmPz634zCAmDRPr
DkL+JBQHxJpJyM2kYogZAGpHjS4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 445->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQax4ujmYbMHnxnIavHpw+d/bPrR3YHNbFxmYDML
l71YzcBjPr74wKWOFPfj8zs2Pj7zCYkTUoduPjFxhM9+fG7FZwYxaZhYdxDy
J6E4INZMQm4mFUPMAAAGVo0u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 446->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OSgAhziyGC4ziBVHNw+bPfjMQFaLTx8+/2PTj+4ObGbjMgObWbjs
xWYGPvOJiSdsZuBzPwMSxud3bHx85hMSJ6QO3Xxi4gif/fjcis8MYtIwse4g
5E98ZiKrYSAyvxDyEwMOcexmAAAsGYsu
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 447->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmECuObh42e/CZgawWnz58/semH90d2MzGcLs9EkbTi8te
rO7AYT6x8YTNjcS4H1dc4+PjM5+QOCF16OYTE0f47MfnVnxmEJOGiXUHIX8S
igO4PJH5hZCfGHCIYzcDAIFhiy4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 448->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTFDMxGMWLnuxuQOX
+bjig4FA+BByPwMSxud3bHx85hMSJ6QO3Xxi4gif/fjcis8MYtIwse4g5E98
ZiKrYSBgJiE3I5tDKL8gzAAA8TeLrg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 449->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgc0sXPZiMwOf
+cTEEzY+PrUMeOKBEB+f+YTECalDN5+YOMJnPz634jODmDRMrDsI+ZNQHBBr
JiE3w+UI5BVUMwBcWI1v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 450->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBpjGIY5LDB3gMxubX/Dpw+d/bPrR3YHNbAy3o9MMuM3H
6w4c5hOKD1zqiHU/LrPx8fGZT0ickDp084mJI3z243MrPjOIScPEuoOQPwnF
AbFmEnIzXI5AXkE1AwBeR4wu
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 451->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGZgMwuXvYTM
IORvfG7CZzc+83H5HRsfn/mExAmpQzefmDjCZz8+t+Izg5g0TKw7CPmTUBwQ
ayYhN5OKIWYAAJjcje8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 452->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgc0sXPYSMoOQ
v/G5CZ/dGOZDMT6/Y+PjM5+QOCF16OYTE0f47MfnVnxmEJOGiXUHHBDpd1xu
ZiAyvxDyEwMOcexmAABgrovv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 453->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
NrNw2UvIDEL+xucmfHZjDXscZuPj4zOfkDghdejmExNH+OzH51Z8ZhCThol1
BxwQ6XdcbmYgMr8Q4ydiMMQMANJkiu8=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 454->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
NrNw2YvVDBjGIocvPrCFPSnuZ8BhNj4+PvMJiRNSh24+MXGEz358bsVnBjFp
mFh3wAGRfsflZuQ0gk0/ITcjm0MovyDMAAAEy4nt
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 455->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OciAkDg+M4gVRzcPl/24zEBWi08fPv9j04/uDlxhgs0MbGbhsher
GXjkiIknbHxi3M+Aw2x8fHzmExInpA7dfGLiCJ/9+NyKzwxi0jCx7iDkT3xm
IqthQEsn+NyNV45AXkE1AwDZIotv
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 456->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgc0sXPbicwc2
OWLiCRufGPcT8js2Pj7zCYkTUoduPjHuxGc/PrfiM4OYNEysOwj5E5+ZyGoY
iMwvxPiJGAwxAwDXnIuy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 457->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHYQzCGOAOqGC4zGtD041KPbh42e/CZgawWnz58/semH90d2MzGZQY2
s3DZi88d2OTwxQcudcS6n5DfsfHxmU9InJA6dPOJcSc++/G5FZ8ZxKRhYt0B
B0T6Ha+b8aQDQm4mFUPMAADiaYsw
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 458->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBpjGIY5LDB3gMxubX/Dpw+d/bPrR3YHNbFxmYDMLl704
3YEWfrj8jc9N+OzGFfb4/I6Nj898QuKE1KGbT4w78dmPz634zCAmDRPrDjgg
0u+E3Iyujlg3k4ohZgAAFDCL7w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 459->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCaYQ/FDLjNJ+gO
qBmE/I3PTfjsxhr2OMzGx8dnPiFxQurQzScmjvDZj8+t+MwgJg0T6w44INLv
hNyMro5YN5OKIWYAAMePjC4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 460->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
NrNw2YvPHejhjzWe8LgJn91Ywx6H2fj4+MwnJE5IHbr5xMQRPvvxuRWfGcSk
YWLdQcif+MzEpwafuwn5iRgMMQMAHGiLbw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 461->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD5390/QxY/IvNbJxm2CPMwGY+
Ke4g5G98bsJnN66wx2Y2Pj4+8wmJE1KHbj4x7sRnPz634jODmDRMrDsI+ROf
mfjU4HM3IT8RgyFmAABt4Yvv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 462->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGaAaWxiWOzF
5w4GHHbhig9c6oh1PyG/Y+PjM5+QOCF16OYT40589uNzKz4ziEnDxLqDkD/x
mYmhBk86IORmZDMI5ReEGQBs3Yyu
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 463->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OSgAhziyGC4zsLkDm3p087DZg88MZLX49OHzPzb96O7AZjYuM2B+
xxDDYi8+d6CHP654IhQ+xLqfkN+x8fGZT0ickDp084lxJz778bkVnxnEpGFi
3UHIn/jMxFCDJx0QcjOpGGIGAGNJi28=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 464->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmECuObh42e/CZgawWnz58/semH90d2MzGZQaYxiaGxV58
7kAPf1zxRCh8iHU/Ib9j4+Mzn5A4IXXo5hPjTnz243MrPjOIScPEuoOQP/GZ
iU8NPncT8hMxGGIGAF22jDA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 465->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmECuObh42e/CZgawWnz58/semH90d2MzGZQaYxiaGxV58
7mCAmoPP3/jchM9urGGPw2x8fHzmExInpA7dfGLiCJ/9+NyKzwxi0jCx7iDk
T3xm4lODz92E/EQMhpgBAJzGi+8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 466->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZAaaxiWGxF587
GKDm4PM3PjfhsxtX2OPzOzY+PvMJiRNSh24+Me7EZz8+t+Izg5g0TKw7CPkT
n5nIahgImEnIzaRiiBkA5LaLsA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 467->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmgGkc4rjE0AE+s7H5BZ8+fP7Hph/dHdjMxmUGzO8YYljs
xecOBqQwxOVvfG7CZzfWsMdhNj4+PvMJiRNSh24+MXGEz358bsVnBjFpmFh3
EPInPjPxqcHnbkJ+IgZDzAAAs6iLbw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 468->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmgGkc4rjE0AE+s7H5BZ8+fP7Hph/dHdjMxmUGzO8YYljs
xecOBqQwxOVvfG7CZzfWsMdhNj4+PvMJiRNSh24+MXGEz358bsVnBjFpmFh3
EPInPjOR1TAQMJOQm0nFEDMAeKiK7w==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 469->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmECuObh42e/CZgawWnz58/semH90d2MzGZQaYxiaGxV58
7mCAmoPP3/jchM9uXGGPz+/Y+PjMJyROSB26+cS4E5/9+NyKzwxi0jCx7oAD
Iv2Oy80MWMwkxc3I5hDKLwgzAGmYijA=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 470->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmECuObh42e/CZgawWnz58/semH90d2MzGZQaYxiaGxV58
7mCAmoPP3/jchM9urGGPw2x8fHzmExInpA7dfGLiCJ/9+NyKzwxi0jCx7iDk
T3xmIquBpQ1cZhJyM7I5hPILwgwAZpWLLg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 471->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmECuObh42e/CZgawWnz58/semH90d2MzGZQYuMWz24nMH
GBDwNz434bMbV9jj8ztW9+Exn5A4IXXo5hPjTnz243MrPjOIScPEuoOQP/GZ
iU8NPnfjlSOQV1DNAADI+Itx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 472->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm7343IFN
jph4wsYnxv0MOMzGx8dnPiFxQurQzScmjvDZj8+t+MwgJg0T6w44INLveN2M
Jx0QcjOyGYTyC8IMAGAijG8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 473->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZAaZhenCYT4w7
sMkRE0/Y+MS4nwGH2fj4+MwnJE5IHbr5xMQRPvvxuRWfGcSkYWLdQcif+MzE
UIMnHRByM6kYYgYAAASMbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 474->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OSgAhziyGC4ziBVHNw+bPfjMQFaLTx8+/2PTj+4ObGbjMgOXGDZ7
8bkDmxy++MCljlj3M+AwGx8fn/mExAmpQzefmDjCZz8+t+Izg5g0TKw7CPkT
n5n41OBzNyE/EYMhZgAAgBeMMA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 475->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OSgAhziyGC4ziBVHNw+bPfjMQFaLTx8+/2PTj+4ObGbjMgOXGDZ7
8bkDDAj4G5+b8NmNNexxmI2Pj898QuKE1KGbT0wc4bMfn1vxmUFMGibWHXBA
pN9xuZkBhhkw5YhxM7I5hPILwgwAp8iKbw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 476->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm7343AEG
BPyNz0347MYV9vj8jtV9eMwnJE5IHbr5xLgTn/343IrPDGLSMLHuIORPfGZi
qMGTDgi5GdkMQvkFYQYA7eWMMA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 477->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
LjFs9uJzBzY5fPGBSx2x7mfAYTY+Pj7zCYkTUoduPjFxhM9+fG7FZwYxaZhY
d8ABkX7H5WYGGGbAlCPGzcjmEMovCDMABwKKrg==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 478->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHYQzCGOAOqGC4ziBVHNw+bPfjMQFaLTx8+/2PTj+4ObGbjMgOXGDZ7
8bkDmxy++MCljlj3M+AwGx8fn/mExAmpQzefmDjCZz8+t+Izg5g0TKw7CPkT
n5nE2E2sm+FyBPIKqhkA7D6NLg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 479->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGbA1dtDMQ4z
CLkDmxy++MCljlj3M+AwGx8fn/mExAmpQzefmDjCZz8+t+Izg5g0TKw7UNQR
4Xe8bsaTDgi5GcUMAvkFYQYAezOLLg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 480->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGaAaWxiWOzF
6Q6oGYT8jc9NDUhmEON+dLWEwgKbGLFpDZd/8MUtMXGEz358bsVnBjFpmFh3
kOIebH5Fj1t0dcS6GT19EJNnGuwBohqMrA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 481->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGZgMwuXvVjN
QMKE/I3LTQx4/IYz7HGYjY+Pz3xC4oTUoZtPTBzhsx+fW/GZQUwaJtYdpLgH
m18J2U2sm+FyBPIKqhkAEFSMbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 482->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGZgMwuXvfjM
IMbf+NyEz26sYY/DbHx8fOYTEiekDt18YuIIn/343IrPDGLSMLHuIMU92PxK
yG5i3UwqhpgBAELaji4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 483->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGaAaWxiWOzF
4NujYkL+xuUmBjx+wxn2OMzGx8dnPiFxQurQzScmjvDZj8+t+MwgJg0T6w5S
3IPNr4TsJtbNpGKIGQCKsIys
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 484->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZIkUMGyGK4zCBWHN08bPbgMwNZLT59+PyITT+6O7CZjcsMXGLY7MXgI9NE
+BuXmxjw+A1n2OMwGx8fn/mExAmpQzefmDjCZz8+t+IzA1/4kuoOOECLI1x+
x+dmfOmAUL4jFUPMAACytoys
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 485->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YIDFHGSALIbPDGzi+MTQAS6zcfkFnz58/semH90d2MzGZQYu
MWz2YvBxxAEuf+NzEz67cYU9Pr9j4+Mzn5A4IXXo5hPjTnz243MrPjOIScPE
ugMOiHAPNr8SsptYN5OKIWYAAIPzi+0=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 486->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGbgEsNmLwYf
mSbC3/jchM9uXGGPz+/Y+PjMJyROSB26+cS4E5/9+NyKzwxi0jCx7oADeySM
x+/43IwvHRByM6kYYgYAcIiMbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 487->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGbgEsNmLwYf
jSbkb3xuwmc3rrDH53dsfHzmExInpA7dfGLcic9+fG7FZwZWdXjiAp874MAe
CePxOz4340sHhPIdqRhiBgBTyouu
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 488->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YIDFHGSALIbPDGzi+MTQAS6zcfkFnz58/semH90d2MzGZQYu
MWz24nQHDrPwxQcudcS6nwGH2fj4+MwnJE5IHbr5xMQRPvvxuRWfGVjV4YkL
fO5AUUeE3/G5GV86IJTvSMUQMwDDAYys
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 489->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwytlDMDY9yPrwmUGsOLp52OzBZwayWnz68Pkfm350d2AzG5cZDfaIMGTA
YT5BdyDR+PyNz024/IYz7HGYjY+Pz3xC4oTUoZtPTBzhsx+fW/GZQUwaJtYd
pLgHm18J2U2sm0nFEDMAxPCMrA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 490->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZIkUMGyGK4zCBWHN08bPbgMwNZLT59+PyITT+6O7CZjcsMMI1NDIu9ON2B
ROPzNz434bMba9jjMBsfH5/5hMQJqUM3n5g4wmc/PrfiMwOrOjxxgc8dcIBk
Bj6/43MzvnRAKN+RiiFmAADY+Ixt
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 491->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YIDFHGSALIbLDGLF0c3DZg8+M5DV4tOHz//Y9KO7A5vZuMyA
xQOGGBZ7cboDicbnb3xuwmc31rDHYTY+Pj7zCYkTUoduPjFxhM9+fG7FZwYx
aZhYd5DiHmx+JWQ3sW4mFUPMAABLcoxt
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 492->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwyuHRg6wPnxnEiqObh80efGYgq8WnD5//selHdwc2s3GZgUsMm7043YHF
PYTiA5c6Yt3PgMNsfHx85hMSJ6QOm/8JuQuf/fjcis8MYtIwse4gxT3Y/ErI
bmLdTCqGmAEAUAqNrg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 493->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZIkUMGyGK4zCBWHN08bPbgMwNZLT59+PyITT+6O7CZjcsMXGLY7CVWPS5/
43MTPrtxhT0+v2Pj4zOfkDghddj8T8hd+OzH51Z8ZmBVhycu8LkDDpDMwOd3
fG7Glw4I5TtSMcQMAGhEjO8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 494->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YIDFHGSALIbPDGzi+MTQAS6zcfkFnz58/semH90d2MzGZQYu
MWz2YvDRaSzm4ooPXOqIdT8DDrPx8fGZT0ickDps/ifkLnz243MrPjOIScPE
ugMOkPIYPr/jczO+dEDIzaRiiBkArCGLbQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 495->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YIBHD7I+cszAJ4YOcJmNyy/49OHzPzb96O7AZjYuM3CJYbOX
WPW4/I3PTfjsxhr2OMzGx8dnPiFxQuqw+Z+Qu/DZj8+t+MwgJg0T6w5S3IPN
r4TsJtbNpGKIGQCA3Y0u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 496->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YIBHD7I+cszAJ4YOcJmNyy/49OHzPzb96O7AZjYuM3CJYbOX
WPW4/I3PTfjsxhX2+PyOjY/PfELihNRh8z8hd+GzH59b8ZlBTBom1h0o6ojw
Oz4340sHhNxMKoaYAQAmTY0u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 497->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwymGxBxkgi+EzA5s4PjF0gMtsXH7Bpw+f/7HpR3cHNrNxmYFLDJu9xKrH
5W98bsJnN66wx+d3bHx85hMSJ6QOm/8JuQuf/fjcis8MYtIwse5AUUeE3/G5
GV86IORmUjHEDABJE4zv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 498->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OWBgj8DoepD14TMDmzuwqUc3D5s9+MxAVotPHz7/Y9OP7g5sZuMy
A5cYNnsx+Ejhhm4/Nj/gchMDHr/hC3t8fsfGx2c+IXFC6rD5n5C78NmPz634
zCAmDRPrDlLcg82vhOwm1s2kYogZABQLiy4=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 499->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OWBgj8DoepD14TODWHF087DZg88MZLX49OHzPzb96O7AZjYuM3CJ
YbMXg4/HPdj8gMtNDHj8hi/s8fkdGx+f+YTECanD5n9C7sJnPz634jMDX/iS
6g44QIsjXH7H52Z86YBQviMVQ8wAAK7ziq4=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 500->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHYQzCGOAOqGC4ziBVHNw+bPfjMQFaLTx8+/2PTj+4ObGbjMgOXGDZ7
Mfh43IM1nnC4iQGP33CGPQ6z8fHxmU9InJA6bP4n5C589uNzKz4ziEnDxLoD
RR0RfsfnZnzpgJCbScUQMwA2GIwu
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 501->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmECuObh42e/CZgawWnz58/semH90d2MzGZQYuMWz2Eqse
l7/xuQmf3VjDHofZ+Pj4zCckTkgdNv8Tchc++/G5FZ8ZxKRhYt1Binuw+ZWQ
3cS6mVQMMQMAg22MsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 502->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAS5wBVQyXGdjcgU09unnY7MFnBrJafPrw+R+bfnR3YDMblxm4
xLDZS6x6XP7G5yZ8dmMNexxm4+PjM5+QOCF12PxPyF347MfnVnxmEErbpLgD
DpDMwOd3fG7Glw4I5TtSMcQMAM0Ji64=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 503->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGbgEsNmLwbf
ngEe9uj2E4oPFLvw+A2f+/H5HRsfn/mExAmpw+Z/Qu7CZz8+t+IzA1/4kuoO
OCDCPdj8is9cQm6mBEPMAADyTowu
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 504->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm70YfHsI
xuYeYuOpAc0MYtyProeYsMAmRmxaw+UffHFLTBzhsx+fW/GZgS98SXUHHBDh
Hmx+xWcuITdTgiFmAAB6Powu
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 505->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
LjFs9mJVj8NvWOMJj5vw2U0o/ogJC2xixKY1XP7BF7fExBE++4kJC2xmEJOG
iXUHKe7B5ldCdhPrZlIxxAwAvVqNbQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 506->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAS5wBVQyXGcSKo5uHzR58ZiCrxacPn/+x6Ud3BzazcZmBSwyb
vcSqx+VvfG7CZzeheCImLLCJEZvWcPkHX9wSE0f47CcmLLCZQUwaJtYdcGCP
hPH4HZ+b8aUDYuKZFAwxAwCFb41t
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 507->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm70YfHQa
i7mE4glM4/EbMfFETFhgEyM2reHyD764JSaO8NlPTFhgM4OYNEysO+AALY5w
+R2fm/GlA2LimRQMMQMAQyaMrg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 508->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
LjFs9uJ0Bxb3YI0nPG7CZzeh+CMmLDDEcMQ5Nntw+gdP3BITR/jimpiwwGYG
MWmYWHcg+5OQe7D5lZDdxLqZVAwxAwAr5Ytt
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 509->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmgGkc4rjE0AE+s7H5BZ8+fP7Hph/dHdjMxmUGLjFs9uJ0
Bxb34IonQuFDjPvxmY2Pj898QuKE1GHzPyF34bOfmLDAZgYxaZhYd8ABEe7B
5ldCdhPrZlIxxAwAn3mMbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 510->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyYEBDnFkMVxmgGkc4rjE0AE+s7H5BZ8+fP7Hph/dHdjMxmUGLjFs9hKr
Hpe/8bkJn92E4o+YsMAmRmxaw+UffHFLTBzhs5+YsMBmBjFpmFh3wAER7sHm
V0J2E+tmUjHEDADqiIzv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 511->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwd4DMbm1/w6cPnf2z60d2BK0ywmYFLDJu9xKrH
5W98bsJnN4Zb8ZiNj4/PfELiWP2DJ26JiSN89uNzKz4ziEnDxLqDFPdg8ysh
u4l1M6kYYgYAbJeM7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 512->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwd4DMbm1/w6cPnf2z60d2BK0ywmYFLDJu9uPyP
zT3ExhPWuCDkfjxm4+PjM5+QODHpC93/hNyFz358bsVnBjFpmFh3kOIebH4l
ZDexbiYVQ8wAABMzi/E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 513->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
LjFs9uLyPzb3YI0nPG7CZzeGW/GYjY8PF8OR7rDZi9c/eOKWmDjCZz8xYYHN
DEJpmxR3IPsTjnG4B5tf8ZlLyM2UYIgZADAdiqw=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 514->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQu
zIBHDq6GAbc5YGCPwOh6kPURYwa6ODa12OzAZzYuv+DTh8//2PSjuwOb2Shm
4PAPLvOx8mEYh3uw+QFDHEd4Eet+fH7HxoeL4Uh72OzF6x88cUtMHOGzn5iw
wGYGVnUEwguXO5D9Scg92PyKz1xCbqYEQ8wAAAZTi6g=
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 515->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAZwymGxBxkgi+EyA0zjEMclhg7wmY3NL/j04fM/Nv3o7sBmNooZOPyDy3ys
fDz+weVvDHFccUGk+/H5HRsfLobFbnxxgtM/eOKWmDjCZz8xYYHNDEJpmxR3
IPuTkHuw+RWfuYTcTAmGmAEAg8GMqg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 516->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm724/I/N
PUTFE47wIuh+PGbj48PFsNiNL05w+Qdf3BITR/jsJyYssJlBTBom1h1wQIR7
sPmVkN3EuplUDDEDAFivjW0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 517->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTOBsHP7BZT5WPgzj
cA9R8YQjvAi5H5/Z+PhwMSx244sTrP5BMwOb/wm6C4/9xIQFrjAhlIax2YNL
DdyvBNyDza+E7CbWzaRiiBkAVQmN6Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 518->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAS5wBVQyXGcSKo5uHzR58ZiCrxacPn/+x6Ud3BzazUczA4R9c
5mPlwzAO9xCKD2xxT6z78ZmNjw8GSG4nNq1h9TeaGdj8T9BdeOwnJixwhQmh
NIzNHlxq4GFGwD3Y/ErIbmLdTCqGmAEAxqKM5w==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 519->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAS5wBVQyXGcSKo5uHzR58ZiCrxacPn/+x6Ud3BzazcZmBSwyb
vRh8PO4hFB/Y4p5Y9+MzGx8f7mYc6Q6bvVj9g8UMbP4n6C489hMTFrjCBEMd
gfDCF6bwMEOmsbgHm18JxRUxeYYcDDEDAG2Zi+k=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 520->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBrHi6OZhswefGchq8enD539s+tHdgc1sXGbgEsNmLy7/
Y3MPofgAi+MIL0Lux2c2Pj4YYLGXUFrD5m50c7D5n6C78NhPTFjgChMMdQTC
C1+YEusebH4lFFfE5BlyMMQMAJkjjao=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 521->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
LjFs9uLyPzb3YI0nPG7CZzeh+CMmLPC5j1Baw3ALEsYVt0TFER77iQkLXP4g
lIYJhQW+MMPlHmx+JWQ3sW4mFUPMAADdi4ys
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 522->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAS5wBVQyXGdjcgU09unnY7MFnBrJafPrw+R+bfnR3YDMbxQwc
/sFlPlY+DONwD6H4wBfmhNyPz2x8fDBAcjuxaQ2bu9HNwOZ/gu7CYz8xYYEr
TPClbWzuwBem6GGGyz3Y/EoorojJM+RgiBkADCKMJg==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 523->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OciAkDg+M4gVRzcPl/24zEBWi08fPv9j04/uDlxhgh7muMzFZS+6
GQx43ENsPGHjE6MWl9n4+HAxHOkOm71Y3YnFDGz+J+guPPYTExa4wgRDHYHw
whemMHeiY2LiAKe5RLiZEgwxAwC/MI1l
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 524->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
LjFs9mLw8bgHazzhcRM+uwnFHzFhgSKGI91hsxerO7GYgc3/BN2Fx35iwgJX
mBBKw9jswaUG5k50TEwc4DSXRDeTiiFmAADtJYym
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 525->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAS5wBVQyXGdjcgU09unnY7MFnBrJafPrw+R+bfnR3YDMbxQwc
/sFlPlY+DONwD6H4wBsXBNyPz2x8fLgYjnSHy40YbsFiBjb/E3QXHvuJCQtc
YUIoDWOzB5cadPdiCzusavGZS6KbScUQMwBFzY6k
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 526->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwd4DMbm1/w6cPnf2z60d2BK0zgbBz+wWU+Vj4e
/+DyN4Y4rrgg4H4UNxAZFihiWOzGFyfY3I1uBjb/E3QXHvuJCQtsbiUmDWOz
B5cadPdiCzusavGZS6KbScUQMwATF43l
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 527->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm73E+geX
OgxxHOFFyP3I+hmIDAsUMSx244sTbO5GNwOb/wm6C4/9xIQFNrcSk4ax2YNL
Dbp7cbkHm19xmkuim0nFEDMARKiOKA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 528->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVUksOQDAQfbEQW0dwBQ4grsAJKmElkbAQO0dHSEO9mZZkyLxO30ebtWPd
RwDm5HjVZqmmyaxNfDadGYp8OBfTu4CthP1qBd86ZB77SDjemMQRirt8TEfj
eM5q+7T8bL/rg3F/vBNM4qd9+eZw9X3n8eTQsqnnoWRnvcWEe8d0aR7Bu5vf
60vRD/kXzGvIHWY60gzzz/ywWZH3p+e/dXHsH3GMKA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 529->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAS5wBVQyXGcSKo5uHzR58ZiCrxacPn/+x6Ud3BzazcZmBSwyb
vSh8PP7B5W9C/iXW/fjiAB8fLoYj3eFyI4ZbsJiBzf8E3YXHfmLCAptbSQkz
csMVm3uwqcVpLoluJhVDzAAAwsmNKg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 530->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm70ofDz+
weVvQv4l1v3Y3EAoLFDE8MQvLnEMe6EYV9wSFUd47CcmLLC5lZg0jM0eXGpQ
wgxH2GH1Gz5zSXQzqRhiBgB9OY4o
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 531->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAS5wBVQyXGcSKo5uHzR58ZiCrxacPn/+x6Ud3BzazcZmBSwyb
vSh8PP7B5W9C/iXW/djcQCgscLmVmLSG4RYkjCtuiYojPPYTExbY3EpMGsZm
Dy416O5lwKIHq1p85pLoZlIxxAwArlyNaQ==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 532->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm724/I/N
PcTEE67wIuR+fHGAj4/PfELiKHwYxhIeJMURHvvxuRVdDaHwxBcXhNSguxeX
e7D5Fae5JLqZVAwxAwAgNYyu
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 533->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm724/I/N
PcTEE67wIuR+uBged2Dj4zOfkDgue3HFLVFxhMd+fG5FV0MoPPHFBSE1cHU4
/E1s+kP2M7q/CbmZVAwxAwCEH40s
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 534->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OciAkDg+M7C5A5t6dPNw2Y/LDGS1+PTh8z82/ejuwBUm2MzAJYbN
Xlz+x+YeYuIJZ1wQcD++OMDHx2c+IXH0NIsrPEiKIzz243MruhpC4YkvLgip
QXcvLvdg8ytOc0l0M6kYYgYAo0uLbw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 535->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OciAkDg+M4gVRzcPl/24zEBWi08fPv9j04/uDlxhgs0MXGLY7MXl
f2zuISaecIUXIfcjpx1c7sDGx2c+IXFc9uKKW2LiCJ/9+NyKzwxi0jCx7iDF
Pdj8SshuYt1MKoaYAQD+wIzv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 536->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm724/I/N
PcTEE67wIuR+uBged2Djw8XwxC8ucQx7oRhX3BITR/jsJyYssJmBVR2euMDn
DjhA9jMO92DzKz5zCbmZEgwxAwBuGYzr
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 537->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm724/I/N
PcTEE67wIuR+uBged2Djw8XwxC8ucWLSF7r/CbkLn/3YzMAXf3jDE4/b8bkD
RR2eMMJmJiFzCbmZEgwxAwDsLY0u
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 538->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHYQzCGOAOqGC4zGtD041KPbh42e/CZgawWnz58/semH90d2MzGZQYu
MWz24vI/NvdgjScC/iXW/fjiAB8fLkbAPGLjEVt4kBJH+OzHZga++CMm/ZHq
DlLcg82vhOwm1s2kYogZAMV5jG8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 539->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwax4ujm4bIflxnIavHpw+d/bPrR3YErTLCZgUsMm724/I/N
PcTEE67wIuR+fHGAj4/PfELixKQvdP8Tchc++/G5FZ8ZpIQZqeGKzz3Y/ErI
bmLdTCqGmAEAPyCM8Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 540->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwd4DMbm1/w6cPnf2z60d2BK0ywmYFLDJu9uPyP
zT3ExBPOuCDgfrgYHndg4+Mzn5A4MekL3f+E3IXPfnxuxWcGMWmYWHeQ4h5s
fiVkN7FuJhVDzAAA2yWMsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 541->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
LjFs9uLyPzb3YI0nAv4l1v3IaQeXO7Dx8ZlPSJyQf7D5n5C78NmPz634zCCU
tklxBxzYo9EEwgObGmLTASE/EYMhZgAAeRSKbw==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 542->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQ+
zEBIngG3OXCAZg4yQBbDZQY2d2BTj24eNnvwmYGsFp8+fP7Hph/dHdjMxmUG
LjFs9uLyPzb3YI0nAv4l1v34zMbHh4vhiV9c4uhpFleaIyWO8NlPTFjgChNC
aZhYd8CBPRKNI69g8ytOc0l0M6kYYgYAGZWNKA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 543->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBpjGIY5LDB3gMxubX/Dpw+d/bPrR3YHNbFxm4BLDZi8u
/2NzD6H4wBsXBNyPz2x8fHzmExJH4cMwjvDBFSbY1OBLH4TCApsZxKRhYt2B
4X4s/iY2/aGoI9HNpGKIGQClKY3r
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 544->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHx2c+IXFi0he6/wm5C5/9+NyKzwxi0jCx7sBwPx73
YPMrTnNJdDOpGGIGALuRjLA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 545->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIonPHGBz/34zMbHh4uh+51AWsPqHzT3Y/M/IXfhi2tiwgJXmBBKw8S6
A5f7sYYHFrU4zSXRzaRiiBkAuoyMLg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 546->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHa4Y9AuNTj24euj0MeNSj+wWfv/D5H5t+DHfgCBNsZuASw2Yv
Lv9jcw8x8YQrfAm5H5/Z+PhwMTzxi0scq5144paYOMJnPzFhgc0MQmFGijtw
uR9neOBxM7FpnpA8MRhiBgD4L4wu
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 547->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7YCbgUc9ul/w+Quf/7Hpx3AHjjDBZgYuMWz2
4vI/NvcQFU/44gKP+9HNICYscLkV2R3Y7MXrHzxxS0wc4YtrYsICmxmEwowU
d6CoQ8a4wgOPm7HlMWLdTCqGmAEAfxyMaw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 548->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/0o4kSGBS63ErKXWP9g8z8hd+GLa3xuwmcGMWmYWHegqEPG
BMIDm5vh4kSkd0J5gpg802APAINKjW0=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 549->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/0o4kSGBYoYHr9jswerf6Dm4IpbYuIIX1wTExa4woRQGibW
HVjdT0T8YnMzsWmekDwxGGIGAFb9jW0=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 550->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHh4uh+51AWiPGPwxo5hATR/jimpiwwBUmhNIwse7A
5X5C4YFNDbFpnpA8MRhiBgAUyo0u
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 551->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHh4vh8Ts2e4jxDzb/E3IXvrjG5yZ8ZhCThol1B4o6
ZEwgPLC5mdg0T0ieGAwxAwBcp40u
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 552->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHawYSjU89unno9jDgUY/uF3z+wud/bPox3IEjTLCZgUsMm724
/I/NPcTEE67wJeR+fGbj4+P0G4G0Rox/GNDMISaOMOwhIh5wxR++8CQUXvjU
wNWRkN+wqSE2zROSJwZDzAAAgZeL7Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 553->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHawYWeWzq0c1Dt4cBj3p0v+DzFz7/Y9OP4Q4cYYLNDFxi2OzF
5X9s7iEmnnCFLyH34zMbHx+f3/DFCTH+YUAzh5g4IhQGhMIClxmE0jAhd6AD
XGLEpAV8aZlYN5OKIWYAAA8IjDA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 554->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHx+c3fHGC0z/IYgTCEJsbiEmP+MIClxmE0jAhd+AL
M1zuwaaWUFom1s2kYogZACbnjW8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 555->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHh4vh8Ts2ezDcgoRxxS0xcYTVP2juwxcW+MzAl4YJ
uQNrmGERIyYt4EvLxOQZcjDEDAA0xI0s
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 556->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHx+c3fHFCjH+w+Z+Qu7D6h4SwINYMQuGFTw1cHTIm
EB7Y3AwXJyK9E8oTxOSZBnsAxg2NrA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 557->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHa4Y9AuNTj24euj0MeNSj+wWfv/D5H5t+DHfgCBNsZuASw2Yv
Lv9jcw8x8YQrfAm5H5/Z+PhwMTx+x2YPhltwpBd0/xNyF1b/kBAWuMwglIYJ
uQNfmOFyDza/YjWXiPROKE8Qk2ca7AH3XY1p
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 558->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYhmJ86tHNQ7eHAY96dL/g8xc+/2PTj+EOHGGCzQxcYtjs
xeV/bO4hJp5wxgUh9+MxGx8fLoYW3/jsxesfPHFLTBxhDQMSwgKXGYTSMCF3
4AwzNDFi0gK+tEysm0nFEDMAbquMaw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 559->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7SBkNja/4NOHz//Y9KO7A1eYYDMDlxg2e3H5
H5t7iIknvHGBz/14zMbHh4thMQNfnOD0D564JSaOMOxBxkSEBTYzkMMHl18I
ugNXmKGJEZMW8KVlYvIMORhiBgBnPIus
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 560->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGB1/14zMbHh4thMQNfnOD0D564JSaOsIYBCWFBrBn44oKQGvQw
YyAifrG5GS5ORHonlCeIyTMN9gAGeY3p
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 561->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4cBj3p0v+DzFz7/Y9OP4Q4cYYLPz+hi2OzF
5X9s7iEmnvDFBV734zEbHx8uhsUMfHGC0z944paYOMIaBiSEBbFm4IsLQmpQ
3IHHPdj8itVcItI7oTxBTJ5psAcA6iaM6w==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 562->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHh4tBMTH24vUPnrglJo6w+oeEsMBlBqE0TMgdWMMM
ixgxaQFfWibWzaRiiBkAAviN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 563->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwdEGMGilo8/sLnf2z6MdyBI0ywmYFLDJu9uPyP
zT3ExBPOuCDgfnxm4+PDxdDiCgzwxAlO/2Axg5Q4wuofEsIClxmE0jAhd2AN
MyxixKQFfGmZWDeTiiFmAACk/I1r
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 564->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHh4tBMTH24vUPnrglJo4oDQtizSAUXvjUYHM/zvDA
42Zi0zwheWIwxAwAp/iObQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 565->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7SBkNja/4NOHz//Y9KO7A1eYYDMDlxg2e3H5
H5t7iIknvHGBx/34zMbHh4tBMYoZeOIEp3+wmEFKHGH1DwlhgcsMQmmYkDuw
hhkWMWLSAr60TKybScUQMwCUfo0s
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 566->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYhmJ86tHNQ7eHAY96dL/g8xc+/2PTj+EOHGGCzQxcYtjs
xeV/bO4hJp5wxgUB9+MzGx8fLoYjrnG5Ead/8MQtMXGE1T8khAUuMwilYULu
wBpmWMSISQv40jKxbiYVQ8wAAEU6jSw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 567->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHa4Y9AuNTj24euj0MeNSj+wWfv/D5H5t+DHfgCBNsZuASw2Yv
Lv9jcw8x8YQrfAm5H5/Z+PhwMRxxjcuNOP2DJ26JiSNKw4JYMwiFFz416GHG
QET8YnMzXJyI9E4oTxCTZxrsAZi7jig=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 568->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwdEGMGilo8/sLnf2z6MdyBI0ywmYFLDJu9uPyP
zT3ExBPOuCDgfnxm4+PDxdDiCp+9eP2DJ26JiSNKw4JYMwiFFz41KGGGJkZM
WsCXlol1M6kYYgYA/OeOaw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 569->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwd4DMbm1/w6cPnf2z60d2BK0ywmYFLDJu9uPyP
zT3ExBPOuCDgfnxm4+PjdR+eOMHpHyxmkBJHWP1DQljgMoNQGibkDqxhhice
sZmJz1xS3UwqhpgBABFdjms=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 570->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwd4DMbm1/w6cPnf2z60d2BK0ywmYFLDJu9uPyP
zT3ExBPOuMDjfmzxRExYoIihmYPPXrz+wRO3xMQRxWFBpBmEwgufGmzuxxke
eNxMbJonJE8MhpgBAINnjiw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 571->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYxiGOSwwd4DMbm1/w6cPnf2z60d2BK0ywmYFLDJu9uPyP
zT3ExBPOuMDjfmzxRExYYLgf3Qw8cYLTP3jilpg4whoGpIQFDjMIpWFC7sAW
ZgzIGFd44HEzcjiT6mZSMcQMAIH3jqg=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 572->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHR3E/kfYS6x9s/ifkLqz+ISEscJlBKA0Tcge+MMPl
Hmx+xWouEemdUJ4gJs802AMAWV2Paw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 573->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYhmJ86tHNQ7eHAY96dL/g8xc+/2PTj+EOHGGCzQxcYtjs
xeV/bO4hJp5wxgUB9+MzGx8fnxn44oQY/2DzPyF3YXULCWGBywxCaZiQO3CF
GTYxYtMfsWmekDwxGGIGAEhEjqw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 574->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwaYhmJ86tHNQ7eHAY96dL/g8xc+/2PTj+EOHGGCzQxcYtjs
xeV/bO4hJp5wxgUB9+MzGx8fnxn44gSffxjsMfXiChOsaigIC1z+IZSGsbkD
p/+wuB9feOB0MwyT4WZ0c4jJMw32ALtqjKw=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 575->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7YCbgUc9ul/w+Quf/7Hpx3AHjjDBZgYuMWz2
4vI/NvcQE0944wKP+/GZjY+P1ww8cUKMf+BmkBBHWN1CQljgMoNQGibkDmxh
hk2MmLSA7jdy3IwtfAibAQCMn4ys
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 576->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7YCbgUc9ul/w+Quf/7Hpx3AHjjDBZgYuMWz2
4vI/NvcQE0944wKP+/GZjY+Pzwx8cYLTP+hiJMYRVreQEBa4zCCUhgm5A1uY
YRMjJi2g+40cN2MLH8JmAACgYI3r
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 577->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4cBj3p0v+DzFz7/Y9OP4Q4cYYLPz+hi2OzF
5X9s7iEmnvDFBT734zMbHx+fGfjiBKd/8MQtMXFEaVgQawah8MKnBq4OGeMK
DzxuhosTkd7xyhPQjzADAEmXj2k=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 578->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4cBj3p0v+DzFz7/Y9OP4Q4cYYLPz+hi2OzF
5X9s7iEmnvDFBT734zMbHx/F/UTai9c/SOZg8z8hd2FLM6SEBa4wIZSGsbkD
lxps7scZHnjcDBcnIr0TyhPE5JkGewBzsY2s
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 579->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHR3E/uhl44oQY/8DNICGOsPqHhLDAZQahNEzIHdjC
DJsYMWkBQx0R6Z1QniAmzzTYAwBd0I2s
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 580->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHa4Y9AuNTj24euj0MeNSj+wWfv/D5H5t+DHfgCBNsZuASw2Yv
Lv9jcw8x8YQrfAm5H5/Z+Pgo7ifSXmL9AwYkxhGlYUGsGYTCC58abO4nFB7Y
1BCb5gnJE4MhZgAA7juNrA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 581->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7SBkNja/4NOHz//Y9KO7A1eYYDMDlxg2e3H5
H5t7iIknvHGBx/34zMbHR3E/kfbi9Q+SOTA+KXGE7g5SwwJXmBBKw9jcgUsN
sjvhGFd44HEzehiR4mZSMcQMADUsjqg=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 582->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DZT8uM5DV4tOHz//Y9KO7A1eY4PMzuhg2e3H5
H5t7iIknfHGBz/34zMbHR3E/kfYS8g8DshiJcURpWBBrBqHwwqcGxR143IPN
r1jNJSK9E8oTxOSZBnsADoGO6w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 583->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHa4Y9AuNTj24euj0MeNSj+wWfv/D5H5t+DHfgCBNsZuASw2Yv
Lv9jcw8x8YQrfAm5H5/Z+Pj4zMAXJ8T4B5v/CbmL0rAg1gxC4YVPDTb3EwoP
bGqITfOE5InBEDMAfZeN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 584->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQGehqiQkfXP7AZhY+s3GZgUsMm724/I/N
PcTEE764wOd+fGbj46O4n0h78foHyRxs/ifkLnR3kBoWuMKEUBrG5g5carC5
H2d44HEzsWmekDwxGGIGAHoYjS4=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 585->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DAfYQjM8MZDfh8xc+/2PTj+5fXGGCz8/oYtjs
xeV/bO4hJp7wxQU+9+MzGx8fxf3oZuCJE5z+wWYGCXGE1T8khAUuMwilYULu
wBZm2MSISQv40jKxbiYVQ8wAABlvjKw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 586->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DAfYQjM8MZDfh8xc+/2PTj+5fXGGCz8/oYtjs
xeV/bO4hJp7wxQU+96OIExkWGO5HNwNPnBDjH+T4xxUm+MKInLAg1gx8biek
Bpv7CYUHNjXEpnlC8sRgiBkAeCuOKg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 587->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQGehqiQkfXP7AZhY+s3GZgUsMm724/I/N
PcTEE764wOd+fGGEy1347GeAYRxqiPEPzAxS4ojSsCDWDHxuJ6QGrg5PGGEz
E6e5RKR3QnmCmDzTYA8Az56QKA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 588->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4cBinGZgaIWj7/w+R+bfgx34AgTfH5GF8Nm
Ly7/Y3MPMfGELy7wuR9fGOFyFz77YfGGSw0x/kGOe1xhgi+MyAkLYs3A53ZC
atDV4XIPNr9iNZeI9E4oTxCTZxrsARXCkCg=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 589->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4cBinGZgaIWj7/w+R+bfgx34AgTfH5GF8Nm
Ly7/Y3MPMfGELy7wuR9fGOFyF4b77VHZ+NyI0z/oZpAYR+juIDUs8IUJvjSM
zR241GC4F4d7sPkVRQ1MnIj0jleegH6EGQAc2I4o
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 590->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQGehqiQkfXP7AZhY+s3GZgUsMm724/I/N
PcTEE764wOd+rGFEwF0Y7rdHZcMxFntw+geLGaTEEbo7SA0LYsMTX1wQUoPh
XhzuweZXFDVo8USKm0nFEDMAfVSPpg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 591->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DAfYIjMsMZDfh8hcDFjux+QObWfjMxmUGLjFs
9uLyPzb3EBNP+OICn/uxpgMC7sJwP1qYwzEWe3D6B4sZpMQRpWFBrBn44oKQ
GhR34AgjrGpxmYsljRMbz8RiiBkAr2KOpA==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 592->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DAUSYgewmXP5iIOB/bPrR/YsrTPD5GV0Mm724
/I/NPcTEE764wOd+rOmAgLtQxLCEORxjsQerf9DMQebjChMMPoVhQWx44osL
QmqwuRdreGDxK654IsbflGCIGQCfXY8k
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 593->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHaQYOeWzq0c0DA3skTMAMZDfh8hcDFjux+QObWfjMxmUGLjFs
9mL1Pw73EBNPuMKXkPuxpgMC7kIRwxLmDDjsxesfLGaQFEcUhgWx4YkvLgip
QXcvMiYmLWCLJ3T9xMYzsRhiBgDPro4i
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 594->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c0DA3skTMAMZDfh8xc+/2PTj+5fXGGCz8/oYtjs
xep/HO4hJp7wxQU+92MNIwLuQhFD10/Ajbj8g2EGqXFEYVgQG5744oKQGnT3
YnMzVrW4zLXHbQ4xfiIGQ8wAAIL2j6Q=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 595->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c3DBvCZgawGn7/w+R+bfnT7CbkFm5/RxbDZi8v/
2NxDTDzhiwt87scaRgTchc9+BgJuxOUfDDNIjSMKw4LY8MQXF4TUoLsXm5ux
qsVlLg4ziIlnYjHEDAAB5o/n
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 596->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c0DA3sIJsYMZDfh8xc+/2PTj+5fXGGCz8/oYtjs
xep/HO4hJp7wxQU+9xMVL1jCBpcZDATciMs/6GaQHEcUhgWx4YkvLgipQXcv
NjdjVYvPXBLdTCqGmAEAJmqR5Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 597->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DAfYIGpcZyG7C5S8GLHZi8wc2s/CZjcsMXGLY
7MXlf2zuISae8MUFPvcTGy/Y4gmrfgJuxOUfXPGGK0zwhRE5YUGsGfjigpAa
FHdgSZ/Epj8UdSS6mVQMMQMA3a+QZw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 598->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DAfZINA4zkN2E1194/I9NP7p/cYUJPj+ji2Gz
F5f/sbmHmHjCFxf43E9svGCLJ/TwhfHxuRGrf9DjiYA/sLmL0rAg1gx8cUFI
DYo7sIQdsekPRR2JbiYVQ8wAAMEhjyY=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 599->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM7CEYl5koanG5CY//senH6g48/sHmZ3Qx
bPbi8j829xATT9j8Soz70fWjhzmusMFrBj434vIPCf7A5i5C6R7DDAJplqC7
0fyKL51jDUe0sCYmLRAKN0JuJgdDzAAALvWNZQ==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 600->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM8JiBoRaXm/D4H5t+rO7A4x9sfkYXw2Yv
Lv9jcw8x8YQvLvC5H1dY4XMXPvsZCLgRp3/wxBkxcURpWBBrBj5/4vIv1nC0
R2BiwhynuSS4mRwMMQMAkOmPpg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 601->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM8JiBoRaXm/D4H5t+rO7A4x9sfkYXw2Yv
Lv9jcw8x8YQvLvC5n5j0gi1s4GJ49GCzB6t/CMQZUXFEYVgQG57IbsTmDnxh
iO5eGCYmzHGaS4KbycEQMwC+HY+m
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 602->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM8JiBoZaI8MHlD2xm4TMblxm4xLDZi8v/
2NxDTDzhiwt87icmvLCFDRgQ0IPNHhR/I2EUNQT8gc1dlIYFsWaguJ0Id2AL
D1jYYfU7NrX4zCXBzeRgiBkAoNaQZQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 603->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM8JiBoZaI8MHlD2xm4TMblxm4xLDZi8v/
2NxDTDzhiwt87icmvLCFDS4zCKlB8Tc2/yFhUuIIwx4Sw4LY8ER3O0F3YAkP
MEDzJzFpgdR0QMhPxKaBBnsArVGPZw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 604->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7UA3gwGHGRhqcbkJj/+x6cfqDix2YzMDlxg2
e3H5H5t7iIknvHGBx/3EpBdsYYPLDEJqCLkFOc5JiSNC8U4oLIgNTxR3EuMO
LOEBp9HcSWz6IzYdEPITsWmgwR4AUySPZw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 605->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM8JiBoRaXm/D4H5t+rO7A4x9sfkYXw2Yv
Lv9jcw8x8YQvLvC5n5j0gi1scJlBSA0htzDgCUts7sCZvkgMC6LDE82dBN2B
JTxQzCAyzAnFDT43U4IhZgAASzGP5w==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 606->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM8JiBoZaI8MHlD2xm4TMblxm4xLDZi8v/
2NxDTDzhiwt87icmvLCFDS4zCKkhxi3oYUNMHFEaFqSYAaaJdAe28EAxg8gw
JxQ3+NxMCYaYAQD4dZDp
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 607->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7UAxA8kcXO4i6C88/semH5c78LmdkBg2e3H5
H5t7iIknvHGBx/3EpBdsYYPLDEJqUPyNhHGJ4QoTfGGELd4JhQUp4Ql3JzHu
wBIeKGYQGeaE4gafmynBEDMAt4GNKA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 608->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcOcJiBTS2p/semH5c78LmdkBg2e3H5H5t7
iIknfHGBz/3EhBe2sMFlBiE1GG5Bl0fCpMQRpWFBihlwdxLhDmzhgWIGkWFO
KG7wuZkSDDEDAI7bj6g=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 609->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7SDWDAy1uNyEx//Y9GN1Bxa7sZmBSwybvbj8
j809xMQT3rjA435i0gu2sMFlBiE1hNzCgIRJiSOiwgItPeCKP0JmwM0iwh3Y
woOQe7D5lVDc4HMzJRhiBgAUVI/l
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 610->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7UAxA4+d+NQS639s+gm5A5vbCYlhsxeX/7G5
h5h4whsXeNxPTHhhCxswIKAHmz0o/oZhdPfZI8zGFSb4wghnWCCZiy/+CJkB
N4sId2ALD0LuweZXQnGDz82UYIgZAAmKjyY=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 611->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7UAxA4+d+NQS639s+gm5A5vbCYlhsxeX/7G5
h5h4whsXeNxPTHhhCxswsGdAiWdccYkz7OzxmEFqHBETFjjCk5gwQVfHgMMd
+MIQqxlEhjmhuMHnZkowxAwA4veNqA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 612->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7UAxA4+d+NQS639s+gm5A5vbCYlhsxeX/7G5
h5h4whsXeNxPTHhhCxtcZhBSg1WMQNogKo4oDAtSwhPmZmzuICY8UMwgMswJ
xQ0+N1OCIWYAAO0sj+k=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 613->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUEut/bPoJuQOb2wmJYbMXl/+xuYeY
eMIXF/jcT0x4YQsbXGYQUoNVjEDaICqOiA0LItMsobTNgMMdxIQHihlEhjmh
uMHnZkowxAwAIGSQqA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 614->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM7CEYl5koagm4CZs6bPqxugOPf7D5GV0M
m724/I/NPcTEE764wOd+YtILtrDBZQYhNVjF0NjY4p0Bi59Q+PjMZEA1m5g0
izM87VHdg+4OYsKDkHsw/EbAXEJupgRDzAAA25mPJA==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 615->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcOcJiBTS0+N2FTh00/LnfgM5OQGDZ7cfkf
m3uIiSd8cYHP/cSkF2xhg8sMQmqwiqGxwYDUOCImLEhIs4TMYMDhDmLCA9ks
dDdh9RsBcwm5mRIMMQMAfnCPZw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 616->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcOcJiBTS1WN+HxPzb9GO7A409cfkYXQ/YH
Lnfg8g8uf+PyLz6/EYo/QmkCHRDSg+JHfGmByPBlgKrF6i5iw4LINIvTDCQ3
Y3MHMeGBbBY292D4jYC5hNxMCYaYAQBiZJBj
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 617->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqjD439s+rG5g5DbCYmBAQF34PIP
Ln/j8i8+vxGKP0JpAh0Q0oNNDVYxIsOXAaoWq7uIDQsi0yyhtI3Nn7j8i0sd
zD/EhDmhuMHnZkowxAwAz5qQpg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 618->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUwtXgsAebe9HZYGCPwPjcTkgMZhY+
d+DyDy5/Y/MvrrjAZgYp6QVr2OAwg5AarGLocYYkhmE3gfDCaiayOiLTLKG0
jc2fuPyLSx26WwilBVLTASE/EZsGGuwB3naN5w==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 619->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2WBgj8D4zCQkhs1eXP7H
5h5i4glfXGAzg5T0gjVscJhBSA1WMTQ2cpjD7YaZTSC88IYFnrgkOjwJpFli
wgPdLGLCnJA6QmmfXAwxAwBlNY9l
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 620->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2WCAw2xcZuASw2YvLv9j
cw8x8YQvLvC5n5j0gjVscJhBSA0hMQZ0PgOmOL7wwhsWUExMmsVnBr40S0x4
oJtFTJgTUkco7ZOLIWYAAKJej2k=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 621->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqjD439s+jHcgWYGNrcTEgMDAu7A
5R9c/sblX3x+IxR/hNIEOkAPX1xq8NnNgIThfAb8/sAXXnjDAk9ckhKe+NIs
vjDEMIOEMCekDp+bKcEQMwBVBY8m
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 622->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+EWYSEgMDPPGAz++4
/I3Lv/j8Rij+CKUJdEBIDzY1WMWQwpkBT1hicweh+McXD/jSLKG0jc2fuPyL
Sx2utEWM39DVEUr75GKIGQCBIZAo
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 623->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+EWYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNrjMIKSGkBgDEiY6jrD5kcSwICU88aVZYsIDTpMQ5oTU
EUr75GKIGQDlhY8q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 624->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUYqjD4X9s+rG6g4DbCYlhsxeX/7G5
h5h4whcX2MwgJb1gCxtcZhBSQ0iMAQmj+AOLn/D6EVtYoInjS7M4w5NAmiUm
PNDNIibMCanD52ZKMMQMADhMjuc=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 625->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNnAxPHqw2YPhFixhzIBFPQMyG094EWsGoTSLMzwJpFl8
YYiuDj3siPUbsemAkJ+ITQMN9gCKQY6o
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 626->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNnAxPHqw2YPhFgLpBVeY4AovZHNJCQtSwhNfmsUXhhhm
kBDmhNQRSvvkYogZAA99jiw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 627->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEkM3A5s7cPkH
l79x+Ref3wjFH6E0gQ4I6cGmhhgx9LAhKo7QzSAxLEgJT3xplpjwgNMkhDkh
dYTSPrkYYgYAgh6Paw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 628->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNrjMIKQGwy1IGG/4YvETPj9iDQs0e/ClWXxm4EuzxIQH
ulnEhDkhdYTSPrkYYgYAdFqP5w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 629->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNrjMIKQGwy0E0guuMMEVXnjDAo9dpIQnvjRLTHgQqx6f
39DVEUr75GKIGQDM/I8s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 630->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNrjMIKSGGDH0sAHTWPyEz4+khgXR4UkgzRITHsSqx+c3
dHWE0j65GGIGAO0Sj+s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 631->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNrjMIKQGwy1IGCufAUkciztw+hFbWKCJ40uzOMOTQJol
JjyIVY8vbaOrI5T2ycUQMwB0VI5n
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 632->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2bj8gs1MQmLY7MXlf2zu
ISae8MUFNjNISS/YwgaXGYTU4BJjgLGRMIo/sPgJnx+xhgWSuYTSLKG0jc2f
OP2GQx0h9fj8hq6OUNonF0PMAADMiI9p
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 633->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2bj8gs1MQmLY7MXlf2zu
ISae8MUFNjNISS/YwgYuhkcPNnsw3ILNDCQxZHuwuYNQ/GOEBZFpllDaxhoW
OPyLSx0h9fj8hq6OUNonF0PMAAC6II9p
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 634->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEoMDPO7A5R8U
dXjiCV9coKslpJeQu/DZT0gNVjFiwhdbeOLxI86wIDLNEkrb2PyJy7+41BFS
j89v6OoIpX1yMcQMAMlTjyo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 635->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
XB2eeMIXF+hqCekl5C589hNSQ0gM7kd0f2DxEz4/4gwLItMsobSNzZ+4/IZL
HSH1+PyGro5Q2icXQ8wAAC20jms=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 636->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUwtXgsAebe9HZYGCPwPjcTkgMm724
/I/NPej+weVfXHGBrpaQXkLuQhHDowebPRhuQTMDW5zhiyNC6RrDDCLTLKG0
jTUscPgXlzpC6vGmbQbccqTGM2F/AwDLj40q
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 637->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2WBgj8D4zCQkhs1eXP7H
5h64OjzxhC8u0NXC5YhML1jDBkf4oAN88YE1PPGEJTZ3EIp/DDOITLOE0jY2
f+LyGy51hNTj8xu6OkJpn1wMMQMA4eGMaw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 638->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmQGmiUwv2MIGFi7YwgafGwmJMdijmosrTHCFF7I5WMOCyDRLKG1j
8ycuv+FSR0g9vrSNro5Q2icXQ8wAAMtzjOs=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 639->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNrBwwec+bPYQIwYzm6Q4wuMnFHVEpllCaRubP3H5DZc6
Qurx+Q1dHaG0Ty6GmAEAeIeN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 640->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNsS4D5s9xIihhw2YxuInfH4kNSyIDk8CaRZfGKKrI6Qe
n9/Q1RFK++RiiBkAgqiPLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 641->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2Sh8AmYSEsNmLy7/Y3MP
MfGELy6wmUFKesEWNrBwgWF8cUlSWkAzE1eY4AovZHNICQtSwhNfmsUXhtjM
IDbMCakjlPbJxRAzAKNojKw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 642->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2bj8gs1MQmLY7MXlf2zu
ISae8MUFNjNISS/YwgZFDIcebPYQEmOwxzQPLo7FHYTiH8MMItMsPjPwhQW+
MERXR0g9Pr+hqyOU9snFEDMAQ3iPaQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 643->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqiDYnxmYjMLhU/A7YTEsNmLy//Y
3ENMPOGLC2xmkJJesIUNMe7DZg8hMQZcYYnFT/j8iDUs8KRNosOTQJrFF4bo
6gipx+c3dHX43EwJhpgBADGbjqo=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 644->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqiDYnxmYjMLn9m4zMAlhs1eXP7H
5h5i4glfXOBzPzHpBVvYEOM+bPYQI4YeNuTEEalhQUp4EhsWhNQRUo/Pb+jq
8LmZEgwxAwBYOI4u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 645->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqiDYnxmYjMLn9m4zMAlhs1eXP7H
5h5i4glfXOByPwMe/fjchSKGRw82NxISAwO0OCMnjkgOCxLCE1+axReG2Mwg
NswJqcPnZkowxAwAJ3mM7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 646->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqiDYnxmYjMLn9m4zMAlhs1eXP7H
5h5i4glfXOBzPzHpBVvYEOM+bPYQEmPAE5bY3EEo/okNC0Jhgq6OmLAgpI6Q
enx+Q1eHz82UYIgZAI0pja4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 647->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2fjMxmUGLjFs9uLyPzb3
EBNP+OICn/uJSS/YwoYY92Gzh5AYtrAhJ46whgUUE5NmCbmbmLAgpI6Qenx+
Q1dHjJvJwRAzAEz+ju0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 648->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2fjMxmUGLjFs9uLyPzb3
EBNP+OICl/sZiEwv2MIGDLCYgQ7wxQct4whnWBCZZnGaQSDN4gtD9DAjpB6f
39DVEUr75GKIGQDCtI0s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 649->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqjD439s+jHcgWYGNrcTEgMDAu7A
5R9c/sblX3x+w5AjMr1gCxti3IfNjYTEGPCEJTZ3EIp/osMCj35sYUZMWGBT
x0DATmL9hq4On5spwRAzACKejio=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 650->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2fjMxmUGLjFs9uLyPzb3
EBNP+OICl/sZiEwv2MKGGPdhcyMhMQY8YYnNHYTin+iwwKOfWH/i8hsKIGAn
sX5DV0eMm8nBEDMAp3mNrg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 651->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqjD439s+rH6l4DbCYmBAQF34PIP
Ln/j8i8+vxGKJ0JpAh0Qch828wmJMSBhYuMIqx9pEBaE/InLb7jUEVKPL22j
qyPGzeRgiBkA6DaOqg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 652->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDFs5uHyPzb3
EBNP+OICl/uJMQNX2BDjPmzmExJjgJlBQhwRCg9qhQUhf+LyGy51hNTj8xu6
OmLcTA6GmAEA9KyOLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 653->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDFs5uHyPzb3
EBNP+OICl/uJMQNX2BDjPmzmExJjgJlBQhwRCg9qhQUhf+LyGy51hNTj8xu6
OmLcTA6GmAEA9KyOLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 654->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDFs5uHyPzb3
EBNP+OICl/uJMQNX2BDjPmzmExJjwBOW2NxBKP6pGRaE/InLb7jUEVKPz2/o
6ohxMzkYYgYAu7uOrg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 655->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDFs5uHyPzb3
YPibiPSAL2xwmU0oTaADfPGCzV5i0gK+sMTmDkLxT82wIORPXH7DpY6Qenx+
Q1dHjJvJwRAzACCoj20=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 656->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDFs5uHyPzb3
EBNP+OICl/uJMQNX2BDjPmzmEyPGAMXExhGh8KBWWDSguYtQWGBTx2CPShMb
5oTUEUr75GKIGQD1W41t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 657->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudnFLPsoZiAO3D5
B04TiCd8cYHL/cSYgStscJmBTQ0paQHmVwY8/sAXXrQMC2xm4QsLQuoIqcfn
N3R1hNI+uRhiBgB2gI1t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 658->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDFs5uHyPzb3
EBNP+OICl/uJMQNX2BDjPmzmEyMGBuhuxeInfH7E6l88cUl0eBJIs/jCEF0d
IfX4/IaujlDaJxdDzAAA74WOrA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 659->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDFs5uHyPzb3
EBNP+OICl/uJMQNX2BDjPmzmEyMGBuhuxeInfH7E6l97hLnkhAUhf+LyGy51
hNTj8xu6OmLcTA6GmAEAtp+Paw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 660->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDEM8/D4H5t7
sMYHEXGNK2zgckSmF2xhQ9B9WOwlJi3gCktsfsLnR1z+RfczLn/gM4PYsMCm
jgHNDGLDnJA6QmmfXAwxAwBc1JBn
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 661->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDFs5uHyPzb3
YI0PIuIaV9jgMptQmkAHeN2HxV5i0gKusMTmJ3x+pEVYgGkCaRZfGMIBgbAg
xm/o6gilfXIxxAwAZXOPLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 662->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudnFLPsoRhZHo//
sbkHw99QMwjFNa6wgcsRmV6whQ1e96GpISUt4ApLbH7C50eSwwKPfmxhRkxY
YFNHinp8fkNXRyjtk4shZgAAT+ePaQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 663->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudnFLOw2YvH/9jc
g+FvqBmE4hpX2MDliEwv2MIGr/vQ1JCSFnCGJZbwxOdHksMCj35i/YnLb9gA
Merx+Q1dHTFuJgdDzAAAo0qOqg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 664->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GLoZGHw8
fsfqb6gZhOIaV9jgMptQmkAH+OIFm73EpAWcYYnsdzzhRcuwIORPXH7DBohR
j89v6OqIcTM5GGIGAKiyjqo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 665->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDEGdHk8/sfm
Hgx/E5Ee8IUNLrMJpQl0gC9esNlLVFpAwrjCEF940Sws8IQNPjPgANlvxKgn
4Dd0dYTSPrkYYgYA5XWPpg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 666->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDEM8/D4H5t7
MPxNRHrAFza4zCaUJtABvnjBZi8xaQFnWGLxEz4/Uj0s8IQNPjPgAMkPRKkn
4Dd0dYTSPrkYYgYAOsuP6Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 667->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2YTsxudndDEM8/D4H5t7
MPxNRHrAFza4zCaUJtABvnjBZi9RaQHJjyhuxeInfH6kRVgQ8icuv2EDxKjH
5zd0dcS4mRwMMQMADmCOLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 668->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zOKWVjMwODj
8TuyO1DMxOFffH4jFE+E0gQ6wBcv2OwlKi3gCkssfsLnR1qEBSF/4vIbHGDx
B7FhTkgdMW4mB0PMAAC3xI3p
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 669->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GDZ7cfkf
m3tg7oDLEZEe8IUNNjcTkybQAb54wWYvMWkBZ1hi8RM+P9IiLAj5E5ffsAFi
1OPzG7o6YtxMDoaYAQA0s43t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 670->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2fjMxmUGLjFs9uLyPzb3
EBNP+OICl/uJMQNX2BDjPmzmExJjgJmB7lYsfsLrRxqEBSF/4vIbNkCMenxp
G10dMW4mB0PMAADifIxv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 671->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUoqjD439s+rG5g5DbCYnhczsuOwnp
xeVffH4jFE+E0gQ6IOQ+bOYTEmOAmYHuVix+wudHqocFnrDBZwYc2CNhYtQT
8Bu6Onz+pgRDzAAAaHqPqA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 672->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUwtXgsAebe9HZYGCPwPjcTkgMw+14
/I/NPRj+xuImfHGBzYwGIs3AGTb43IemhqS0gCsssfgJnx9JDgs8+rGFFTFh
gaIOyQ9EqSfgN3R1+PxNCYaYAQCsWY9l
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 673->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+FOMzE58YAxYzGPD4
H5t7GpD0o/PxxTWusCHFDFxhg83fuNSQkhZwhiUWP+HzI8lhgUc/trAiJiww
1OGIW2LCnJA6QmmfXAwxAwBYc4/l
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 674->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+FOMzk5AYuhkMePyP
zT0NSPrR+fjiGlfY4AorQmkCHeCLF2z2EpUW0MILJQyxuAOnH0kMC0JhQow/
cfkNGyBGPb60ja6OGDeTgyFmAACOWI8m
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 675->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GAMUw+Xx
+B+bexqQ9KPz8cU1rrAhxQxcYQMG2PyGBvDFB9bwxON/bO7A6UdSwwKLu3CZ
hy/N4gxDpLAiSj0eN2NTRyjtk4shZgAAT72OJA==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 676->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GAMUw+Xx
+B+be3CZSSiucYUNKWbgChswwOU3HOFGVFqwR5iNEYZY3EEo/okOCxz6GdBo
QmkWaxjiCBec6onwG7o6QmmfXAwxAwC/iI8g
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 677->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GAMUw+Xx
+B+be3CZSSiucYUNKWbgChs4QNeDJy0RlRbsUc1FCUMs7iAU/0SHBR792MIK
HeDzGyz+4ZiQeiL8hq6OUNonF0PMAADXT49j
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 678->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wWYGsln44hpX2DCg0YTSC0bY4HEHAxZ9pKQFZL+i+AOLn/D5keiwYMDt
LmxhRijNYg1D5PAiRj0RfkNXRyjtk4shZgAA3GuO4Q==
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 679->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wWYGPv/i8xtcDo0mlF4wwsYeFaObja6PlLSA7Fei44hAeOANCwbc7iLo
RizuwBmGWOIOr3oCfkNXR4ybycEQMwDeJo2m
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 680->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wTADTS2+uMYVNgxoNKH0gi1sGHDoJ+RGYsRw+h+LOwjFP8GwYMDtLmLc
iM2thNIpMeoJ+Q1dHTFuJgdDzAAAi9KNqg==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 681->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wTADTS2+uMYVNgx49OGLewyAxSx0gC8+4OGLJ53iChNc4UVyWDBgdxdB
d2PxJy7/4nM3sWFOSB0xbiYHQ8wAAFSkjOs=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 682->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wTADTS2+uMYVNgx49OGLewyAxSwGZIzFjcS4BWY20XFEIDzwhgUDdncR
dDcawJfO0eOdoHo8fsWljhg3k4MhZgAAsH6N5w==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 683->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wTADTS2+uMYVNgx49OGLewyAxSyYGC43YnMLhhkMqGFFMI5wuIWosGDA
tJNQOsKXZjH0YYl3vOqx+Q2L29DVEeNmcjDEDADZDozl
                    "], {{0, 
                    17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 684->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wTADTS2+uCYUNsSmF2xhAwck2osuhhwuKPaSEkdY3EGsm5DliAlPQmkW
Qx+WeMerHpvfsPgPXR0xbiY3DTTYAwApeY5n
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 685->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wTADTS2+uCYUNhh60Gkc7kIBaPrhGIe96GLI4YIRHsTGEZo7SAkLZDli
wpNQmsUWpvjCE5s9WP1KQB0xbiYHQ8wAAInmi+c=
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 686->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wTADTS2+uCYUNjj1EnAXCkDTR8hedDHkcMEID2LjCM0dpIQFshwx4Uko
zZIantjswedXXOqIcTM5GGIGAFDWjOk=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 687->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBhAzcLl
Dlz+wTADTS2+uCYUNsSmF2xhAwfI6omwF10Mlxqs/sfiDuSwIScs0O3B0Esg
/WFzK7p+OCZGPTa/4XA3NnFCYUtOGmiwBwBDSoyq
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 688->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GBzgcQcu
/+A0C4d/8fmN3PSCzW5c5sL8iU+emLTBgBb2uNyBrB7DHCLCAlkOaxgQSH/o
7sCmH9kvBNVj8xsOd2MTJxS25KSBBnsAwnqMqg==
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 689->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+Af9g8zO6GDZ7cfkf
m3uwmYXLv/j8Rm56wWY3LnPBAI+96GI4zcDhb5zuwuZ+IsIC3R5CZhBKs8TE
BT71WP2Gw93YxAmFLTlpoMEeABV1jiw=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 690->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+FOMzk5AYA5o52NyB
yz9YzcLjX3x+g8uRmF6whQ0uN+Czl5S0gc3/2NwB52NzPzFhwYDbHdjMIJRm
iYkLfOqx+g2Hu7GJEwpbUjHEDAA6kI6o
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 691->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+FOMzk5AYA5o52NyB
yz/YaHz+xec3ctMLNrtxmQsGeOxFF8NpBg5/43QXNvcTERbo9hAyg1CaJSYu
8KnH6jcc7sYmTihsyUkDDfYAz7aOaQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 692->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+FOMzk5AYA5o52NyB
yz/YaHz+xec3ctMLNrtxmQsGeOxFF8NpBg5/43QXNvcTERbo9hAyg1CaJSYu
8KnH6jcc7sYmTihsyUkDDfYAz7aOaQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 693->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+EWYSEiPGb7jkwcAe
CaOpxRfXGGaRmV6w+QOXG3D5EV884kunOMMESxhhmEOEm9DtIWQGoTRLTFzg
U4/VbzjcjU2cUNiSiiFmAAA10o1r
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 694->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+EWYSEiPGb7jkwQDJ
Hehq8cU1hllkphds/sDmBgYkGpcbMfTgUINsJ8E4YsDuN3xmEEqzGH7Cog+b
O4iJC3zqsfoNh7uxiRMKW1IxxAwAqkaNaw==
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 695->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUwtXgsAebe9HZcD4U43M7ITFi/IZL
HgyQ3ICuFl9cE4pzYtMLNn/gMhfmVpzyDAT4aPGGM0ywhBGuuMcXFuhqsPkH
X/pDdwcxcYFPPVa/4XA3NnF8YUtuGmiwBwCTyIwq
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 696->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2XA+EWYSEiPGb7jkcfkb
l3/x+Y3c9ILNH7jMZYBhXPJY/IPVDBxhiNNdJJpBKM0im0MoHgiagcfdpIQ5
qekAnxwpaaDBHgAFMY6q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 697->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUErIHm3vR2bj8gs1MQmLE+A2XPC5/
4/IvPr+Rm16w+QOfuQx47MXmH2LSEi53wPkkmkEozRKTprG5g5i4wKceq99w
uBubODFhS2oaaLAHAGHKj6w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 698->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUwtUgYXxmYjMLhU/A7YTEiPEbLnlc
/sbmX1xxQUgtofSCzR/4zGXAFydY/ENMWsLlDlxxRMgMQmmWmDSNzR3ExAU+
9Vj9hsPd2MSJCVtS00CDPQBoiY5r
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 699->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUwtVAMS7/Y9OPAtD043I7ITFi/IZL
Hpe/sfkXV1wQUksovWANGzzmMuCLEyz+ISYt4XIHnE+iGYTSLDFpGps7iIkL
fOqx+g2Hu7GJExO2pKaBBnsAw+KPKg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 700->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUwtUgYXxmYjMLhU/A7YTEiPEbLnlc
/sbmX1xxQUgtofSCzR/4zGXAFydY/ENMWsLlDnLNIJRmiUnT5LiDkHpsanC5
G5s4MWFLahposAcAF5iO6w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 701->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1Dt4eQnfjUwtWg0zjMxGYWnI+kH5fbCYkR4zdc
8rj8jc2/uOKCkFpC6QWbP/CZy4AvTrD4h5i0hMsd5JpBKM0Sk6bJcQch9djU
4HI3NnFiwpbUNNBgDwB48Y+q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 702->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwZcDxZxbGrR7UA3gwGHGRhqiQgfXP7AZhY+s3GZgUuMkJn4
5HH5m5B/SQ0bYtIENoBVHx57sfmHkPuJiSNSzcAXf8TIYwsHYswgpB6bGlzu
xiZOTNiSmgYa7AF4H49r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 703->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBpi2RzUHm3p089DtYUAzB90MFLV4/IXP/9j0Y7gDR5hg
MwOXGMwMXO7FaicWc3HFB964IDJs8KYJLGGDz1wGPPZi8w8h9xMTR6SagS/+
iJHHFg7EmEFIPTY1uNyNTZyYsCU1DTTYAwCzapCm
                    "], {{0, 17}, {
                    17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 704->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyTHgEmdAFcNlBpjGIY5LDB3AzGDAYwaKWjz+wud/bPox3IEjTLCZgUsM
5hdc7sVqJxZzccUH3rggMmzwpgksYYPPXAY89mLzDyH3ExNHpJqBL/6IkccW
DsSYQUg9NjW43I1NnJiwJTUNNNgDAAs0keU=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 705->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcM8JiBoZaI8MHlD2xm4TMblxm4xBgIuBef
nbj8Tci/pIYNMWkCG8CqD4+92PxDTFrC5Q5yzSCUZolJ0+S4g5B6bGpwuRub
ODFhS2oaaLAHAM/akKo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 706->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcMCJiJopaI8MHlD2xm4TMblxm4xBgIuBef
nbj8Tci/pIYNMWkCG8CqD4+92PxDTFrC5Q5yzSCUZolJ0+S4g5B6bGpwuRub
ODFhS2oaaLAHAC8Bj+s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 707->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcOcJiBTS1Of+PwPzb9WN1BwO2ExBiQMC53
4PIPLn/j8y8uv5GbXrCFDT5zGfDYi80/xKQlXO4g1wxCaZaYNE2OOwipx6YG
l7uxiRMTtqSmgQZ7AKJOkCg=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 708->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcbH5df8PkLn/+x6cflDnxuJyQGBvYQjMsd
uOzE5W9C/iU1bIhJE9gAKWmJ2LSBMwyxuINcMwilWWLSNDnuIKQemxpc7sYm
TkzYkpoGGuwBiFePrA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 709->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcF4DATXS2p/semH5c78LmdkBg2e3H5H5t7
iIknfHFBTNgQkyawAVLSErFpg1AYYnMXqWYQSrPEpGly3EFIPTY1uNyNTZyY
sCU1DTTYAwB3xY9t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 710->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcF4DATXS2p/semH5c78LmdkBg2e3H5H5t7
iIknfHFBTNgQkyawAVLSErFpg1AYYnMXqWYQSrPEpGly3EFIPTY1uNyNTZyY
sCU1DTTYAwB3xY9t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 711->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwYKbY9KY1OLbgeyGXCAxQxsagn6H4u9uMzCZzYuM3CGAwOm
PC7/Y3MPMfGELy6ICRti0gQ2QEpawuUfotISDneQawa++CNGHls4EGMGIfXY
1OByNzZxYsKW1DTQYA8AJh2Pqg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 712->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcbwOUXfP7C539s+nG5A5/bCYlhsxeX/7G5
h5h4whcXxIQNMWkCGyAlLRGbNgiFITZ3kWoGoTRLTJomxx2E1GNTg8vd2MSJ
CVtS00CDPQCa948u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 713->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eQY8atHtQDYDDrCYgU0tqf7Hph+XO/C5nZAYNntx+R+b
e5DDEV0tPr+SEjbEpAlsgJS0hDVt4DGDlDgi1QxCaZZgmsYSDsSYQUg9NjW4
3I1NnJiwJTUNNNgDAAMWj2s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 714->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eQY8atHtQDYDDrCYgU0tQf9jsReXWfjMxmUGLjFs4YfL
/9jcQ0w84YsLYsKGmDSBDZCSlnD5h5i0hMsd5JpBKM0STNNYwoEYMwipx6YG
l7uxiRMTtqSmgQZ7AAs7kCo=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 715->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcD4PELPn/B1WNRh00/Lnegm4PPz+hi2OzF
5X9s7iEmnvDFBSG1hNILtrDBZy4+eWz+ISYt4XIHuWYQSrPEpGly3EFIPTY1
uNyNTZyYsCU1DTTYAwBcnI5t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 716->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAMSxqYW3Q5kM1AAHr/g8xeKO3D4A5e9uMzGZQYuMXQ/
YHMHLjtR1OHwB6G4IKSWUHrBFjb4zMUnjy6GzwxS4ohUM/DFHzHy2MKBGDMI
qcemBpe7sYkTE7akpoEGewACuY1r
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 717->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAMU41KLbgeyGSgAj1/w+QvFHTj8gcteOJ+A2wmJoYcB
Nnfg8g+KOjzxhC8uCKkllF6whQ0+c/HJo4vhM4OUOCLVDHzxR4w8tnAgxgxC
6rGpweVubOLEhC2paaDBHgC7a47p
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 718->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwcD4PELPn8R4w9c9sL5BNxOSAxbeODyPzb3
4AsnfP4lNmyIDTNsgJS0RGzawBWG2NxBrhmE0iwxaZocdxBSj00NLndjEycm
bElNAw32APujju0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 719->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eQY8atHtQDYDBeDxCz5/EeMPXPbC+QTcTkgM3Qxs7sDl
HzgNw1j8QSguUOwiI71gCxt8bsAnjy6GzwxS4ohUMwilWYJpGks4EGMGIfXY
1OByNzZxYsKWFAwxAwDKy43r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 720->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwebGC6/4PMXMf7AZS8us3GZgUsMm724/I/N
PWCaiDDBFReE1BIbZtgAKWmJ2LRBKAyxuYtUMwilWWLSNDnuIKQemxpc7sYm
TkzYkpoGGuwBssON7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 721->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eTDAoRbdDmQzcLkJ3S/4/EWMP3DZi8tsXGbgEsNmLy7/
Y3MPvnDC519iw4bYMMMGSElLuNIGMWkJlzvINYNQmiUqTZPhDkLqsanB5W5s
4sSELalpoMEeABLDje8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 722->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwebGC6/4FRDpD9w2muPwPjcTkgMm724/I/N
Pcj+weYPQnFBSC2h9II1bPCYi08eXQyfGcTEEblmEEqzxKRpctxBSD02Nbjc
jU2cmLAlNQ002AMA3wSOLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 723->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAPMDBxq0e1ANgMF4PELLn8xEOkPnPbiMBuXGbjEsNmL
jY/LPfjCCV9cE4pzYtML1rDBYy4+eXQxfGYQE0fkmoEv/oiRxxYOxJhBSD02
NbjcjU2cmLAlNQ002AMARlqL7w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 724->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAMO9ejmoduDAfD4BZ+/iPEHLnvhfAJuJySGHgbY3IHL
P7jUEeNfYsOG2DDDBkhJS9jSDj4zSIkjUs3AF3/EyGMLB2LMIKQemxpc7sYm
TkzYkpoGGuwBunKN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 725->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAMSxqYW3Q5kM1AAHr/g8hcDkf7AaS+RbickxoDDv7jc
hs7GF0744ppQnBObXrCGDR5z8cmji+Ezg5g4ItcMfPFHjDy2cCDGDELqsanB
5W5s4sSELalpoMEeAFv/jOs=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 726->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eQY8atHtQDYDl5vQ/YJTDZH+wGUvLrNxmYFLjAGHf3G5
DZ2NL5zwxTWhOCc2vWALG3zm4pNHF8NnBilxRKoZhNIswTSNJRyIMYOQemxq
cLkbmzgxYUtqGmiwBwDm0I5t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 727->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eQYoxqYW3Q5kM3C5Cd0v+PxFjD9w2YvLbFxm4BJjwOFf
XG5DZ+MLJ3z+JTZsiA0zbICUtIQ1beAxg5Q4ItUMQmmWYJrGEg7EmEFIPTY1
uNyNTZyYsCU1DTTYAwCs0I5t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 728->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAMSxqYW3Q5kM1AAHr/g8xcx/sBlL5xPwO2ExND9j80d
uPyDog5PPOGLC0JqiQ0zbICUtIQt7eAzg5Q4ItUMfPFHjDy2cCDGDELqsanB
5W5s4sSELalpoMEeABBKjio=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 729->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwebGC6/4PMXMf7AZS+cT8DthMTQzcDmDlz+
waWOGP8SGzbEhhk2QEpaIjZt4AxDLO4g1wxCaZaYNE2OOwipx6YGl7uxiRMT
tqSmgQZ7AFuyju0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 730->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAPMDBxq0e1ANgOXm9D9gs9fxPgDl724zMZlBi4xbPbi
8j829+ALJ3z+JTZsiA0zbICUtIQt7eAzg5Q4ItUMfPFHjDy2cCDGDELqsanB
5W5s4sSELalpoMEeAC+ljW8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 731->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eTDAoRbdDmQzcLkJ3S/4/EWMP3DZi8tsXGbgEsNmLy7/
Y3MPvnDC519iw4bYMMMGSElLuNIGMWkJlzvINYNQmiUqTZPhDkLqsanB5W5s
4sSELalpoMEeABLDje8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 732->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAMSxqYW3Q5kM1AAHr/g8xcx/sBlLy6zcZmBSwzd/djc
gctOFHV44glfXBBSS2yYYQOkpCVsaQefGaTEEalm4Is/YuSxhQMxZhBSj00N
LndjEycmbElNAw32AKVujaw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 733->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eQY8atHtQDYDl5vQ/YLPX8T4A5e9cD4BtxMSY0ALA2zu
wOUfFHV44glfXBBSS2yYYQOkpCWsaQOPGaTEEalmEEqzBNM0lnAgxgxC6rGp
weVubOLEhC2paaDBHgCRlY+q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 734->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAMSxqYW3Q5kM3C5Cd0v+PxFjD9w2YvLr7jMwCUGBnji
AZffsYYlnjDBFReE1BIbZtgAKWkJW3jiM4OSOCJkBr74I0YeWzgQYwYh9djU
4HI3NnFiwpbUNNBgDwCi6Y7r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 735->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAPMDBxq0e1ANgOXm9D9gs9fxPgDn70M9oTdTkgMm724
/I/NPfjCCZ9/iQ0bYsMMGyAlLWFLO/jMICaOyDUDX/wRI48tHIgxg5B6bGpw
uRubODFhS2oaaLAHAGbZjS4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 736->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwebGC6/4PMXMf7AMMseghuQaHxuxymGI9xx
8XG5B1844fMvsWFDbJhhA6SkJWLTBrZwxeUOcs0glGaJSdPkuIOQemxqcLkb
mzgxYUtqGmiwBwAff5Aq
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 737->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwebGC6/4FRDpD9w2Qszg4GA2wmJYbMXl/+x
uQdfOOGLa0JxTmx6wRY2+MzFJ48uhs8MouOIDDMIpVli0jQ57iCkHpsaXO7G
Jk5M2JKaBhrsAchMjm0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 738->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwa6PAPMDBxq0e1ANgMF4PELPn8R4w9c9uIyG5cZuMSw2YuN
j8s9+MIJn3+JDRtiwwwbICUtYUs7+MwgJY5INQNf/BEjjy0ciDGDkHpsanC5
G5s4MWFLahposAcAcIeM7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 739->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwebGC6/4PMXMf7AZS+cT8DthMTQzcDmDlz+
QVGHJ57wxQUhtcSGGTZASloiNm3gDEMs7iDXDEJplpg0TY47CKnHpgaXu7GJ
ExO2pKaBBnsA93mPLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 740->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eQYoxqYW3Q5kM3C5Cd0v+PxFjD9w2YvLbFxm4BLDZi8u
/2NzD75wwudfYsOG2DDDBkhJS1jTBh4zSIkjUs0glGYJpmks4UCMGYTUY1OD
y93YxIkJW1LTQIM9AP9Cji4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 741->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eQY8atHtQDYDl5vQ/YLPX8T4A5e9cD4BtxMSg5nBgMXt
OO3EZi4ME+lfXGGDLT6ICTNsgJS0hDVt4DGDlDgi1QxCaZZgmsYSDsSYQUg9
NjW43I1NnJiwJQVDzAAACMOOqg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 742->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eWzq0c1DtwebGC6/4PMXMf7AZS8us3GZgUsMDnDEAz47
sdlNrH+JcT8pYYYNkJKWiE0b+MIQl7tINYNQmiUmTZPjDkLqsanB5W5s4uTE
M+F0BADKe43v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 743->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QwUgMcv+PxFjD9w2Uus2wmJYbMXGx+Xe4iJ
J3xxgc/9pIQZNkBKWsLlH2LSEi53kGsGoTRLbJom1R2E1GNTg8vd2MTJiWfC
6QgAncuNMA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 744->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLMyBhZLW4zMAmDwY41KLbjWwGLjeh+wWfv/D5D5t+XO7A53ZCYtjs
xeV/bO4hJp7wxQU+95MSZnBARDrA5UZi3YIvDLG5i1QzCKVZotI0Ge4gpB6b
GlzuxiZOTjwTTkcAKCWPqg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 745->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf+0kJM2x8UtISLv8Qk5bIdQexYUGsGYTSLDFxgU89NjW43I1NnJx4
JpyOAM1Ljm8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 746->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLg4E9BCOL4TIDmzzMDGxq0e1GNgOXm9D9gs9f+PyHTT8ud+BzOyEx
bPbi8j829xATT/jiAsUuEtISLnfhchsxbsTmH2LSErnuwBcW+NIsUWmaDHcQ
Uo9NDS53YxMnJmxJwRAzAJVujqw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 747->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLMyBhZLW4zMAmj009shg6wCWGyy/4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy5Q7CIhLeFyFy63EeNGbP4hJi2R6w58YYEvzRKTpslxByH12NTg
cjc2cWLClhQMMQMAcdaPaw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 748->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMljU48shg5wieHyCz5/4fMfNv243IHP7YTEsNmLy//Y
3ENMPOGLCxS7YGIkpBe8YUNCWiI2bRAKQ2zuINUMQmmWmDRNjjsIqcemBpe7
sYkTE7akYIgZAG4gje0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 749->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQa6PAPMDBxq0e1GNgOXm9Ddhc9f+PyHTT8ud+BzOyExbPbi
8j829xATT/jiAsUuEtISLnfhchsxbsTmH2LSErnuwBcWuOKPGHl0QKwZhNRj
U4PL3djEiQlbUjDEDAC1II5t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 750->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4z0OUZ7DH1Y6hBA7jEcPkFn7/w+Q+bflzuwOd2QmLY7MXl
f2zuISae8MUFil0kpCVc7kLhk5CWcPmHmLREyB2kmoEv/oiRRwfEmkFIPTY1
uNyNTZyYsCUFQ8wAAMLzjW0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 751->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMmj60dXgw5wieHyCz5/4fMfNv243IHP7YTEsNmLy//Y
3ENMPOGLCxS7SEhLuNwFBgTSAS43YvMPMWkJlzvINYNQmiUqTZPhDkLqsanB
5W5s4sSELSkYYgYAohGN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 752->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMmj60dXgw5wieHyCz5/4fMfNv243IHP7YTEsNmLy//Y
3ENMPOGLCxS7SEhLuNwFBgTSAS43YvMPMWkJlzvINYNQmiUqTZPhDkLqsanB
5W5s4sSELSkYYgYAohGN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 753->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgWIXCWkJl7vAAGoWKWkJl3+ISUu43EGuGYTSLLFpmlR3EFKPTQ0ud2MT
JyZsScEQMwAuA45t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 754->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgWIXCWkJl7vAAGoWKWkJI5wImEFKHJFqBqE0S2yaJtUdhNRjU4PL3djE
cYU1uRhiBgDAj44s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 755->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsIMBZAY1vjinZi0hMsdpKRHbPaRagahNEtMXOBTj00NLndjE8cV
1uRiiBkAWlKN7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 756->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqYObRUR6JCWOSDWDUJolNk2T6g5C6rGpweVubOK40im5
GGIGAHpSje8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 757->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqYObBcM4zMIXhtjcRaoZhNIssWmaVHcQUo9NDS53YxPH
lU7JxRAzAOLpji4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 758->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmJFiNy51xLoFXxhicxepZhBKs8SmaVLdQUg9NjW43I1N
HFdYk4shZgAAUkON7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 759->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqYObBcM4zMIXhiiATDMIpVli0zS6u4iJC3zqsanB5W5s
4rjSKbkYYgYAL+mNrg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 760->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsIMBZAY1hjugmEcbsEXhujuIMcMQmmW2DSN7i5i4gKfemxqcLkb
mziudEouhpgBADjajS4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 761->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqSPWLfjCEAWQkB6x2YeuhtQ0je4uYuICn3psanC5G5s4
rrAmF0PMAACeUo3v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 762->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqSPWLfjCEJu7SDWDUJolNk2T6g5C6rGpweVubOK4wppc
DDEDAFFhjm8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 763->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqSPWLfjCEJu7SDWDUJolNk2T6g5C6rGpweVubOK4wppc
DDEDAFFhjm8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 764->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmJFiNy51xLoFXxhicxepZhBKs8SmaVLdQUg9NjW43I1N
HFdYk4shZgAAUkON7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 765->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmJFiNy51cLNgGIdZ+MIQm7tINYNQmiU2TZPqDkLqsanB
5W5s4rjSKbkYYgYA48uNrg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 766->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmKEAEsMaa9iRkJbwuYMcMwilWWLTNLq7iIkLfOqxqcHl
bmziuMKaXAwxAwAQy40u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 767->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmJFiNy51xLoFXxhicxepZhBKs8SmaVLdQUg9NjW43I1N
HFdYk4shZgAAUkON7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 768->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqSPWLfjCEJu7SDWDUJolNk2T6g5C6rGpweVubOK4wppc
DDEDAFFhjm8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 769->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqSPWLfjCEJu7SDWDUJolNk2T6g5C6rGpweVubOK4wppc
DDEDAFFhjm8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 770->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqYObBcM4zMIXhtjcRaoZhNIssWmaVHcQUo9NDS53YxPH
lU7JxRAzAOLpji4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 771->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf3aSEGSl241JHrFvwhSE2d5FqBqE0S2yaJtUdhNRjU4PL3djEcYU1
uRhiBgBW8Y2w
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 772->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLgwGa/fjMwCaPy1xsdiObgctN6Gbi8xc+/2HTj8sd+NxOSAybvbj8
j809xMQTvrjAZzcpYYYCSAxrDHfBMA634AtDdHeQYwahNEtsmkZ3FzFxgU89
NjW43I1NHFc6JRdDzAAAOriMrg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 773->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLgwGa/fjMwCYPNwOLWnS7kc3A5SZ0v+DzFz7/YdOPyx3Y/InLz+hi
2OzF5X9s7iEmnvDFBT67SQkzUuzGpY5Yt+ALQxRAQnrEZh+6GpLSNJbwISYu
8KnHpgaXu7GJ4wprcjHEDACupI0u
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 774->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQp
mAGdz4DbHGSArB+OGVDV4jIDmzw2e9HNQ7cfmxguM/H5C6//sOjH5Q58bick
hs1eXP7H5h5C/iAUF/jsJiXMSLEblzpi3YIvDLG5i1QzCKVZYtM0qe4gpB6b
GlzuxiaOK6zJxRAzACZNjS4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 775->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSx
mAGbGANuc5ABshlggGY/PjOwyWOzF908dPuxieEyE5+/8PoPi35c7sDndkJi
2OzF5X9s7iHkD0Jxgc9uUsKMFLtxqSPWLfjCEJu7SDWDUJolNk2T6g5C6rGp
weVubOK4wppcDDEDACcDjO8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 776->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLM8DE0ezHZwY2ebgZWNSi241sBoYYDr/g8xde/2HRj8sd2PyJy8/o
YtjsxcbH5R5C/iAUF/jsJiXMSLEblzpi3YIvDLG5i1QzCKVZotI0Ge4gpB6b
GlzuxiaOK6zJxRAzAJ93jK4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 777->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLM6BhZLW4zMAmDwY41KLbjWwGNjdh8ws+f+H1Hxb9uNyBz+2ExLDZ
i8v/2NxDyB+E4gKf3aSEGQogMawx3AXDONyCLwzR3UGOGYTSLFFpGkv4EBMX
+NRjU4PL3djEcaVTcjHEDAAZyIzr
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 778->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLMyCLo6nFZQY2eWz2otiDBnCJ4TITn7/w+g+LflzuwOd2QmLY7MXl
f2zuIeQPQnGBz25SwgwFkBjWGO4iIj2SEkekmkEozRKbpkl1ByH12NTgcjc2
cVzplFwMMQMAfweMbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 779->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLM8DEoWxktbjMwCaPzV4Ue9AALjFcZuLzF17/YdGPyx343E5IDJu9
uPyPzT2E/EEoLvDZTUqYkWI3LnXEugVfGGJzF6lmEEqzxKZpUt1BSD02Nbjc
jU0cV1iTiyFmAABJc42u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 780->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLM+DQg88MbPKEzEAHuMRwmYnPX3j9h0U/LnfgczshMWz24vI/NvcQ
8gehuMBnNylhhgJIDGusYUdCWsLlDlLSIzY3kWoGoTRLTFzgU49NDS53YxPH
FdbkYogZAL3Lja4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 781->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqSPWLfjCEJu7SDWDUJolNk2T6g5C6rGpweVubOK4wppc
DDEDAFFhjm8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 782->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqUNxCwlpCZ87yDGDUJolNk2T6g5C6rGpweVubOK4wppc
DDEDALn4jq4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 783->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsIMBZAY1hjuIjEt4XMHOWYQSrPEpml0dxETF/jUY1ODy93YxHGl
U3IxxAwADemNrg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 784->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsIMBdhDMClpCSOcCJhBShyRagahNEtsmibVHYTUY1ODy93YxHGF
NbkYYgYANYSN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 785->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgdUuEtILtrAB6YdhYtMSLv8Qk5ZwuYNcMwilWWLTNKnuIKQemxpc7sYm
TkzYkoIhZgAAmMuNLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 786->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy6w2kVCesEWNiD9MExsWsLlH2LSEi53kGsGoTRLbJom1R2E1GNT
g8vd2MSJCVtSMMQMAJmtjK4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 787->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmGHlk5CWcPmHmLREyB2kmkEozRKbpkl1ByH12NTgcjc2
cWLClhQMMQMAL3SNbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 788->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc8uUsIMg09CWONKO7jcge5/vO4gwwxCaZbYNE2qOwipx6YGl7uxiRMT
tqRgiBkA+ceN7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 789->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be1Ds
JsG/eO0iIb3gDBsSwhpX2sHlD3xhiM1dpJpBKM0Sm6ZJdQch9djU4HI3NnFi
wpYUDDEDAB3Djm0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 790->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPit0k+BevXSSkF5xhQ0JYYw07JEwoLeF1B46wwGcGoTRLbJom1R2E1GNT
g8vd2MRxhTW5GGIGAOAijSw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 791->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmJFiNy51pNhNShyRagahNEtsmibVHYTUY1ODy93YxMkJ
a8LxAADKk49t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 792->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqSPFbqLjiAwzCKVZYtM0uruIiQt86rGpweVubOLkhDXh
eAAAIJ+QLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 793->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHL4xLDZQY2eUJmoANcYrjMxOcvfP7Dph+XO/C5nZAYNntx+R+be4iJ
J3xxgc9uUsKMFLtxqcPwDxHuJxhHZJhBKM0Sm6bR3UVMXOBTj00NLndjE8cX
1uRgiBkATZCPrA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 794->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf3aSEGSl241KH4R8i3I8vjhjsEZgUMwilWWLTNLq7iIkLfOqxqcHl
bmzi+MKaHAwxAwDxAo3t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 795->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLgwGa/fjMwCYPMwObWnS7kc3A5SZ0v+DzFz7/YdOPyx343E5IDJu9
uPyPzT3ExBO+uMBnNylhRorduNSRYjfRcUSGGYTSLFFpGkv4EBMX+NRjU4PL
3djEyQlrwvEAAA4Pj+s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 796->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf3aSEGSl241KH4R8i3E8wjnCYg88MQmmW2DSN7i5i4gKfemxqcLkb
mzi+sCYHQ8wAAKQRjm0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 797->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLgwGa/fjMwCYPMwObWnS7kc3A5SZ0v+DzFz7/YdOPyx343E5IDJu9
uPyPzT3ExBO+uMBnNylhRorduNSRYjcpcUSqGYTSLFFpmgx3EFKPTQ0ud2MT
JyesCccDALchj6w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 798->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf3aSEGSl241JHit3ExBGDPRTjsQtXWOBLs8SmaXR3ERMX+NRjU4PL
3djEyQlrwvEAAG4uji4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 799->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eTDAoRbdDmQzcLkJ3S/4/EWMP3DZi8tsXGbgEsNmLy7/
Y3MPMfGELy7w2U1KmJFiNy51pNhNSRwREw/40ixRaRqLO4iJC3zqcfkNn/2E
wpASDDEDALXhjq4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 800->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmJFiNy51pNhNSRwREw/40iyxaRrdHcTEBT71uPyGz35C
YUgJhpgBAMWhjq4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 801->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmJFiNy51pNhNShyRagahNEtsmibVHYTUY1ODy93YxMkJ
a8LxAADKk49t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 802->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf3aSEGSl241KHzT/EpCV87iDHDEJpltg0Tao7CKnHpgaXu7GJExO2
pGCIGQCUl45v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 803->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf3aSEGQogMawx3IWEiUlL+NyByz/4zCCUZolN0+juIiYu8KnHpgaX
u7GJ40qn5GKIGQCmBYyu
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 804->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLwwGaGC4zsMnjMheb3chm4HITupn4/IXPf9j043IHPrcTEsNmLy7/
Y3MPMfGELy7w2U1KmKEAEsMaa9jZ4zYHXxhicxepZhBKs8SmaVLdQUg9NjW4
3I1NHFdYk4shZgAAK3WN7Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 805->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf3aSEGQafhLDGGnZImFBawusOHP7BZwahNEtsmibVHYTUY1ODy93Y
xHGFNbkYYgYAYRSNLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 806->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM8Dk0NTiMgObPFZzGbDbjWwGLjehm4nPX/j8h00/LnfgczshMWz2
4vI/NvcQE0/44gKf3aSEGQafhLDGlXZwuQVfGGJzF6lmEEqzxKZpUt1BSD02
NbjcjU2cmLAlBUPMAACYJI5t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 807->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLg4E9BCOL4TIDmzzMDGxq0e1GNgOXm9D9gs9f+PyHTT8ud+BzOyEx
bPbi8j829xATT/jiAp/dpIQZNj4paQmXf4hJS+S6A19Y4EuzRKVpMtxBSD02
NbjcjU2cmLAlBUPMAAAKY45t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 808->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM8Dk0NTiMgObPLp+dDXoAJcYLr/g8xc+/2HTj8sd+NxOSAybvbj8
j809xMQTvrjAahcJ6QVb2DDYIzCxaQmXf4hJS7jcQa4ZhNIsUWmaDHcQUo9N
DS53YxMnJmxJwRAzAIKJjSw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 809->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM8Dk0NTiMgNdngEJY1OLbjeyGSgAj1/w+Quf/7Dpx+UOfG4nJIbN
Xmx8XO4hJp7wxQU+u0kJMww+CWGNK+3gcgu+MMTmLlLNwBd/xMijA2LNIKQe
mxpc7sYmTkzYkoIhZgAAzgiN6w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 810->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eTDAoRbdDmQzcLkJ3S/4/EWMP3DZi8tsXGbgEsNmLy7/
Y3MPMfGELy7w2U1KmGHjk5KWcPmHmLRErjvwhQW+NEtUmibDHYTUY1ODy93Y
xIkJW1IwxAwAEsON7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 811->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eTDAoRbdDmQzcLkJ3S/4/EWMP3DZi8tsXGbgEsNmLy7/
Y3MPMfGELy6w2kVCesEZNiSENdawQ8KE0hJed+AIC3xmEEqzRKVpMtxBSD02
NbjcjU0cV1iTiyFmAAA1l4zt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 812->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY2eVzmYrMD2QxcbkI3E5+/iPEHLnuJdTshMWz24vI/NvcQ
E0/44gKf3aSEGQafhLDGlXYIqcMVJvjCiNh4wJdmiU3TpLqDkHpsanC5G5s4
vrAmB0PMAABn2o0w
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 813->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM8AwA6paXGZgk8dqLgN2u5HNwOUmdDPx+Quf/7Dpx+UOfG4nJIbN
Xlz+x+YeYuIJX1zgs5uUMMNmNwMJaQmnf4hIS/jcQY4ZhNIssWka3R3ExAU+
9Vj9hsPd2MTxhTU5GGIGABsRjW0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 814->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY2eWzmopuHbj82MVxm4vMXPv9h04/LHfjcTkgMm724/I/N
PcTGE664wGU3A5HpBWfYIGFS0hIxaRLd/3jdwYDdL/jMIJRmiU3T6O4gJi7w
qcfqNxzuxiaOL6zJwRAzAMAGi+8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 815->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PAMMM2BXi243shnEugmfv/D5D5t+XO7A53ZCYtjsxeV/
bO4hNp5wxQU+u0kJMww+TIzEtERMmkT3P1534PAPPjPwxR8x8uiAWDMIqcem
Bpe7sYnjC2tyMMQMABY5jG8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 816->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PAMMM2BXi243shkoAI+b8PkLn/+w6cflDnxuJySGzV5s
fFzuITaecMUFPrtJCTNsdoMBiWmJmDSJ7n987sDlH3xm4Is/YuTRAbFmEFKP
TQ0ud2MTxxfW5GCIGQBMKoxv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 817->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PAMOe9HNQ7cfmxguN+HzFz7/YdOPyx343E5IDJu9uPyP
zT3ExhOuuMBnNylhhpUPjWNS0hIxaRLd/4TcQUx6xGYXqWYQSrPExAU+9djU
4HI3NnF8YU0OhpgBACivjDA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 818->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM2DRh88MdHkGJDOwqUW3G9kMFIDHL/j8hc9/2PTjcgc+txMSw2Yv
Nj4u9xATT/jiAp/dpIQZBh+KiU1LWP2DxwxS4oiY9IjNTaSaQSjNEhMX+NRj
U4PL3djE8YU1ORhiBgCKsIys
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 819->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM2DRh88MdHkGJDOwqUW3G9kMFIDHL/j8hc9/2PTjcgc+txMSw2Yv
Nj4u9xATT/jiAp/dpIQZBh+KiU1LOP1DRFrC6w4c/sFnBr74I0YeHRBrBiH1
2NTgcjc2cXxhTQ6GmAEAIxWMbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 820->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM2DRh88MdHkGJDOwqUW3G9kMFIDHL/j8hc9/2PTjcgc+txMSw2Yv
Nj4u9xATT/jiAp/dpIQZBh+KiU1LOP1DRFrC6w4c/sFnBr74I0YeHRBrBiH1
2NTgcjc2cXxhTQ6GmAEAIxWMbQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 821->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM2DRh88MdHkGJDOwqUW3G9kMFIDHL/j8hc9/2PTjcgc+txMSw2Yv
Nj4u9xATT/jiAp/dpIQZBp+EsMaVdsCAiLSE1x04/IPPDHzxR4w8OiDWDELq
sanB5W5s4vjCmhwMMQMAFiSM7Q==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 822->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PAMOe9HNQ7cfmxguN+HzFz7/YdOPyx343E5IDJu9uPyP
zT3ExhOuuMBnNylhho1PTlrCxycmDElxB76wwBV/xMijA2LNIKQemxpc7sYm
TkzYkoIhZgAARHuN7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 823->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PC5zcalBNoNYN+HzFz53YNOPyx343E5IDJu9uPyPzT3E
xhOuuMBnNylhhsEnIaxxpR1cbsEXhtjcRaoZ+OKPGHl0QKwZhNRjU4PL3djE
iQlbUjDEDADPSI3v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 824->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PAMOe9HNQ7cfDqBm4HMTPn/hcwc2/bjcgc/thMSw2YvL
/9jcQ2w84YoLfHYTk15whg2R+nCFHSlpCa87yDADX/wRI48OiDWDkHpsanC5
G5s4MWFLCoaYAQBDfI7r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 825->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PC5zcalBNoNYN+HzFz53YNOPyx343E5IDJu9uPyPzT3E
xhOuuMBnNylhRorduNRh8w8xaQmfO8gxA1/8ESOPDog1g5B6bGpwuRubODFh
SwqGmAEAxFeObw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 826->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PAMOe9HNQ7cfDqBm4HMTPn/hcwc2/bjcgc/thMSw2YvL
/9jcQ2w84YoLfHYTk15whQ2x+nCFHSlpCZ87yDEDX/wRI48OiDWDkHpsanC5
G5s4MWFLCoaYAQA4i49r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 827->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwa6PC5zcalBNoMY9xLyFz53YNOPyx343E5IDJu9uPyPzT3E
xhOuuMBnNylhhsEnIayxhh0SJpSW8LoDh3/wmYEv/oiRRwfEmkFIPTY1uNyN
TRxXWJOLIWYAAC7Aje0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 828->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwYKjcdcdPPQ1cEB1Bx8bsLnL3zuwKYflzvwuZ2QGDZ7cfkf
m3uIjSdccYHPbmLSC86wIVIfzrBDwgTTEj534PAPPjPwxR8x8uiAWDMIqcem
Bpe7sYnjCmtyMcQMAMUwjKw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 829->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1cGBPQTjcxM+fzVA9WNzBzb9uNyBz+2ExLDZ
i8v/2NxDbDzhigt8dhOTXnCFDbH6cIUdOWkJl7tINQNf/BEjjw6INYOQemxq
cLkbmzgxYUsKhpgBAAo8ja4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 830->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1aEAAn7B5y98/sOmH5c78LmdkBg2e3H5H5t7
iI0nXHGBz25SwowUu3Gpw+ofEtISLneRkh7xqSFkBqE0S0xc4FOPTQ0ud2MT
xxfW5GCIGQD8co1v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 831->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1aEAAn7B5y+wPA7/YdOPyx3Y/EesGDZ7sfHx
2UlMPOGKC3x2E5NecIUNsfpwxTs5aQmXu0g1A1/8ESOPDog1g5B6bGpwuRub
ODFhSwqGmAEA8/6MsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 832->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkDy+MwD5t+XO6AmYPN7YTEsNmL
y//Y3ENsPOGKC3x2E5NecIUNsfpwxTs5aQmXu0g1A1/8ESOPDog1g5B6bGpw
uRubODFhSwqGmAEAcHKNbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 833->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1YGBPQQT8gs+fzVAzcDmDmz6sbqDAWEONrcT
EsNmLy7/Y3MPsfGEKy7w2U1MesEXNuSkJYx4ISEtkeoOfGGBK/6IkUcHxJpB
SD02NbjcjU0cV1iTiyFmAAAZfowu
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 834->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1YEBAbvQ7cHpbxz+w6YfqzsYEOZgczshMWz2
4vI/NvcQG0+44gKfXcSkF3SzkMODgQh9OOOdjLSEy12kmoEv/oiRRwfEmkFI
PTY1uNyNTRxXWJOLIWYAAPHai28=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 835->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkDy+MwD5t+XO6AmYPN7YTEsNmL
y//Y3IPLL4TiGqddSH4hJr0QEzakpCV8fGLCEJs7SDUDX/wRI48OiDWDkHps
anC5G5s4MWFLCoaYAQCmbYvv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 836->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+nG6wx6CsbmdkBiKeTjC
E5d/0P2FTT+huMCwy54BxT/EhhlWPhZz0NXhindkM4hNS7jcQUp6xKeGkBmE
0iwxcYFPPTY1uNyNTRxfWJODIWYAAA2bii4=
                    "], {{0, 17}, {17, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 837->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+nG6A4v/sPkZXzjgC09c
/kH3FwMJ/sVrFwnpBW/YkJGWiEmT6P4n5A5S0iM+NYTMIJRmiYkLfOqxqcHl
bmzi+MKaHAwxAwDCtYrx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 838->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+vG5A91/2PyMLxzwhScu
/6D7i4EE/+K1i4T0gi0sYG4hJy1hiJGQlnC5i5T0iE8NITMIpVli4gKfemxq
cLkbmzihsCYVQ8wAABMwjG8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 839->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+jHcgYwZsLudkBg2e3H5
H5t7SIlHfH4jJlzxhRm2sCEnLaHwcZiDLwxRgD2CJsUMfPFHjDw6INYMQuqx
qcHlbmzi+MKaHAwxAwDH2ovt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 840->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+jHcAcNoanD5GWc4EAhP
XP7B5i9i/UuMXaSEGbawISctofBxmIM1DLG4Ax43JJqBL/6IkUcHxJpBSD02
NbjcjU0cX1iTgyFmAAC4Govt
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 841->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A5saXH7GGw54whOX
f1DUERGP+PxGTLjiCzMMPglhjSvtMOAwB1cYYqQXewRNihn44o8YeXRArBmE
1GNTg8vd2MTxhTU5GGIGADQ+iu8=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 842->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qbcLqbgP+w6UcB9kgYTQ0uP+MNBzzh
ics/KOqIiEd8fiMmXPGlCWL14lOHVYyEtEQovIg1A1/8ESOPDog1g5B6XH7D
Zz+hNEAJhpgBAGx4iu8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 843->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A5saXH7GGw54whOX
f1DUERGP+PxGTLjiCzNi9eJTR6oYrjDBFV7EmoEv/oiRRwfEmkFIPS6/4bOf
UBqgBEPMAADyy4vx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 844->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qbcLqbgP+w6cfmDmxqcPkZbzjgCU9c
/sHqLxz+xRUX+OwiJr1g+APZPDLSEnocMWAxB1cYEgovYs3AF3/EyKMDYs0g
pB6X3/DZTygNUIIhZgAAXEyKsA==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 845->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A5saXH7GGw54whOX
f7D5i1j/EmMXKWFGrF586kgVwxUmuMKLWDPwxR8x8uiAWDMIqcflN3z2E0oD
lGCIGQAv6Yxx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 846->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qbcLqbgP+w6cdwBwyjqcHlZ0LhgCs8
cclj9RcO/+KKC3x2EZNecPkDPYyJTUv44olQGBITnsSYgS/+iJFHB8SaQUg9
Lr/hs59QGqAEQ8wAAJAAizA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 847->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A5saXH4mFA64whOX
PDZ/EetfYuwiJcyI1YtPHaliuMIEV3gRawa++CNGHh0QawYh9bj8hs9+QmmA
EgwxAwCEU4wy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 848->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qbcLqbgP+w6cfmDmxqcPmZUDjgCk9c
8lj9hcO/uOICn13EpBdc/kAPY2LTErZ4QjcHVxgSE57EmIEv/oiRRwfEmkFI
PS6/4bOfUBqgBEPMAACDxYrx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 849->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A5saXH4mFA64whOX
PDZ/EetfYuwiJcyw6WUgIy2h8JEwMWmJmPAkxgx88UeMPDog1gxC6nH5DZ/9
hNIAJRhiBgBV1Irx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 850->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qbcLqbgP+w6cfmDmxqcPmZUDjgCk9c
8lj9hcO/uOICn13EpBdc/kAPY2LTEnoc4VOHK0xwhRexZuCLP2Lk0QGxZhBS
j8tv+OwnlAYowRAzABkmirI=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 851->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A5saXH4mFA64whOX
PDZ/EetfYuwiJcyw6WUgIy1hiGExB1cYEhOexJiBL/6IkUcHxJpBSD0uv+Gz
n1AaoARDzAAAKOOLcQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 852->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A5saXH4mFA64whOX
PDZ/EetfYuwiJcyw6WUgIy2h8PH4kZQ4ItUMfPFHjDw6INYMQupx+Q2f/YTS
ACUYYgYAvjWLMg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 853->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qbcLqbgP+w6cdwBw77cPmZUDjgCk9c
8lj9hcO/uOICn13EpBdc/iBWH654J0YMV5jgCi9izcAXf8TIowNizSCkHpff
8NlPKA1QgiFmAACdf4vx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 854->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A5saXH4mFA64whOX
PDZ/EetfYuwiJcyI1YtPHboYAxpNKAyJCU9izMAXf8TIowNizSCkHpff8NlP
KA1QgiFmAAAZ8ovx
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 855->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+lGAPRRjcRsuPxMKB1zh
iUsem7+I9S8xdpESZrj0MpCYljDEcJhBTByh8EkwA1/8ESOPDog1g5B6nH7D
Yz+hNEAJhpgBAHijifE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 856->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+rG5A0xDMTa3ExKDAzzh
ics/2PxFrH+JsYuUMCNWLz51WMWQwpZQGOJ1Fwlm4Is/YuTRAbFmEFKP0294
7CeUBijBEDMAkhKMLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 857->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+jHcAcNoanD5GV844AtP
XP7B5i9i/UuMXaSEGbF68anDKgbFxKQlvO4iwQx88UeMPDog1gxC6nH6DY/9
hNIAJRhiBgC0tIvv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 858->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+jHcAcNoanD5GWc4EAhP
XP7B5i9i/UuMXaSEGbF68anD6R8i0xJed5FgBr74I0YeHRBrBiH1OP2Gx35C
aYASDDEDAPqYi+8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 859->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+jHcgYwZsLudkBgYEAhP
XP7B5i9i/UuMXaSEGbF68akj1j9YwxCHOwjZhU8duhpCZhBKs8TEBT71uPyG
z35CaYASDDEDAP5HjG8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 860->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+vG5A91/2PyMLxzwhScu
/2DzF7H+JcYuUsIMl14GEtMSVnvQzMEXhjjdRWR6xKeGUJomlGaJiQt86nH6
DY/9hNIAJRhiBgAUbooy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 861->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+jHcgYwZsLudkBg2e3H5
H5t7SIlHfH4jJlzxhRmxevGpI9Y/+MIQX3gRawa++CNGHh0QawYh9bj8hs9+
QmmAEgwxAwBRxIww
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 862->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+nG5A5v/iBXDZi8u/+Oy
k9h4xOc3YsIVX5jh0stAYlrCaQ8RaQmvu4hMj/jUEErThNIsMXGBTz1Ov+Gx
n1AaoARDzAAA6h2Ksg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 863->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+nG5A8zG4XZCYuhmYHMH
Tjux+ItY/+KKO2L043MXMXbjUkesf9D9j88duOzDZwa++CNGHh0QawYh9aT4
DZs4obAmFUPMAACzjIsy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 864->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1aEAAn7B5y+wPAzj8Acue1H4aObg8jO+cGjA
4w5c/sHmL0L+xWU3oXgmlCaI1YtPHbH+Qfc/Pnfgsg+fGfjijxh5dECsGYTU
k+I3bOKEwppUDDEDACNEiXE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 865->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkDy8MwDn/gs5cYtxMSw2YvLv9j
cw8p8YjPb8SEK740QaxefOqI9Q++MCTWXfjMwBd/xMijA2LNIKSeFL9hEycU
1qRiiBkAtq2L8Q==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 866->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD5z9s+nG5A5/bCYlhsxeX/7G5
h5R4xOc3YsIVX5gRqxefOqxiWMTxhSGx7sJnBr74I0YeHRBrBiH1pPgNmzih
sCYVQ8wAAPJYjHE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 867->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkDy+MwD5t+XO7A53ZCYtjsxeV/
bO4hJR7x+Y2YcMWXJojVi08dsf7BF4bEugufGfjijxh5dECsGYTUk+I3bOKE
wppUDDEDAOqbi7I=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 868->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkDy8MwDn/gs5cYtxMSw2YvLv9j
cw8p8YjPb8SEK740QaxefOqwimERxxeGGO4iwwx88UeMPDog1gxC6rGpweVu
bOKEwppUDDEDAModjK4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 869->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1aEAAn7B5y+wPAzj8Acue3GZjcsMQuGALzxx
2YnNX4T8S4zdhPTjcxcxduNSh1UMizi+MMTqLhLNwBd/xMijA2LNIKQeq99w
uBubOKGwJhVDzAAAsiCL7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 870->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79Q9GCxF5dZuMzGZwahcMAXnrjs
xOYvYvxLyG5C+vG5ixi7canDKoZFHF8YEusufGbgiz9i5NEBsWYQUk+K37CJ
EwprUjHEDADuYoxv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 871->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn7/g6mEYiz/w2ovudzxmEAoHfOGJ
y05s/iLKvwTsJqQfn7uIsRuXOmL9gy8MiXUXPjPwxR8x8uiAWDMIqSfFb9jE
CYU1qRhiBgDopYuw
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 872->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn7/g6mEYiz/w2ovudzxmEAoHfOGJ
y05s/iLKvwTsJqQfn7uIsRuXOqxiWMTxhSGGu5AwsWbgiz9i5NEBsWYQUo9N
DS53YxMnFNakYogZAFELjKw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 873->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHwoRibm/D5C8VONHOw6cflDhQzsIQFPjEM
M3DwcbmHlHjE5gZ8dhGTXnCFDbH6cMU7Pv/gC0MMd2GJF2LiAVf8ESOPDog1
g5B6bGpwuRubOKGwJhVDzAAAqHKL7Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 874->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHwoRibm/D5C8VOPO7FaS8Rbickhm4GLj4u
95ASj/j8RiieCaUJYvXiU0esf/CFIbHuwmcGvvgjRh4dEGsGIfWk+A2bOKGw
JhVDzAAAquyM7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 875->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn78w3IjDvTjtxeJ3BiRz0P2MLxzw
hScuO7H5ixj/ErKbmPDC5S5i7MalDqsYFnF8YYjVXTjSCL6wwBV/xMijA2LN
IKQeq99wuBubOKGwJhVDzAAAiFmNLA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 876->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD0IfDvbjsxeZ3bGGBT4wYM3DZ
ic1fxPiXkN2E9ONzFzF241JHrH/whSFWd5GQHvGpIWQGoTRLTFzgU4/Vbzjc
jU2cUFiTiiFmAABLmI4u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 877->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCdGjBm47MTm
L2L8S8huYsILl7vQ9TKQmJaI8Q+6//G5g5Bd+NShqyFkBqE0S0xc4FOPy2/4
7CeUBijBEDMAn7WN7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 878->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCeGYh4SxhX2
6GwUN2PRT6zfiAlXfGmCWL341OESw/AnvjDEE17EmoEv/oiRRwfEmkFIPS6/
4bOfUBqgBEPMAAB/iI5r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 879->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCdGyF/47MTm
L2L8Ssj9xJpByO3kpCVi0iUpYUjILnzq0NUQMoNQmiUmLvCpx+U3fPYTSgOU
YIgZAFsMjm8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 880->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCeGYZ49BOMK
e3Q2LneT6jdiwhVfmsCll4GAPkJuxxUm5MYRMWbgiz9i5NEBsWYQUo/Lb/js
J5QGKMEQMwBU0Y4s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 881->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCdGyF/47MTm
L2L8Ssj9xJpByO1gcRLTElZ70MwhJQzhgMj0iE8NoTRNKM0SExf41OP0Gx77
CaUBSjDEDABVkY0u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 882->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNgMWt2PzD07zkTCu
sEdn43I3qX4jJlzxpQli9eJTh0sMXRxvGOIJL2LNwBd/xMijA2LNIKQel9/w
2U8oDVCCIWYAABIxj2s=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 883->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNgMWt2PzD07zkTCu
sEdn43I3qX4jJlzxpQlcehkI6CPkdjDAEiakxhE2d+ALC1zxR4w8OiDWDELq
cfoNj/2E0gAlGGIGAAy2jio=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 884->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNgMWt2PzD07zcZiB
y05s/iLGrzjdz4ApRii94Aob5DAhJS3htIeItERMHBFjBr74I0YeHRBrBiH1
uPyGz35CaYASDDEDAKtxjiw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 885->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNgMWt2PzD07zkTCu
sEdn43I3qX4jJlzxpQli9eJTh0sMDIhIS8TEETFm4Is/YuTRAbFmEFKPy2/4
7CeUBijBEDMARSKO6w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 886->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCeG1Xw8YY/O
xuVuUv1GTLjiSxPE6sWnDpcYujhRYYjDj8SYgS/+iJFHB8SaQUg9Lr/hs59Q
GqAEQ8wAAAOujq4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 887->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNgMWt2PzD07zkTCu
sEdn43I3qX4jJlzxpQli9eJTh08MPUxIjSMGXObiCAtc8UeMPDog1gxC6nH6
DY/9hNIAJRhiBgDMxY8q
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 888->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNgMWt2PzD7HmE7IT
m7+I8StO92Oxn1B6wed2ctISCh8JE5OW8LqLBDPwxR8x8uiAWDMIqcfpNzz2
E0oDlGCIGQBhmY4s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 889->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNgMWt2PzD07zcZiB
y05s/iLGrzjdz4ApRii94AobYvURcjssTIhJS6S4C58Z+OKPGHl0QKwZhNST
4jds4qSmE+LSEQAz6o7r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 890->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCeGYZ49BOMK
e3Q2LneT6jdiwhVfmiBWLz51WMXQwoOoMCTCXfjMwBd/xMijA2LNIKSeFL9h
Eyc1nRCXjgB3mI6s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 891->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCeGYh4SxhX2
6Gxc7ibVb8SEK740QaxefOqwimERxxuGRLoLnxn44o8YeXRArBmE1JPiN2zi
pKYT4tIRALyAjqw=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 892->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNq6wwCdGyF/47MTm
L2L8Ssj9xJpByO3kpCUMMSzipIQhAxlm4Is/YuTRAbFmEFKPTQ0ud2MTJzWd
EJeOAGyGjm0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 893->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMJlNgMWt2PzD07z7VFp
QnZi8xcxfsXpfgZMMULpBVfYEKuPkNuxqcUbhkS6C58Z+OKPGHl0QKwZhNST
4jds4qSmE+LSEQBpSo8s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 894->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KlD0YPHvbjsRWHDMJawwCeG1Qw8
YY/OxhXOhOIaV9wRHV443EVILz51WMWwiOMNQyLdhc8MfPFHjDw6INYMQupJ
8Rs2cVLTCXHpCABcrY3r
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 895->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KlD0QPF2NyLy14UNoyPZA66n/GF
QwMW/QTtxOIvovyKI2zQ7SImveAKG2L1EXI7NrUEw5AId+EzA5caQmmaUJol
Ji7wqSfFb9jESU0nxKUjADhLjG0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 896->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnD0IPDvbjsJWQPup/xhQOyG9Dd
gc9OXOFMyK+44o6k8MITNsTqI+R2BiziBMMQmY+EiTUDX/wRI48OiDWDkHps
anC5G5s4qemEuHQEAApyjes=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 897->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnDZSc2d2Kzl5A96H7GFw5wtj0E
4wp7dDYhfxCKC3S3kRJe+MKGWH3EuJ1QuOJzBwORcYNLDSw+GPC4C6s+LOFD
TFzgU49NDU53YxEnNZ0Ql44A88uNrA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 898->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79Q9KCZg00/Lnfgsgfdz/jCAUUM
T9hjU48r7PDFNa64Izq8cLgLIwxITEuE4oWYMEThExk3uNQw4HADrvjFl2aJ
iQt86rGpweluLOKkphPi0hEAYVeMqg==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 899->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79Q9OBxL057CdiD7md84YAr7AjZ
iSucCcU1rrgjOrxwuIuQXnzqsIoRiBuCcURk3BBSg8+92PRhCx9i4gKfemxq
cLkbl5tJSSfEpSMASkmOLA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 900->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHj43ITPn/hshObO3HZi88ebO7DFQ64wo6Q
nYT8QSgu0N1GSnjhCxti9RHjdkLhSsgd2OzDZwahcMIXv/jSLDFxgU89NjW4
3I3LzaSkE+LSEQC/zY5v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 901->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6zWAPxQzY1aLbjaIXjY/LTfj8hctODHfisRefPdjchzUc
cPiDGDsJ+YNQXKC7jZTwwhc2xOoj5HZYGiGYlvC4A5t9+MwgFE744hdfmiUm
LvCpx6YGl7txuZmUdEJcOgIALoiOrA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 902->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6zWCPwNjUotuNoheZj8dN+PyFy04Md+Kyl4A96H7GGQ5Y
1OEKe2LUE+tXdDej20VMesEVNsTqI8bthMKVkDuw2YfPDELhhC9+8aVZYuIC
n3psanC5G5ebSUknxKUjAGFJj2s=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 903->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6zYDDXnTz0O3HxsflJnz+wmUnhjvx2IvPHmzuwxoOOPxB
jJ2E/EEoLtDdRkp44QsbuDoS0xJWu4hJS3jcgdVdeMwgFE744hdfmiUmLvCp
x6YGl7txuZmUdEJcOgIAIfqObQ==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 904->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHj43ITPn/hshObO3HZi88ebO7DFQ64wo6Q
nYT8QSgu0N1GSnjhCxu4OhLTEoYYTA8RaQmX+VjdhccMQuGEL37xpVli4gKf
emxqcLkbl5tJSSfEpSMAMK+M7w==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 905->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6zWAPwbjUotuNoheNj8tN+PyFy04Md+KxF5892NyHNRxw
+IMYOwn5g1BcoLuNlPDCFzbE6iPG7YTClZA7sNmHzwxC4YQvfvGlWWLiAp96
bGpwuRuXm0lJJ8SlIwBklY+s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 906->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jc9MbHbj0otuBja1xPgfl3vx2YvPHmzuwxUOuMKOkJ2E
/EEoLtDdRkp44QsbuDoS0xJOu4hIS7jMx+ouPGYQCid88YsvzRITF/jUY1OD
y9243ExKOiEuHQEAzF+OLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 907->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSp
mAGZzYDbHGSASw6Zj8sMdBoOcKjFUIdFLzY7saklGBZYzMBlFj45fH7GFw64
wo6QnYT8QSgu0N1GSnjhCxti9RHjdkLhSsgd2OzDZwahcMIXv/jSLDFxgU89
NjW43I3LzaSkE+LSEQCIQY4u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 908->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jc9MbHbj0otuBja1xPgfl3vx2YvPHmzuwxUOuMKOkJ2E
/EEoLtDdRkp44QsbYvUR43YwICIt4TIfm334zCAUTvjiF1+aJSYu8KnHpgaX
u3G5mZR0Qlw6AgC9bo6u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 909->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSp
mAGZzYDbHGSASw6Zj8sMdBoOcKjFUIdFLzY7saklGBZYzMBlFj45fH7GFw64
wo6QnYT8QSgu0N1GSnjhCxtsaYyYtIQtjTKgmUMoDHH5i5j0SEw44YtffGmW
mLjApx6bGlzuxuVmUtIJcekIAF7GjO0=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 910->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6DQc41GKow6IXm53Y1BLjf1zuxWcvPnuwuQ9XOOAKO0J2
EvIHobhAdxsp4YUvbODqSExLGGJImNgwxOUvYtIjMeGEL37xpVli4gKfemxq
cLkbl5tJSSfEpSMAgeSNbQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 911->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSp
mAGZzYDbHGSArp8BzX58ZqDTcIBDLYY6LHqx2YlNLcGwwGIGLrPwyeHzM75w
wBV2hOwk5A9CcYHuNlLCC1/YYEtjhOzAZS+hcCXkDqzuwmMGoXDCF7/40iwx
cYFPPTY1uNyNy82kpBPi0hEAkGKNbQ==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 912->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSp
mAGZzYDbHGSASw6Zj8sMdBqXuejmoavDxsflJnz+wmUnNnfishefPdjchysc
cIUdITsJ+YNQXKC7jZTwwhc2+MIVlx1YxZAwsWGIy1/EpEdiwglf/OJLs8TE
BT712NTgcjcuN5OSTohLRwD8xoxv
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 913->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHj43ITPn/hshObO3HZi88ebO7DFQ64wo6Q
nYT8QSgu0N2GYj4R6QVX2MD0o5uBTR0xaYcBh/sJxRGxcUNIDT73YtOHLXyI
iQt86rGpweVuXG4mJZ0Ql44A+5GMbw==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 914->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79w2YnNnVjtJWAPup/xhQOusCNk
JyF/EIoLdLehmE9EesEVNnB1JKYlYtImoTDE5S9i0iMx4YQvfvGlWWLiAp96
bGpwuRuXm0lJJ8SlIwBly4zv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 915->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79Q9KCZg00/Lnfgsgfdz/jCAVfY
EbITVzgTimtccUd0eOFwF0YYkJiWcNpFRFrCZT5Wd+Exg1A44YtffGmWmLjA
px6bGlzuxuVmUtIJcekIAA2IjW0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 916->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn7/g6pEwNvfitJeAPeh+xhcOuMKO
kJ24wplQXOOKO2LCC5+7COnFpw6XXjAgIi3hMh+bffjMIBRO+OIXX5olJi7w
qcemBpe7cbmZlHRCXDoCAF95jW0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 917->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnDZSc2d2Kzl5A96H7GFw64wo6Q
nYT8QSgu0N1GSnjhCxti9RHjdjAgIi3hMh+bffjMIBRO+OIXX5olJi7wqcem
Bpe7cbmZlHRCXDoCAI2ujq4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 918->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KkjFB64zMInh8/P+MIBV9gRshOX
u0n1GzHhSoy7COnFpw6XXjAgIi3hMh+bffjMIBRO+OIXX5olJi7wqcemBpe7
cbmZlHRCXDoCAPXTj20=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 919->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn7/g6pEwNvfitJeAPeh+xhcOuMKO
kJ24wplQXOOKO2LCC5+7COnFpw6XXjAgIi3hMh+bffjMIBRO+OIXX5olJi7w
qcemBpe7cbmZlHRCXDoCAF95jW0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 920->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KlD0YPHvbjsJWQPup/xhQOusCNk
J65wJhTXuOKO6PDC4S5CevGpw6UXDIhIS7jMx2YfPjMIhRO++MWXZomJC3zq
sanB5W5cbiYlnRCXjgBYxI7t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 921->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KmDq0fC2NyLy15C9qD7GV844Ao7
QnbiCmdCcY0r7ogJL3zuIqQXnzpcerG5k9g4IjZuCKnB515s+rCFDzFxgU89
NjW43I3LzaSkE+LSEQC54Y2u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 922->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnDZSc2d2Kzl5A96H7GFw64wo6Q
nYT8QSgu0N1GSnjhCxti9RHjdmzuJDaOiI0bQmrwuRebPmzhQ0xc4FOPTQ0u
d+NyMynphLh0BAApB45v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 923->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79Q9KCZg00/Lnfgsgfdz/jCAVfY
EbITVzgTimtccUd0eOFwFyG9+NTh0ovNncTGEbFxQ0gNPvdi04ctfIiJC3zq
sanB5W5cbiYlnRCXjgCZ4Y2u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 924->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79w2YnNnVjtJWAPup/xhQOusCNk
JyF/EIoLdLeREl74woZYfcS4HQyISEu4zMdmHz4zCIUTvvjFl2aJiQt86rGp
weVuXG4mJZ0Ql44AzpCOLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 925->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79Q9KCZg00/Lnfgsgfdz/jCAVfY
EbITVzgTimtccUd0eOFwFyG9+NTh0ovNncTGEbFxQ0gNPvdi04ctfIiJC3zq
sanB5W5cbiYlnRCXjgCZ4Y2u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 926->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1eFzD7qb8KnDZSc2d2Kzl5A96H7GFw64wo6Q
nYT8QSgu0N1GSnjhCxti9RHjdmzuJDaOiI0bQmrwuRebPmzhQ0xc4FOPTQ0u
d+NyMynphLh0BAApB45v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 927->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79Q9KCZg00/Lnfgsgfdz/jCAVfY
EbITVzgTimtccUd0eOFwFyG9+NTh0gsGRKQlXOZjsw+fGYTCCV/84kuzxMQF
PvXY1OByNy43k5JOiEtHAP6Ije0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 928->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jctcdPPQ1WHw8bgJn79w2YnNnVjtJWAPup/xhQOusCNk
JyF/EIoLdLeREl74woZYfcS4HQyISEu4zMdmHz4zCIUTvvjFl2aJiQt86rGp
weVuXG4mJZ0Ql44AzpCOLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 929->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6zWCPwNjUotuNoheNj8tN+PyFy04Md+KxF5892NyHNRxw
+IMYOwn5g1BcoLuNlPDCFzbE6iPG7WBAKC3hcQc2+/CZQSic8MUvvjRLTFzg
U49NDS5343IzKemEuHQEALhojqw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 930->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM2DRh88MdJoBicamFt1uFL1ofFx+wecvXHZiuBOPvfjsweY+rOGA
wx/E2EnIH4TiAt1tpIQXvrAhVh8xbsfmTmLjiNi4IaQGn3ux6cMWPsTEBT71
2NTgcjcuN5OSTohLRwBkFY2u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 931->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jc9MbHbj0otuBja1xPgfl3vx2YvPHmzuwxUOuMKOkJ2E
/EEoLtDdRkp44QsbYvUR43Zs7iQ2joiNG0Jq8LkXmz5s4UNMXOBTj00NLnfj
cjMp6YS4dAQAWMeObw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 932->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jc9MbHbj0otuBja1xPgfl3vx2YvPHmzuwxUOuMKOkJ2E
/EEoLtDdRkp44QsbYvUR43YwICIt4TIfm334zCAUTvjiF1+aJSYu8KnHpgaX
u3G5mZR0Qlw6AgC9bo6u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 933->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM2DRh88MdBqXnejmoavFxsflF3z+wmUnNnfishefPdjchysccIUd
ITsJ+YNQXKC7jZTwwhc2xOojxu3Y3ElsHBEbN4TU4HMvNn3YwoeYuMCnHpsa
XO7G5WZS0glx6QgAVamN7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 934->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSp
mAGZzYDbHGSArp8BzX58ZqDTuOxENw9dLTY+NvcS8hcuO7G5E5e9+OzB5j5c
4YAr7AjZScgfhOIC3W2khBe+sCFWHzFuBwMi0hIu87HZh88MQuGEL37xpVli
4gKfemxqcLkbl5tJSSfEpSMAk4CN7Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 935->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTRxfHZwY6jc9MbHbj0otuBja1xPgfl3vx2YvPHmzuwxUOuMKOkJ2E
/EEoLtDdRkp44QsbYvUR43YwICIt4TIfm334zCAUTvjiF1+aJSYu8KnHpgaX
u3G5mZR0Qlw6AgC9bo6u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 936->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM2DRh88MdBoOcKjFUIdFLzY7saklxv+43IvPXnz2YHMfrnDAFXaE
7CTkD0Jxge42UsILX9gQq48Yt2NzJ7FxRGzcEFKDz73Y9GELH2LiAp96bGpw
uRuXm0lJJ8SlIwB2i41v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 937->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSp
mAGZzYDbHGSArp8BzX58ZqDTuOxENw9dLTY+NvcS8hcuO7G5E5e9+OzB5j5c
4YAr7AjZScgfhOIC3W2khBe+sCFWHzFuBwMi0hIu87HZh88MQuGEL37xpVli
4gKfemxqcLkbl5tJSSfEpSMAk4CN7Q==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 938->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSp
mAGZzYDbHGSArp8BzX58ZqDTcIBDLYY6LHqx2YlNLcGwwGIGLrPwyeHzM75w
wBV2hOwk5A9CcYHuNlLCC1/YEKuPGLdjcyexcURs3BBSg8+92PRhCx9i4gKf
emxqcLkbl5tJSSfEpSMAT7uNLg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 939->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DSp
mAGZzYDbHGSArp8BzX58ZqDTcIBDLYY6LHqx2YlNLcGwwGIGLrPwyeHzM75w
wBV2hOwk5A9CcYHuNlLCC1/YEKuPGLeDARFpCZf52OzDZwahcMIXv/jSLDFx
gU89NjW43I3LzaSkE+LSEQC0Yo1t
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 940->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTZ0CzH58Z6DROMxmw241LL7oZ2NQS439c7sVnLz57sLkPVzjgCjtC
dhLyB6G4QHcbKeGFL2yI1UeM28GAiLSEy3xs9uEzg1A44YtffGmWmLjApx6b
GlzuxuVmUtIJcekIALm8ju0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 941->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyeGTx8bGpgaZxmUmunnoarHxcfkFn7tx2YnNnbjsxWcPNvfhCgdcYUfI
TkL+IBQX6G4jJbzwhQ2x+ohxOzZ3EhtHxMYNITX43ItNH7bwISYu8KnHpgaX
u3G5mZR0Qlw6AgBWM48u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 942->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTZ0CzH58Z6DROMxmw241LL7oZ2NQS439c7sVnLz57sLkPVzjgCjtC
dhLyB6G4QHcbKeGFL2yI1UeM2wmFKyF3YLMPnxmEwglf/OJLs8TEBT712NTg
cjcuN5OSTohLRwCGy49t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 943->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTZ0CzH58Z6DROMxmw241LL7oZ2NQS439c7sVnLz57sLkPVzjgCjtC
dhLyB6G4QHcbKeGFL2yI1UeM2xmITEu4zMdmHz4zCIUTvvjFl2aJiQt86rGp
weVuXG4mJZ0Ql44A7G6PrA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 944->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTZ0CzH58Z6DROMxmw241LL7oZ2NQS439c7sVnLz57sLkPVzjgCjtC
dhLyB6G4QHcbKeGFL2yQ0wfRaQmHvQxo5hAKQ1z+IiY9EhNO+OIXX5olJi7w
qcemBpe7cbmZlHRCXDoCAC5fjqw=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 945->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyeGTx8bGpgaZxmUmunnoarHxcfkFn7tx2YnNnbjsxWcPNvfhCgdcYUfI
TkL+IBQX6G4jJbzwhQ2x+ohxO6FwJeQObPbhM4NQOOGLX3xplpi4wKcemxpc
7sblZlLSCXHpCACH6Y/t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 946->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyeGTx8bGpgaZxmUmunnoarHxcfkFn7tx2YnNnbjsxWcPNvfhCgdcYUfI
TkL+IBQX6G4jJbzwhQ2x+gi5nQGKiUlLuMzHZh8+MwiFE774xZdmiYkLfOqx
qcHlblxuJiWdEJeOAByMj6w=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 947->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyWGTZ0CzH58Z6DROMxmw241LL7oZ2NQS439c7sVnLz57sLkPVzjgCjtC
dhLyB6G4QHcbKeGFL2yQ0wfRaQmbGBImNgxx+YuY9EhMOOGLX3xplpi4wKce
mxpc7sblZlLSCXHpCABdUI4s
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 948->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyeGTx8bGpgaZxmUmunnoarHxcfkFn7tx2YnNnbjsxWcPNvfhCgdcYUfI
TkL+IBQX6G4jJbzwhQ2x+ohxOzZ3EhtHxMYNITX43ItNH7bwISYu8KnHpgaX
u3G5mZR0Qlw6AgBWM48u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 949->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyeGTx8bGpgaZxmUmunnoarHxcfkFn7tx2YnNnbjsxWcPNvfhCgdcYUfI
TkL+IBQX6G4jJbzwhQ2x+ohxOxgQkZZwmY/NPnxmEAonfPGLL80SExf41GNT
g8vduNxMSjohLh0BALraj20=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 950->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLgwGa/fjMQKfhAIdaDHVY9GKzE5taYvyPy7347MVnDzb34QoHXGFH
yE5C/iAUF+huIyW88IUNsfqIcTs2dxIbR8TGDSE1+NyLTR+28CEmLvCpx6YG
l7txuZmUdEJcOgIAdY+Nbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 951->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY6jctOdPPQ1WLj4/ILPn/hshObO3HZi88ebO7DFQ64wo6Q
nYT8QSgu0N1GSnjhCxti9RHjdjAgIi3hS5PoZuMzg1A44YtffGmWmLjApx6b
GlzuxuVmUtIJcekIAL0Gje8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 952->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLM2DRh88MdJoBagYuteh2o+hF5uPxCz5/4bITw5247CVgD7qfcYYD
FnW4wp4Y9cT6Fd3N6HYRk15whQ2x+ohxOxgQSkt43IHNPnxmEAonfPGLL80S
Exf41GNTg8vduNxMSjohLh0BAHA6jus=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 953->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY6jctOdPPQ1WLj4/ILPn/hshObO3HZi88ebO7DFQ64wo6Q
nYT8QSgu0N1GSnjhCxti9RHjdmzuJDaOiI0bQmrwuRebPmzhQ0xc4FOPTQ0u
d+NyMynphLh0BABYX42w
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 954->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwyaHLYxPHZwY6DQZ41KLbgaEXxsfjF3z+wmUnNnditZeAPeh+xhcOuMKO
kJ2E/EEoLtDdRkp44QsbYvUR43YwICIt4UuT6GbjM4NQOOGLX3xplpi4wKce
mxpc7sblZlLSCXHpCACFZo5t
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 955->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLM+ASx2MGOs0ANQeXWnS7UfQi8/H4BZ+/cNmJ4U5c9hKwB93POMMB
izpcYU+MemL9iu5mdLuISS+4woZYfcS4HQwIpSU87sBmHz4zCIUTvvjFl2aJ
iQt86rGpweVuXG4mJZ0Ql44AbdKOLA==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 956->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLM+ASx2MGOg0GeNSi242hlwHJHTj8gs9fuOzE5k5s4UDIHnQ/4wsH
XGFHyE5C/iAUF+huIyW88IUNsfqIcTs2dxIbR8TGDSE1+NyLTR+28CEmLvCp
x6YGl7txuZmUdEJcOgIAwZOMbw==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 957->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLM+ASx2MGOk1ILbrd6Hpx+R+bWmL8j8u9+OzFZw829+ELB2zuJGQn
IX8Qigt0t5ESXvjChlh9xLgdmzuJjSNi44aQGnzuxaYPW/gQExf41GNTg8vd
uNxMSjohLh0BACDtje8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 958->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoNNggEctLnuw8nH4BZ+/cNmJzZ047cVjD7qf8YUDrrAj
ZCchfxCKC3S3kRJe+MKGWH3EuB0MiEhLhNIqMemRmHDCF7/40iwxcYFPPTY1
uNyNy82kpBPi0hEA6RKM7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 959->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoNNggEctLntQAEwdDr/g8xcuO7G5E1s4ELIH3c/4wgFX
2BGyk5A/CMUFuttICS98YUOsPmLcDgZEpCVCaZWY9EhMOOGLX3xplpi4wKce
mxpc7sblZlLSCXHpCADC5I0u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 960->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoNOE1OKyB4OPxy/47EHRg2YONv243IHLHnQ/EwoHbO4k
ZCe+sMMX19jcjG4XMekFV9gQq48Yt4MBkWkJm/nY7MNnBqFwwhe/+NIsMXGB
Tz02NbjcjcvNpKQT4tIRAJMYje0=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 961->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoNOE1OKyBxsfl1/w2YPLTlzuxOUOXPZgcx++cMDmTkJ2
EvIHobhAdxsp4YUvbIjVR4zbsbmT2DgiNm4IqcHnXmz6sIUPMXGBTz02Nbjc
jcvNpKQT4tIRACKnjbA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 962->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoNOE1OKyBwXYQzAuv+CzB5eduNyJyx247EH3M6FwwOZO
QnYS8gehuEB3GynhhS9siNVHjNuxuZPYOCI2bgipwedebPqwhQ8xcYFPPTY1
uNyNy82kpBPi0hEAPVuNbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 963->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoNBQjE8tLntQABY7saklxv+43IvNXmLsQfcz1nBgwK4O
V9gTo55Yv6K7Gd0uYtILrrAhVh8xbsfmTmLjiNi4IaQGn3ux6cMWPsTEBT71
2NTgcjcuN5OSTohLRwA9mY2u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 964->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHmwAl1/w+QuXnejuxWYvMfbg8zMuMwiFPTHq
ifUrupvR7SImveAKG2L1EeN2bO4kNo6IjRtCavC5F5s+bOFDTFzgU49NDS53
43IzKemEuHQEAFhfjbA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 965->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsz4HELPntQABZzsKklxv+43IvNXmLswepnBvzmEwp7
YtQT61d0N6PbRUx6wRU2xOojxu3Y3ElsHBEbN4TU4HMvNn3YwoeYuMCnHpsa
XO7G5WZS0glx6QgA/nqObQ==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 966->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHgyAxy/4/AVXj4SxuRebvcTYg8/PuMwgFPbE
qCcmrrG5Gd0uYtILrrAhVh8xbgcDPOFKyB3Y7MNnBqFwwhe/+NIsMXGBTz02
NbjcjcvNpKQT4tIRACnBjW0=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 967->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHqxiOPyCz18YfkQyB5t+XO7AZQ8+P+Myg1DY
E6OeGL9iczO6XcSkF1xhQ6w+YtwOBnjClZA7sNmHzwxC4YQvfvGlWWLiAp96
bGpwuRuXm0lJJ8SlIwBmq40u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 968->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHqxiOPyCz18YfkQyB5t+XO7AZQ8+P+Myg1DY
E6OeGL9iczO6XcSkF1xhQ6w+YtwOBnjClZA7sNmHzwxC4YQvfvGlWWLiAp96
bGpwuRuXm0lJJ8SlIwBmq40u
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 969->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcgcsefH7GZQahsCdG
PTF+xeVnUsMLV9gQq48Yt4MBnnAl5A5s9uEzg1A44YtffGmWmLjApx6bGlzu
xuVmUtIJcekIAPK+je8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 970->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcgSJHpJ9xmUEo7IlR
T4xfcfkZXYxQeOEKG2L1EeN2QuFKyB3Y7MNnBqFwwhe/+NIsMXGBTz02Nbjc
jcvNpKQT4tIRAHmvjW8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 971->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn9h6MHhXmz24pQj0s+4zCAU9sSo
J8av2MIG3S5i0guusCFWHzFux+ZOYuMIVxrAZwahcMIXv/jSLDFxgU89NjW4
3I3LzaSkE+LSEQDfE41v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 972->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcgcsefH7GZQahsCdG
PTF+xeVnUsMLV9gQq48Yt2NzJ7FxRGzcEFKDz73Y9GELH2LiAp96bGpwuRuX
m0lJJ8SlIwCOF42w
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 973->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn9h6MHhXmz24pQj0s+4zCAU9sSo
J8av2MIG3S5i0guusCFWHzFux+ZOYuMIVxrAZwahcMIXv/jSLDFxgU89NjW4
3I3LzaSkE+LSEQDfE41v
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 974->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8yM2/bjcgSJHpJ9xmUGMuwip
J8av2MIG3S5Sw4sYvfjU4dKLzZ3ExhGuNIDPDELhhC9+8aVZYuICn3psanC5
G5ebSUknxKUjALLMjHE=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 975->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn9h9SMW92Kzlxh78PkZlxmEwp4Y
9cT4FZub0e0iKrxwhA2x+ohxOxjgCVdC7sBmHz4zCIUTvvjFl2aJiQt86rGp
weVuXG4mJZ0Ql44AWa+Nbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 976->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcgSJHpJ9xmUEo7IlR
T4xfcfkZXYxQeOEKG2L1EeN2bO4kNo5wpQF8ZhAKJ3zxiy/NEhMX+NRjU4PL
3bjcTEo6IS4dAQAVCI0w
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 977->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn9h9SMW92KzF6cckX7GZQahsCdG
PTF+xRY26HYRFV44woZYfcS4nVC4EnIHNvvwmUEonPDFL740S0xc4FOPTQ0u
d+NyMynphLh0BADgkYzv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 978->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHqxiOPyCz18YfkQyB5t+XO5AkSPSz7jMIBT2
xKgnxq/YwgbdLmLSC66wIVYfMW7H5k5i4whXGsBnBqFwwhe/+NIsMXGBTz02
NbjcjcvNpKQT4tIRAIjmjG8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 979->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlxi2PyCz18YfsThXmz2EmMPPj/jMoNQ2BOj
nhi/YnMzul3EpBdcYUOsPmLcjs2dxMYRsXFDSA0+92LThy18iIkLfOqxqcHl
blxuJiWdEJeOAMA9jTA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 980->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHqxiUIzuF3z+wvAjDvdis5cYe/D5GZcZhMKe
GPXE+BWbm9HtIia94AobYvUR43Zs7iQ2joiNG0Jq8LkXmz5s4UNMXOBTj00N
LnfjcjMp6YS4dAQA3/WM7w==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 981->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHqxiOPyCz19w9UgYm3ux2UuMPfj8jMsMQmFP
jHpi4hqbm9HtIia94AobYvUR43Zs7iQ2joiNG0Jq8LkXmz5s4UNMXOBTj00N
LnfjcjMp6YS4dAQAxwuNLg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 982->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHqxiOPyCz18YfsThXmz2EmMPPj/jMoNQ2BOj
nhi/YnMzul3EpBdcYUOsPmLcDgZ4wpWQO7DZh88MQuGEL37xpVli4gKfemxq
cLkbl5tJSSfEpSMA/7qNrg==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 983->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHqxiOPyCz18YfsThXmz2EmMPPj/jMoNQ2BOj
nhi/YnMzul3EpBdcYYPLPfjswCpGIG4IxRGxcUNIDT734vMjLjW47MCnHpsa
XO7G5WZS0glx6QgAxz2Mbw==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 984->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn9h6MHhXmz2EmMPPj/jMoNQ2BOj
nhi/YnMzhl1EpBdcYQPTj24GNnWkpAdiwhCXv4g1g1A44YtffGmWmLjApx6b
GlzuxuVmUtIJcekIAJK6jS4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 985->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHgyAxy/4/AVXb4/dDFxm4ZMj1s+4zCAU9sSo
JyausbkZ3S5i0guusMHlHnx24LKXULgScgc+d+EKC0JyuOIXX5olJi7wqcem
Bpe7cbmZlHRCXDoCACpxja4=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 986->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHgyAxy/4/IWiB497sdlLjD34/IzLDEJhT4x6
YuIam5ux2UUoveAKG1iYYgsTbGFFbHogJgxx+YtYMwiFE774xZdmiYkLfOqx
qcHlblxuJiWdEJeOADxHjO8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 987->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHgyAxy/4/AVXj4SxuRebvcTYg8/PuMwgFPbE
qG9A8wu+uEB3G4r5eMzB5S5cYYAvLZGSHogJQ1z+ItYMQuGEL37xpVli4gKf
emxqcLkbl5sJhTUpGGIGADYmi64=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 988->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/B1WNRh00/Lnfgsgefn3GZQSjs
iVFPTFxjczNWuwikF1xhg8s9uNQRmx6ICUNc/iLWDELhhC9+8aVZYuICn3ps
anC5G5ebSUknxKUjAA4Ii/E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 989->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn+h6EHC6O7FZi+GHJp+Qn7GZT6h
sCdGPTFxjS1s8NlFrLvQ1WPj4zIXn1340hIhd+BzFz6/EgoHdDMIpVli4gKf
emxqcLkbl5tJSSfEpSMAH5yMLg==
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 990->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn+h6IFibO7FZi+GHAEzcImhm0co
7IlR34DmDnxxge42OLBH0MSkCXQ+rjjGpY7Y9EBMGOLyF7FmEAonfPGLL80S
Exf41GNTg8vduNxMKKxJwRAzAPSsi+0=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 991->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn+h6IFibO7FZi8x9uDzMy4zCIU9
MeqJiWtsbsZqF4H0gitscLkHlzpi0wMxYYjLX8SaQSic8MUvvjRLTFzgU49N
DS5343IzKemEuHQEAEJHjO8=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 992->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcgcsefH7GZQahsCdG
PTF+xeVnOLCHYhzm4XIXrjDAl5ZISQ/EhCEufxFrBqFwwhe/+NIsMXGBTz02
NbjcjcvNpKQT4tIRAJkEi/E=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 993->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHqxiOPyCz1/4/I9NPy53oMgR6WdcZhAKe2LU
E+NXXH7GZRex7kJXj42Py1x8duFLS4Tcgc9d+PxKKBzQzSCUZomJC3zqsanB
5W5cbiYlnRCXjgDwvIsy
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 994->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcAWYjYWL8jMt8QmFP
jHpi/IrLz7jsItZd6Oqx8XGZi88ufGmJkDvwuQufXwmFA7oZhNIsMXGBTz02
NbjcjcvNpKQT4tIRACOKjDA=
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 995->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcAWYTMAOXGBzYIzC+
sEdn4ws7fH7F5WcMuwiEF66wweUeXOqITQ/4wpBQWiXWDELhhC9+8aVZYuIC
n3psanC5G5ebSUknxKUjACptizA=
                    "], {{0, 17}, {17, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 996->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcQYwZuMTggIC7cLkH
X9jh8ys+9+Mzn5C70PVg42NTR2x6wBeGhNIqsWYQCid88YsvzRITF/jUY1OD
y9243ExKOiEuHQEAbLiNMA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 997->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcQYwZuMRQABFhj87G
UI+E8fkVn/thbiFkBr6wwRXHuNQRmx7whSGhtEqsGYTCCV/84kuzxMQFPvXY
1OByNy43EwprUjDEDAAF34tv
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 998->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcQYwZuMTgwB6CCYU9
OhtDvT1us/D5DVu4YjOfkLvQ9WDj4zIbl324zMQVJrj8RawZhMIJX/ziS7PE
xAU+9djU4HI3LjcTCmtSMMQMAKIlizA=
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 999->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcQYwZuMRQzCMi7NHZ
GOqRMD6/4nM/GBBIV7jcha4HGx+bOmLTA8EwxGI+PnfhCgtCcrjiF1+aJSYu
8KnHpgaXu3G5mVBYk4IhZgAAh1qL7w==
                    "], {{0, 17}, {17, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False], 1000->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBbCBOamKOsVEOSFIQihkYGuwZ4DQl
GAbwySHLowNkcVxmoMsTUovLHlx2Y/MLPn/h8z82/bjcQYwZuMQIuQ+fncT4
i1BcYHM/up2kuAtdDzY+LrNx2YfLTFxhgstfxJpBKJzwxS++NEtMXOBTj00N
LnfjcjOhsCY9HQEA/3+NsA==
                    "], {{0, 17}, {17, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Tiny,
                  ImageSizeRaw->{17, 17},
                  PlotRange->{{0, 17}, {0, 17}}],
                 StripOnInput->False]}, Dynamic[$CellContext`i28$$],
                Alignment->Automatic,
                BaseStyle->"ListAnimateCore",
                ImageSize->All,
                TransitionDirection->Horizontal,
                TransitionDuration->0.5,
                TransitionEffect->Automatic],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
        GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}}], If[
        And[
         CurrentValue["NotebookSelected"], 
         CurrentValue["SelectionOver"]], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i28$$, \
$CellContext`i28$44530065$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 1000, 1}, 1000, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{309., {82.884033203125, 88.615966796875}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.7736080358500643`*^9, 3.773608046941958*^9}, 
   3.773608095393882*^9},
 CellLabel->
  "Out[318]=",ExpressionUUID->"329ae6ae-909f-49c7-90a9-607b7bd0f3b6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ropes", "=", 
   RowBox[{"CornerMembrane", "[", 
    RowBox[{"35", ",", "35"}], "]"}]}], ";", " ", 
  RowBox[{"WatchImageWalkSATCRN", "[", 
   RowBox[{"ropes", ",", 
    RowBox[{"{", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.773608250347067*^9, 3.773608262705228*^9}},
 CellLabel->
  "In[321]:=",ExpressionUUID->"f2a005ea-d507-4765-ab72-0285222c9a4c"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i30$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i30$$ = 1}, 
     "\"max\"" :> {$CellContext`i30$$ = 1000}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i30$$], 1, ""}, 1, 1000, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i30$46967524$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            TagBox[
             StyleBox[GridBox[{
                {"\<\"\"\>", 
                 AnimatorBox[Dynamic[$CellContext`i30$$], {1, 1000, 1},
                  AnimationRate->Automatic,
                  AnimationRepetitions->1,
                  AnimationRunTime->0.,
                  AnimationRunning->False,
                  AnimationTimeIndex->5.,
                  
                  AppearanceElements->{
                   "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons",
                     "DirectionButton"},
                  AutoAction->False,
                  DisplayAllSteps->True]}
               },
               AutoDelete->False,
               
               GridBoxAlignment->{
                "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "ListAnimateLabel",
              StripOnInput->False],
             {"ControlArea", Top}],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydlE1KQ0EQhB8uJNcQb6AHCF4hnuAJZhUQ4kLceXQNKMpY9VXNG0jM9PRP
VXe1N08vh+PVsiyvu6+vw/r2cD6v74/Xl8vzerq/O10eb78/y/Kx//38nGQb
7XRcHvU25nR/yaZyO8wU+9emuKv7DC7ipPrhsKk41VfqRXvfMnv3O2He4uO0
1OiYYlRup41UL+nM3R3GVtvEMXFVJ+1Z2w9la/bP4ZjBPsa3PJVP0lXDq9GO
w5pm0HBUMYRlhgPlGvErTg3+2R4l7Tg/xStp03Fv5+94E3fXD+LtcjQ+xD3N
Mu23y6t4On1t2aPEXdVXeWZ8SYuuL8pGmmjmq+5pFxOOVJPyjrGkDerziKnZ
U8fL1UuzUm9pJu27w0q6onmkfWrwK3vTN9c7F0P1ZziPNnVv8TU1qT7tupuP
8qe6M/8H0txVXsJKep7ReeqDwkn4VBzxdCfNhmJU3dQ7ZU+9TNqnPR19nX+j
DdcL5TOrfepfyqd6RTzo7vCpd9oz6jnlaudK8a1e0h6NZ2ZPSIeUm3j+7/En
z7zQMw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 2->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0lOAzEQtDigfAPxA3hAxBfCCwaJnCIhJQfEjadDUHBmempzWprFdi9V
7eqHt4/d/q61dtr8vnbT58vxOH293p8X79Ph+elwPny8PK19b6/Pv7m9uq+M
5UFnNSf7qj2Um2FWsfM9xB2tR3ApTn+2vT4K2yoO8GVxQ+sb7579O8y3+DAt
JTpWMSg304ar53TG1gxjqm3F0XHtRuqo/6T/yYwtzspsVF9qojdKC5Ub8nG6
Sngl2mFY3R0kHFGMxBJyaCZXxY84KfxMD8zPzRvrBftHa8XJ9Y/Vr6awsT10
7nqe+iju8BvqTuVFPJm+6DwQ/STcUX3Vm8RXaZH1Be0pTcy5u9yO/wgOiOGC
oz/C6tyguuye03uoOShnMMOMr+Rj8CO8sIa5Q6UrpXM3Twl+tJ/0jfWOxaj6
I5zrHlorDaezndRXs87up+MheZzWFffuRziivAqr0rvTRMeh+iDwK3woTvHs
NqjHrhsQg+q63qF918vF1+iQ1WN6c/fLci5yAx+q/ZkmqF/RjcxHeqV4qDXk
V89JrVVOoP/qj+IZLxhP+gTxmTtnOBAeaGruwtyqT+se/wBgsdMJ
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 3->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0tOQzEQi1ggroG4ARzgiSuUEzwkWFVCahcVux4dKtF04tieeYz0PpnM
x+M4j+9fu8+71trx4fe1W0+vh8P6/XZ/WXys+5fn/WXz6e9p7bzcnqtlPvS3
sEZTddjeUNN8nY/VppiT3Ohjs7P1Flxyput6uT3Rr+aLRnnFeiL2HPst4zr6
WV80xjmd0+EI+DPtKS1VdIz8ME5ZXacRFxdrVrXl+iNOxf3gE488V9HH/Vf4
R43h/5RDsNIzFfgzvqKx2ViM1BXEqPiqdhTW7AwqM/Z/oX92DpUZWlIL8XeL
Z23wKz2ouOy+MZxxjf9srWaq8Kf6ozls/Qsc4j49r3/GuNn7PmJLZt3CKdZx
/glT1E+m56Q/1q7GsvvVljmv5yT3Y8hRtcyMU93K/cpwNJgv5qKP7OH5YJ9Y
X54JYhJ3ROoFcCmtIS5mSluSM7OP+LGP4izTeXafKviZv8Kb4k7luP5bZkYf
W089UKcEp9NGqlOCQ52PmtnNkel24lzMyOo6rE7vmSY6jgIPDL/Dx/LcnN02
6rHrhuSwvhl3zJ9xOXwTHap+LYmvaINZRV/DXtCEjAPd2HqCKzeHW9P5cF/0
mmoS/WM8y1dz0XzBE8WXnLnCwfBQc/euWNvxNHP8A4gRz+s=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 4->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1tOA0EMi/hAXANxAzjAiiuUEywS/aqEVD4Qf3t0qARLxrE9aaRp55FJ
bI/3/vX9cLyJiI+7n5/D+vl8Pq9fL7eXxdt6eno8XQ4ffkfEtvyPv5jt4X6k
NYaqw86Gmubf7bHaFHOMuDE/7zHubH0NrpK3pAHrrLHil4PqivVE7rbU3A1x
iL4YVPMY+QThM/QNsSdyGIaOjxVnphmrs7F7Ji9r0vWW65/3yx31jYkh31X0
cfOO/ugxnEt9lVdVEG2cxoonyynfichhGnS1mvnB9elw3OdNv9s3gnquFuLf
A7DsZ/ndYT3kijzlP8c5r3GuvMdwd/RT/TEcNqlBeN6sRjfHcR/eLmObcJ1q
GlwH98bOT+pdrumPtbu5pWfSiOIgOUzTgSPZVxzDcKGeZGfG1wF56FN2hu+T
Q3k23ykYVG/nF8ClvIa4WChvMXzyPKqeTBul2cznxZMOQ7OXW2M+C3XH9b+G
M+4xb5ce6FOC03lD9Wc9VN0ZZ9V3ho1xUVhYXYdV9UbPSR7kO2Q6bJAXE3xF
B8KZYQroTTEtZJA7uX9XO7bvNMYeM6+rfuqdpu8rag61SY70PmhK84x/u1op
Hqom3mXaDRxIr1KT+H8P8iYKP84LFpFX8p0vmdcgnA9yDZXbqS15RuW4Ld+i
Wc9N
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 5->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOA0EMizggvoH4ATxgxRfKC4oEp0pI5YC49em0orvKOLYzHWnazkwS
O477+P61+7yLiO+H88du//N6PO5/3+4vh4/94eX5cHl8uu6I03L+WK7f67qe
891pGXe+j5ybl6mDv3POVm8ZzwWX3LHalPNaX+Qif+ydnW/hxbBU71lj1V9e
Vlczj60WxJ6Qh8DFRTXPXCKGWkz3nOO8lGshB+VjpzfTgdWl/gCNnIcGjoCv
5svq5vuSI/JD7PJG6igfMp8r/bOvZu873taTRJtBL+xX9InaMN64nDZUqwnf
5L66GdC8qPeqh5tnBPVcrcyh+Jbxx1mhdzMuiWPYzDsqDn8r7zHeU94X+Lgc
N6lB+L4xt41BLUzMqsHArekVe2A+UbPMGM5zpX7n5wYfayOOiqXchcZstkrT
oUeMMz3GUs+s/22xN+PrgDj0KXvD+ShvlJkoDgrb+QV44cyknmQpbzF+8j2q
nojJcvC+45IxZnMcB3XGeLZUjsO/pWe8Y+eCIbw4g+nwGYaq2/Xs+uh8WzQX
XFhdx1Vho+fW/qnvJ3Qo/8+GX9FhIZv0HYBNOYlamJPxnXYdptMYtQnAZbHU
G038jDcGbXJtgiu9L+ZTPCX8y+qxeag+VE3MZdoNPRCsUpP4f1tGR+bdzvcs
rsSbmWNPyJ9xKEt4jPYY9U15keX/7z8V3tAt
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 6->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVklFOAzEQQ0d8IK6BuAEcYMUVygkWCb4qIZUPxN8enVa0ZeI8T0KkbTfZ
iT32+P71Y/d+ExGfd8ef3fr1fDis3y+3p83bun963J8+PpyfiG05/izn//h9
v+yvZ/G3p/NI+2YVOPqOeEt6AnjhjLCx5wu+uav9q3ba/6cv4spa8z574vTl
Rb52eKZ2W/raTfswvLrQ89xLRINFvuc7VZYylvbgclz5rT4oNuWCcG1NtP8b
8Lv5ujrFHPnS6aM5mxnrrBodoNv51ukw5+ivy+pgWb9UL8yxOQetYXqovEGv
nC8B+BMzwHvOD9Dg5lBqSHgVVu6hyy31r7PS7GZeqCNuyo6r03fao6ZJ/xy/
rqo360HUuvXusGZSezO73NtAq2qgnLhZZo4qcx3+KM8DfsVWHleLvRd509k6
TxuNWldojKXfk/7rom9FrkPqNKf0TefjstHNxPXguKu8SF86M+snLJct6s9+
j95P5aQ7ek54mMmqh0muaq/12QPHNaN1SnPwmfqC3CaLM5wVP3E43JFmxzvq
jbS4XggXeQTD3hX9mPsJHzTTHe/IhwUe0B3CjT0ZLL2T+Umf0ztT13GI385n
nUHz3WDPZqPxJnulNRF+5mY+VfZsnfBob6TDYaqnGbvz3M0gWEOXZfBRe1RP
R7mnOswI6CZNlZ96h/Yu99qX1lud0Wvclh8SWsul
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 7->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FOw0AMRC0+ENdA3AAOEHGFcoIiwVclpPKB+MvRaUVTvOM3TojUNrvr
nfGMp/evH7v3m4j4vDt97fZfz8fj/vvl9rx42x+eHg/nw4fLJ2KeTl/T5Td+
35f1dS/+1rQfaT08DY6+I96UPgG8sEfY2POCb+5q/6qd1v/pi7iy1rzOnhRN
xsN5EkzFg96u+FI7ax+gceg56jnONWLAIt8zdpeljGVxQ/xv/Eb/gnFKPsSj
LkNDj8JPWVIvXLatL7muy4fRrTwxgQ7Q7Xwres0++uuyuvJYv1QvzHHYB61h
eui8Qa+cLwH4G2aA95wfoMHNodWQ8Dqs3EPJLfWvs9LsZl6oI27KjqvTd1qj
po3+OX59ut6sB9Hr1rurNRu1D7PLva1oVQ2UEzfLzNFlruCv5XmFX7GVx9W6
3pWDfBn26I6razRGowUzSWdNrkPqNKd0pvNx2SgzcT04bpMh6ktnZv2Ex2WL
+st6bR4MJ2VZ9wnPZdJ5upWrW2t99sBxbdG6SXOMnIQdjlvySH122aD/luNw
uKi5mdXW3khL0WvmN+iiPBluzdyiBXMv9SU3U+UvvE1viqUzLjMS34oWg6V3
nG80f8tp6hyHZld91hkM5wa7na/UFz+cz1F9Ge4DP2WX+nS50N4Iz2Gqpxm7
eO5msMJZcmjuk6c0o4xDdZgR0E2aWj/lDq1d7rWv5R5mgDQM/f8AwDrLkQ==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 8->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk1FKA0EQRBs/xGuIN9ADLF4hnmAF/QoI8UP826ObYBK6q1/NZCHJzkxP
VVd15fH9a/d5FxHfD8ev3frzejisv2/3p8XHun953p8On86fiG05fi3n3/h/
v6yve5HWsB9pXR7FkbVyNLwlfcLwUo+D94IzuKv9bqZ3xWoYphfiKnrSOnvS
NBkPiz8L4EFvV3yp3bQP0Fh6jn6Oc40oWC4nbo9q9N3dafkhzbKfH8oF4dqa
qL8b8FOW1AuXbetLrtNPwna6lScW0AG6nW9Nr9lHf11WJ4/1S/XCHMs+aA3T
w8gb9Mr5EoB/wwzwnvMDNLg5DDUkvBFW7mHUi/NfM1B4oY64KTuuTt9pjZpu
9M/x6zPqzXoQY916d1pzo/Yyu9zbRKtqcDkhTZljlLmGP8vzhF+xlcfVut4b
DvhS9qAvWzfQGKCF8pR7LPUDfNI3xDXzyecu15uclx4ct8kQ9aUzs37q3eC6
ljvRbjkGnOSBchGey6TztPXv5g46bE6SB47Labo+wOnmlDmdj8gN/w/yxGWj
8Q84HK7N2oR31htpUb1ufkUX5WmSvzx31KEYlJul8zde05vOlGbcZiS+tf+D
w5Y75Jubv+U0dY5Ds6s+6wzKucF280VMmLli5rOGb+YznS3lUzi0N4fntLv+
m+duBhNO9Bjuk6d4P/lJdY4Pcyl3hn7KHVq73Gtfl3uYAdJQ+v8DBsjGCQ==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 9->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk01KA1EQhBsX4jXEG+gBBq8QTxBBVwEhLsTdHN0EM6Ff9Vf9MjBx3k93
/XT5+P61+7yLiO+H089u//N6PO5/3+7Pi4/94eX5cD58urwR63L6WS5/4/97
W1/3Iq1hP9J6eLSPrBWj9FvSGwaXODbfQ5+mVvmuhrv2Kj0Ml8JB9aR19qRo
WsSLZTyj13FzdwdNZh5DffIu4xRt4htlMPe2mcz48u1qSn6cR5Az7VPyIR51
GRo4dvPLj8yesm19yfcIY4YtOM430ov7Zq376G+T1e6xfhmvM++iGTQRB537
LflBXwL6Q2/FwTrnB/jseHb5HnwFL4ib5ZLPILOUP3ePsGlu7p5+0xo13eif
w9en42Y9iF631iIHk/9O+zC7zG2ilXI49Iu6rx7jvnKS3Ld5jrrX6VUcd9dx
L33Uv4mng0aodRoDtFCeMsfhftOf9LV9zXzyucv1KucDhxj7Im/SJbir40Z1
W23wvZI70W4xGkzyQLGon8uk87Twd3MHHTYnyQOH5TRdH8B0cyq5kN7hsOH/
gzxx2dC8dhiur83aBLfLAGmiMzc/1VXyMclfnjv6qz0oN0vFL7iGm2LSuswo
PaWn9lCN0fs2871gwrrD0Oyqz0Vv1mN635KtMrPcO1hnmVmuB/x2tpRP1eN0
Gi00B+JfPHczmGCix1BPnmL9xsXcc3jkoWpq/ZQaWrvcK6+tDjMgOuvc/gCA
AcG6
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 10->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA0EQhQsX4jXEG+gBBq8QTxBBVwEhLsTdHN0Ek1D96nvVM5Cfnu6u
9/v4/rX7vIuI74fT127/83o87n/f7s+Lj/3h5flw3ny6fCLW5fS1XH7j//91
fXsXaQ3vr3fKo3NkrXvDvMRl2Gtw3WzSkjHpvPJdDXfkD1xn91RrXmdPiqZF
vFjGPfo4bu7soMnkMdxP3mWcok18ow7m2baTGV/+uzulP84j02/qBc21Z2L8
XQW75JcfyZ66bX3J5whjhi04zjfSi+/NWt+jv01Xu8f6ZbzOvItm0EQcNPct
/UFfAubDbMXBe84P8Nnx7Po9+ApeEDfLJe9BZ6l/7hxhU25Oa97Ts+Rr5r3F
P8TPz4RP60H0uvUucjDd6LQP2WVuE63Uw3LfZJnPUIa2P7M+R33X6XV4lJPD
DeKx0dNBI92lfHWuwRwe8Ib6odkM/Nxckw9pUP9W2R84xDgXeZMuwV0dN7p3
vRt8ruQv2i1Gg0keKBbNK/sTTwt/lzvosD1JHjgsp+n2AKbLqfRCZofDFm3O
E9cN7WuH4ebark1wuw6QJtpz+amu0o9J/3Lu6K/OoN4sFb/gGm6KSetV99NT
ZuoM1Ri9bzPfnfcuH+d314XSM9GwBZt00KzSO8Et801fp9lSP1WP02m0UA7E
v3juMnCY4M8qXN3MMlfwnCbk12Su3W/91DuwLpnH3OfSAeFVc/sDlq7AMg==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 11->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktKBGEMhIML8RriDfQAjVfQE4ygqwFBF+Kuj67izJBUvkr3D/P4H0k9
Urcv709vVxHxefP79XT4evz4OHw/X/9tXg/Hh/vj3+Xd6ROxLr9fy+k3/v+f
95ezSHs4P9e0pX1kr3elX+JS7gZc15u0ZEx6r3xXwx35A9etOtWa99mTpmkR
L5Z65+6JWyz903wx8yj1ybuM07SJb5TB3NtmMuPLf1fT8uM8MvmmXFBf+ybq
r85LZ1aWzJ6ybX0R/pS7EVtwnG+kF8/NXs/R3yGr07J+Ga+LX6oZNBEHnfue
/KAvAf2ht+JgndRmH/bkeJyR9CMviJvlom8ks5Q/ynbzFXwinpovl2utL5p2
+of4eW3wGT2IWbfWIgfpu0d79qBw29CqGpq26OfqMenJXFr/rTxHP5v0Ojya
k8MN4rHT06KRamm+2tdglgXeUD50NoWf62vmQxjqX65pHKL2Jd4088xL8+Yy
02qD37X5i3aLMWCSB4q1xSVjOE8bfzd30GFzkjxwWE7TZQHmpPlc43xEbM2p
8cRlQ/NqPTBZJy9y3YRrueknc3Ln0Df3a/kYsDVDmAPtMXkG73TeqC/jwn7V
+7Raz8FbrSHftI7mTt67+ShG4Qg+a5aKJ8P7rWy1meXewTrbzHI95HWcLeVT
vQKdkxaaA/FvnrsZOEzwZxWurmfzRvCcJuQ35E2zP/opNbRvM49tnwsvqeW5
/QCzRMKy
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 12->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktKA2EQhBsX4jXEG+gBglfQE0TQVUDQhbibo6uYhO7qr/rPQDLzP7rr
0XX78v70dhURnze/f0/7r8ePj/338/Xf4nV/eLg//B3eHX8R2+73b3d8x//3
aX3ei7SG/VPN+YFep3Xuuylu7pfqy9mA63rrXcV0XDLfzXBH/sC18QKs0P3s
H/Tf9FxnN5xb3a7Xykfgj/OKfs/xyPVjJqPW2b5p3fLjPKJ8S5+WD/FoylDh
aOan2HmmpC+/sxfE387NYQuO8430Kq5qmPbR3yGr00OZaXnI5yG9L5gxYTpv
nDb0RflHPyMcrJPa850LczzOSPoRJnGzXPSOZJbyR9kuOSGf0+O05jO9q/VF
08I/mgXmacFn9CB6TfM8DD/BJx5Oe/agcFtoVQ1NW/R99ZT0ZC6t/yrP0fcm
vU47zcnhUjbC9CVeOQOtluarfQ1mecAbyofOpvBzfc18CEPnr34XDlHvEG+a
eeZFeJSZos/kqPEXHMUstYQp55TFVc5VH/Zz/N3cQdNqRi0vekfqWqZhXnZO
0flk3eVbOUJmJk/0WzGaBybrLcOifcqk9UN/IViOq2pO/ZTvlJWmifyDPtYz
hx3MjfTTetPz9JAW563WkG9ap7477918FKNwBJ81S8WT4b7tF9KTZh6sE7Nr
crmcLeVTvTI5pR6KfdYN/JvnbgYOE/zZhKvr2fIleE4T8hvyptkf/ZQaWreZ
x9rnloGo7z63H3pnvmU=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 13->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktKA1EQRQsH4jbEHegCGrcQVxBBRwEhDsRZL90E06HerXPrpSHpfp+q
ur/H96/d511EfD+c/nb7n9fjcf/7dn9efOwPL8+H8+HT5RexLqe/5fKO/+9t
fd2LtIb9reb6QK9tnfuuOjf3S/XDWTPX9da7OtNhyXhXgx3xA9aCC2aF7mf9
oP+q5+pdc255u14zHQE/+hX1nsOR60smIaMlh9o3rUt+nEaUb+lT8iEadRka
MBr/dHb2lPjl95WDPHbGbLbMcboRX52rHLp91LfJavdQZkoe8nlI7xs8pplO
G8cNdVH8Uc9oDtZJ7fXOjTluPZJ+NJOwWSx6RzI7/aV7qrXzzXFVnWmNnCb6
kReYpwke0qnoavpr7aCVzCcceEc0GLBNuK4yy/mKnDrvo57FUnm3+gh24k14
MdeTueih8xvuICbRJc/Kb+yvfsP9jBv1cpmivsYfmqEZ0PeAIeqZ9iTPMy6a
R5kpugffK/4rfjeDZsq5Zv+WnCs/7OfwO9+BE/VD7QB/yzXXL3PO2SPsLXNC
MRLuRhP97nKq/Z0/w9N4hRkmfoTJ7ce4Vl6Kt8tK4UT6QR+rmZsdjI3403rV
8/QQF6et1pBuWqe6O+2dPzpjwKh3IUuDJs19m62QntQ7mCdm1+Ry6i3l0/Cx
+6IP+UD4i+bGAzsT9FkF68xXrN/qgBPia/Km2W/1lBpaF89jrnPJQIzv6tsf
BuC5IA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 14->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FOw0AMRC0+ENdA3AAOUHGFcoIiwVclpPKB+MvRaUVTvOM3XhqpTTa7
Ho9nJvevH9v3m4j4vDv+bXdfz4fD7vvl9rR42+2fHvenzYfzL2LZHP8253v8
Pq/ry7tIa3i/1lwuwFrXGXfRvhkv1Q97TV+HrWe1p+OS+S6GO/IHrrM6nTWv
F+Be/JDzC9Ub/9R7xJrpCPzRr6jnHI9cXzIJGS05VNwQ/V3WnCaAi/kQjboM
DRyNf9o7e0rz5TvWQ8/im+stfZxuThN6T2s6i5xNVruLsljyEGk/BPsfHlNP
p42bDXUJwAds7YN1Upu1+U+OW48Ej3oSN8sl70Fmr3nXZTJfbtZhLspH5i+8
O/3IC8xTx0f7GlyHr7WDVtKfeOAZ0UD5drMu0It8xZk676PuZfw2z1HfXZNN
zPWkL3ro/M7nlYd51l757vDLBdpQPqaZIlzjD/XQDOh94BB1TzHJ88yL+lFm
QnoqJvLXszDLsKc9ZZ8wZznX+Sye0T9j5hnCrfV8jDjEv+xRpsEv59N6Rx3z
s34TTpdGE33ucqr4zp+ZHopp9dBfSC/HNSqmfh+6pqyUmVzuARM1c72DudH8
rR4RI18zi9NWa0i3me6lJ6y7HgNHPQtZGjRpzttshWDCLG5OzK7RZ+ot5dPM
Y9+LPuSDaoaaGw9sT9BnEa4zX7FeeYafR+cofrmsmUzmGloXz8PoHFF8HbSB
DP6d+wHVzroc
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 15->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVklFKA0EQRBs/xGuIN9ADBK8QTxDBfAWE+CH+zdFNMBt6ql/1xoVkd2Z6
qqur6vH9c7u/i4ivh9Pfdvf9ejzuft7uz4uP3eHl+XA+fLr8Isbm9Le5vOPv
e1lf9yKtYX+5c30Aa1ln3KF9M166P501fR221mpPxyXzHYY78geua/d01rwe
wL34ITWD7hv/1HutvUlH4I9+BWMQj3y/ZBIyWnKouCH6u6w5TQAX8wFeuAxN
HFVz0zt7SvPlN96HnsU311v6ON2cJrRPa6olzqjbykNZLHmIdB6CfYPH1NNp
081WdAnAB2ztg/fkbtbmlhy3Hgke9SRulks+g8ziXnBdl8n8uFmnuSgfmb/w
7vQjLzBPHR/ta3Advt6dtJL+xANrRAPl2806oBd5jTN13kc9y/htnqPu/Seb
mOuVvuhh4/ekVeahWJCP6Q7h5xp4iDfO4jKl68Yf6qEZUL2nWUgrwaT7mSPV
UWaK7qBV4a+1hi+uo54T5lrOdT6L5/jHvI+6G4+Ur9OqnFGmwS/n0/JGHfO3
yWzRBTREvKg6O6x8TtidHopp9dBfSC/H1dUBX6cLzuRyD5iomXyrvqUvzNnq
ETHzNbM4bYt2YXRqdC89Yd31mDhqLWRp0qSpt9kKg5lrzZyYXaPPqreUTzOP
3Rd9yAfVDDU3HtieoM8QrtQjY+F95Rl+Hp2j+OWy1uRk4i/r4nkIL6gtGYj5
rVqMzS+cArqW
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 16->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktOA0EMRC0WiGsgbgAHGHGFcIIgkVUkpLBA7ProJCJB7vIrz4w0n552
2+Xnenz/3B3uIuLr4fzY7b9fT6f9z9v9ZfGxP748Hy+bT9c7Yiznx3J9x9/3
bZ3//a/z/3Q+0r+AXCVP1BpTvnR+2mvqutwaqzWdlqx3GO2oH7Q6Bq7XvB6g
vcxDYgadb2ZdNIAPWo6gH+cVPofVZbgNiJl8GDVmmpvzmmMCedEfMAvnoUmj
MB+qRVgQg+I/0E41y9xM31rHcXNM6D/2u4Wvyb12kReLHyLth+TeMGOq6dh0
vZEPrB+aOnhOzmY2W3zczkjyUU3SZrXkPfAs/guO6zyZL9fr1Bf5I+sX3R0/
mgX6qdOjdU1el1/PTqwyT+BHGlVTgN6u1wG1aNbYk5m99Ujja+Qj2qlv8mbp
wXhxYiE11uaNvQIv8gfmDZNP5qhs0B+qTfNRfudLqKEemN4xxyAryUnns0aK
I88U7sCq6E9XpxfXcJbqr/mcYjDfBv3Wo92M6FqaGOdpmJeb0+2NHPO38Wzh
Ih6x+WKOUZ9r/tIL8TJsdQ956B1Sy2l1caDXccGenO8hJ/Yv38qXtGmfLY+I
Wa/pxbEt7MJwariXmrDuakwaNZb4ZiZNvPVWmJw51vSJ3jV8yhzM3bJa6VP5
0ByUGTI3M7A1gc8QrVRDvU71XE+or/Gbet9xozO0LjMP0QWxxQMxv1XbWH4B
/zW7Eg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 17->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA1EQhBsX4jXEG+gBgleIJ4igq4AQF+Jujm6CSeiu/qozA/P3Xr+u
n67H96/t511EfD8cH9vdz+vhsPt9uz/9fOz2L8/70+bT+Y5YNsfH5vyO/+/L
f167/uf1dD7S2vWC3rmvYpR+6XzZG3Bdb61VTMcl810Md+QPXJ0HTmv+X4B7
m4fULHR+mHXjADkYfdQMuJxE2B6Wl/FtgRrNodaUubmsOU+gL+YDZuEyVDiK
54tyES/Ig5Y/4E6Y2Qdch/OTb84TWke9a/w1vW9dlMWWh0j7Ib1XzJgwnTeT
NsqBzcOAg+fkbPZmTY7HGUk/wiRulkveg8ziWnDdlMl8Oa1FF+Uj8xfek380
C8yTzijgO7pG4oXzCtDsvIastDrxQPlOWhV7Ufy8HuAlzN5mZMg1+iPcSTdl
s2kwWSxeCMateTv91EvzgX3D9NO5B/NGLUNe0J/o8yGM4p++o9ao78SbzhMX
5BadZ9bnfG98ovMNxSBM4OqwXM6pBvut4G8zOs2Irs1Q47yFebk5Xd7oY/42
mW2+SEZsv6g1mnPt37SQX8Zb3UM/9A7BknXVRh4pX+cLajK5b/UwF8UsawM3
1w/9iKh8A3oN3jbvQKPFh/OUk1sYhaPWQpaKHqi/ma3gnqXW6MT+xh+bEblH
rwad2kOxs5bMEz03M7CY4I/OhDBoTornNCG/IW+afecbeaQ9ml7h4/LYMgB+
1Pcfyj68Eg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 18->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkFOA1EMQyMWiGsgbgAHqLhCOUGR6KoSUlkgdnN0WlGqxHnOdKTp9P+f
bzuOH98/t/u7iPh6OP1sd9+vx+Pu5+3+vPjYHV6eD+fDp8sbsWxOP5vLN/7+
/6/z3nWd99P9SHvXB7AzrnIUvHS/nAmv7hG2alRO1CI+LEY76getzgPXq2og
/EXP4aydm1k3DZCDxWhp2lOf2QM9Vwyry/i2QI3mUGvK3FzWnCeES/mAWbgM
KZbiNR/CcA6+qnbizD7gPtxf8408Ia+wX+MbZll9XHlKFhUHvG7YN8yYOHXe
t/RGOXB5mHjwntzN3tyS43FGgkecpM1qyWeQWdwLrpsymR/Xa+lryB7pnvyj
WRStyT/Kfgif9ki6cF4BPTuvISutTjxQvU5Lq1Mu3Q/wEmZvMzLkGv0R7dQ3
ZbP1YLJYvBCOtXm7/glL84G4YfB07sG6sZchL5M/DVPWxT/9Rq1R30l3uz9k
hbDa3BQje6D61VeabZg13C38wuVyTjXOkzX9NqPTjOjZ+Bqat3JMPecMIrbw
UGabL5IRixe1RnOu+K0X8st4q2foh74hXE4r1QVwDb5gTyb3rR7mopxlb9Dm
8NCPiKo3AGvwtnkHPa753vyD9cRRNGotZKn0A/Wr2QrGLLWmT8Q3/tiMyDt6
NfSpGMqde1H9zXMzA8sJ/uhMiIPmpHyuJ9Q35E2z73zTO4TR+hU9Lo8tA+BH
/f4CK26+EA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 19->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0FOA1EMQyMWiGsgbgAHGHGFcoIiwaoSUlkgdnN0WtGixHnOMNK0/f/n
O7bj3r9+7N5vIuLz7vSx2389H4/775fb8+Jtf3h6PJwPHy5vxLqcPpbLd/z+
vq7z3irv9bnej7QXgKU417ulL+0t9Uz76h5hK0ftOfX92zfciT9xdR6oV7Re
N/ZJ3zrU0awbh0Ez+ggZwJykc8WwvIxvmsXGIXpNmZvx1XpCuEvFdLNoNWF8
BaxVemNP8aDxl6dx1TkY3fn+lm/kCXmFvhjflJvmsXnluFPWSC9h/2PGrsbV
O22UA5eHqQ/mKPp+qf2HRquDvJaebeYxcMlnkFncC66bMpkfp7XoGrJHvCf/
aBaFa/IvZL/9jq6ReDXeJoPWa8hKqxMPlK/lknGSf5ZDgJcwe5sRMxfnnXIn
3ZRNp2HqG9Jja95OP2FpPhA3DJ7OPZg3aqG86NpoUs/zuvin31Fr1Hfi3e4P
WSGsNjfFyJqVv/pKsw2zhrulv/RyOaca58kWf5vRaUb0LL6G5q09Js0544gt
feg/0XyRjFi8qDXkWcZ38ymP8VbP0A99Hafg++RR6TX4QvsBdYRJc9GeZW/g
5vDQj4jKNwBr8LZ5BxoJi3KqGHY+ep77ai1kqeiB+s1sBWOWWqMT8c18bEbk
Hb0adCqG9s5alH/z3MzA9gR/dCbUg+ak/Zwm5DfkTbPvfNM7RYfJr2pzeRxz
vnRu6/ID22DARw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 20->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk1KA1EQhBsX4jXEG+gBBq8QTxBBVwEhLsTdO7oJJtKv+quecWCi8366
q76u+9eP3ftNRHzenX52+6/n43H//XJ7/njbH54eD+fNh8sbMZbTz3L5G7//
X7/z2pD3+pT71xpSS+tc7059aW2Z97q+rvZwdczd3Pdv3Wgn/aTVMVBW9D1W
1snfaM7RrIuGxjNyzBqTz8xA97WG1WW4aRaLhqhnHDPybb0JiyEvzaKckdo6
L60/Pa4esQPtql854DrcX+NGTIiV+nBcSbPmsbDKXFS78iK/rvbKjJWf+tvq
jXLg8tD1wRxFXZ/ObvBofUg96llmHo2WvAeZxbXgc10m8+O8Fi3h75Mnx49m
MWlN/Cj7If3UI+myuSZWsE9ZKecMrxBNxFDnN6C/ZqRk2DAjTy7XxE61k2/K
pvPQ9Q3psTZv559qaT6wbph6Ovdg3eiF8qLfxpMyz98TP5OHvN9pLHWUmTlH
mfkP96Inqt7QHtRT9qf+0svlnM44Jmv6bUaBB9X4e3SOndesz/jJnnPGsbb0
yeeLD8qYmZOynfwZTm4+02PY6h7y0NdpCr5PjKZeDRdaDzhHNWku2nNa26IN
Zlp8Rsx6o/bs2BZ2dB9qUU61hp2P7ue+etZodvPblK1InuBRjdOjM42qbzUj
wHZTlhsuljvkGZmbGdiewEdngj2UH/RznlBfkzeaB3HTO5Muk1/SSGfbnAOL
sfwACHK9RQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 21->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk1Ow0AMhS0WiGsgbgAHiLhCOUGR6KoSUlkgdjk6rWgq+/l7kzBS0mbG
Y7+/x/fP3eEuIr4ezq/d/vv1dNr/vN1fPj72x5fn4+Xw6fpEzNP5NV1/4+//
8p33ZnmW1e4vPWLcZ7lb5tLeVM9Gc13v2fUxd/Pc277BTvgJq9MgYCZhyFh1
n/jNcH/kdcMw4Iw6Akbyq3CIrgviMrppFhuG6DVOM+JtuYkWszzkRauR3uqX
9i/L9SPtALviVx1wH+6v6UaakFbKw+lKmDWPTausi2JXvYiv673iseqn/LZy
oxy4PIzmYI6i75faDRwtD+lHM5vnMcCSzyCzuBdcN8pkXo5rwxL+PnFy+pEX
BWvSj7IfMk85Ei7rF3Auempvg1ExEV6HpdXpLODXtATvbUYGuSbtFDvxpmw6
DpSHrGeeQVkk7xoO6KX5QM828FKNCGuZT3nRb8NJNVc9KAd5ZtHY+Ix9VDNT
R5n5j+5Ns+h4Q2fQTDkv84mn3NdzzVrLyAp+m1HQg3rclvo44prxGT6Zc844
9pY5ub7xoIwZn1SLws/o5Pwpy2irZ+0+zLWYgvUkjcqsgS60H1BHPckXnVn2
tmADTxvPiIo3+sy817CqdnQfelFOtYf1Z3Deag1m55/LlmpqsxsdY1nqaXR8
qxkBbTdlGXiGYGm9IM8tF8BddSAfrMZpVukpuMnDVqdzKNPEW+cPfNA7rS7h
W/Nca1sGhKdim6dflfC8xQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 22->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydk01KA0EQhQsX4jXEG+gBBq8QTzCCrgJCXIi7OboJZqDq1fd6RhsmyVR3
V72/3L9+HN5vIuLz7vxxmL+eT6f5++X28vI2H58ej5fNh+sTsUznj+n6Hb+/
1/dcW+TJ9XI/9Rj1WWeXuVSb6t66aK7rvbg+5i7iN9gJP2F1GgTMJAwZq9aJ
3wL3R143DAPOqCNgJL8Kh+i6IC6j2wJnyozoZ5xmxNtyEy0WeciLdkZ6q1/a
vyzXj7QD7IpfdcA63N/SjTQhrZSH05Uwax6bVlkXxa56EV/Xe8Nj1U/57eVG
OXB5GM3BHEWvl7M7OFoe0o9mNs9jgCXvQWaxFnxulMm8HNeGJfx94uT0Iy8K
1qQfZT9knnIkXNYv4Fz01N4Go2Jq78RV6tk/zABkXvUhzVrfQa5JO8VOvCmb
qjHpTZ7nGTaL5EveMzo2jwd9VbuC08wa+kp9Bvq0nqBH0RA46j75rH1QM3OO
MvMX3YeaQT7wHe6W+cRT7ut+ydw/8KMnWx7RmvwZiw38cj6t39hb5rT/Avhc
cmF8Ui0KP6OT86cso63utfsw12IK1pM0KrMGulA94Bz1JF90ZqlFrzds4Gnj
GVHxRu+Zaw2r007etRflNNfJ3z37ysFhdv65bKmmNrvRMZalnkXHRzi2tN2V
ZeAZgqX1MrksWIG76kA+WI2TVqUnZL15mjEDP9IZeet88CDMnXZutAdYFE/x
UngqtmX6AfAhuYQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 23->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydk01OAkEQhSsujNcw3kAPQLwCngATWZGY4MK4m6MLkZGqV9/rGZ0Ehu6u
rnp/3L++b/c3EfFxd/ra7j6fj8fd18vtefG2Ozw9Hs6HD5dPxLQ5fW0u7/j5
Pa9/9+K6nqR2vh+pVnto/bzWszZXeiueAIz5TpujfYCfzs13Cbv2mgxWp0HA
TMLg9CUPJtnTOtK8YRhwRh0BI3qT19F1QVxGN81owxC9xmlGvC0W0WKSD3nR
agLmQT+ajTNFgzZDnoZVfSBP5f5IN6cJ7SsPpyth1jw2rbIuil31Ir6u94LH
qp/yW8uNfHZ5GM3BHEXfL7UrOFoe0o9mEieLRWsks5TjcpZ+UyZJH8e14Bxk
z3Fy+rnMNA3Vo4DfARwBl/XL3G1aQ1ZandFLtbIaprulD2BseQfvKSN6Z5jn
6HuIi/QK1lizSZ7nGTaL5Es+Mzo2jwd9VbuC08wa+kp9Btq0nqBH0RA46jn5
rH1QM1NHmfmL7kPNIB+4hrtlPvGU+3peMvcP/OjJkkf0bHyNxQZ+OZ/mN/aW
Oe2/ANnU/C72U35GJ+dPebJnxNXdh7kWU7CepFGZNdCF9gPqqCf5ojPLXvT9
hg18bjyT3oSxeEFYnXay1l6U07xP/q45Vw4Os/PPZUs1tdmNjrE86ll0fIRj
SdtVWTY8M5bWy+SyYAXuqgP5YDVOWpWekPXmqerptI7Oo/kFflDfgoPqYnAG
WBSPzphg1vX9DSVWvAI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 24->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA0EQhQsX4jXEG+gBgleIJ4igq4AQF+Kuj26CGa1+9b2aCSSZ6a6f
93f/+rF/v4mIz7vzz/7w9Xw6Hb5fbi8vb4fj0+Pxcvlw/UaM3flnd/2P3+fl
/e8s/t+H1C79kWp1htYv73pX9spsxROAMfeUPTBH+ene3EvYddYwWJ0GqlkY
DE5f8mDImdaR5gVDw7noaDKA3jidOlykG+moGKLWOM2It8UiWgz5khelJmAf
zKPduFM0KDvkU7CqD+Sp9BMHzQplkfhpL9USZs1j0SrrothVL+LrZq94rPp1
2nTcyGeXh24P5ijq+VS7gaPlIfNoJ3GyWLRGMks5nu7SM2WS9HFcFWeu1TPi
5PRzmSkamuyH7CscAZf1y/QWrSErpS5rsKIfaph6pzmAseQdvKeMaE+b56hn
iIv0CtZYs0me5x2YRedLvjM6Fo+buardhNPt6nylOY02yp/0mDRUjpBb8lnn
uH6qo8ygzkZ3nTFp5nbQTrmfOBBPqKeaMm8jfvTE6KMed1q1XHP/Rp8IT549
PStGwq2ZVFw6T/mZLDt/CmbalTC02LZgCtaTNNJz2j3WMGVuyt/4ku8xA929
8bnwjJjxRp2ZzwpWpx1o5nQv+sG79rl75eAwO/+KNzTPcFAcWKOeRcVHONa0
3ZRlwzNjsdjSc8kFcFcdyAercdKq208elr6GD2Vy6H6HHzRcekp9NHe0Q/Do
jgG7/v9/ABnmuAA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 25->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktOA0EMRC0WiGsgbgAHiLhCOMEgkVUkpLBA7ProJCIzuMuvurPIpD9u
u+rZj++f+8NdRHw9nD/75fv1dFp+3u4vm4/l+PJ8vFw+XX8RbXf+7K7/8bde
99tZ/O+bxK7vI8VqDo1f93pX6kpu1ROgMb8pdSCP+tO6+S1p11zNaHUMlFkY
DY4v9aDJmcYR86xN76YczQxgbxynkS7iRhxVQ9QYx6zzMNMiLJr8qBclJqAe
5KPaWFMYIFejXzngObwnDzorrmeO35bbcFNtOo9WO8xe4UV+KXf0seTF9ZTY
jLwRx+JxcDeco6jnpN1pHvZI8lFN13PUEsZj7oWeBccpa8fHec1aNFbPNHbE
T+ev3CV+IedlHeARdNl+mbeFtdGu/dhyTPghw/S2ywMay7xD72lG9M1wnqOe
oS7iFcxYZ5N6nmvgLI76MuFYejzIq+w6nXpmdLiZLntgo/5XrToDWhc9T/KV
eYL3FEczg5wNd82x5RnVoJpy33kgnxBPMSVf9HdOP/bE8Gmqd8Bq6DW/v7FP
pCfn7taqkXSrd9Wl+dSfmWXXn6JZaum6qwPMppqCeRIjPScubaYpe1P/pi/5
HmdgdG/6XHxG9Hqj5sxnRatj55gB98IP9vrO3asHp1n7pKwx98SD6sAY7VlU
faRjxvamWTY+sxarLa3LXIB35UB9sIwTK8dFdXS1oR75oZlsWt/pB4brmxIf
gzuqIXq0Rpmv7v8XGQ26tQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 26->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklFKA0EQRBs/xGuIN9ADLF4hnmAF/QoI8UP826ObYHbtqX7Va8CYmenp
qXpd968fh/ebiPi8O38d5q/n02n+frm9LN7m49Pj8XL4cP2LWKbz13T9H7+/
1/W2F3/rbT/fk1rtkXvntZ6Vd9M7m9akR9/NuoLegT7qT9/Nd0m79lqMVsdA
mYXREFOtXfSc/EIdMc/a9GyXo2rXXlE9FE6dLuJGHFVD1BrHbPCg52bOmgvl
nutKTfj3tBdpxX7EjrIWoFXraaYhNeBBs+Jm5vitd6mWNGserXbIXuFFfql3
jLXkxWoDNp034lg8NmdFj3w0Py5zTqv1If2UaTdz1BLGY+o57MGciEn2qnyc
16yl80m1HT/1VM7Eq+areDbeKIfFB2RLexcdzTyWrC12WMt+9jX0AY0l7zB7
yojeafMcdQ91Ea9gxppNmnl+A7PYzWWHY5lx01fZDTp1z+hwmcY+wkb9r1ox
15Rj4OP6lTzBfaqjzCBnw117bH0MP1zD3cED+YR6qnFM9vTjTAyf0qNhNXxc
ps3cBs/5nW4GIV7oDfMu+Sj91J/JsptP0Zy16G99J6TmP5qCeRIj3Scui9ap
JmFW6sFrPscMdOdmzsjOZKZkjbQ6do5ZVO6FH6z1njtv9dI56Le9dzyoDqzR
mUXVRzqUJa13s2x8Zi1WW/qtsyTvyoHmYBknVo6L6hjehvfID2Vy0fedfppF
iC7w07EgNmX+wrUy+QH69Lm1
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 27->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktOA0EMRC0WiGsgbgAHGHGFcIIgwSoSUlggdn10EpEM7vIrDyPl02O3
XfXs+9eP3ftNRHzenb52+6/n43H//XJ7PrztD0+Ph3Pw4fKJGMvpa7n8xu//
63l9F3/nIbnufjT517PGSt9Ua9Wa9ARo1P5TH6ij/pwHp11rDaPVMVgf8Vp8
LDV3aJz8Qh4xz9o0tslRtWutqB4Kp04XcSOOqiFqzjQ3w7swNXPWvaC6Guv2
TJm7+WJPYYBcjX6qjTMNyQEPuisdf+J3zSGPpFn30WqH3Su8yC/VjjmXvFht
wKDzRhyLxyZW9MhD8yEeTqv1IfWUaTdz1BLGY6o5vYM5EZPsVfk4r1lL55Ny
O37qqcTEq+5X57Nw1frqA3Yr1y7xjXmMrC02WMv77GuqAxqLZ2BCO6J32n2O
+g51Ea9gxjozmnnugbvYzWWDY5lxU1fZlYd6OW10R9+ZfXYzKAzVI/Bx9co+
wX3Ko52Z/m9w1xrrXcMPz3B36k8+IZ9yHJMt/TgT2svgGuuzNDmOrZnb5DnV
LjVi1jt5oR6mb9l7rQ27HAvUijob4kUzUh1Tn5Ac0Y2agnkSI31PXIbmqSZh
VvLBa47jDnRxM2dkZ3am7Bppdewcs6jcCz846z0XV37d/rh9srU7D6Cj7EJE
nVnWJveGajEz/k9O5zNrsdoMV5qjMnO7YxlnpoZLmW8Yno0f2kmaKeonzmH8
RhOjHqJHewzJmZn8AJ4pu3Q=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 28->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklFOA0EMQy0+ENdA3AAOsOIK5QSLRL8qIZUPxN8cnVa0S+LYmVZquzuT
ydgvfnz/3O3vAHw9nH526/fr8bj+vN2fXz7Ww8vz4bz5dPkCYzn9LJd//D1f
37c1/L8PqnXn0dRf33mv3Bt6bVqDHgiNfH+6R5xhf86D0869htEqGQRv7BWq
Hrl20D9Im6tTzAubxnOZB2sHCudB+4WT00X9XJaSjvDpcmz5z7QQi7H4vrzX
5YyZu/nKO4mB5Gr0q95ypqAaaN3KN9/r+MWelp3i1nlCfra8jNfSO5zjPTk3
9Gw6b4pj8djsFT0w+8jnOXNOq/VB/Zip6oNOC4zHOCeeD8SaYK3uZs/MStWy
T1Xb8WNPZY+8cr46n4Ur92cfIluxd9mfzCNlDxPWtB59qQxzRuQ8BbPSt8l1
0oO6JnUpXtCMeWZq5vEO6bOby4RjYQXfl9nJGsFWagsMk1/jh+cTz3MG+F7p
edKv46yy4nqV5wl37pEY3cDPnU33K5+iXtXY7E30y5moXEL32D5LU+PYmrkl
z6F36YGsN3mh98KFvZMPd36WZTefojlq4WfQHaAa4ZP1pHXVk5jKLIuzVhMx
c5zimbhfMiDW1X7hotiZzJSs3ahVceIcqpzGdZWPW/Z5bl1+XJ7a3s4D1xqf
ZWZRWzjHOpileu9qOp9Ri9UG2FnGj2LmstPOb8KlzBeGp8gy94ta2jrT1+ZO
+OlYKDZltsizqkx+AU/cwOo=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 29->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1OXEEMhEtZRFwD5QbhAE+5AjnBRAorJCRYROz66AEFiLtcnx8jzcx7
bXe5fnz96+H27oukp6uXn9vLnx+Pj5fnn19fX35f7m++378Wv719pXW8/Bxv
//r3/P7+cab/78t66b6G/vd3r7W5BeuDa+GjwNHnb3PCHddHGoi7Yy3gGj0o
2lyrUr/23gVYUe+QVfRm0NzycO5S83lZvflEvAyPdmnjUT7THqP/Z1zMi3Uw
rtemPaNcE9eIB3ydu/NP2DFTWY8y76Tb55J/FRO9S75NmrQ/n/nlWht2uee1
mJtmbyZtycemcag1PoK69vuul7iiDsNzTxOO5+BnUWPNyfNROAtep9mu2b2i
Xj/z3sk/19RqppX2a8zeeGFeYbcqdquf5LFxE/sXPSx34w4cXRPxdrwNd9jr
5J1zT7qbX4G766DM64yoc8oFfMSMxbitlnqCt5Fb8XDTC3pazurvzUPwaQG2
Y5DPaVcIqz2f+O4Ym0ef8I/uem5NZ+gnP+PunfCPmaS9lGGEvUp3am/zFnJz
z9aAHTM4oAZz5bwIW+x9qifPXY/Sc9UKnqV88VzQV+ZMPtZz5GSe4Y6avmUz
ictn+EU/pH2ucfSzxhV4Iafgez2Le6R+j+qeG+2P5+ReI/agYeulHs+sciv3
nId7md6nnkln5YLcJMwyaW9YYXfG/E58afkK/Ay77HiVy9gHuLh3g/ekLfHx
GW2/tv+/Ix7CKQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 30->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkFOQ0EMQy0WiGsgbgAHGHGFcoKPRFeVkMoCsZujQwUqiWNnfqXf9k8y
if2S+9f3w/EGwMfdz9dh+3w+n7evl9vLy9t2eno8XYIPfw8wB9Ivxu8zhz+L
5zPErrno82PPPX1hNKa++NfCsTlyLN6Jd1u/TvuodZJW6HtJq/CqOF4/Rh+U
NqFf+Sxsdnh2c4q6Exd+pxrpTHjudinpCB/OsfzJh2Sk6hJXN4uSo/o1e8e7
IesZvayd9avacqagHGjdyjf3dfxiTctOces8If9f8WKvpXa4xzE5N/RsOm+K
Y/HYxIoemDjyffbrtFofVI+Zqjo8Bz6THuOceD4QZ4K1rAfvNWrhXD7j3I7f
UitqTO1XO3vSZefFD/Uuu7eYR9IGz08yDHflDozqiT0rZqVus9dJD+oZsy/7
xyzMU/Yh6I89pM9uLoYj84tcXN0SUzmCrdQWGCa/qPmRs5oLx9zuKD6uXsdZ
7YqrVf4vuHONxGgHP3eX51Z8inzHU+7eQj/vgp0RqIbYK3VHaqP7qznNprac
wTAx0xesy9WGYN/EFXP2w/OLOniHMMQDrSedw+SFPh3HeG41ETPHif1N6um0
7NEneQC5L2nks8Ld6LKaBPd4JvcI9Z6L89zc/vCcmLWt3XhIuS6HZxa1hXus
g1mq9y6n8xm1WG2AnaXyXmrxI/jwTDouZb4wPMUuc72opc0TNSfrUH6Dvo6F
YqN6lP1Kv99LUcIr
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 31->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkFuFUEMREtZIK4RcQM4wIgrhBN8JLKKhBQWKLs+eohAwf1c5ZnFh0y3
2656rvvvPx8e7yT9+vjnn4fb76/Pz7eXbx/ePn7cnr58fnq7/PTvJ61D2/86
/v7Wkc/q+Sp377Wa69eFGfVMQeM2V//78q7O5Jv6dmNB/UevWUXbpkFdF99t
Wk+8LmoO+uS0Gf2OeWNzwXPaU9W9ceG38VlruaeYJXCJb5SZ0Ydl5PqCa9pF
q3HzhtwxK7Zf0Evt1O96250KNfK6nW/OTfxqz8jOcZs8af/7jBe9tt7lHe/s
3jSzSftOuWkeh7vWV+Fe+3v6nbQmnZseMJ08Oy3v3/RY98T9yJyZHNl+yl6r
FtbyjLUTv1Ot6ncuX+PuoYvvXLYi54kfzjZtyvxcfkV96rXufBk97Effbi+J
HbU7345jZOzyUPRzT83ntJfAkfwql9SX/m3NSabor/lVr6+c3V54l7Lj+KR+
E2eXlaSt/X3CnT02Rhf4pbfbfOezajk8B6vfsHYamIW4I/VaznBvNi1Gr9sb
ma2LvRdmtP04Lcx58BuzPNw75vTTeBQdzFDS7fRs5wp1ZY7NsslW1ARmiRM5
LMxMWq7oszwkO7dlyfVP3idNhns9szmCrjaT98o6ba0663F28LDVphrurGor
76iDLN33VDP5rFrSd9XJXTrvrRd/hg93MnFp+1XgmbKs7qPti3UhfzF3A3vq
ctzt/tVrdiav6nHCJw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 32->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktuVFEMREsZILYRsQNYwBNbCCtoJDKKhBQGKLO39BCBgl0+5e7BS/re
60/Vse+//3x4vJP06+OfPw+X31+fny8v3z68HX5cnr58fnp7/PTvk85D7b+O
v9959LvTvnovu6Mcv6Me6U6gcfTV/zvZW+3pOTW3sXD9x4w5i7amQVOX5zWt
N3htmoM+kTbQT8wHmxs8pzlV3Y2Ln8FnjfU5xV0yLjFHmZn7QEZU17imWYwY
6rfsne8K1gt6Xbvrp9o4U1mMWDf59r6JX60Z2RG3zZP672u83OuoXfL8Deem
nU2ad9qb4XF5G3UV3tXz3e+mNelseozp5pm0vJ/dY52Tz0dwB3uE9ZS9Vi0e
63ceu/G7qlXzjfZrnb3p8jzarch542d3TZsyP9pfuT7NWLo/QY/Xc980l8TO
tZPv4UULY9qHot/nNHxucwkcXVvlkuq6f4y5slPub/g1bT4Lmou/pd1xfjpy
vY1z6pd2hpgm7l6jMbqBX2Ou4IF8Vi3EPukH1l5v1Nlm5B5gryinaQG9aZ/e
+6l72moT47QrqEn99+AiZpbeaWfcz+BRdPgOJeakp90rxJU+uAOwW2kvnVni
5BxO65m03KIPeRROpJHYjtxt5pBDc3d2xJLq47uyTozVZL32Dh5abIrxmVVt
Jc91OEs6bzGbz6olnatOnyV5H7X8Az40E4ofdb039Bu7rOljzMvjwv7FvUt+
QZd78tkTc2JxHq+1cMij
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 33->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkFOA0EMBC0OiG8gfgAPWPGF8IIgwSkSUjggbvt0iIBgt6udPWyyOzP2
tKv79vlt93oVEe833z+7/cfj8bj/fLo+fbzsDw/3h9Pm3e8TsS5R/mP5ef97
aE3XQ9a29AnYC+q1/Pcc743/Ne2T79SaXFtYqP6ln1mTtqIhui6tK1plJpq1
aDb6grSBfuRr2E8zO5/KPJmLfrsewFA5TlxsTXhmqoE4YF/h6rxoZ+i+IXeU
ldbP6FXtqt/lkPJdzgTrprn1Xscv97TsiBvM1LgQD+Ov1q1yF3kcS39vZ4CB
89vlpvk27LW+Yfaj1uu8k1ans+gRptPMpOX8rTNmn9SfgDXIkevnZs1aslZa
07MTv4tao+9RvkbvRZfWUbaIS8veBT+KtoGf7Z3vjn6W1lfQo/10JvLFsVPt
NHebJQbGlIekX31qc06+GI6qLXNxfXV+PHMhUzpfm1e0qRfki+657Ci/WHy/
ibO7z2WGmDru2qMw2sCvMA8zA82ZtRD7DfqJAWbbeSSaXa5KjeGkel2eznVR
GWlvzLBmErKCM0R9b1yCmbl9yozO03ikM5ohx5z0lHXqSdkwHMmnpkmYOU7K
YZU7nZYt+pBH4kQaiW2rnTyHGvJd2RFL6o/7AfvGB73f+ahMXXbPZ90Z9Sxr
g9kpJ+57OjPNmbW476xTvaTZWy99gA954rhor3I33NeyHH2O5peeM/mj3I3z
gi5lZf2PWtPrvgBfzMri
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 34->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktuFEEQBVMsLF8DcQNzgBZXGJ9gkPDKEtJ4gdj10bEFjKoi41X3ome6
q/LzMl5+/v7z8vKpqt4e338u11/fbrfr7+eHj48f19evT68fl1/+PVX7VtN/
bX/f/z92xvPxv07W4fv4jPFjzdi3hnupwz5jzpjLvvsW9LIm6kxay/MSL9Zh
37u+RS2dN/hxxH41c/IpziPzRS1gOPVfcVnlVGZGDcZB64Jr8qLFWL/F3h3V
5Ay6S0G/7mHY7ykmcDCN7Jv43fUGbtTMfSTHiYvxCP4yb0cv86O2/t5ihEGa
MfncfFvcNT0V7hf+JM1Lj0bWZBvq0Aee6YyjT/Sn5Ez2KNVLs45ayI1njF3x
O9Ra/c72a+k9dDHPdsu4FHof+TFpq8zP9reor3qsne+ih/U4k/mS2FG7zd1m
IS+ZN3meemrv5CVrJVaLupxfYw52ivO1eaGNXpgvvEu7U7wPPrNOYmZxtjPG
NHFnjYnRCX4T8woz2JyjFmN/Qr8x0N1OHtHjsFdTTuBEvWmf7nnlZ+TS9hp6
6XPLI7MSLuXM0r3tzDSD8RhiuEOJufpSzpOMpt0IHM2npgnMEidy2NEzaTmj
T3kMnEyjsW25K88lx3wnO2Np9fW+5D74wP7JRzJNu3uPTTH0bNQms9uepO9V
zGrOUUv6HnXSS5u91eIjfMyTxIW1pt7Sr+1y9TmaX4wL+2d7t5xXdJFV9L/m
nJ73B7oHzGY=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 35->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklFqW0EMRUU/QrZRuoN0AaZbSFbgQPJlKCQfpX9eehPaGs3RuWMbnt+b
GY2ke66+Pv98fP1SVe/3H3+Px18/3t6Ov5/uPhcvx9P3h9Pn4bd/T9X5UMu7
Dn+//z+2x/3+rhvz8Lvf7fFpf6lb7bw9XdtZ9vuPfY7+oWXJiTxLr+X3Ei/m
YV3rmX2o3uAHn8TANCefoh7RF3spMNrNUiGHMIrM7H7gcFmDxfmQ8/Is8adf
zH8tJznrLBkX6OK8kOcSEzhYj6yb+FGDajVu1GSzYTxsjmrGKq8dg9SbMEga
k89kQD+4P2bCzjf+pJ63HnV+ZBvy0DPuDY3I2T0xn4xJ4ftaj+yF3LjH2B2/
q73WPLP52nqPvnjPZsu4FGpb3IgpWQcuppGzMDysrDnlo6Y018aOvZvuoYW8
gl7zPNXU2slLyaWsJJ/6WZvYnnvna4neWmPpqfnCszQ7zLmsa+YY8xR64ews
2vidZpT5Cndv5Lcwr6DBdPZeDvP8lv6NAXOpDqwZy7la7gRONstJc/eTe+Qy
5hr9kpPe6zpKuJQzS+c2M4uGwKNYQ7T2XtWXcp5kNGolbVfmkswSJ3I4hxpW
O/kcdYun7NHYjrs7z+WO+U52xtLy63nJefCB9ZOPZJpm9xKbYuhZ702025xw
bxdjum2Wes+27n3SS9M+cvERPuZJ4sJcS+1Q6/ITbeb5iAvzZ3O31Yscxir6
X+udee8PtXnOZA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 36->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkFOw0AQBFscEN9A/AAeEPGF8IIgwSkSUjggbn46RBCY7aleO5Jjr3c8
O13dt89v+9crSe8333/7w8fj6XT4fLo+L14Ox4f743nz7veSlp2Gu3Y/z5eL
3vn7etfGPv5cv6316f1wrsp+uaq2Bd7Xn89JmpfU0/oMs4q/S7y8j+xcmtnn
QL3EzNlPGJDm5FPUY/uuH/222aZcgh/kReNvMxCHv7WxaPnY9bqUIffI+/le
6umcMUvExXRRXtovZIKyMuNP/FwDaiVuromyQTwoR+q1yGvGIM0GDJLGLblx
rcSnZYL2J/6kmaceVX7ONvRxz/xd02g9qyfkEzGRPa/N6LM4N3/ntTN+q7Oq
71G+pt7bXP4dZYu4yM6mulYjWAcupNGz0DxU1txml3rfSa6Jnc9OupsW5wV6
k+fpTDw7eQm9aE390E9Namvvma8CvRpr3VPyBXNNmiFrqR/mKczi2Rm0wXPi
TrkbGG3gNzBX0EA66yy7vp8Y1J7EALO9osNrZbW1b+Mkqwevk0/RL+jjjFNW
YvaDZzHLk33KzBYezRvQWmdFX8Q8ndGQDeJoDFETMEucnMMSzqCzk89R9+Rc
zyn21/gucfFviJGzI5beD/cvP983nQusZz4605TdOkfKQuMbevuF2ldqSDdl
qc5M6zqne0naWy/IW2Tsa8pE0NZ40pygjTxvdZDvYR5t1Gs9iNWa/97v//4F
D1DO6A==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 37->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA2EQRBsX4jXEG+gBBq8QTxBBVwEhLsTdHF2DGrurX3UmMJn5/vqr
flW3z2+716uIeL/5/tvtPx6Px/3n0/Vp8LI/PNwfTot3v0/EukR5x/Lz/ffQ
nM7nd2yso9/5bN7v5su9kdbTk3tbYT7/VCf1vLqaUqdoDT6nvNYFelFmRrPq
wH6JmbIfGFDPzqcyl/uhdaclhNGUJXNnq0HMjCbicB4Li5YPcx/yE2+0nq7Z
mtIvZkm4FE+Ea+h6/plMUFZIH/WnZ4lr4ws8G9OkmXiQRuVkeU0MnDZg4Hp0
PisD9UPnWyaMLueP0zx6lPkp2ws969nS21Az90U+EZOQb6exnIuqkzg2vbKP
+F3UGn0NfZy8F116bspWOU93g8a85zwfnh/lN1Qf3EnzegfV03mXa2Kn2qlv
4kiM1TPi6e7Eu42XVIvGVA/9jGFvrj35GtBv1L3qKfmCuTY6NGuuHubJaNEM
ld7g23Gn3BVGG/i5jJUeqM+sZenrjkGuSTyz5q19qEche0td5RSyH7wmz8v5
6LUxw6C31CIPxAfda7M8rFNmtvBQJtRr1oq+hJzXmpQN4igMsSdg5jhRj3QH
3e18tn2bjGom8hzmYfIczhAjZUcsqUZbT8zVX/JB73c+ai7QZ9HhstD4Gn/0
UdZTlpofQ59ZixtnncqBem+1IG+Tv2VMnpveGk/SCb2R520f5FtzsalfqUGs
Lvmv9f7fX2Hi0KU=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 38->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktOA0EMRC0WiGsgbgAHiLhCOEGQYBUJKSwQuzk6hE9kl195ZqROZuxu
d/m5bp/f9q9XEfF+8/2zP3w8nk6Hz6fr88fL4fhwfzwn7/5WxLKL8h+73/f/
RTGN5//YWEff89m838XLvZHyaeXeFoiXZ9fv1Z6xvtRqPKMyaLVgj+OoT2Ov
tSTfmCl7k0OOYeqExERryzstwbzRS+bOViOAv9FEXrh8Cwvrkei5xk9nCHs3
1ZR+W0ye5kHhSr7KnMgTC8RJH/WnZ4lr4ws8G9OkmXiQRuVkeU0MnDZg4Hp0
c1YGOg+NN08YXW4+TvM4o8xP2a70rGdLb0PN3BfNiZiEvOfH9Zq16F6N6d6J
36rW6Dmc4zR70aXnJm+V83Q3zV0ZrPAj/4bqgzsprndQPY07XxM71X6pCXNs
PjarcVDtUfcVLY4daFpcbeGCy/Vg+reeIr/kZ/AxzUVz6B2oqTy1RvOT0aIe
Kr3Bu3LHeiH5jfycx0oP1GfSpn5c9PzgG6rX+Kz0oTMK2VvqKqeQ/TBrmnk5
H702ehj0llqwr+jS3icvD3nyzBYeyoR6zVpxLiHntSZ5gzhOnsu6hJnjRHXV
i6TF6gMujgdp1FipH4FaScdC98udOU4sqUbLJ+Y6X5qD3u+8pb7AOYsO54XG
18ynecp4Z9pDfZOXsmb6zjqVA/XeaoHfpvmWb5q56a3xJJ3QG8286TQzoFzT
MO0FVmvzx/n9/H8BgMPRYA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 39->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktOw0AQRFssENdA3AAOYHGFcAIjwSoSUlggdnN0CJ+ou/rV2JYmsefT
U/W6bp/fDq9XEfF+8/1zWD8eT6f18+n6/PGyHh/uj+fFu78RMZYo/7H8vv8P
mtP5/B876+h7Ppv3u/lyb6T1NLK3AfPlWfq96llrjKStaIiuS7XoWeVEHPVp
7LWWrFOvddAacnR1QuZEa1t3WqJ6aByIi+uH1Gy5A02Uhcu3sHAZ0fuQn/YQ
9u6qKX7bnDwtg8KVcpU5USYGzJM+8qdniWvjCzwb06SZeJBG5WR5zRg4bcDA
eXR9VgauH6jHaZ/0x2me9ijzU7YbnvVs8R11T66ZfVGfiEnIe36cV9JAGaK9
M34zrS3Lk3y5XJIuPTfLVjlPd1PflcEGP72/1HU5B0+km+rpvMs1sVPtyu1y
B+XYjMZBtUfdV7Q4dqBJ89TyBfVaPzf8Klvb1wC/UfdqT6kvuobZgZrKU2u0
PBktmqHiDd6VO9YLWd/Jz2WseCCfcl7XkYHUJJ55714f2qOQvcoNPUIup56D
57KPph30kte8rzEL4BKic2OdMkN81IcyIa9ZK/YlmGfZG/Uu5DjLXNYlzByn
7MP1h7S4deJi7wWNOlf8G63EadD9cmeeJ5ZUo/U/vZd18TngG3sD685D0QEM
s64gbeCNcqJzsz3km7KSubdv8aUc8kP9alkzDKknjgtl1/FEH9F9uDy5bDs9
6He2F1ht9R/79/P/BSOn0eI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 40->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA0EUhAsX4jXEG+gBBq8QTxDBrAJCXIi7OboGTeyu91X3NEwy0z+v
q75X96/vu8ONpI+7n5/d/vP5dNp/vdyeP972x6fH43nx4e+R1kXdv5bf98uj
pc75XtneS720f13qu5+97Md52b02J1sjL2Us9V73sJqW9rvTAFpdi591Tmre
16C5sPdatk699ofWkGOqo/857I3CmZQDyGDkkvoRckmaE4fu21hgRuA+5Oc9
hL2baprfMmejZNC4Uq5aTpSJFeZJH/nzs8knZYJ64gxkGkgPDfJ5rTfpMWob
+BpxKXyIQ2BQMhF0pf7MPG7JYzcmnv0s5aKMloeEfSImsvd2JK+kgTJEe0f8
RlpLlgf5KnPE1bUIWMDZ63m6m/ruDCb8/P6ubso5eCLdVM/nU66JnWt3btc7
KMfhKRxcu98pY5tyHTimb6pX+hlY4l2jvgr8qt/rPaW+YK6DDu9Zqod5Clo8
Q503eKeelnqy9Y38UsY6D+TTzvs6MoAMFP2U7YkP3yvb69zQI+Ry6NnqeQ+2
sBT8t1qQmYCLmFlap8wQn8IqnXfmo76IeXZ71d9VMjDLXKvLmCVO7pX6Q1rS
euthxoM0+pzXIq3ECe+3O9t5Ykk1Sv+b927dfK7wPcqW5yJlF1m1w3vWagNv
lBOfG+0h35SVlnv5bvkCh+LdOJSsBYbUk8SFspt4og9VHylPKdtJD/ol3on7
hv7net/S6tTm
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 41->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktOHEEQRFNeIK5hcQN8AMQVhhMMklmNZAkWyLs+uhkJcNXLF9Vd0kDX
LyviZfx8/nN6+VFVb7cff07n98fX1/Pfp5vr5Pf58uv+ct28+/xVbQ/1///n
bxt+tsb1wtpXvel8zXX4zbtf53W98C7WCnuqmeOhv0sPG7SM80mDaKUW3iWn
Gr63oLmxZy3rUck7xmaPIzwWNMTe8HzSUrOHxsG4pH6EXJrmxGGag4VmRN6b
zkAbv1l/ryb9tjWMlkFwtVyNnCwT9Jb0GYfGZcXOuNGTZUN4mEZyirxW/Uja
Fr7s/l5u6DXVmHgEXdqfAx6P5HEaO55513LRxsijSvtU0NwyhLqRpWiwDNnZ
Fb+V1pblRb7amnGllhIWcvf7vr1tfSeDHX72flGfvGnrLSfUKb5Tru19ak+a
yXHls3Ggdplv8lbq5V4tckm90Lzyzlhb+GpexgEmyrD6XBmKDp1Xr9HyFLQw
O5M3+SZ3rVfYP8hvla9vD+YT97mfGEzeTL9le8cHzxbO2rvWp+k7+Rnq0Mc0
DrDUnMNX4e60vsryYt8yY3waq3Sf/Vn1pZznJjViBvYyRz8V9DMrOGO+jYft
G5f4rmjkmjJe9VzuJEbjurG0Guz/+D3tw+cm81W2mIuUXWU1DvZs1CbeLCdc
W50x35aVkXubj3yFQ/MODi1rgaH1JHGx7JJnqz36qO4j5SllO+lRv8Y7cT/Q
/1zvH2gF2GY=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 42->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklFqHDEQRJt8BF8j5AbJAQZfwTnBBuIvQ8D5CP6bo9sm2UV6/UqWYHdm
JHV1VXV9+fn74fFTVf25e/t7uPy9f36+vPz4/P7x6/L0/dvT++HX/7+q86jp
Wce/9+uvjr7H/cLeFW+6D2y+s/Z6X/cLfbFXOFPOXEfvSw0nuJyC1fwEtmFN
HEfd9AyreU8smw2w+TPv1UfRWPjW2Yz3+bR5SwajL+xBjBL/rT5kYeRrOTZc
y9CUEZkRsXYwqbftYbUMwlfL1eiTZYLaEj/zofmy8s58oybLhvhhHOlT9Gs1
j8Rtocvqd3Oz49lNY+Cl89nQuJPHae1wlNnwScxRl82pwLllCLhJq3GwDNnd
lX8rri3Li3y1PZsJuZR4IbWTHukz3QE/1hCz+SC5JXfiJc1NX83PqSblOcw/
8b71OHqt3rc8kDt7QnvrFzgxTy1fJbX0O3ipvcRfzcu44Il6GPxoHgoP/a6O
0fIUuDA7kzZ5t5k2vML5pn+rfN00mE7U8zx5MGkz/pbtRd+Rm2aYvhinkNel
ZtExrQ0vNefGZag1jiMmcezcMmP+NK9SPXO2mku5n6dgWAaobaXpo5y2rDBr
otv8sHPzJfYVjtxTj4OeVJM8GvfNS8Pg/Mf36Rw6T/leZYu5SNlVr8bFmY3c
RFvyNfJd5SDoHLnod+Bv5zavlrXgoc0k+WLZpZ8Ne9DAfqs8Wc80m6jX/E6+
b8w/470CA2rbKQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 43->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkkFKxFAQRBsX4jXEG+gBglcYTxBBVwPCuBB3OboOmtC/+lUngZnk/6T7
V72u+9eP0/tNRHze/f6d5q/ny2X+frm9Lt7m89Pj+fry4f8XsUwx3GP6e15/
kX60v8g9Ur/he+mtz1q7fr+3v+0Fa8haqGa7ptpfPSzSO68HDSFnTFWL1i7y
TUxjLWku7IkDMSa+ygb2iEH2GLJ2cxxqnRb1IYyQi5uH4wmaHQfVSzmmvpSh
MmfIp/bf66l+y55cJYPCh3KVOVEm1JvTRxwKl44dcVNPlA3gQRqVk+XVzcNp
a3xRfcerzGqH2ebR6ML5HPB4JI/DdUQjzEbv2jP7ojmFaC4Zkr7OK2mgDNG3
HT/V6pgW3Xq+ywno0rpBB9QOfuCc4RvRpzXas3CA3Kp27ec8F38RhbXeLZ+o
PEn3dsZUa/F7yoNq1zPFezlvh6Nbq3b1RXktNcKWOGc/g9+IwgQZGh6FIejA
ddQedDZp6bTRM82U+hVGB/h1+VrPRp9Sr++HeueT9FO2m3OzNspf4UKaTF5b
z3LXGRxhiTknLamWNOae2ofeo17gU1i5es1ZNxfgVbSnnpjlvcypnzD6NSua
NfBNPOj9wEV8uowOPWUPGRs/rsYxyvvEknro/PPz8F58LrDusqW5cNlFVvnS
mWVt4M1xtXq7HBifWQuujX56X+YlPMhn4QYclQtlN/PE3smDntflic50s9Hc
U03JgLl38/f9fgDae9ur
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 44->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklFKxEAQRBs/xGuIN9ADBK+wnmAF/VoQ1g/xz6Or6IaeqleTBDTZmema
19V1+/x2eL2qqvebn3+H48fj+Xz8fLr+/fFyPD3cn3437/7/qr6WGt61/H1f
/mrxtb6n72p6w1nR1m+tvZzfWl/Xihk6C9Wsz+L6qWfTbI/5KdqkNeiV7KmH
elfQMo/AZ1sDD4jd5tHPQ892b8kescCZmKXEoF5oHTAnHyJLygjMezgjbDOt
PZrar63JYxkUfyhX3SfKhPZGfNqjnu280TvwzXqibKgfwE0+Rb9m80hsG+dn
uUqe0zwiT2Dv/ZrXO5lneRyePYzlevpWzd4XzcnmrXOa5TSwKKuu6dmtmXfW
5Klx6/0pJ8CldQMH1FJfmpV1T/iUTTXNB8htupPWLSfKCX2nXNP9yq7c6x2L
1+J5yoOy653Su9234WP6rezaF+XVasRb8rn3M/RbZZ6gh8EP8xA48He5Bt1N
LDM2+qaZkp55tMO/Wb4ud2OfUq/7yYOhN+KnbE/u7WyUP/OlinuEvE57lrfO
YI+XmHNiabXE2DVVh/aRF/wxr1K95mw2F/DL2JsmZnkjc9ZPBX7KiuxrHflB
+4Mv0mfK6KApa+hx6CfVJI/6OnlJGrZP/rU10lJPkvZWD9Gr/ujMqmwOxKGa
kXeWg9BnZ4lswL+e197l27IWPKSZJF8ou515KxvEmvJiXobZRL7k98Z7Nv+s
9w1budvs
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 45->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkFOA1EMQyMWiGsgbgAHQFyhnKBIsKqEVBaIXY8OlcqQbz//GUZq/0zy
4ziOb1/ed29XVfVx8/O3238+HY/7r+fr88fr/vBwfzgn7y6/qtNj/Z2X36n9
KNZzelbDG+7WiKPvWvt7fy2+xIo5dC5U02sVP81smIIzcG1zqy4l3G0Xeh84
V8AyjUBni2kfiZEGepdmtr4lOeICd6KXEgfVQuuAs+lA36LFFp9YHjAIy/YX
MHVei8ljHhR9yFddpzTDms91RrtbHDc84Kh580bVuHPgTToN2B1vto/ELWkW
6v/jmzXNFv6BF9VvmXGLH4dnC8dyPD0V03ZbEAMfnbQWOKpPlAN5iO7O9FOu
SVPjrf2TT4CX1g08oJbmUq8sOeGn3BTTdADfpp4UN58oT5g7+Zr6K3fljT1m
98kPyl17yuym24qO6Xs5w1zkV6vp2KAv+qU/oglqGPQwDYEHfpdjUG/iMuNG
77RTwjONNug389dvb5xT6jWfNBhmI/7k7Unfzo38Z7pU8Yzg1+nMcuoOtmiJ
PicurZY4dkzFoTzyBX1Mq1SvPpvtBfQy7g0TvRz8pjOt+RS9Inmto/6UH3SR
OZNHh54SQ41p/qQZ6G7aw/fAYZYn/VqMsFSThL02Q9SqP6pPle2BeGzZOfLb
MGfnkr47T+1js8u7eS1oSDuh+8m7Xc81bxDX5BfqOfM7zrtyl87Z/jPeNyhQ
3q0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 46->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNktFNA0EQQ0d8INpAdAAFRLQQKggS+YqEFD4QfykdAiSatZ/37qRk73Z3
PLbH96/v2/1NVX3c/fxtd5/Px+Pu6+X2/PG2Ozw9Hs6HD/+/qtOmhrU2f+/9
dzm3fVgr3K/NiK3vWnvhsrR/3Svm0LlQTa9V/KTZMAVn4No8VV9KuA+1dB84
V8Ayj8Bn26M+wN3m0bGgzvqWnBEXuKMzMl/SPJKfwNl8oG/xYk1O7BzOCMvm
FzBVr/qkj2VQ74d8KyZxT9pK7tHdq4aZdzqnMFvLhq7Am3wadHa82TwCt+jZ
iiykeppH5BO4d73m9YLGNXkcnjUcy/F0Vcyuy+bc3jVHJ60FjpoT5UAZorsz
/5Rr8tR4a/+UE+CldQMPqCVdmhXaI26KaT5AblNP2o9YkBGtQe/D/BPvWQ+8
T3koqdeeoh21TnxM39c16NJ5Yo3oJp+7nkFvlXmC8w9+mIfAA7/LMag3cZlx
o3eaKeGZRyv8m+VLMamfZpU0Jv7kJ2Z70rdzo/yZLwUaNa9Bk+KkOQ6Y2kf4
Ws6JS6sljh1Tcegc+YI/5lWq15zN5gJ+GfeGiVkOeaPMqmfJJ9VC80n96Xzw
RXSmjA49ZQ89Jv3JM/DdvIfvgcPsnPxre4SlniTsJQ3Rq/6oP1U2B+KxZubI
b4XOziV9d57ax7TLu2UteEgzofspu93PpWwQ15QX6jnLO+ldukvrbP44v9/1
G7uE4uo=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 47->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklFOwzAQRFd8IK6BuAEcIOIK5QRBgq9KSOUD8ZejQ4Gi3dk3diK1jmN7
PfN2bp/fDq9XEfF+8/13WD8eT6f18+n6PHlZjw/3x/Pi3d8vYluijLH8vuff
Zb19hzHM/lhqbX3Xs1kLfc/1Lg9pyFroTD6r9Z3nVlPqFK3ZR3AtvV89bQPN
yqhxIMbA0bGhDLR+5FrgOXQMszbIgWop+XEalEUAfzpvsoBaduakrcMa1Wr9
MzXVr3LSp2VQ95t8a03S7ryF7KO9/x5G7LRPprctGzqCbuJUfOZ6o34YbY7Z
niy489QPq8doz34b64nHPXkszx6N0evpqDWzr9bn9K452vQsaNScqAbKEO0d
8ZtmChhiH11OQJeeKzrgLPnSrNA30qY1GwfIrbuTvre8q07w7XJN96NXk0PM
kfFKPKmH1Af0OuDo5sqtzEPYTs5soInyUvxGNCbYf8OjMQQdOI9eg+4mLSNt
9E49pXqNkdGLPEm71KT7NKvk0eknfZjtiQ/dW3KlXKJ7dTyGnmVUXsSU9Lac
i6/YoTHXJG603vQCn8bKnV9YK/YFeDXdqWbzMsgbZVaZEaOSFVnXc3Q/rRcu
4tNltNwp35Ax+XfMgHtjD/OiYbRO/NI3qqVMXO2ZB8sqP8onovWBdOzpOerb
4TNrcfOsU+9p3uW9Zc0wpJ7QfpfdzHOWDdLq8kJ3jvJOfmd7aRz1H/v3M34B
r6nlMQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 48->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktOw0AQRFssENdA3AAOYHGFcAIjkVUkpLBA7Hx0COCop/pV25acyXzc
U/W67l/fD8ebiPi4+/k5zJ/P5/P89XJ7mbzNp6fH02Xz4f+NWKYYxpj+/ud3
3S/rMIY5H9NYW//rt1kLred660Mashb6pnwbUbQWH1pT64TcYTiGaC/+9Dx5
N7XonHIua8Cm80zMyHPoGGavyQExWlSv64fjCZoLB5oLiz05KfuwR7VK/0xN
9auc9CkZ1PMm31qTtDtvIefo7NVDx87kFbklzWUE3cRp8CkcnE7lR35ddtpc
wffUD6snewdfyHrD4548KrdNjVHr6Vh6ke8Cr6Xf2iep67ySBsoHne34UV+I
6erF5ausUU9Ui9ZUPo0vzQqtkTatWThAbt2dtF7yrjrBt8s13Y9eTQ4xR8Yr
8aQeUh/Qa8PRzZXbMBf/W98soInyElRzquzUP/EoDEEHzqPWoLtJS6dt0BA8
d/UKI6MXeZJ2YOs0675jQD7J617uw3995SFP13nDrvOsWrIPd0/JCunPWjY0
5prEjfaLXuBTWLnvJ9aKfVFepFvWVQP1hjyVnhlG+rr+uPtpf+CSNBAP0qgZ
ID6YUcdMuYsmyonqavfXx+SDaikTV3vLg9M5PMpn1dWw3ttz1LfDZ9bi5lln
54/6QTWIIfWEzrvsZp5b2SCtLi90Z5f3om/HWRq7/mP/fsdvnAHl7A==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 49->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktOAzEQRFssENdA3AAOMOIK4QRBIqtISGGB2PnokCgT7OpXPR4pGP/a
r6rr8f1zd7iLiK+Hvz+7/ffr6bT/ebs/Tz72x5fn43nz6fqLaEv8j9dfk9+6
n9ZhDHNea+v/evfy9fuy3tdbP2LoWehOuhthfVCW4U5fJ/Ib5GMIe9Kn50m7
qUXn1Oe0Bt5Umsmz26fMEZlR94ockEdNeV0/nJ/AnHyguXgxk5O0D3tUK/XP
1FS96pN+KYN63txTn4ndaQs5R2dvGirvTJ7Rt55ZR+Amnwad6oPhHPoWrNdl
p8xVcX/LM/KD8pO83tA4k0f1bYaxykX6JAupz93/mqOmd+l9w6JndU3PVv65
LLvsuXylNeqJsmhN9afQpVmhNWLTmskHfR9yrvVQM/U6xrEtebT+CL/jVr3I
DlrJT+oh9QG1Fj66ufo2zOGt6k4DJsrLoFdqaU/bUvvhMqk+p3nkGlWv0nuG
jdapp1QvaTS8TivmFvK2xZIyZ+4QH2a78F31plyJL6rpNgc/ZjQrS6/DvaP9
CeLvWTYY+5rkG+0nXvAneeXuL8yKfVG/iFvWlYF6Q5pSz4xHpJX6496n/cGX
jgHfBUbNAPmDGXWeqe/CRDlRrnJ//Uw+qJZ64mpvaXCcw6f+rFyF17M9R74J
nT2LmxM/6aN+UF4GFvBtmFPPjbaescoGsbq80JtV3hPfxFkaq/5j/y7jL5uz
5K0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 50->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkFOQzEMRC0WiGsgbgAH+OIK5QQfCVaVkMoCscvRoVVbkvEb/xDpN40T
2zPjuX/92L3fRMTn3e/Pbv16PhzW75fb4+Ft3T897o+XD+cvoi3xt5+/Jh/F
+ni/R1dP34apGZB7Wkv3X+J9veEe6hAGXa3Lczo0qT3kCEbtoVg0ty2SS++J
u6lF71TnFANtKs6k2XWRzm6WhAXeqA5NexTzQD0Jn+pA5xhrzPgk3cMdxnR+
pubAF3TSlTQwvHAZT2zxCHlHb68cKu2Mn1E3xQx+Sz4SnQaeqoPBOcwtmK/z
TumrIn9Ls6QH8EKtNzjO+FF1m8FY+SItmm9ADHzUNJf6Gyz6VmP6ttLPedl5
z/krxWgmikVrqj4FL/UKxQib1kw6aH/wudZDzjTrGPe25N3qI/gdbuWL2IEr
6UkzpDkg10JHd1bdhjP0qnIaYCK/DHylls60LbUezpOosc5ZalSzSv0MNorT
TKle4mjwop6AVftTP8KSPGdyCN9/dVe+yVeiy6UHnVWPLc6kW88j3QHe5PNl
fBcTGPsY6db3dJ5BXiF1XP7CWHEuIfk0b4krBpoNcUozK7ylXGk+rj/dD7p0
GEgPwqgeIH3Qo04z1V0wkU8UV3l/WcYfVEs1cbW3ODic7l7n7bSenTnim+DZ
Y8Fzv8gXyk3+k18GLKDbcKaZG249xsobhNX5hXpWfk/4Jt7SXs0f53fafwA7
nuOz
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 51->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA0EQhQsX4jXEG+gBgleIJ4hgVgEhLsTdHF0j+al+9b3qaZhMpru6
6v09vn9u93cR8fXw97Pdfb8ej7uft/vTx8fu8PJ8OB0+nZ+IZRO39/lZ5HF7
Iecx6RGmZ76XMV37Rt0vj3BQbgWzrCXdcxwW6T3ciXQ36gzFondVF50z9HPa
KxfjjfIstTCDOJNmGWPR2XmpWKhGdWh0yUvnOP0VA+oAfdbmpJzDGe6pf6bn
wJf2ZBUNDC9cJhMzHuoj1Wa8VjvKsvZx2YC8lRyJTgNP1cHgHHwL5uuy0+aq
uT/TrOgBvFDrCcc1eVTd1mDsclEW+RuwBzla9C7NN1i0Vve0ttMvY+g0vXBx
+Sp75Ili0Z6qT8NLs0J7hE17Ol8KvqY/ciavY3wvMNPqI/iLfzBDs4P1lIe4
9cGZwh25Njq6b9VNz1q+8m091UxKJohL0dDo4TKJGqvP0qPzqswz2GifPKV+
haPBW7gmDSm3NucGS8mcuUP4iu6mDnWknIkuV67wPeizgjN5nHmUM8Bbcr4Z
62IFxrxHec0zXWaQV0gfd3/DWNGXkPvakzxuMHScimc0S/2R805XrRu4hvRu
9CCMmoHC0WXUaFZ0F0yUE8XVnl+WyQf1Uk1c7xkHh9Odq4ad1ms8R3wreGYs
+J0X5UK5yf9B60ZD8oTqO24ZY5cNwuryUuZN8q61zrPZu/Mf/ft//wIKOuO1

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 52->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk1OAzEMhS0WiGsgbgAHqLhCOUGRYIWEBAvELkeHokKd5+85Q6TpdBLH
fn/Xj6/754uIeL/6/tkfPu7f3g6fD5fHj6fDy93ty/Hw5vREjF2c36dnyOP2
Qs5j0SNMz3wvY/rrG7IfzT3og5hljXTPcRjSe1Av5SDYqZdiXM5x2httilbC
s9SCBkVHoxlxVm2mM8JCNapDowtiWOiv92k29flPTtTLTXvqn+k58aU9WUUD
wwsXYHFZoTkd54zXakdZ1j4uG5C3kiPRaeKpOhick2/h+XYcV7lZabnUA3g5
3/6DkfKoum3B2OWiLPI3zco1mqOhd2m+waK1uqe1nX4ZQ6fpxIt8NDkhXHpv
wkG5AV6aFdojbNrT+VLwNf2RM3kd83vATKuP4C/+wQzNDtZTHuLcB2cKd+Ta
6Oi+VTc9Q43THZcp1TnzmebIfJ03dr0eLpOosfosPTqvyjyDjfbJU+pXOBq8
hWvSkHJrc26wlMyZO4Sv6G7qUEfNoyzNYMlkwruFM3mceVDGFW/J+W6uiw0Y
8x7lNc90mUFeIX3cfdI/KpayH9CTPDZ+rDhR7sss9UfOO121buIa0rvRgzBq
BgpHl1HiRroLJsqJ4mrPf5fJB/VSTVzvFQeH052rhp3WWzxHfA0PqsHvvCgX
yk3+T1o3GpInVI8Zz7M3ZIOwuryUeYu8ay3VuzvOe/Uf/ft5fwHp2ec7
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 53->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkktKA1EQRQsH4jbEHegCxC3EFbSgo4AQB+Ksl66RJNa7dW69tqHTeZ+q
ur/bl/fd21VEfNz8/OyWz6fDYfl6vj4uXpf9w/3+eHh3eiPWx/j7nt51w5vv
huxRD93X/5c3Ybr0DdmPpg76IGZ51lTX6RDSs/RSDoKdeinG6RynPfQa+Io+
w9rczbNJg9ILOKs2w5nDpndUh0YXxDDRX+tptvbVHM9yol5u2hMvXc+BL+3J
U2rBY6ojnVQHx+Nc23HOeK12+hInlw2TKce1ZF91MDgH38Lz7TjOcjPTcqoH
8HK+/Qcj5VF124Kxy0V5yN80K9/RHK1aS/MNFr2re3q30y9j6DQdeJGPJieE
S+sGHJQb4KVZoT3Cpj2dLwVf0x85k9cxfleYafMcdY90U76IHbQmPclD8gG5
NjriOu2H4NBZ6qudRZ5qX8i4ywL5grmGGS5r1G/mVZlnsNE+eUr9CkeXS+hF
WKmnq1cdrP8y03Ed9jselBPKiHKFtfYlPqUO+Nkz9Rd0ytgLJ4Mx71Fe80yX
GeQVUfTF+lmOgRd5S9nq/JhxoryUWeqPnHe66r2Bq/Js9NDzVXqg7i6jxM3g
KTNhnTG05+fH5IN6qSau94yDw+nOVcNO6y2eI76GB93BdX4oF8pN/g9aT3KJ
HoHnejbM3pANwuryUuZN8q536b6rcd6r/+jf7/cbwPHoQQ==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 54->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk1Ow0AMhS0WiGsgbgAHQFyhnCBIsKqEVBaIXY4OlZrief6ep42UNnE8
9vu7f/vcfdxExNfd389u+X45HJaf19vjy/uyf3rcHz8+nO6I9Tn+/0/3esGd
e0NqNEPr+hwnHBnTea7Wo+4rNeFWMMu1ZgyNDiEzyyzZrdhplmKc7nHaw6zM
t2itGuY96pHONZoRZ9Wm7FEseh6wlPcZBqe/4UC7da7meJYT9ZLOuJpio3ln
3FSTq5wFj+kc6aTYHbftbKdDxmu1I+90jsuGyZTjWrKvOhicg2/h+XYcZ7mZ
aTnVA3g5367BSHlU3S7B2OWiXORv2pV7NEernqX9Bov2ak17O/0yhk7TgRf5
aHJCuPTcgMPkhvxQnyk/ik21cr4UfM185Exex/i/wk6b56g10k35InbQmvQk
D8kH5NroiO+pHoJDd6mvbhfpW+ZCxl0WyBfMNexwWaN5M6/KPoON6uQpzSsc
XS5hFmGlmTPMxNHhJ3xFd9NnM5y4DM+QwZJJmTvjjLOj+aaegE4Ze+FkMOYa
5XX77vhYXoIZvYnKv+QYeGn/0Bt8njjYzAVg0t4r/XFYSPdyptGj08Hq7jJK
3IzuZSe8Zwzt9+0y+cDeqLhdNjoODqf7rhoSN5cTixc8Jh7oFWAr+CkXyk2e
cz/mEnQb3o0umt2s5ywbhNXlpeyb5F17qd+dIU/J/7BzfgHbjuz6
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 55->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA0EQhQsX4jXEG+gBBq8QTxBBVwEhLsTdHF0jial+9b3qaZhMuqe6
6v3dv37s3m8i4vPu92e3/3o+HvffL7enzdv+8PR4OH18OD8R6xLX9/lZNzy5
NuSMeui5/o8zjozpv6+eZ7xxfWuvzK1gllX6dbxDzvKS2YqdeinG6ZxO+4Zv
0Xqpz7rUGaij0azgA23KHMUimhGWslcMuYfT0+lhZmtfzfEsJ+ol3dGenb+U
jeGO6gj41QfiVZbJWsst3e10yHg7fVxeSq1iNplCnoCl6AA4C9bwfG0+NuRm
pmWrR1RcTvMZxy15VN22YOxyURb5m2blmoGbZspgDIPF6ejwdvplDJ2mAy/K
p8kJ4dJ7Aw7KjfFDfab8KDbVyvlS8DX9bd7V6xjfK8y0eY56RropX8QOWpOe
5CH5UHwjHxtPh6VcgL/66maRvqUvZNxlgXyx+soMlzXqN/NKawkbehB17/o5
TOUu9CKsXc8OS8mcuUN6Ft1Nnc1w4jL8l36FO/SdcbZ+dd8o58BnOJtgzGeU
18t3x8fyiij64v1JJoiX1g+1wfeJg81cACatpVw0/jgspHu50+jR6WB1dxkl
bkb3MhP2GUP7/bJMPrA2Km6XjY6Dw+m+q4bEzeXE4gWPHQ+Xr7LP+lEulJv8
z/XKE/eqo9FFs5v1nGWDsOp80nJL3rWW6t0d8pT8R//+3j+CLOq3
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 56->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0tOHEEQRFNeIF/D8g3gACOuACcYS2Y1kiVYIHZ9dD4CnBXxIrtL6umu
qqys+M2vP//uHn5U1dPPt5+78/Pt4+P55f7qffL3fLm5vrxv/v58qrZT/X9/
PtuBp9eWrFEPXdfv76dh+u5bst7xlpyDPohZhvWbeJes9aEcBDv1Uoy790za
D3w3mS+6h73t5NhN795L8YE2cQ80SVhsrhh6j6Sn3hkySHgpx3s5US/pjPac
/KVsmMfl2E2HL56Bl42QtZFbOzvp0PFO+qS8WK1iDplCnoDFdACchrUy35iP
A7nZ03LUoxxX0nyP45E8qm5HME65sEH+trt6zcJNMxUwVsCSdEx4J/06hknT
hRflM+SEcOm5BQflJvihPlN+FJtqlXwxfEP/mHf1utb3BnfGPJevkW7KN2IU
zug54CAfzDfycae3aqa+og6n9YzeRfpaX8h4ygL5gtmAO1LWqB/VKkf1i7wz
Xcrnqd+IKei3+AJZST0nLMSRzpCepnuoixluXJZv6Wfcoe8e55SJeG87Tzot
uSngFDD2Ncor3Wl4gZdyRG/KOVq+gZfWL7XF54lD1LIAk9ZSLmQ/cdE+xlXP
DHpMOkTdU0aJW9Dd7oR5xzDuf40hX1Zbx+7e45Bwpn3LOdyfvCDPk8eJR8qX
zfugXCg3+e71yhPnlfeNK/l/IBuE1Twd/i+Uc8q91pN36Z34Rv8+3q/Z4ez8

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 57->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk01KA0EQhQsX4jXEG+gBgleIJ4igq4AQF+Kuj66BaKpffa96GiYz09NV
9f5y//qxf7+JiM+735/94ev5dDp8v9yeX94Ox6fH4/njw+WKGLu43i/X2HDl
syF71EP39TkuODKm/766n/HG9T71E24Fs6zSr+MdspeXzFbs1EsxLud02jd8
h7xnv4o26pH2NZoVfKCN/dbkQLGUd8WQezg9dSZkx3GhHK9yol5SDWndcVAN
XIZ0lVozl2pd1lbc1Ec6m/Fafcg77eOyscBCOk08VQfA6TxwvLr6LjcrLVs9
ouJymq84bsmj6rYFY5eLsjQP6T528xnN5NBawBgGi9PR4e30yxg6TSdelE+T
E8KldRMOyo3xQ32m/Cg21cr5UvA1/W3e1euY7wNm2jxH3SPdlK/FKJzRc8BB
PhTfyMcmq9NSLsBffXWzSN/SFzLuskC+dHnMM1zWqB+dVY7qF2bGZNJlq/jv
MBn9Jl8gK65nh4U4Ug3pWXQ352yGExd9tlluPFjhzxyn5bwMr9OUmwBOBmPe
o7zSzIJXeVEuXP0iE+oP6TnkjNaTH13mJj6gD2mkc0g/wkK6lxrokbk6Hazu
LqOOG+heZsJ7xtB+/1tNvsrZ2Da7y07pDd7r95JzmO+8IM+dx8QDvQJsBT/l
QrnJcz6vPPE9/HfiWmZvyAZhLZ42/xfKOeXe/T9WtdZ/ODPv/QBbOe3B
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 58->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk01Ow0AMhS0WiGsgbgAHqLhCOUGQYFUJqSwQuxwdKgU6fv6eJyOlSSZj
+/31/vXj+H4TEZ93vz/H5ev5fF6+X24vL2/L6enxdPn4sF0R6yGu9+1ad1zj
2ZA96qH7+hwbjhHTf1/dH/HG9Z76CbeCWVbp1/EO2RuXzFbs1EsxTud02jd8
V3kf/QqdA3uor/ZSfKABejDJQZo/9CBdykynp86E7HRcNMeznKiXVENadxxU
A5chXaXWzKVal7UZN80UnR3xWn3IO+3jsjHBQjolnqoD4HQeOF5dfZebmZat
HlFxOc1nHPfk0c3tMHa5KEvzMNzXQz7TZipyHXElDJQPOtv5NWLoNE28KJ8m
J4RL6xIOyo3xQ32m/Cg21Up1KNhBN+1n865eR75rFto8R90j3ZSvxSic0XPA
QT4U38jHJqtpKZfIPYinm0X6lr6QcZeFTh/K4zjDZY30pbPKUf3CzOgMyKjr
12Iy+rk5s54dFuJINaRn0d2c06wkXubZakr6zDQE7mmB/4qd8l7w7sA47lFe
aWbBC/oUrVz9JBOJH+ilWui+86PLXOID+pBGOof0IyzYV2ugx8jV6WB1dxl1
3ED3MhPeRwzt97/V5KucjX2zu+yU3uC9ficNdX7n517PiQd6BdgKfsqFcpPn
8XxoLb2H/05cy+wd2SCsxdPm/0I5p9y7/8es1voPZ/LeD2AC8T8=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 59->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1tKA2EMhYMP4jbEHegCBrdQV1BBnwpCfRDfZukqXkhOvpMZB9rpf0ly
br1+fDk8X0TE69Xn1+H4dn8+H98fLr8WT8fT3e3p6/Dm5xOxLlHesXz/1g/t
B7xjuBum319dMJa2H1KTOKxLXbd96Vl6536DDjSr4FKsgIXOm5bu/qT9wHeV
dfYrdA7sob7aS/GBBvZsyEGZn3rYTJi+lEniQDpoX83xlJN2Dmfq1Za/lA2X
IX1arZlLtS5rW9w0U3Q347X6kHfax2VjAwvpVHiqDoDTeeB4TfVTbra0HPWI
jstpvsVxTx7d3AnjlIv2aB7Se13qnTFTUeuIK2GgfNDdya+MYdK08KJ8mpwQ
Lq0rOCg3xg/1mfKj2FQr1aFhB920n827eh31rVkY8xx9j3RTvhajcEbPAQf5
0Hzb0FF5lUe5RO1BPFtmFuZLeQnFMGRh0ofymGe4rJG+dFc5ql+YmZ2eUj+H
adJPfaLcYs8BC3FseUi8iKvWON01NzQjEpY8h/bJa8Ko9aoX+a/YKe8NV+Zh
MOY9yivNbHizDqCf9v9PPgs/0GvK6uTHlLnCB/QhjXQO6UdYsK/WQI/M1elg
dXcZddxA9zYT1hnDeP77DPlqd2Pf7Ck7rTd477iqRjZThG+H58QDvQqzzo/J
eOEuvzOuEIy4Vh2NLpRbwthwAnbyfPq/UM4p9+7/sVVr/Yc7de8DlMrvwQ==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 60->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1OAzEMhS0WiGsgbgAHGHGFcoIiwaoSUlkgdjk6FCiKn7/nNFKbmUls
v7/b57fd61VEvN98/+32H4/H4/7z6fr08rI/PNwfTod3f7+IsUXaY/t91h99
D9ijuRum31xHWM5rfp7vz3UD+hAGXUP7NTrQrIRLsQIWOi9auvvCI2nY8B3y
nnQ3c8ZWsYfOnXsBPtXAnomeCWcIvkaXri9lkjioRiu/Vjkp53CmXpU8ND2V
b/FJVqk1c6nWZW3FTXNGd2e8Vh/yTvu4bCywkE6Jp+oAOJ0HjldX3+VmpWWr
R1RcTvMVx0vy6OZ2GLtclJ6ah2kfW77TZipyHXGdsWhP5ZjuGk4DMHSaJl6Q
CfpWPAEsRQvKjfFDPaH8/OsVlQ/pULCDbtrP5l29jrxrFto8R/1Guilf0l3r
rOeAg3wovi10VF5pNdlxPJUHPRcfor7rDOXQ6VPy2Hhb8Ebu4XyieQ4b6aCY
Z23Rf8DU6ac+UW6xZ4PFZbhwafJLNZhroxc96xz6Tl4TRq1Xvch/xU55L7hm
Hgbj/I3ySjML3lkH0E/7k2faB/mBXl1WOz+6zCU+oA9ppHNIP8KCfbUGesxc
nQ5Wd5dRg590LzPhfcbQnp9Xk69yNy6bbbMjOhbdYLbTUM87P1dZ6rSnHjN2
yu4Zq2rldNWeSSujaWi94a130+wLskFYS14I5yLvqr27TzXUw3mLHv/sX92h
9nY=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 61->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA0EQhQsX4jXEG+gBBq8QTxDBrAJCXIi7OboGNal+9b3qGUjmp7tf
vb/71/fd4SYiPu5+/nb7z+fTaf/1cnt+edsfnx6P58WHv1/EusT1vvze6Udr
Afdo9obBy+cypwtuyPcY9+dzK+AQB71Wxeu8gFkDL+UKXGi9eOn2i47Bw0bv
Ku+D72ZOp5k8I37qgV0TPweeIfwaXzpc6iRpoNmKqz0u2MFr1AXNBvvQYKre
kpNc5ayZS2dd12batGe0N/O13lF2iuO6MeFCPg061QfDkzKY6aLzXW9mXrZ+
ROVFHm7RuKWPbm7HEfN2mNqHdF+XcY/NSfritF44AKZqHPaqv/o+81v0Yr/M
t5IJcCledJkATtA+8iuqHvKhcAffFM9pVszMpcya9TmMJ9DVkkUAtmjGzDfm
UHKb+Ki6ytXpN15mHfRs50PH8Xz0/pQ+NtmWGTFiuJxonuNGPsy8LfqAU8AM
xSKuLWbDxXW4aGn6S2ew18YvetY59J2yJo56Xv2i/JU79b3wyjoMx/yN+koz
C9/sA/in+JTZoD2MPvCr62qXR9c51YH8NR/wUP0jLoirZ7JPknPng/XddbTJ
mXIn7+icairr/1fTr7I3ts3uukMZ0xzENxmTp+X8hsxJB2Fk7qXDSad6pdr0
Wbvnejnsy+/GF+otcSw8gTtljjwnfQ/lZ/bTGcIoes2cq9ffVBD2OQ==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 62->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk01KxEAQhQsX4jXEG+gBBq8wniCCrgaEmcXgLkfXAYnVr75X6UDMdNL9
6v35+P51/LyLiMvD75/jcn09n5fvt/vb4mM5vTyfbh+f/u6I9RDlSXc07/Iz
zF7F0N/bnbhsuCHvY9yfz62Ao3MGnIyd8YwGxMyXahDuipO/Fy/dftExeNjo
XWU9+G7mdJrJM+KnHthv4ufAM4Rf44vikgbqnevgsBbcrus6r+Oi2WAfGkz1
seQkVzlr5tLZjmenTXuGmYTHwNxEO3m56YObPFSfBp3ig+NJGezpmrmd5zOe
dT1wHs5onOmjm9txHHiI3wVT+5Ce62HcY3MSTKd145BmUz9ob5eX67LrHvbL
vCuZAJfiRZcJ4BD/kL1lTb5ILoVfg2/7rllH1I40vSbvUKvpoctcz9nMJ3Mo
ue34qLrKtdMd8jLroN92PnQcz0fvD3Iz2ZYZMWK4nGie44Y4E96SR4gD/uWs
lWuL2XBxHS5amv7SGey18Yt+l+7Ce8qaOCouYjcd1nxKbwI0GY75HfWVZha+
2QfwT/Eps0F7GH3gV9fVLo+uc6oD+VM+lMsOF8TVM4CRtTofrO+uo03OlDt5
R+dUQ/lO/sHl5nfYXXcoY5qD+CZj8rScn8icdBBG5l46nHRix6OuFZN8cvkO
a+ML9ZY4Fp7AnTLv/l+sh8rP7KczhFH0mjn/Xv8A/bb4QQ==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 63->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FKxEAQRBs/xGuIN9ADBK+wniCCfi0I64f4l6PrypLtqX7ViYE1M5np
6uqq8v714/B+ExGfd79/DvPX8+k0f7/cnjdv8/Hp8Xg+fLj8IpYpyvtvPV3X
tM/f8jvMXcXQdVz6Zy4hZ0u6M9QAdzfTylWeRfGaGajXwEu5Ahc6L1q6+zKH
aujmXWQ/6Gv6LFPlHto3YwE/1cCedTkI4dfoorg0g+ZV66k34e7NSTmHM/Ij
9Mxgqo7FJ3lKLXiM+Y4Y/CMdtmZrPQmP4XTCmVw2NriQTsOcooPjSR5szbXn
12FtadblwGlI38nzrTy6vh3HwiPng7yAuwMmea6ZMhxz3coh9aZ80N3OL9Lb
Ydt8mW/FE+BStNBa2Zc8Nt4NGMFa6QyFu+NquKhHWlMyYnKtcyn/or3JLOmu
deVM+Du89d3ohzrKXOVpskNzujlI39IfMh5UH1Uf0pc4obegt+Nf9JW7HTfi
5bQt/nc4oF/2GjPgMBsuJXPT2EfXmt/Sp9Hd3VdPyzp4VvKaOGYs8oD8d9zz
W3EH7oZj/kZ5zT1dZgYdQDOrdcCMqss/cq9zdn60mRP9kD/5M1XeW1wQV2sA
I8/qdLC6u4w2PpPvpB3V6QzlnPSDx/XvsFHD1E+1oj6IbzwmTUv9Ds9pDsLI
3DXDeU7KeMbXdealOjl/h73RhXJLHAtP4E6ed/8vVkPlZ+5TDWGUeU2fq9Y/
P1b0AA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 64->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkktKBEEQRBMX4jXEG+gBGq+gJxhBVwOCLsTdHF1F0azIF9EO9PQnq7Ii
X8Tlw/Pd01lVvV58/t0d3m5fXg7v9+dfL4+H48318at49XNVnbb6u2/fd32m
9/6t38usTf1/91Utmux3rbUZTtv6Pr5v0qf3lnPdDHTWoku1ghaqD5Zuvcyh
Opb1sG7wVT9q3YscDTPS5xiMWsqBmctmQlggfz0TspP81BynnIw61MiP0prp
qRyHT/Ibe8FjzHfV4i1x2JstelK+h+OEM7ls7GghTsucwsHpdDzSXP+5Uq89
ZikHjiF9pxn38ujOTRpTRkdPzUO7L/vdmdBzz89+NuWD1ia/iLfrXbLnBHMk
rqRlsNC98j7yaPQvDIgfcSDtIVukRT1SZiMjJtc6l+of7OEM57nuGzXR7/ot
PAy/waj9Rr5MDc8qucMcxHecARkv2g8zEF/ShN4Cb6d/8JW1SZvzm9g6j2Iu
oRdpjT2DlpG5bT1HnzW/jhP6SLrA0/FcPCt5TYx7r1gP/oyc96trqWIPDWdX
j/NU5mdZ696mlTwiXimryY+YOeGH+smf0NNpwb5hTvU5cbDcXUaDz843mlP3
6UyjDvzo585PvRPTktryDGc7hlpPfv7LczMH9ejaNcN9Tsp476/PXZdycv4u
74YL5ZY0Dp2gnTwnlnt5L9Vn1tMe6jHmNef8sf4AxIj1hg==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 65->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNklFKA0EQRBs/xGuIN9ADBK8QTxBBvwJC/BD/9uga0DhT9arHwGZ3Z3a6
q1/V7fPb/vWqqt5vvv/2h4/H0+nw+XR9fnk5HB/uj+fNu5+ratuV3emqZm28
V/hWa+jz5Rq0jGvTuu6Jdq2jfaY6Y23pm2agXpMu1Rr46r6xTN/LHKpj+l75
NnvUZ9sFjoEZ6VMGcS/5rf1Bm2kQFshfe6YMFuvVHHc5sX3YQ590L9RUjuaT
/OwseIz5rpr8Iw6r2VpPKtdInHCmlI2FFuI0zSkcks7Eo5vrP1dXa8Wsy0Fi
SOs04yqPqW+nscuF1dQ8DPdN1rAn1Fz5OfamfNC3nV/EO9UuObPBHB1X0mIs
iE/wo9M/MSB+xIG0h/2kRT3SM5aRkGudS+cx9tAjeU5szZfyupRF9KnzS/in
X8rOON90hzmIr/WAjCvfNAPxJU3oLfBO+o2vfJu0pZwktskjqxH4Tf7s/D3N
2WmxzKVZQn6xRnlf9Em1p+embsrm9BtqtfsLfzTvl7PFa6RxXKO8Uk/TWz2/
yFrPin7TBbwsr+XnyY82c+U9TD/509RMWrBuM+eYDWVINZB7ymjjc/KN5iR2
7T7wo1/q39XumJbsTc/QOzEczxNTO7/yPMxBNbS3zvX7Thkf6+vzqEs5JX+n
98CFcksaTSdoJ8+J5Srvpi98T2eohnkb+vyx/gJS8/JD
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 66->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk01OA1EMgyMWiGsgbgAHqLhCOUGRYFUJqSwQuzk6FPGTOJ/zGGk6M++9
OI7tXj++7J8vIuL16vNnf3i7P50O7w+X54+nw/Hu9njevPm+I7ZdtCfdMazl
Zww4Mbxr7deV1sq67klPxdE+BSdjS183g87XcJSr0Vf3m5buvMxRuIc5D3VF
d9Nn23XuQX2NfqSB3XN+a3/g1jhErUH9tSf0nvx0/wvn38Sl8aE8DJiqI/0P
Jl2axoJRLpOJ/842ehIew+nkZsJsLLiQTmVO0cHxdHpMc/3nnrBWmk05QA3N
Os24yqPrO3GcctEwNQ/pucka9gTMlZ+5N+WDzk5+kd4OO6RmgzkmXYlL04L0
MX5M/IsGpB/pQNzNvuOiHmlNy4jJtc6l8zTtoYfznLRtvoRgAt7vc9CvaRQV
z10uO6pD5qlzOC4FFzKu+roZSF/ihN6C3o5/01fOOm4uJ05b51HDMPoVX3b9
2805cWmZc7OY/CJG9L7ok3J37wOuy2a5Eta4v/Cn5DXzDF4jjnmN8ko9G9+Y
9bNaa230nuozZajwjl5PfoyZI05G9yl/NMuEk2dwc+ZsqIaEYXUnroPPzjea
k7Qb94ETXa7/hD3OAFpRH8TP2U71pGmrX3k+ZJzOtJqcD8gq6ajvG2CQhuVc
/ja6UG5/eqyyQVzR05B+gzfIz5ynGsJo3po+f1p/ABbG80s=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 67->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk0tKBEEQRBMX4jXEG+gBxCvoCUbQ1YCgC3HXR/eDYlbki+hpmOnuqsrM
+PXl48v981lVvV18/d0f3u9eXw8fD+ffL0+H48318Xvz6vdXtd3WuNOvwlq/
V+hT4Vlrf662tqzrnszUPjpn6dN7y1zHQfmNPorV6Kv7Q8twvvNYsBecB179
XfnqDNRR5xr9SAO75/zW+YBtYKi1BvXXmTA7+em+C+dfwjLwkL+hp+pI30HS
ZWgsPZbLZOJUbtGT8j2cTo4TZWMPC+m08BQdHE6nR+J1yi/12tMs5QA1NOvE
cS+Pbm7CmHIxemoe2n2TNZwJPff87LMpH3Q2+UV6u94lNRvwSLoSlqEF6WP8
SPiHXuZdOQzszjeDRT3SmpERk2vlteAH3JRD5zlxHr50jKqvYgr6DY1Ef3dR
dhxPx8NhWfpCxtFz4kB7gAm9Bb2TR26ew6Zzh0eiLfqv62aG9tI5dI7mxazW
5LHgCfm1uRU8dH7kjZ5DX5dNvWzG+qwdfxaPOs7iNcLY1yivNDPxIc2s1lpL
upyQ+wV3zXryI2aOMBndU/6IS+rTOTiePRuqIfWwuhPW4LPzjXiSdnEfMNHl
5qfekUPASbOX+p7tVk+ajvo9z0PG6cyo6fmArJKO+rxBD9JwOdffjS6U278Z
e9kgrM5T+l6shorPnHfeOe836aVz/rX+BLwd9JA=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 68->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNkk1KA0EQhQsX4jXEG+gBgleIJ4hgVgEhLsRdH10jIVS/+l71NEwyPd1V
9f4e3z/3x7uI+Hr4+9kfvl/P58PP2/1l83E4vTyfLodP1ydi7KL86xPXh77r
fyz6uHet/V/pW9nre0g/4JR56BrQ22oRwlv7RP99mLqiZXM/z56wB9wHXnmv
fHUG6qhzjX6kgT0DHhn/2NUehafRFfXXmTC781Nz7HKC53BGfpA2rl++q3N0
lVrwWHN1WyYTW7m1noTv4XRynCgbKyyk08RTdHA4nR4dry1P12ulWZcD1NB8
J46rPLq5HcYuF2VpHtK/3seZgHPlZ55N+aC7nV+kt+sdUjOAR6crYSlakD7G
jw5/0cvslUPBvsEPm3flEsybcq28qJZ0u82NilWfgLmUsaKvYmr0KxqJ/m5R
dhxPx8NhmfpCxslz5EBngKl4GzIj5h7kkZvnsJW8qkeiLfqv380M7aVzup4r
LCVzjkuTX5tbweN8Uk/Le9PX5lKWzVietfBn8ijjjKqLYix+QXZW/hAf0sxq
rbWky4bcT7ij1jtPbOYAk9O9yx9xKTqsagyfzNXp0Oq+4GTnu5mwzxjac8BE
y83verccGpw0e6rP2U71pGmpX9wJhxt66OyMLfOkjE/c5T3jCsGIe9XR6EK5
JYyEk7CWnqBlCIY27819553rNaSX9+8XiJHz1Q==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 69->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk1KA0EQhQsX4jXEG+gBgleIJ4hgVgEhLsTdHF0TYqx+9b3qsaGTmemu
qvd3//q+3d9ExMfdz8929/l8PO6+Xm5PL2+7w9Pj4XT4cNkRyybKv+64bPqu
/zHpQ89Ue17pW3nX55BehtMVq6wFelstwvdSPen7YuqKls39PHvAHnDfYd6M
m+qWTcWu/fKM3NdpYM+Ah+LXHoWn0dVlgXKUZ3d+Uo5JIzyHM/KDtHH98l2d
o6vUgseaq+symZhyiyh6ERbXw+nkOFE2tJ40VJ0GnqKDw+n06Hit2V2vmWZd
DlBD8504zvLo5nYYu1yUpXmQvLnZJROTew4D5YPuttmHezo38801C/DodCUs
RQvSx/jR4Xd66btyKNhX+GHzrlyCebtck3aEyeXQeU6caS55SNzJN6uR6O8W
8Xc8HQ+HZegLGSfPiQPpS5gU2++560ce5Rq922GjnLhsOY9cvlU/9anTfZZz
ukN57/Qk3QmT8lOf1NPy3PS1uZTlfBxmTfwpOsXfv+qiGItfkJ2ZP8SHNLNa
ay3p8o/cK0/l0u0hZ4CJ7s/yR1yKDk5bw1Nxdjq0uk84OZ3tTHjPGNpzwEQL
cwO6OsykgcNJs9Wf7FHnr9Zj9mJ8X5u/PFuxZZ7qU9FRnjOuEIxON9WBsFNu
CSPhJKylJ2hJvti8N/epJppemomgujPWbyxa9Jg=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 70->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk01KA0EQhQsX4jXEG+gBBq8QTxDBrAJCXIi7ObpGQuh69b3qSUNnZvqn
6v3l8f1zd7iLiK+Hv5/d/vv1dNr/vN2fPz72x5fn43nz6TIj1iXKU2dcJq3r
MyZ16J3u/o9hrXzre0gtw+mKVcYKta0W4WupnrS+mntFy+b82Dthj3pezxV9
1RvpodhVg2ut4V6njd0DHmPtdak1FG9AXeKQ+gEH9XHmV5dlzBHskR+dDpSN
kqEm77fkMA2TiSm3iKIXYXE1nE6OE2VD7zsdkp4xP0MYiWPHa8vsas0063KA
Gpp14jjL4y2aIZaozzQ0D5I317tkIvK9zk+qqWt6ts0+nNO+ii+Wep7WiieA
pWgB+jg/OvxOL/1WDgX7Bj9s3pVLcF2Xa9KOMLkcOs+7noqfclQwNfoVjUR/
N4h/SO2AdceR+ml+qJbe7/RI9UCPdN/4TPhnfnbYKCcuW84jl2/Vz/nU1Zxh
KZlzXJr82twKHueTelrem7o2lzKcj6nXxJ+iU0TKTqpnMOKa+R9s4UOaWa31
LulyQ+6Vp3LpZsoZYKLzs/wRl6KD09bwVJydDq3uE05OZ9sTvkcM7T5gooG5
aThOOTQ4qbf6M3rU+av3MXuRv7fmb+xdsAw81aeio7ynGpAp0k11IOyUW8JI
OAkrcS17LtvOC7NHd6Kp5TJR/foFyUb4WQ==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 71->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVklFKBEEQQws/xGuIN9ADLF5BT7CCfi0I+iH+zdF1YZHu1Et6bJid7Z7q
VJLK7cv709tVVX3e/P48Hb8ePz6O38/X583r8fRwfzp/vLs8Vduh2lufujx0
ru9a4ND/qc/AZcRre/1fHgc5y9oA23pRHkv9pPPN3Gtehvqx98S9er3WNX91
NtJDuasHf1jDveSN/Rbqmy7DlzBIw5RX0KBzXM0Lcat/c1waH50v+EDZaBkK
ef9PDqdlMrHUVtX8Ii4Ow/nkNFE29L7zYfKz1jXEkTQmXXuehLXyLOUAPTTn
pHGVxz2eRS7V39PSPEjeXO86sN6WjZQt8NHxjdmHOu2r/OrQ6+mszQS4KOaI
U8Cl5dHwd37pXjU07jvmYfMumBOHHbkm74iTy6Gbeeqp/ClHjVPwr3kk/rtF
+kuwC86dRuqn+UlYpCF9Iz8o94RHuXT9VtwoJy5bbkYu3+qfm1PCXHFpmXNa
9vAvryPNSXPW/hdrJUzETjkydcnLTXkKr8Y7eLQFji4zUz/wzHqtdwt8+Ufu
VadqSc+UM+BE9U1LyLHj4u6kzGoWnQ/R94Um57PtCfuRQ/wOnGhhboLGpYbA
k3rrfMYZpfm2+4saN3vCGHs3LoNOndPkAcyDtBK23YPuxqt6D5sNOHO5nvib
udi8h3o3O4flMtHn9QPHiPnZ
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 72->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU11Kw0AQHnwQryHeQA8QvEI9QQT7VBDqg/iWo2tByu73N+lCmmQzO/P9
9fH983C8q6qvh7+fw/r9ej6vP2/3l5eP9fTyfLp8fPq/qral6K4u9a3EvUKf
Ms/j3ohl7IfvYz3OxD4SMyzq53SA+dgL9VT7mzlHWob6cfaEvbge61Bf8gZm
IPbkAfUVGthvoZ54Gbyqh8twLXDGaVYab8xx+B8oLIQH/RU6qGxQhkLeb8nh
tEwmWm5VpJfC4no4nRwnlQ0873SY9Ky+RmFUHBOvPdcVk+DQaZZyIDU0+5Jj
k8c9mkUsxXfsN+UB8uZmI4fr2uFn0tHhVZyS3jgX8dXC9WqPPBFYsOfYx2WN
Zgv8Ti98Rw6EfYcfNu/Qc8IQvJZ5Lt6btMe5xVipv9hD/HImYgr6kUY193Mr
8R81RGyOo5qH+bn2NJooXyw/oYfKveqncunmddhUTpy2ziOXb9Rv8qXRvcu5
0x/znvR0OtlcG5+qey7NVfWUvVOOTJ3iRzoZXIQ7aLQFjC4z0zyhmdUaz5bQ
5YbcI0/kki6bs8CfuHR1SoeQFZdZzKLTIepuNHA+O98UT/Kz+y4wqSVzEzi2
HAJONRv9GT1K/tL5psZ5n3IosQw8qX7UQPihuKre9l3wJlzFM2w2xJ7L9YTf
+GLzHuqdd66XywT79Quy5frf
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 73->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FKBDEQRBs/ZK8h3kAPMHiF9QQj6NeCsPsh/s3RdcFZkupXnRiIszPp
VFdVlw9vn8ePu4i4HH7/HNevl/N5/X69v768r6fnp9P18PFvR2xLpCdtOgt4
RoET5nf7reWyv99W897Wa0/FQc6yEp7zYenrFUv9pO+buef6UD16L1jIqT2D
GXZ9zPzVgxar3c4De1bUJ12GL2G4DHd8I5KH9FRcm+Pi/4C4JD4L9C4w1ccN
cCpfnC71c+dBmRhqi0h+EReH4Xxymigbet/50PkZ4xriSBorXTO7whp5VuUA
PTTfUeMgjzOelVwiPxWvy4PkzfVWDbc1Mc/KR8e3zD7UaV/lF0uu1284E+Ci
mC1OAJeUR8Pf+aXvqiHldmIeNu+CqRzcrCvvUCvkqKuJjE05TDMHHqS95aA+
JI+ix8MFc0UfjJekkfppftre7n7lRzV7l3uXhzRf02/EjXLisuVm5PKt/jlt
FeaIS8KZ7In8w+uo5hSj38FaCROxqxyZOtKXfDK8Eu/Co63g6DLT9VPPjC94
N8CXf+RedaqWareeEyfnu/pc1oGf7k6VWc2i86H03Xjg5uzmRjrTPEfnwIkW
5qbQOKPB8aRznU+IduQyMXOtcbOvcohc9kX1zVlIr+QVZIp8Ux+IO+WW/Ew8
4ZvLdcffzMXmvah3s3NYLhN5Xj/vtPrj
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 74->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk01KA0EUhB8uxGuIN9ADBK8QTxBBVwEhLsSdR1fBRXe9r6rbgckk3T31
6i+3z2/H16uqer/5+TiePh4vl9Pn0/Xvj5fT+eH+/Lt593dXfR2qPemmvYJn
BZwy38cZI5ca1qb1GuYN50Zsp6lklsVzPhzm84qlftK66iW/yMfpIu8FCzmN
e5DhNMfkrx6MWOPtPLB74XzTZfgShuvwxLeqeUhPxcUeL/4HxIX4YF4GU30c
8VzfUw9br0y25IPVVt0v4uIw0CfRTjgjf33f+TD5WeszxJE0Jl07d8JaeZZ6
gB6addSY+rjpWeRS/al4Ux+kb2627cBGnoTZONVaU/Jb5yq/OvTzuuYyaXvK
Y+QfPFjxd37pb9XQeruRh+27YCqH1AnnHWoVH1o+1bGbntDHNlM5Bf+aRzXj
4QW5og/GS9JI87Q/42zKgnKx+sAP6r3rQ+x37XOjnrhuuYxiLwFLta0wE5eG
szmTZo0YmKPJqdL30DHCJOzYI5m19FJ6gxkEjrgGGl2GEy55ZnzBdwt8+Ufv
Vaf6ku4pX+Dk+qk+x3PAxb2TOjt5HHyIvhsPXM4uN9LZ8lztAye6sDdB444G
x5P2NR/9j7h8aS2dcdmnHjou6k/TZ/IgrQ07/QbdenbiYnTr5XwZ9Uz8TUds
38N5l53Dcv3seX0Dkkb+YQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 75->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkFKQ0EQRBsX4jXEG+gBgleIJ4igq4AQF+IuR9eAykz1q5rvh5+fmemp
rqqu2+e3/etVVb3ffP/sDx+Pp9Ph8+n6sng5HB/uj5fDu5+36ryr9qW3wt74
LVOrGA5v5PK7/n3OO/kvdQ4HOcvT8IKGsV6x1E/aP5t7rg/Vo/eChZzGM5jh
1Ef2nAcjlmaAPLBnob7pMnwJgzRoXsc+Y+80z5hj6Je4EB+cl8FUH0c8l/eU
w5YrM1vywWqr7hdxcRjok2gnnJG/+uJ8mPysdQ1xJI1J15Y3Ya08SzlAD80+
alzkcYtnkUv1r+JNeZC8/e0FDZqX1TyTj45v7A112lf51a7X6x7ORLkA5oij
3hGO4+/80rVqaLndMA+bd8FUDmkuzjvUqnlXXtWxm56Qx9ZTOQX/mkc14+ED
c532JStOn+My4ULG3SySP3SmflDuXR5ivmvNDXEgow4vcjL+OW0rzMSl4Wzs
Sb1GDMy1mVOl/yFjhOmwbY6k19JLyQ3OwHAkTWfonTIx4ZJnxhe8C778J/eq
k+65d/ICOG3hQrOf6oDL8k4Bhmh1PsS5GQ9cvZub83isQd3jOXCiB3MTshXX
NG+YvdM69o06N8xcNYy4etdlxXFp2KrPzAO9Uuy0Nhmk3JKfjSfsuVxP/E1G
bN5DvZudw3L57PP6At6aAOQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 76->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkFKQ0EQRBsX4jXEG+gBPl4hniCCrgJCXIi7HF0DJsxUv+oeP0x+/kxP
dVV13b9+7N5vIuLz7vdnt/96Ph733y+354+3/eHp8XA+fPhbEact0ptWFHvj
O0ytYji8kcvl+/KcNvkvdQ4HOcuT8AoNY71iqZ+0fzL3XB+qR+8FCzmNZzDD
qY/sOQ9GLM0AeeDOqvpUY/hSZkiDejD2GXtX8yxzDP0qLtM917vAnHgLnst7
lUPNlfKjTLTaIvtFXBwG+iTaCefqHfjifJj8jL6GOJLGStfKqrA6z6ocoIdm
v9NLeVzxrOQS+a14Ux4kb9e9Rd5VHXGgfFBt2RvqtK/yiy3X6x7ORLkA5oij
3hGO4+/80m/VkHK7MA+bd8FUDm2+wTvUCj5MNaZXpW3UnnoO2nSpD8RFeabH
6ElaF7wkLhMuZDwIBzRUZ+QH5b7LA+Y71rlRTly23IzKXJo5KbcKs+KScHRm
hZ/OJ5trM6eo/kP21R/r4VBvcyS9Wi+FB87AcFRtmp1uPsoLPTO+4F3w5T+5
V510z61ptsBphQvNfqoDLu2dAAzR6nzo5uayRPXdffq++tidg3/0YG6KbLUa
dN4we6d17FvqXJi51oThXeXQcVF/kj4zD9KasKtvk0HKLfmZeMIe5hq8pIzY
vBf1bnYOy+Uzz+sH+v0A6A==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 77->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FOwzAQRFd8IK6BuAEcIOIK5QRBol+VkMoH4i9Hh0oE7Nk3azdSmsRe
z87MTu9f3w/Hm4j4uPv5Oayfz+fz+vVye/l4W09Pj6fL5sPvHbEtkZ50R7HW
PsPUKobDa7ns3/u1LfIudQ4HOcuV8AoNbb1iqZ+0vplzrk9VH1Lf7RGnds/N
JmA/vAetZ5oB8sDtVfWpxvClzJCGTXlHJA/pmfi6jEA/919I51zvArPjLXgu
7zpP0pVmLZguPy7Pqpu4OAz0CbjjzIwv5KH61Ok0NdV89bzTNXNXWCPPqhyg
h2Z9pJfyOONZySXyU/G6PEje2vcZ3mm9yhb46PiWvaFO+yq/WHK9ruFMlAtg
tjgBXFIeDX/nl36rhpTbiXnYvAumchjmG7xDreBDV2N6Vdpa7annrq3R6Pwj
LsozXUZP0jrhJXHpcCHjQTigodojPyj3ozxgvmOeG+XEZcvNqMylmZNyqzAr
LglHZ1b46XyyuTZzSllv3yH7lXcJ22jvLsiy66E8cAYwQ+dR6/loPsoLPQN8
0uR8uSb3bhYOL52lbF/BRTWmOuAyPBOAIVydD6O5uSxR/eg8ff/5ONoH/+jC
3AywSw1yvnuH3t15+I+4+dJaVROGd5VDxyWkX9Jn5kFaycOuV/ttMki5JT8T
T1jDXIOXyYMq71A/mp3D2gZY/15/A/FxBKk=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 78->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOA0EMizggvoH4ATyg4gvlBUWCUyWkckDc9ulQiULi2M4w0rLdmYxj
O+b2+W3/ehUR7zfff/aHj8fT6fD5dH3+eDkcH+6P58O7nydi20V7syfMXn6H
qEUMhZe5XL4va9vBb6hTOJQzrIZnNOR6xEI/2f4m7qk+rj6gvpwxTvlMzSbI
eQgPUi0+ygN15uqxhvoCPrC6do/kKPd285Q5Jpzd/0LxVeR3wiy8AU/lHefJ
dNG8i0won0sPwpv5MnmHXjUcnJnwheYIfCo6RY2bL95XulYehzV55nJAPRT7
k17m+4pnlkv0N+KVXpC3zGWF98o8nY+KL2Z48hv7/i64g7hUA+FVzpBH5m88
mPgrv/CbeYPzm+Yh8w6YhQOZxYp3VCvxodSEwBe5yPxpzwv/pEP5x7ggz7aE
/tIvcxD6FJeCSzLO5sI0uDPmB8s9w2u5NP0mbiwnKltqRjaXbE6Em8N0XBoO
zsz4qXySuRZzalnPv9PeyjwbttBeFsmy6pFrEbd5Fl033RNZU5kp/dAzgs80
KV/+k3vUOWlgXipOK1xQY6sjXMY7QTCAq/JhmpvKEquf7rPvXx+nc+IfW6q/
w7YagFv5TXqX+8kvq3Nh5lgTgrfLoeIS0K/pE/NgWpmHpVf+FhlkuWV+Np5k
j+aaeNk8cHkn9dPsFNY2YP15/QUuaQVs
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 79->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk01KA1EQhBsX4jXEG+gBgleIJ4igq4AQF+Jujq4BE7urq6pnHoyTeT/9
qr8q718/9u83EfF59/tnf/h6Pp0O3y+354+3w/Hp8XhefPh7IpZdtDd7wszl
d5g6saJe1nL5voxlB79hn6pDNcNo9QSHwovUQp5sfhHnFAu3P2B/WWOa8pry
Jsh6cG15Lz6KgVpz+3EP44Ic2L52juQo3+38lDkmmt3/QuEq8jvVRAa5nsr7
llzhHMuE4lx8IboZl4kdsmI9sXwiF8Wh8Ix5j/MXz6u+1jyu1sTM5YAyFPNT
vy2PK5lZLdHfWK/kAfJ2nduge/LTcVR6McMTb7z3OuAM1qU9EF1lDXVk/YbB
pF/xwm/GBv2b/JB5dx4SL9awo70SDmVPiPoiF+0O9g19KH5MC+psQ/Rf7ssa
RH9KS6lLMs58YT24NcaD5Z7Va7k0903aWE5UtpRHNpfMJ5V5pc1oaXXQM8PT
caI+Cp9a1vPvNLfGz1Zb9F4GybK6o3CCuo1Z9L7pnGFI9Qb0CP1K1niWcNmS
e+xz6qHVZ9neoKX1mB70SGVwqo0ZdBxcf2pd+ax8U4wLx2md8GND3e9q2x5A
W/lN7i7ns6+uzxWe454Qul0OlZaA+1p/wg/WK2OIuSoZJdpZBhnPppPMMc8Z
y8bA5Z3sn7xTtZah1j/rHxXvBa8=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 80->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk1KA0EQhQsX4jXEG+gBgleIJ4igq4AQF+Jujq4BE6tffa96pmGSme7q
qvd3//qxf7+JiM+735/94ev5dDp8v9yeP94Ox6fH4/nw4e+JWHZR/umJZi//
R9MnVvTLWC7fl7Xs5F3qXB/ELKv0MzoMekEv1ZP2F3PPadHVh9QPZ4Qpnzlv
As6DseVafZwG7qyr1xrSRXWgunIPcpRnd37aHANml6HiucnvrKdqkPu5vG/J
le5RJqbcoupVsDQ9UCfIPXpmdHE6DHrGvIYwEseO1+zJnFG7iWZdDlBDsz/j
W/I40ay7S346HkMeJG/Xvc6ndH+Nn52ODq/O6vTWmmHJnVUcANdwpjgy/kaD
Li8htYpB63WW+jfzw+a98xC8WKMdciUfo851+XKed9/Kw+lHWBRnWYb/9V2y
4vg5LNgrzSZf1ujhvNd+mSP1K7ls5s2wUU5ctpxHbS7JJ5d5h63BUvqsnEmz
HE/NivoU3XvaW+MnYSTuw4IsuxmDTtI39xvmmvuki+Pl+BTNoD9xcrpsyb3y
nHEodylnG7AUjpJVhxlxNJlVrE4H5GjuEBac72bC91XH2TnoR8vN73q3HBqc
NHu4Lx5ZLGavq+ny4nKoWHL2VFfSfNBBtSKMoNvwvSGDpGfBCXvkOWlZNOjy
DvUz71yvZdLrX+sfLCgDsQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 81->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk01KA0EQhQsX4jXEG+gBBq8QTxBBVwEhLsTdHF0DJna9el/1pGGSTP+8
fn+5f/3Yvd9ExOfd78du//V8PO6/X25PL2/7w9Pj4bT48PdErEuUb/dEMzd+
R4MTG/BGLuf381iX/jfhWM4yxnMB/NYlYzos9ZM4unXyotsfsj+tOU6Slc3m
PIxmm9PgWQi28yCt0d2yX3U5X9QHt6+cM7kXz1RreN8KbtQ14jJmQhw6TPVA
M9Zxba90znViqi2qX4VLg2G5iXbFvQzwhXxIfsZ8D3F050nX7FHepLn1DLhb
D2F+prf0ceJZd9blSTpSH6Rvl7kup0av873zkfhSlu5+l/dlyBnFtRoMr7Sm
PEb+jQedfyF7lYPu17s0v1ke2PcuQ5PFFu+sVpdj1HupX5R59646FQ89Gkbp
l+KZfdodnUeN5j7quMtlix+UveKNGh1e6WVz34yb6wl1izJqe+lyos4Tt4ZL
wdl4p7uLdGpXSse638Pcljxt54z2NEyX6Y7kk+COeOleOO98IV2kR/1x+E4T
+XJN71XnTEM563p2BZeiUbqqvWl5TDo7ciUfLHZkfF2nnCk38jj5uHFde6eD
7u+wZxqIp1tP5yUj5AJz3R7KvuuhcqGsiz6Xh3rlOBrf0vusg3Kf855ycL6M
ehLP4Sn+wn+A/h+UHWGtE6x/r38AYZEI7g==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 82->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOxDAQszggvoH4ATyg4gvLC4oEp5WQlgPilqfDCtpNHNvJRirdNBOP
7TH3rx+H9xsAn3e/fw7r1/PptH6/3J43b+vx6fF4Pnz4f4Cy4PJe/t7qUWcQ
b1R4CcPh1Zy2/bbKkn87HMmZVn0Phl9ZWkyFVViD4ajOnRepHlTfnClONCs5
m20JzXJOlWcgbOVBc+Z6Uz3rUr6wD6pO+klc6t5pnjbHgrPLUDfzwCFhsgc8
Y17X5srlnrlHbej96rgEDMmNtCsfd+8EV+dD4yfGNY6juu90zTwOd9ozw11p
Ud7O8OryOPAs3WVtDrPLA+Vt/5b8DHqV78lHx5czmvzmmmbRHcaVGgSv5ox5
1PyDB8k/UC1z4HruxfMbzcPmfTDDYb6Fd1KrmiP6vi5fbuZpzzoZz3pUrS5f
jCfqODv83WoU/VzGoXAm/HCzZ7xa4ygPMt+Y56Zy4rLlZhRzqeYUMi+5BS4d
zmRP1cvp5Kx0GUu/J/5fkodOe7NEll2PxifCrfGavua+8sXpcnrguIT712bC
ea5mk/CSptFcFRfWyFnFBBeuYQ6MlXywGsU81Ixkf9dT7HcfJ885d7xc/4Q9
0uB4qnPuB9G/qzXf4sxDxl0OmUvtKfuqMtv4wF4Ncgm1NxlUud17QHOR9eh9
YJyGy2zeQ72bncMqA6yL1z9uxwpy
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 83->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FKgzEQhBcfxGuIN9ADFK9QT1BBnwpCfRDfenQt2ppMvpnEQPxNdrM7
Mzu9fX7bvl5V1fvN95/t7uPxcNh9Pl2fDi+7/cP9/hS8+91Vx039fTc/X9oU
03d13jWv4eq1mKq56+6bvsoh3XdYZbXvyuCb8tY4YCe+pBfpSPkD9hrzE2bH
76yD9iF9W81UP9Kgi6kvTD5xRp5BV/dOcbe90zyjj8PvgLCoj7B3qKka6Ix1
TX1lZn2Umoo9cqtRrwFLqIHYhDvpeNEOsDodOj1rnuMw0nvHa2W7usuaGezE
hbRdwTX4cVGziKXGr9brZi5+u6ykZ+BLuicdHV71aNJbc7olb7QucgBcXUxx
tPiDBkm/klzFoPnaqwBfmof1+2SGU3+Ddgk75ZPuA14z83Qmf5N+hEVxDsvw
HzAuaElYHL9LTTML8orlB3qQ72d+QH8Xc0y1qtnOW25G0ZcLc5rVTFiGOos9
qZfjSTp2Hkv/m/k4Hug54N4t8LLr0ekkddt6XV/z3vnrP3wqYEmeU6zJE05z
mk3ikDippitY1E/q1VRPObjaWivpYDmC93XuTmfbE85JR4qr73S5/qm2PW9q
9Kr4dca1oP+Qa+6GHIhTb+dDxdJqqrqir6qPoVZG06Kz8SD59tKjGAvm16iD
1umwrPo9xNzsZvku9qf1F4J1DSs=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 84->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk1OAzEMhS0WiGsgbgAHqLhCOUGRYFUJqSwQO44OFdDaL99z0pGmaeKM
/f5un9+2r1cR8X7z87PdfTweDrvPp+vj5mW3f7jfH4t3f2/E1ybO6+Z3pZdq
AWs0fWLWL6JginRWzs3/3JvOC1Z5ytlMi4BestcZiEXqinPlfsZCNZ2tXjl+
/5x0Dumb+ZMWisPp1t0nzsiz0dV9p7jz7M7PNscwr8OSPXEYup6qgXqszzRX
xmvNvWJvudG5Yml6IDbhXjIA+VSsToeiZ8zvOIz0veO18rq+y5oZ7MSFtF3B
NeRxUbMWS4yr9it5SGu5fwHume6djg5v0RZmEB/MnnyjfZED4Co1xZHxNxp0
eQm5qxj0vs4KwNf5YfM+8fDSPNucko8xznXz0PONvNAv89R+VqP0DPnSfmmf
MRWMoAdyhHku4+oDZs7VoA/6anwm/ITX5cb1yl66bDmPSIvTt9Cryzxia7AM
fUSXTk/i5eZ2Pmn+yn/BMvMTMwfcywNZdjOcPkM289xGZ1df5aP6EFfipFi7
TDjNleeMQ8dJNV3BonnSrHb9lIPrrb2I79Q38Zh8dzq7mbTvdKS65k4fN7/r
3XLQrEpeZ1wD5g93zdlwB+o02/msWLKmqivmKmqN8uI0DdqbDFJuTzOCseD9
GHXQPgXLat6bmvNudt/Vzlp/A9xTDSk=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 85->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkk1KA0EQhQsX4jXEG+gBgleIJxjBrAJCXIg7j64BiVWvv1fdGZhMprvn
1fu7f33fH24i4uPu92e/fT6fTtvXy+355W07Pj0ez5sPf3fE9y6GJ93RrOVn
mLOKgXhRuURaK+vmf8Z2mkJmEV6nofilWLoP+KRX11VDdz5zoT2drVk5fVnP
zN/smfpHHpQ97YU5T5pRZ+Or+y5kTp7d5dn2GOZ1XHIm1N8Zpnqg3PSa9spk
rb1X7q02WlcuDQZyo95DngHf2d6LHwXbnHEc6Xuna+V2uMueGe6khbxd4TX0
cdGzlkuMT8UrfUjPcv4K3jPfOx8d3+ItzCA92D35RnFRA/Aqe8oj82886PoS
clY56HmdFcCvy8P2fZLhtX22PaUcY5zr5mHmO7kBL+tUPOtRuoZ+KV56z5wK
R/ADNcI813HNATvn9gAHczU5E3/i63rjsHKWrlsuI/Li8i1gdZ1Hbg2XAUd8
6fwkXW6uzSli6F/5L1xmeWLnQHu5oMtuhvMH9cSoG9caD2d61B/SSpqcLy5P
8kN1zjR0mma5Ehftk3ZVe4O4E52K5TjOeCPXxhPnkZtXfFzc197p5eZ32K0G
s+f67TxsuaxmDjkM3BbyzO8XjXQ+eTDkoV5RL2lWVD2km3p7mRHMBc8DF8Up
XFb73uzR+sp5t/fv9Q+kGQ3u
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 86->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyNk01KREEMhIML8RriDfQA4hXGE4ygqwFBF+LOo+uIYFL5Kt0Pet70X6Wq
Uu/66fXwchER71c/P4fjx8Pb2/Hz8fI8eT6e7m5P582bvxHxdR/tTSNoLepe
pLHCcHiZS6S1sm7+Z2ynSe8S3qQBdad7robjkvfVq53zmQvtae3CedCn+wWX
NGYO5E30unp2Ok+aUefgq7sXUifXnvq5yrHWm7jo94O1zT3yQLnps8yV6bVm
SLmP2mgduDgM5Ea5H/KpXJ0Pxc9Yn3Ec6b7TtTMc7rZnhjtpIW93eLU8bno2
con+VrySh/TW87u8V75PPjq+xVuoQXowe5B19WDytfkAmBmHuLRsO53GL52T
NwH8pn7YvC96uMw3eDdxp/Pke+NLPb+XAXhZp+JZj8R/fMjHxKlwBD9QI9Rz
GQ/CiYpJfXW9V7yscZUHzHewxgkr99Jly/VozCVgTZlHbgOXhiO+TH6SLlfX
9imi5a/8Fy6rfmLmQHt5IMuuRvZJcZue6LpxbfBwpUf9Ia2kie44rWPuYd3h
4V3wfZeL5kmzqrlBXMWGeV6ffJh4I9ehz65vrl4+Q7rLPvhHj6s/Ya80OCy3
Tx6OXHZ7Dn1o3Db6mee/j2KrPtMPzW/LYT5Pc6ObckvvxhPWEJO+H+fv8A3Q
Hq3vnHd7/5q/AdK/DfQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 87->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0FOQzEQQ0csENdA3AAOgLhCOUGRYFUJqSwQO44ORRRNnGf/EOn3908S
j+0410+vu5eLqnq7+v7Z7d8fjsf9x+Pl6eN5f7i7PZwmb36fqs/7mt70FNVq
nKv2bGFQr/P4+99qQ938732cJt1LeEkD6gacVFe9WldtaX3nQnMTpz4X9On8
gEsaO4cNb5SD9qH1pBl1Bl/dvpI+vXc6z3QvqH/iovcHe5t95IFy07GZq3CX
+vkpd6vN+EFcHAZyo9yHfCpX58PgZ22vcRxpv9O18jjcZc8Md9JC3q7wmvK4
6FnkUvNb8YY8tLfL+BbvLd+Tj45v7E2+uXxC1tWD5OvEBTA7TglfwqG8lKyd
9BlfOhf0YoHL0EPna/ZkNZNp75BB4mV6lezXcynBtlkEPOtRG1O+FK99d04D
R/ADNUI/l/EinBoxKQsTZ8gN5ipowHwXa5wyQxkJ2XJnFHMJWDZLBjNxmTIn
viQ/SZdmoq/BczrzVx3i6YATvMPMgfZhQJZdj65RcSc9NevGmsn6ih71h7SS
JtrjtCbPqe7wcG/IyxYXy+c/OVFsw78W+ibemn1bE3zXk757rzgPmDTS2hXO
W9iaV5onDyOXhfz1zCnugL1wnv37Zyi26jPnQXeCPNQsdj2km3JL74kn1OjM
8f44f/95P6iesFJ97PcF2AYMPQ==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 88->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk01OQzEQg0csENdA3AAO8MQVygmKRFeVkMoCsXtHhwpemTifJ+mTQmh+
PLbHuX993x1uIuLj7ufPbv/5fDrtv15uzz/e9senx+N58+FvRKxL/M/L70xj
O0Nr273YBpxVfIeXOUVaa9bN/7kOra9Lf5fwQrgOdQNOta56dV21VeczF9rr
OOW9Qp/uN7ik0fhHHigHrUPnSTPqLHx190Lq5NpVP92bcfWH7wneUOVD5YFy
02+Yq+It5f4pd6vN+EFcHAZyo9y7fAJX50PjZ4zPOI503+maGQ532jPDnbSQ
tzO8ujxOelZyiX5WvCYPaXYZH/Ee+V756PiOPNS7WvfyQdbVg8rXzoe8Jx5m
XNcPl5eQs50+8EX1oRcTXJoaoOWqfIN3yN30UbnSHedzw9fgZZ3rArPhojy7
z+gPwZ7xkrjoHa0dhBPsXaVP/aCsuZ6W+a70Zs8oI0W2XI9GNRTLZslgVly6
zIkvlZ+ky9W1fdr4qw7xtMEpvMOcgPbmgyy7Gtknxe30RK8b1woPR3rUH9JK
mhqfi5qasypbIw1Wk+mz5ZIGYl6TE5cLc85hjngj1wk/XU36nWuV+4BJX3V2
hvMIW/NK++RhyWUif5odlxfXH+JyyYdiqz7TD82vy6VmsXkPoJtyS3PHE9ao
5x3Pyt8r3wetV1jVelvvG4GhCv4=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 89->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU9tNA0EQG/GBaAPRARRwooVQwSHBVySk8IH4S+kQwSWzHtuzWemyd/vw
2B7n/vVj934TEZ93vz+79ev5cFi/X25PH2/r/ulxf9p8+H8ijktc5uVvZs92
hq1t92J7yFnEp3gZMy7f2zgu/l3hUM4whrVJL4puU0NxyftsrzufubA9rJ05
Ko3ZB9av0qeIsVdYB3ggB6zDzjPNVKfxVd0LqJNru36q/4yq77hgjmhtcY95
gNxwtLmCXgfwo5lw2oQfjIvCoD6x3Kt8LlWf8mHwM/ozjCPT6HTNPAp3xjOX
A6aFeTvDq+Rx0jPLJeqMeEMe0oznZ3l3vjsfFd/OQ7yLdc+DZB09cL4WH/Ie
eJhxVT9UXgLOFn3EF9RHvZjgMtQQWlj9LpPIv/TQeM1qDXyItjN/1m/0EvU7
j9Io+UI8PMc8Jn6gTspZcEIvmIcqlwwLc0NzZTTQfDu92TOWEZMt1aOuBmIV
bQ2m46I0tzVJLYch+5T5L+TdZED1SOWXYWRtLPvKp8jvIfRE1U3XjIedHvSH
aWWaBp9NTcyZy1anwWoCTy0XyEbBvCYnKhfinMLseFOuE36qmuw717L7BJMN
d3aGc4eNeWX7zEPLZSJ/mJ2r8iK4nPOB2KhP9APzq3KJWRz+D4Q7yy2bC0+y
xnpeeDp/nZ+EO7vjsNz6WO8H5z4MPw==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 90->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVksFNA1EMRC0OiDYQHUABK1oIFQQJTpGQwgFxS+mQQMLf8Rv786XN36zt
sWc8t89vm9eriHi/+f7ZbD8e9/vt59P18c/LdvdwvzsG736fiMMSf/fyc9Nz
zqFv57o4P5IbS8anXmPt6ZzvkO/m3eEcdD7BVbww81neUpPwYBaKU6zLX2mv
MeitMzt+GteeTjPSQudwulX5ystpFaam1B/8pnvs9J/da+t/41/HyWmgPfRg
X+CVtAGfjxiks/Oz24nDQJ3I94U/XV/SiGZxOdV+td7xmnkqrE6zygfEhbTt
8NGPk5qVs0S+FW/lh+HW/Nm5u31WOrp5Ow21VvteDnhdNah0TTqMMdFwxHX7
cH4JyU38QBflh1pMzLLqoVwi8571ZFW78iDNZXqF1Kedm90mLQHPajSc5C/F
0zzSGPRAjtDPeTwIJ9aY5AXCUt+grwoO6O+K76gZeaTwlttR10OxErcGs5rF
cW57Qq8Kw+5pnH+B98IDbkfOv4QxciPvO51ifA/DJzJv/FZo2PFRfYgrcVrp
XPRUn1Xe6jiUnETTchbxRsL8j08mvTXuFOPN3A6z09P1pP+XXl0cMOlUuTMz
d9iqD8VXOcaX1T6ndu7mrvYJ/09H6hI/sw/1byg29TLxzrd0pznhG2KClkmD
GT1hdqqpsKrv635fe+AKvQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 91->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVkkFOQ0EMQyMWiGsgbgAHqLhCOUGRYFUJqSwQux4dKmjJOM+Z4Uu/8zuT
cWzHt89v29eriHi/+f7Z7j4eD4fd59P16c/Lbv9wvz8d3v2+EcdN/K2bn5Xe
cw3tne9FehHDfGe8zCnS3rBvvjO23U/nDrvTgLoT1+MG8IALnTsvuvrBez2D
3srZ6dNz7ek8U//Ig+Jbo/FSE8yl6DR3Wv8hbzrHmf+rc23vST5Lb9DgPNAe
+mBf0FW8kdkqBvns8uxm4jDQJ8p9k0/XlzwiLq6mm6/ed7pW3g5r5lmXA9JC
3s7wMY+LnrVcoq6KN+QhrVq/yns2z85Hx3fmod7VvpcHsq4edL4WH/KZeJhx
3TxcXkJqiz7wRfWhFwtchh6qJaru1Ux2d4cMEi/TK+R+mbmZbfES8KxH6Sn5
Ujytg9nk+lYj9HMZJ7yhvjsjHTRXM2fiT3yXMkMZabLlZjTroVhF2wSz4+I0
T3tCrw7Dzinz38B32luZJ+YEtA8PZBn1GU6DT1lPVN2413g40xOKe+4PuMop
c51lIvfqZow5WJjRbK4DF9BHPDu8AUt1wp0Avp3mMm+DOfPT9aT/l16zc8Ck
p6td4TzDLrmF86HG5LKb59LM/5MXw+WSD5lr0WfmofkNxaZe5v8st7QWnrCH
mOClejDLuzuj/Wiwuv2x3xeMuAq7
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 92->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0FOQzEMRC0WiGsgbgAHqLgCnKBIsKqEBAvErkcHBL84kzd2Gun358eO
PTOeXj+9PrxcRMT71ffPw/7j/u1t//l4+fPxvD/c3R5+gjd/T8RxF//v3e+b
ni2HzrZ7kR6sYfb5LGPavrd13NV7V8fWN7UrDkeonbFO5wYjxSnW5YdwG2LQ
O3YjZsdP49rTaZb3nQaa6/ID7jmtwtwp9Qe/2TmnuPUx5FX/hUHXRY9Vfgno
oYv6Eq9JG8DosHd+djNxNSa8zveFP11f0oiwuJxqvnrf8Vp5qlqdZpUPiAtp
29VHPy5qVmKJ+a31Bj+kt+av4u7mWeno8HYa6l3te1rgddWg0nXSIcdEw06D
yi8huRM/0EX5oRYLWIYeOe/MuTjtELuZo2J1/oq0n/CTvqol1LMapTX5S+tp
Hswm55ccoZ/zONUb8qsY8aC5mjkTfsK75BnySOEtN6Ouh9ZSbl3NCovj3PWk
XlUNO6eIwWfTPp2tzBN9AtyHBV5GfgbToFPmEzNvPCs07PiE1t36Q13FlLF2
nsi9qhlXHCpO3VwHLMCPcFb1hlrKE+4E4F3hnLlRzU5P15O+T726ONSkVeWu
YNaZBGCjPo6reh2xLPhPvXOWXwyWkz+0ttFR96hVjHinXua78y29CSfFp5qK
H/Qt/V7E6PzcfJ7fF5qCDjk=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 93->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0FKQ0EQRBsX4jXEG+gBgleIJ4hgVgEhLsRdjq4BE2aqX3VPBr5//nRb
U1VdeXz/3O7vIuLr4e/Pdvf9ejzuft7uzx8fu8PL8+FcfPp/Ik6bSG96gs5i
rsXlMTjR4QmXy/dlnTb13uFYfIMdhl/SDVzTueFIdap1/SHaphrcHZuZs9On
db3TeTbuOw+01/VrppwvJ+UAfU6nLjvnoV79LrTPZSjlfzFjVV4CuJG+NAfQ
pX4SR8e9y7ObicPQ/E2ZUy4hulUTzI4WZhZ6iCNpRA+Mzi43zruKj+NOWsjb
Dh/zuOhZySXyW/GmPAxv7V/l3c2z8tHx7TzU/9V7rwuyrh5UviYfxpp42HlQ
5SWkN+kDX1QferHApcv76lycd8jdzFHvdfmKYT/xd/6ql4BnPRJfcBn9Idhj
Zqp8I2fDSb0gD7VeYbl+8tvxJ75LmaGMFNlyM+ruUCzV1mFWXJzm7k66q8Kw
c4qYcpb2w9nKPDEnoH1akGXUZzhNPo16IuvGs8LDTk8o7nh/MbOQ3i4TilfN
wuFVmrq5EhfL54acuFyknsVcOGyH2flp74Tv611dHTBpVb0rnGleyo3ucVo1
68hlIX86q1vy0nFJ2MZH3aNXMfOdvsN/d7mlN/GkesJU/tVvoTijGp3f2s/z
+wWwxQu/
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 94->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1FKA0EUC36I1xBvoAcoXqGeoIL9Kgj1Q/zr0bVgy5tMkjdd2M7uzpu8
JC99fP/c7u8AfD38/Wx336/H4+7n7f788rE7vDwfzptP/zdw2mBa1Y3wra4w
tYzh8CqXy/vlOm3ys8Ox+AY7aVB+KZz0veLUfbXX1YO0DXtVD6je9OVzrNn6
WDmIPkNN3XO9MdawLucVzJnof8hDmqfNsahL/4XB15QxocF5wD2UPu6rdE2z
Fhwd9y7PciYBg/M3ZI65gHSzpmZug5/oa9J8+fxKFqz2gNV5lnKgtChvO3yZ
x0XPIhfMK+MNeSgr16/y7uaZfHR8Ow/5LPe9XiLr7EHydfKh7pGHnQcpL6Da
SZ/whfVJLxa4dHlfnYvzTnI3c+S+Ll8ozwN/5y97KfCsR+SLvIx+EHbNTMq3
5Gw4sRfKQ95PWK5e+e34K75LmVEZCdlyM+p6MBZr6zATF6e566l6JQw7J2DI
2fRcvq3MU+ZEaB8ukWWpz3AafKp6MOuW34KHnR4wbu0fZgaq7TLBeGkWDm/y
UulZ5ZL43JKTcqcziq/DULwdZuen7Sner726fYGprlS7wplnAsFN9XFaOeuS
y0L+eFY35aXhMmEbH/lZeoVR0+p7l1u1Kp5qf8Jk/um/sOBndwYBK30f+/0C
ewAKvQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 95->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0tOA1EMi1igXgNxAzjAiCuUEwwSXVVCaheI3RwdKtHqxc920ieV+STj
2I55+vjaHx4i4rz7+7Nfv99Op/Xn/fHy8LkeX1+Ol+Lz/y9iW2K6sl+Yd+M1
RC9iKLyRy/X5erYF7gX37nuF7TQwv1A3m8H8xTqrVf3Je6yNegL6xVz8DjVL
H0cOZE7qX+Z7pRH5Ox835ED6lE48dM9QlzkmfSpDU/5VxoQm5QFyY/pSjeyY
7Roz5LhXeVY7URiYv5Q55BJ5buLX2FvyM+oexpFppB4InVVulHeOj+LOtDBv
K3yax6ZnlkvMV8RLeRiu2N/lXe3T+aj4Vh7itzj3dkjW0QPn6+TDWAMPKw9c
XgJ6J33EF+RCvWhwqfLe3YvyjnIXe8S5Kl8x3Cf+yl/0kuBJj8AXeoT+AOwx
My7flLPghF4wD7HusFQ/89tlAGe0MsMyYrLlZroZiIXaKkzHRWmeZkbN32HI
PYGuwPvhXWefNCdEezoky1Qf4Ul34HLC3hkPKz2BuON8k7mA3ioTiOd2ofCo
l6iny8XxuSMnCrvDN9VIvnEvDLPyU84kz7dZVZ1gsuN6O5xxJ0G4sTlKK2ad
cmnkb+JwR14qLpgD5SPeU68i8+0+V7llV8aT1SdM4qX8X2j4WX0TBsu9z/N+
AdCGC8M=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 96->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOA0EMizggvoH4ATyg4gvlBUWip0pI5YC48XSoBKuJYzvpStvZzmRt
x/Hev77vjzcR8XH3+7M/fD6fz4evl9vLn7fD6enxdDl8+LsjvndRVnaH2VvX
ELWIwbj+r+152Uv7sfAR7dN9he16YH5h34yD9YznygtXn7zHM8IdBr/wiHlR
H1cNhCfV7+qz6nHDC65FZQLfsf6bPLh5yu+C1KkM4ffBMqR8cB6gNtZfOiMz
ZrPGDDntXZ7VTBQG5i9lDrVE5k36BnNLfkZfwzSyHl1fk9thdZ65HLBemLcd
Ps3j0DOrJeqKeCkPy4r1U93dPJ2PSm/nIb6LvNtFso4eOF+LD+sZeNh54PIS
UFv6I76gFurFQEvyY5cxQ+idZBL1lxkarzFv6zv4nDxS/qKXpH/p0XKVfCEe
1pHZrPUq31Sz0IReYM/MT4cl5yrmrDKAHKPMsIyYbDlOx4FYTKvDdFpUzx0n
43IYaq6JY+0XPGX8akYs95McYb+lH6KTvudywvaMh10/VIP5BlZ+fNdlAvHc
LBSe66mba9Hi9FyRE4VdarpckHzjXBhm56fkJP83ru6cYLLL1U40s3mhNsaj
eg3CX2oH+SsarshLpwVzoHzEZ4axcqX65n+XW7Yyney8YBIv5bfQzGSyH1fW
8/n9AJIiDUM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 97->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1FKA1EQC36I1xBvoAcoXqGeoIL9Kgj1Q/zr0bVgdV5eknld2G53ZzbJ
ZLL3r+/b/Q2Aj7ufn+3u8/l43H293J5v3naHp8fDufjwewKnDaarOhGe1SsC
TsVQPSAtl/vLcdrk/w7H4htskNZJp/Dt8p58LrSouqp1/Ug1wc39br46z5KP
5TmCrorLHKmf53JewbwT/Q95SPu034Xocxma8p8ylr4t8oC1qfmGmtix+5ZY
o9Pe5dntxGFIzQI75ZPrbm+Dn+h71C7VjN1c3ZmwEnbdjdKuZlHedvgyj4ue
RS2Yr4w35KFcuX9Vd7fP5KPT23nI7zLv32GyDPHM7cTWyMPOg5QXUO80n/CF
tUgvFrS4WVBPwd9lkvVPOwxeKy6wXrVz5y97Kea3HpVjyhfjcZ/YTe13+Zaa
jSb2QnnI9YRl92r27DLAHEuZURkJ2UqciYOxlNaEmbS4mTtOxZUw3F4Hjjov
ear43Y5U7ldyxPNO8wid8r2UE/UseNjNIzWEb6Dy194uE4yXduHw0kxV05KW
pOeKnKxiQ+gdaiLfvJeptuCn5RT3ycehLjDVkXpXNCtPWZvicbNC8HPvSv4m
DVfkpdPCOXA+8n+FUbmG/ua+y626Kp2qLncK4mMPQt67nfE7HVbi+Of5Bnzu
C4o=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 98->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOA0EMizigfgPxA3hAxRfKCxaJniohlQPixtOhEoLEYzvpSu3sTDKJ
7XjvXt4Ox5uIeN/9/B22j6fzeft8vr1sXrfT48PpErz//UV87WNZ2Y/Fgqxh
6kRXLyqWSGflXLznPpNzW1vowPT6e0hcYWRxpYXLDxcjvTFf8ct8Rjqm8zC4
cl3s4fKRl/SNuGP1N35w81Q+YXnT74l5SOngNEBsjF+JkRmrbwkxKuydn9VM
VA2KmdRm/lSc1NzKvehz2CwZx46X5dzo7GrnOww748K0lRydH4eaWSyxrliv
+CGtmK84WJ8KLJi/YApf1+md8S+chZeDnKmZyBho2Gng/BKQu/AjuiAWqsUA
C2Iq/Ab+7rSj2MUcESu7g+9FI6Uvakn4S41QF/Y4/jCbnK/8TTELTM7HzAeO
n8KFMcTDPIA9Rp5hHjHaup6uB9bCPl1Nh0VxXnpGj9/VUHNlvMp7OpvMk/qE
cC/PUMuMIyC/3HM+YWdGw44PxWC+AcSP2qp5Yj03C1XPcUJNWywOzxU+mdYO
grfEiL/VvNnclZ6yJ9k7HZe44g39WH9XW+5VX+NvpaHDMvEfzuoav3RYltpC
R3ynWqVeJb/Zd75lK8PJ4uw7KfidvgNdGX62V7Vcj/8+38KvDIY=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 99->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0FKQ0EQRBsX4jXEG+gBxCvoCSLoKiDEhbjz6BoQnKl5VT0Gkp8/M7+7
6nX96+e3x9eLqnq/+vl5PHw8nE6Hz6fL883L4Xh3ezxv3vx+q77ua7nSl/YK
rhXqVFevZi01rE3rNfQD7bvrrnaJVsdi0jFygB7kWfcdi3Te9SKeX6KR+ioH
mhdyHNaVheqY9lxvOU+e0Wfg6p7TZ8beLePEr9a97n2iDDkOiUHShBxgxu5d
Uo1Oe5dnNxNXAzVDbcqn85QYkRZ3hmZJHjtf0fPgO7FLepx28kJsrceUx01m
UUutV6035QFYOY9bOTVa9PyiqXLdxHvUv3g2WS5YczOxe8KwY5DyUnJ28Qdc
VAuy2NCimjomu5lU/csMA2vUoHpp5o6vsgT/lpFwwU/yL7MZz7t8o2ajKeWY
cpD8OV2ufzqr57cyQxkJbFPP1ENraZ+uZtLiPC89q9efari5kq/p/7C2M0/M
CXifPpssRx0l56fnUk5oLTDs/KCG4epmVnK2ywTxcOuuXvKkTHe0aJ5G/7s5
2fbZ5QLy3bGw+slrw7jjuOw7ptKP+qfa9t71DfnWfgX99exO/nRW/8lLp2Wp
bTjqf2Q19JrON/ddbulKOml/yQvM0/Ld4Er66d7VSj3++nwD4QUOiA==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 100->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0FKA1EQRBsX4jXEG+gBgleIJxjBrAJCXIi7HF0DkvRUV1X3BJI/M/9P
d9XryuP75/5wFxFfD38/++X79XRaft7uLzcfy/Hl+XjZfPr/Rpx3UVb2ZXvX
93a3NUydGNTLWiI9Wz1PfZl29Ry9qtoBWqXvAN+mR/aEfjsW7rzqxXieQaPy
mTmweSHfXAvrOgar6+Y880x9Gq7qPXwn924ZO35R92z+RYYUB8fAaaIcyIzV
fwk1Ku1dntVMVA2qmdRm+VSeHCOmRZ1hs2QeO1/Wc/Lt2Dk9Sjvzwth29Wke
h8yslqgr1lvlgbBSHkc5FVoUR6V3NN/8jsqnyHKQZ2omcg8Ydgwcv4CzxR/h
glooi0YL8mF9pnNR7Kh2MUfUqvIV6XrFiNSlWST1JCPgQj8bspPPW4+kn9PE
ZqF4qlpKl+rvzrr+XY5XGdnIdtIDa2Xv5Tmp6bQ45li70+9qIC/aI/sFpqy/
mhHL/SRH6Lf4ETkt7xmN17PkP9TNh/mhGtKqZhZwtsuE81M4iXrOE+PbacE8
Zf/TnIx9drkg+e5YSP3Ma8O441j2FVPox/q72vJe9TX5xn5B+uPZSf5wVlvy
0mkptQVHvKasUq/V+ea+yy1bmU62X/JC5in5Drgy/exe1XI9bn1+Adv4EEs=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 101->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FOw0AMRC0+ENdA3AAOEHGFcoIgwVclpPaj4q9HhyKg3tmZsVMpjbLZ
tWeeJ/evH7v3m4g43n3/7dbT8+Gwfr7cXh7e1v3T4/7y8uH3ijgvMd3Zxd79
n1uu9zB1olEva4m0Nqynvky7WkevqnaAVuk7uG/WI3tCvxULt1/1YjyHWRmf
mQObF3rNtbAuY3BeZh5uP2ZKccnakIU7h2dQ6+Q1RhaSX8zvbP6Bw9TbfVvA
wGmiHMiM1beEGpX2Ks9qJqpGNTuXT+XJMWJa1B42S+ax8mU9p1k5dk6P0s68
MLZVfZrHJjOrJeY71ousmbBSHls5FVoUR6W3Nd98RuVTZDnImpqJfAcMKwaO
X8DeyR/hglooi4YWZFox6WYS9U/9DGvVK+D8NHNSl2aR1FOMkAv9bchO3m89
kn5OE5uF4qlqsTo0r429rn+V4yEjG9l2emCtn1+Du8u548/OIB/Wy9VAXrRH
9kt4dubpcqI8dFlG3pMvPGc05vOMi/Kl/KC3ob/JXJA1lwnnZ9hXfD+4j2nq
asE8TTlqaGE5oz4LXrlGNW82d8lT9GTPjiN7r/oMe0l/V9t6EHlR+VYMnRa1
5mZVzX6Llj+f037BldaAGSK36rnKLbszney9mimypXwbXKtvpKrlelz7fAEY
ig0Q
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 102->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1tKA0EQbPwQryHeQA+weIV4ghX0KyDED/HPo2tEN901VdWzgc0mMz3V
9ei5fX47vF5FxPvNz9dh/Xg8ndbPp+vzn5f1+HB/PG/e/T0RX0sMb/awve3c
cnmHwQnxO+NlLpHWynrqy7irddSqsEPwYxjIVfXIdagXOaJOV696DXri4k3h
bHJArsrfjIW45bOQvYXwSjqQv8o062NeuHN4JvduPXb+xbhn7xP44GbM3p2G
E/WBZKzuEnJU3Lt5VpkojC47N59Kk/OIcVE1LEumsdNlNaesnHeOj+LOtDBv
O3w6j5OeWS4xvhEvMmfildI4NaeCi/JR8Z3KN59R8ylmOciaykTugYedB86/
gNpBH/EFuVAvGi7oD+szm4vyjnInPSPzEb1knoCBPQcvCZ70CHyhnx2zk+ut
RtLPcWJZsN9OH8Oh8zpR6/p3c1xmZKe3Mz0Q6/cz4bubc+c/O4P+sF4Oo9WZ
dG1v8szgqjlRGma9lNyUBsJxqyV3qMuH6UFtpb+ZuSBrbiacnlLX3B93D9xZ
xiVMXfbBciD+U52NX4jj8ma5Sz9FT/bf+cj2VZ9SS/o7bKtBzIuab+Wh46LW
bOZN9nu4/Ouk80h8pRiQIfrm8uvmdsMm3FQODLvgBfTbM+9NZngmDJZbr3l8
AwyNChA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 103->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOA0EMizggvoH4ATxgxRfKC4oEp0pI5YC49elQYJfEYzvTlbazzWQc
28ncPr/tXq8i4v3m+2e3/3g8HvefT9fnPy/7w8P94bx59/dGnJb4X5fflb1r
Dout52J9ITeWEZ/VWp/tO8VKPNVFDW087Sts58OJYDMcFQ+iN3NkXrh8VQv1
UKymD8hV+ZuxELc8C9nDGQEdjL/yJXNDL9w5Nw+tx86/GPfsfQIfhtriHPPA
caI+kB6ru4QcFfdunlVPFIbTM3CJsS7TNINZsE1d7CXT2OmymlOvnHeOj/SM
aAkR7/QOvk96ZrnEuCLe6g2umD/Lu+snw2ScHK7zO/MfNJtZ7uZbzc62Bx52
Hjj/AnIHfcQX5EK9aLigP6zObF+Ud5Q7qRmZj6il+okYWHPwkuBJj8AX+lww
OznfaiT1HCfWC/bt9DEcOq8Tua5+N8dlRi70dqYGYv08E767OXf+szPoD6vl
MFqdSde25hc0O1w1J0rDrJeOG9VAOG655A51/WF6UFupb2YuSMzNhNNT8pr7
4+6BO8u4hMnrtBW+EzPb+YU4rt+s79JPUZP9dz6yfVWn5JL6DrvTMOyZ+VYe
Oi4qZnve9L7z3c2l8hG/Cwb0EPvl+tfNreOm+sCwM17h4e6CiTHu7EwYLBev
mr8Ap00KlA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 104->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVVkFKBEEQKzyI3xB/oA8Y/ML6ghX0tCCsB/Hm03XR1apUkmobxpmt7kkl
qQx4/fiye76IiNerrz+7/dv98bh/f7g8/XjaH+5uD6fNm58r4mOLv/v2fWfX
+Qyrnd+LdJVzW8dnvc7r9znVSl08Z2xWLxxhIZ67mm8Ex9VRL+vJ6uy86lVq
qvcwh9h6H+ZvxkLcsjayhxkBHYy/8iVzQy+s/yYPo8fOv+h79nsCH1pv8R7z
wHGiPpAZq28JOSruU57VTBSG09O4RO/LNK1gFmzTF2fJNE66rOY0K+ed4yM9
I1pC1Ce9zfdFzyyX6HfEO3uDdzy/ynuaJ8NknByu8zvzb5pNlqd8q+z87oGH
kwfOv4CzTR/xBblQLwYu6A/rszoX5R3lTnpG5iN6qXkiBvZsXhI86RH4UvqA
50y/y6XViJwdJzEL9uz04TmZ14Wzrv+UY/T5P96u9EAsxtVhOi7Oc9eT9XIY
o84I+v/mlNsJW2kvC71MF2YdudEZGI65R8adsqf0oLbS32QuSM1lwukp54wG
p2l6l3HB+ax+D22mC5md/GJ5cfPEuUs/RU/22/lY9gkmW+7sCufyO3lU9ky+
20xFFmQGVmc+zH7y3eWyaCe+Ugzwqb274LnKbdauuOSlsAteQD+VbVNj3Nk7
YbBcvc7rE/cEDoo=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 105->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVVkFOA0EMizggvoH4ATxgxRfKCxYJTpWQygFx4+lQYNuJYzvTlbazm8na
jpORevv8tnu9ioj3m5+f3frxeDisn0/Xx5eXdf9wvz9u3v3fEV9LnNflb2X3
lpNiZA2Si3mKa7tOz0MsxcXziM3iqNFhu7v4RnBcHOtlnCzO8hVXiinupg+x
VB7m74iFuOlayJ7iDtBJaqZzY3xV37l5aD12/kXdc+cpnRXG7b4DD5wm6gPp
sTpLqPGUZ2pTfjAtzh9VT9ESlZfVNIOZsA0v6yP73tXV3b9X4103V9QzUkuI
eFdv8X3SM6sl6op4mze4Yv6s7q6fDJNpcrjO71F/qdnMcjffanZOe+Bh54Hz
LyC31Ed8QS3Ui0YL+sN4ZvuivKPaCWeMegSX6idiIGfxkuBJj8CXxMNmkWCo
ubQ1omanSfSCPbv6ME/O60Su4+/mGH2+xNsZDsRiWh2m0+I8d5yMy2G0dUbQ
/5vJz0lcNSeqhjLDwD3OutKWMI1GGmv2XT1YW+I3Mxck5rS6elKeqcHV1H07
o2X2PJSeTsxs5xebF9dP7Lv0U3Cyd+dj2ieY7HK5M5rT++BR2jPzXXoqZuES
z92cMe4Om3qImDA/rB8MY6w75U94LvtKfGS6lFanM2kzHrIzwLSzMxIirvJ5
/74BqoMRzw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 106->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1tKBEEMDH6I1xBvoAcYvMJ6ghH0a0FYP8Q/j64rLiTVVZW40Dsz3Zl6
JXP7/HZ4vYqI95ufv8P+8Xg67Z9P1+eHl/34cH88H979rYivLZYrW+wsyDVI
LdbhfebIWiLtlX1xn7GVp6yRYgv/LAvUMd1Hv7ifdXb1iqvsKe6mD6pfmG/m
QNwlAzxrPDL91EtUbZiFzX+DFbV+8Ro8l0lflRb1rbgcXAZOE80BM3bzTjxg
X52+ricuH+Vn0RIrL87kFLNgG17WR/a+89Wt31+TnZ0rlRnxEmK/87vkPszM
aon1iniXbPCK9VPdXT8ZJtPkcF3eWf/imcw6m3/XE3kGGXYZuPwCahd/JBfU
QrNotGA+jGfaF5Ud1U44s3bFpfqZ38f5oLNI8GRGkEvhYbNIMNRcWo+oudHE
esHunT+GQ+d1UOv4uznGnP+T7YQDsZhWh+m0uMwdJ+NyGK3Py4/MbM53gqvm
RHko38YWC3eedaWNeiAa6R45X7iFH/RW+M3MBdlzWp2fUmdmzPWoe3ekJa/G
G74zwjaYbl4cd5un4GTPLsdyTjDZz9VONJdn6M0y74RbfRNOi9qb9IVxd9g0
Q8SE+WH9YBjZd6kfZK76ynJkupRWp7NoMxlOclXfSIh9Vc95vgGxMBFN
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 107->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk01KxEAQhQsX4jXEG+gBglcYTxBBVwPCuBB3Hl1HHOiu/t6rMtBJp7vz
/qpy+/x2eL2KiPebn9th/3g8nfbPp+vzy8t+fLg/njfv/kbE1xbLkwbtBTwD
zuZzeT5yjFpiWJvWxXzEVp4Il/DcoNxIi1rPfonzkmV1XnFNayYH5S/v5/nC
m+dC87JXeCT96CVmbTkLm/+WRsznF6/BuXTqqrSof8Xl4DJwmjCHnLHrd/CQ
6+r0VTVx+Sg/i5ZYeXNPdjEnbMNLdaTvna9qOCyHnb0vmYGXEOuV3yX3ZmZW
S6zPjPd7wTOf7+quakCYpKmNS7mp/oRep/53NZF7KUPX0w7H9YGtSdKCWRRa
cj7E062Lyg61A+eoXXGpeo7f5/7AXgQ8mVHKZeIRtXM1H/mtx6y50ES1oLnz
RzhVv6qzjr/q45zzf7LtcGQs0uownRaXueMkLodR+rxc0LNjvh1c1SfKw/Rv
bLFwj72utKEH0IhrsL9wCz/Z28Rvei5gzWl1fqZzpsdcjapvW1rGUXhTei12
E7ObRa4x5ik46d3lOO0DJl3ubEfz9J5qs/Q7cKt/wmlRa526EHeFjRlmTFMD
19uj72m9kbmqK+YKupRW8op7jf+jU7OMM2bQOc8831IKFJI=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 108->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0FOQzEMRCMWiGsgbgAH+OIK5QRFglUlpLJA7Dg6FEhJnDdj86X0/zqx
PZ6ZXD++7J4vWmuvV18/u/3b/fG4f3+4PP152h/ubg+nzZvf1drH1v7e28+b
Vj9DsZ7X+gpn27bWp179OX8PsSkuvsfaFFd1qZ5bC29Qx8XjvNSzc5mdV72m
mOmt5ut5pFfkd+xx/haYl71kRsLvZiHPZHltC6vN55dZDZZMV5eHd8bw4Dhw
mJAHuEOjXhMvMEPU1eHLNHH8kK8WTUAzys04IiyuL+GkfKd7tlwtV1vx5vRp
Ip7Nu/Be5Mxiaes71vt+4B3PV3FnGlBNwlSuS7wpf4LXyf9OE7kXOHSednWc
D6wmAQtykWCJ/FCfqi6KO8QOPUfsqpfSc8yP/kAvqrrEUeBl6iO0c5pT/wwL
zeN6TfnDinsLLqiT+VWdjefJk8rHkef/cJv60miW8e58rvhXObEn9XI10jn7
A54d+a3UVT5RM0x3A7QcvaCw4QyAEWPiHlTmibOp/ktu0YeZlksf4zGnUaZr
CQvMn2GJeNPahZpVLqLGyKfoSf/PPGb7UJMed7aCefq/temeLX6H3upOOCwq
VtGFeme1W8wXMaWB8/Y49xQnjhM/WV4Bl8K61FV+KNyPimaxzshB5Tz3+QR9
thKS
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 109->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0tOAzEQRFssENdA3AAOMOIK4QRBglUkpLBA7HJ0CGCw26+qzUiTmdju
rk/XXD++7J4vIuL16vNnt3+7Px737w+X5z9P+8Pd7eG8efNzR5y2+Htu30+6
2xlaa3XR7nQ2trk/YbXr971bG9bFe9+b1k/bXKv6uXvyDfq49ayXMJuX1XmF
NawZbKWv1dG8sr89xu+74Ex7TiPxd1ooM1Vdn1vKzqTVcKnm6urwmzE+OA8c
J+lDAH5/B3OjuTp+1UycP5Qr4j74JvRWHhEXh0s8qd7NvbpdL9db+eY8CbFe
6Z3yuOiZ5RLzM/f7uuCpMl7xrmZAPYnTcl/yTeUTsk75dzORe8lDl2nXx+XA
ziRxQS8KLtkfwlmdi/IOuQNmz11hqXn29TkfmEXVlzxKvjgs0u9yaTVmvIIT
zWI47/YAYzWv6mw+T5lUOe45B52LGtNh5F7E1fV0XEgz1WRMwnI9Sp3tSl4O
fi72VTlRGoZvo/cUsq64oQbgiGvFvtOTtSn8qXYxh9UsJxyjwWmq5rrChfRX
XDJfqfMfPVe9yPlCPwUm/c91ap960uXOrnBemQnhKK0B+Pms+4aquRB21Tty
vVhTM3DZ7nUP6+RxkSfrK/BSXKe+Kg8L38fKzHKf3oOV84zzAdn5FFk=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 110->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FOw0AMRC0+ENdA3AAOEHGFcoIiwVclpPKB+OvRoUBg430zNpHSpLve
mfF4cv34snu+iIjXq8+f3f7t/njcvz9cnv887Q93t4fz5s3PHXFa4u+5fD/p
XmtobT0Xw72pW2Z8hTdqimFtsy7eRz5aPy3zWYXn7sk3wFHr2QPFmWtVveJy
/mz8Ff1NWtP7xJvfhWbaO7n6AVtlZ8IHL9y5fGbk7ngs/YM9dw6/GeOD88Bp
kj4E8JMW6IHqlL5qJs4fyglp3/gm+q08Ii2Ol3TSeTf36nZYDlv55jwJsV71
O+Wx6ZnVEvMz431d8FQZr3RXMyBM0tTGJd9UPiHrlH83E7mXPHSZdjguB3Ym
SQt6UWjJ/hBPdy7KO9QOnNkP9/1Mnq8X5AOzqHDJo6TPcVH/Lpe2x8xXaKJZ
bOrdHnB086pqcz3NUOV41Ix1UXO6byVjZZ4K02lRGZ44g/WrOVW+K47ffpeY
/Wziqpy4Hja8az1kPdfjDIzGak31pfpBDcXMcq4cZzVLWld4rqdqrh0t1H+l
JZrY/8FU2LRf+ak46X8+p/YJky5X29HcmQnxqF4D+HNtJ39qLsRdYUc+L9bU
DFy25brxWPVkfQVdSuuEq/JQ5Lw7s3x29KBTzzwfsi8SXQ==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 111->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FKxEAQRBs/xGuIN9ADBK+wniCC+7UgrB/i3x5dVyRMel5Vt4FsNjM9
1dVVlfvX98PxJiI+7n5+Duvn8/m8fr3cXl/e1tPT4+m6+fB3R1yWmJ500952
blxL7+N+NPBGLjGs7dbF/x0HMVM+S3iZv5wbsKr1rMG4r7Rw9aqX02enr5hv
4po9zn3zf8GZ9i6ufsBW2ZnwQQt3Lp8Ze3c0lvrBnjuH34zRwWngOEkdAvoT
F5iB6qo8K0+cPpQT4r7TTcxbaURcXF/iSeed79XtsBy20s1pEmK9mnfKY1Mz
yyXmZ8b7veCpMl7xrjwgTOLUxiXdVD4h61UWiBfuJQ1dph2Oy4H1JHFBLQou
WR/q0/VFaSe5L+mOmSt5T35uF+QDs2hwJ42SLrtLeOc8p/7IBfo5Ti7buafC
Ipwqr6o21zuttzkgIy5brqfMpfCso3uHi8ow9ayy4TDKOQe87Zl1b+KqnFQz
jP2zvzsvllQHOimO1ZqaS81DHCrPcq5cz8pLWld4bqbK1w6X7KGry56Wc/4D
U2HTfqWn6knv+ZzaJ0y6XG2Hc8cT6qNmDeifazv5U75Q7wo78nlYcx5UNbhu
NFYzWV2Bl+I64ao8NL6PjmcZJ8S6quc+3xjtFd0=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 112->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FOw0AMRC0+ENdA3AAOEHGFcoIg0a9KSOUD8ZejQ4G2G++b8abSdhOv
dzweT+5f33f7m4j4uPv5282fz8fj/PVye3p5mw9Pj4fT4cP/ilimuO7T307r
nEOx9l4ATkyQJ/BaTtHEVvGmbu7BxZepxyFsp0PGaHvu4oQP/VZauHxVi/Ss
ZtfVgRmSvufc1bPgTGeLy2+wlXc6fNDC3ct32tojGkv94Mzdw2/G6OA0cJyk
DgH1iQv0QHmVn60vVZ+in45L6LqOC2GusE1d4kn33dyr5bActtLNaRIiXvXb
+XFQM8sl+j3j/f5gVx6veFczIEziNIxLuil/gteRo5mJnFfS0Hna4aw4q/5A
l8wFtSi4ZH06XhvmrbST3Ke0oudKs6ccp9+IvyLvhB39u5qVm/n5nvM3ca44
KW+rbwR5AY7zq8vN+U7rSx/gEectV1P6UsxsRPcRLsrDVLPyhsMo+8zP03Vl
fStc5ZOqh0tdpVHmlnBVP05n4rWlH+JQzSz7ytWsZklxhed6quY6wiXP0OXl
mZZ9bsBU2HRe6alq0nu+p84Jk34ud4RzhU1+db0G1M+5I/5Tc6HaFXbXZ5qr
0iU/qxyMD2iutEddgZfi2uEqPxQ+H/kWKN5qsAVnff8bPWAW2w==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 113->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0FOw0AQG3FAfAPxA3jAii+UFwQJTpWQ2kPFLU+HAmk3XtszIVKadHbW
Y3ud+9eP3ftNRBzvvn920+n5cJg+X27Pf96m/dPj/rz48HdHzC2uz/b7ZPfS
w2r9viA40UifwOs5RVdb1bu5qMHV5zbiMGznA2L084Y6wWd6sY46Xb+axfzM
znOYI/rR36VX7Vvx6PNQ0NhjK+4DPvHC+m/yUPFY+kfWKv6vvhnjg/PAcZI+
BJnPuKhMFDzJfEDPnS9KE8tnlQvDXGGbuYwn2+/OPcuE89lhK9+cJyHqVKPL
Y9EzyyXGJ+L9XOSpMp7xdvwUJuNUxmW+qXySrGdZYLzoGnjoMu1wJG6MehwX
6kXCBf0ZeKGn5lyUd5J7gztGruzsZ9iH/NC/Sr6C9Lmssv/V7Cw8Xb4Z54yT
yzbOVFgMJ8ur6sV+doYqx4qz0ruFP+bjchV8r3BRGWYzs2w4jFQnvrNvpoir
cpJpuMxVHiE3wFV6nM+M1xY9jEN2ZkxLlgmnB+tKg9PUc/ovFzxD14dnmurc
gFn1gvmenZvCZfvUOsNkl+utcM6wWV6d1iDzsbeSP5UzNjvDHnQWc4vvqofW
C54r76mvhJfiOuCqPCQ5r3wLrN57sAVnvf8LUo4Y2Q==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 114->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0FOQ0EMQyMWiGsgbgAHqLhCOUGRYFUJqSwQO44OhfaTyX/2pCO1v53J
OLbjf/v8tn29ioj3m5+v7e7j8XDYfT5dH/+87PYP9/vj4d3pE/G1if/n5u9J
n3MN7eV7IWpXdQIvc4q0N+zHulfGq/XIuaxhz/hQMTKP1T7gk966XzW4etWr
64PSV30YcKmvuTfwSDnoaMzYivsKH7yw/ps8dDyW/sFZx//8rjgfnAeOk/Qh
oD9xUZloeDLzoXrufFGaKJ9dLoQ5YJu+xJPuu7nPMuF8dtjKN+dJiH3U6PLY
9MxyifWz4v0ueKqMd3urzBImcWrjkm8qn5D1WRaIF54VD12mHY7EjbUexwW9
aHCpPUnLssxclHeO+xlz5SFwHPio3IJ/nXwF1Lms0v9udjJvq1H0c++Pynbt
qbAIZ5ZXVVvraYYqx4qz0nsJ/5qPZTV8b3ERGaaes2w4jKnOE1bU3+DvDJdy
gnhFw1IXY232qvKkGTiOy3nGNHMYamLErb8VF8qH0qnmWe+6GZOG2YwyJ1Xb
yVXVP+NSe6o75H9Xo+utPFEeKVy6p84Jk5ar7XCeYat5Ka30jtTaTv4oZwG8
O/N0ut15/T3UTHJJXBX3lq/Aa1lGVz63eei8J8397MElOOP9b9SFEts=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 115->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FOAzEQQ0d8IK6BuAEcoOIK5QSLBF+VkMoH4o+jQ6G7TSbPzhBpu93E
8Xgc5/b5bf96FRHvNz8/++Xj8XhcPp+uTx8vy+Hh/nBavDs/EV+7uLx3f296
VgzNtftCYAec4Gs1RTPXzcdYq+XLeNScRjdnfMgcrY5hHvip3zyfe3B4Vavq
g+ov+9DxUl2zr9PR5KDSY8uttA/84IX13+Sh4rH0D9Yq/rd3xfngPHCapA8B
9UmLykTBk5kP2XPni+qJ8lnVQpwdt6lLOmm/O/dZJnJv1Uwp35wnIeZn/Q55
LHpmtcT4zny/A94q49XaKrPESZrKvOSbyidkfZYF0oVryUOXaccjeWPsx2lB
Lwpack3qZRuzfIN3TvvKOXgIGjs9KrfgXyVfATiXVfquZqfVbXsU9dz9UdnO
NRUX8czyqrAZT2foPCPNqt//6M/52EbB95IWkWGqOcuG45j2eeaK/B/8nfFS
TpAvebbhoscOnI1OOgOncVuHM5B3I+VA1hM5pXx0fcZcS97rzphwszNqNSls
JVfZG4XrvC1wk/+Vx2HJn8yvatJ33qfWiZOGw1Y0z7jVealeA+pn7MxzlbMA
3ZXzHPos5jb/Jw65t+C58t7dFYVXe1etas3lvHIXaJ56rPD0+78BbdsUHg==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 116->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FOw0AQQ0d8oF4DcQM4QMQVygmCRL8qIbUfiL8cHQq0nXhtzzRSukl3
1uN96zy8fWx3dxFx3Pz8bOfPl8Nh/nq9P728z/vnp/1p8vH/jlimuI7T38ju
cw37L68LUTvUMb2sGdf387VM8Az1WZv+n2+48jrHYSE9Q/Rk+qiT59lcVa96
dTi4/SGHYT1hptatfKTerfqkrbIz6BMWlr/JQ4ex5Efm3Dr2rTgOjoHzJDkE
6c+8qEw0mFQckLnjovbE8tn1wjRX2qYv88nWu3OvMqF8VdqKm2OC/Tp5pXls
MrNeYhxR7/cio8p4t7fKLNNkntq6jJvKJ8l6lQXmi84BQ5dppyN1Y9yP80JZ
NLxgT8cE89th57xnfsjDfT8yt4RfJ19B6lxW2Xs3O9m33aPo574flW3sqbSY
TpVXmZUQ/cg+2T6YZ7XfW/xjPi5Xg3vLi8gw61llw2mU+0x6lxG5N3VVTtj5
DB6gP9VM58LOwHmkXgxDzIDqgZ6xP2OR91t5wbXujFlddUbZk6rt5ArZqDpk
W2njGSgt57tbz/woxnKdOSemyS5X2/G8ek+emBbrrfLkvFTMGRs83yqzNpfN
3OIz05BrG8zVuVKuxJfyOug2s+iYuhrH8xad9fpv4PMTmg==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 117->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk0FOQzEMRC0WiGsgbgAHqLhCOUGRYFUJqSwQux4dWmib77wZu5F+05/Y
4/F4/v3rx/r9JiI+735/1puv591u8/1ye3h522yfHreHy4f/J2K/isu++tvp
obtTXo6j84xR5R7XaY90Hhw/YtP5yCGvxZnRYQ81Q9Qk/Iwz3tNdFa9qOR3c
jJQOKn+MVXkLHjQDFz9gK+9M+KCF1d/4oaOx1A/uXJ7yqdLBaeA4SR0C6hMX
5YmGJpUOWXOni+qJ/NnlQpgLbFOXeFK+m3v1KF4VttLNaRLivOqXeHY0s1xi
3jPeccGuPN6trTxLmMSpjUu6KX+C1ysvEC+8Sxo6TzsciRtzP44LatHgkmtW
mnR9kflT3Khf1sN9P9K3oF/HXwFxzqv03vXOyNv2KOq570d5O9dUWIRT+VXF
5niaodOMOKt+r+Gf/XFeDd1bXISHqWblDYdR9jngnffcXxNX+YTmM3FIezUX
moHjiFyMhtkDqsaZc/ENZP65T8Ul57oZU1w1o2quisukE+hlOVyDXWBSv66+
iic+SmOZZ+ZEmLRcbIfz4j3NZvIK1FZ+clwqzUmbPN/Ks9aXTd/m/yoGzxua
q7mirsBLcZ1wm150mroYp+c1OMv8HxJSFN0=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 118->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOw0AQG3FAfAPxA3hAxBfKC4IEp0pI7aHilqdDA213vbZnslK6ze6M
x+NxHt+/dp93EXF8+P3ZzafXw2H+frs/v3zM+5fn/fny6f+JWKa47dPfzh52
d8nDOHaOGFnuui57wHnw+BabnbcccHVnRoeF1AxRk+EjTnvP7rJ4Vcvp4Gak
dFD5bazK63iwGbj4Blt5Z8AnWlj9jR8qGkv9yJ3LUz5VOjgNHCepQ5D6jIvy
REGTTAfUPPWo4N7pJvqtYnbYpi6bH8t3fWWP4pVhB+QPmjGdjFauX8azopnl
EuOOeOsiu/J4tbbyLMNknMq4TDflT+L1zAuMF70DDZ2nHY7EjbEfx4Vqwbgk
mmaaVH2B/Ie4qXmIHmr2qH2nUYIn+zPzQl3Ue9U7LW/bo6inODhvY02FxXAy
v6pYjGczdJoxzqrfLfzRH9dV0L3CRXmY1cy84TDSPhu86479FXGVT9h8Bg6w
U0zCLdMMNeq4GA3RA5Qv/M9mtmBO5Fww152zuGxG2VwVF9SJ6WU5bMDOMFm/
rr6KZ3wQh713eW5OBJMtF1vh3L03nBgWqz3ECC9s0Zxpg/PdMk/Wp+LOdHXe
Ri4KS/XkdO3wCC/FdfgWlB8Sn1e+BXaeYaX3K9cfOKEVFA==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 119->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVk1FKA0EQRBs/xGuIN9ADBK8QTxBBvwJC/BD/cnRNMDLT86q6s7DZ7E5P
dVV1zf3rx/b9JiI+735/truv58Nh9/1ye3p52+2fHvenxYe/O+K4ieVJd9A3
qA+DE8XezOWCdbmOG/9/xFCaItUQHmlVHEfN5KflktZprapXvaw/1azBB7V/
rFX7Jh4wA6cR+Ys9eRZUp3TmC+cMuBmzmmuVf8ppPg9uZvmcESfpQ6z9kYvK
RMOTyofseZlRwX3yTejtYk7Ypi/Nr8rutbfiVWFnPxbPyCfjldNLPDueWS5R
6zhf8FQZ7/bueEn5oNrKQ9KD2YOsV1kgXriWPHSZdjgSN1Y9jgt6QVwKTytP
urnI/Je6zXCDH2r22fvJowJP6jPzyr6o9252Rt5Wo+inOLhs554Ki3CqvKra
XE8zlJkZbpct11PmUszM+Z7n5bioDFPPKhsOo9Q54P0/s74mrsoJzWfhIM7V
whHqSI/yeeJiPMwZmDgkLmMGc3/yIut1XPLe6XvKP9VVM6rmqrgseOCX5dDF
bmCSXtdf1ROfjEPv0z6Rd4VJl6vtcFYZISzqvdSILFzjOXnjPKywSafiTr66
bMvvat7CC/J1rCdeiutyFlQejP/ds0DfK9xy/cz1Bz9JFRg=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 120->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOw0AQG3FAfAPxA3hAxBfKC4JET5WQygFx69OhCKJdj+2ZRNqm2Uw8
Htt7//p+ON5ExMfdz89h/Xw+n9evl9vrw9t6eno8XV8+/K2IyxLpzlawPVIf
ohYxVK+RS/zfA/bF/xFDzRRQo/DcSrqJngwfcVRPts/qVa9SBzPndon6YH3N
dxMP4oGbkfFX36AX1cyUu+nNcBGz8rWjP+YUz4PzDM8Z4yR1iNyfclGZaGhS
6YCalxkV3CfdxLxdzAnb9GX+VdnduxSvChv1SJoxnYxWbl7Gs6OZ5RL1HL8X
uauMd3t3tGT5YLWVhmwemj2S9SoLjBd9Bxq6TDsciRt5HseFatHggj0rTbq5
QP6pbhkW0UN5j9pPGhV4cj6jEeqinrvZGXnbGUU/xcFlG3sqLIZT5VXVYr2b
k80RQ80ebcsewjOnO/rluFCNh75OT+yl5pTZEXNt9yXvdXBVTpg/iYM4V8oX
5oHjSLkYDRlX1AT/V55d8JuoueC30z7kn9VVHlW+Ki4JD86MwtuN3cBk87r+
qp7xQRz2nPZUdgkmu1xth3PCHnRM54H0TjXCrz2ab152tG/4meYU9UpXlz+5
39Bc+Yp5dtlg79NZUHkw+nfPgtvfizP78Q0MJRbb
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 121->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOAzEQG3FAfAPxA3hAxRfKCxYJTpWQ2kPFjadDV7RKPLZnNtJudpOJ
x+NxHt+/9p93EXF6+Hvtl/Pr8bh8v91ffj6Ww8vz4bL59P9E/Owizexhe8Hi
xDrGy5iBS1zngHXxPWKomvCswnNP0k3kZPiIo3KydRavcnV1UPWtQ8QHy2vO
TTyG3ndqZPzVGexFVTPlbnIzXMSs+trRf7wfU25zDjVwnKQOkfNTLsoTDU0q
HVDz0qOC+6SbqLeLOWGbvKx/lXe3PopXhY16JM2YTkYrVy/j2dHMcom6jnWQ
WXm8m7ujJfMHi600ZPVQ7xGvV15gvOgeaOg87XAkbuR6HBeqRYML5qw06foC
+ac44zmVC/uZMIh+HX8FiXNeZf9d74y8bY0in7s/ytuYU2ExnMqvKhbjXZ2s
DsZZ1av40xyiZx3dO1yoxkNepyer2fWh4nXFu827vNbBVT5h/UkcxL1SfWE9
cBwpF6Mh45r4wnfVM/TVFKc8AWfR95gb46oeVX1VXBKeqc3xKLEbmKxel1/F
Mz6Iw/6nc8LvCpMNF9vhPPJYx/Cd7gPJnWJEv5TmVF+3jnU0+pnqNlyYrgqD
6aSwrG+JrojPeN2GwMb9tCc8v+UuuPWtOHM/fgH0qRVb
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 122->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FuAkEMizhU/UbVH7QPQHyBvmArtSekSnBA3Pp0CqJoxrGdsNKy7EzG
sR3vy+fP9nsVEYfnv5/tctzs98vp4+ny8rXs3t92l83X2x3xu470ZDfbC1Yn
1rHenY1bv/szZo7q/8hVacKzCk9xZH6F6MnwEQd7Mg2uXvXq+qD0qT6j3qkW
/iusMR9Y6zxTXJJO46s6N+WOzRe1Gi7VXDv+j9mbeptz6IHjJH2I3J9yUZlo
eFL5gJ53Msq4T74JvV3MCdv0ZfOrsvvorXhV2OhH8oz5ZLxyehnPjmeWS9Q6
rhd5qox3e3e8ZPlgtZWHTA/NHsl6lQXGi+6Bhy7TDkfiRtbjuFAvGlywZ+VJ
NxfIP9WZzKleOM+EUeBJfcYjxFPv3eyMvK1G0c99Pyrb2FNhMZwqr6oW6xU/
pYNxVnoVf8wHZl1pc5gVF+rx0Nf5yTS7OVS8/vHuz3Ve6+CqnLD5JA7iu1Jz
cdlgHCkX4yHjinwV9xGLeYFrjguexdzHsM40VDOq5qq4JDyjjeJ2sRuYwdZM
f1XP+CAOe5/OibwrTHa52g7nkcf1En6z/kwryxfWsvo0xyKPVWZtLg0X5qvD
sJ6G3mea0nniPc2BwMb9tGc87H4Lbv1RnHkeZ1F7Fpo=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 123->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVlEFOw1AMRC0WiGsgbgAHiLhCOUGRYFUJqSwQO44OLSUk/m/GTqTwmx//
8cx4wu3z2+71KiLeb37+7PYfj8fj/vPp+vTwsj883B9OL+8ud8TXFP/r9LvS
/Vez2qM6gxPNs3HpN6+x4Gh+L7nS/kpruvI55wf5Rj0JP+PknqTB1ate1p9q
TqbPUu+qNv1WWMv387minuarvKLMVOdWuaP5Zq2GSzVXd46+leybOpc9cJyk
DzH2Ry4qEw1PKh+y584/pYny2eVCmCts05fmV2V36614VdjZj8Ez8sl45fQS
z45nlkvUOs4XrCrj3d4dLykfVFt5SHowe5D1KgvEC98lD12mHY7EjVGP44J9
cv0Uq/9B5GnlSTcXmT/Vqb6qV57nkNsCT+oz88p46rmbnSVvq1H0c9+Pynbu
qbAIp8qrqs31ip/SQZyV3i38A7CIq8N0XNDjRV/nJ2l2c6h4/eHN6zTudXBV
Tmg+AwfxXam5uGwQR9yr3sOVM+e4UD4C9hwXp2eeldFQzaia62YuoM3xKLEb
mFFgd+uJT8ah59U5kXeFSZer7XAecBc+ZizqPdSIeSnP0V+xX+XPac/5U1zI
F4chPS08J03DefBe1gP2fDXy0LnlTDZgtPqceX0DQJsXHA==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 124->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydk0tOA0EQQ0ssENdA3AAOEHGFcIIgwSoSUlggdhwdwid0Vz+7ClrqzKQ/
tsvlubx/2j6eRcTzxcfPdvdyezjsXu/Oj38edvub6/1x8+p7Rrxt4ve5+XrS
/DkzrdE5gxMNvNOM4RmDRvM+YtP6VGsa+Z7zg3wjTsLPOJmTanDnw+0J7tFn
VR9hTfdzjQKXPJg0N85Tf5VXOTsuw0q74q586fTV3aNvJfum7mUPnCbpQ6z8
qEVlouFJ5UP23PmnaqJ8drUQ5oRteKl/VXb/OpWuCjv7sXhGPhmvXL2ks+OZ
1RJ1HZ8DnirjXe6Ol5QPOlt5SPVg9iDrVRZIF+6p2kw/lH8K1/Uk30Ee1Q/y
tPCJ1jveldrJQ8GV+7nktsBTdWT/8l2n171TzaNuW2Phj+OiGtwecXTzqs46
ftWThaPIluN030rGIq0O02lBjxucpyEwKt/ldzV4Ob0PXBWuygn1Z9EgvivV
F5cN0ohr1T6MnDmnhfIRsGYzUdQTQx0Kz9VV9bWrZcqNwfszdsevArt7nvRk
HPo/3RN5V5g03NmO5gV38HHJD3BTxqhfLpPYR7UO3FU/l7qNFvJFYZBPCqv8
JpKvGZ90nYbAzvsuD51JPXHr/51fut4BTsoYmg==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 125->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOAzEQG/GBuAbiBnCAFVcoJ1gk+KqEVD4QfxwdWug2cWzPRCJSuts8
PLbHe/v8tnu9ioj3m5+f3frxeDisn0/Xxz8v6/7hfn/cvPubEV9LXJ7L75PN
85lujZ0zOFHA22Y0z2g4mvcWm613WmHgPefH4BvBcevIE9cZF3U+3J6o3fqs
9DGs7j5qFLjMg4Fzcp71V3mF2XEZVtxVbeQmc0zOqQzJfZZXcw89cJykDzHW
p1xUJgqeZD6g584/pYnls8qFYXbYpi7rX5bd2al4Zdjox+AZ88l45fQynhXP
LJfIdZwGeaqMV2tXvGT5YGdn+4s52gbJepYFxqvSL5dphzPgmjqSi9BT4dLh
FTyZ6YvLqdMnOUI/h9wmeEoH+od3HV/3zjS3vK3GxB9Xq7vfTOYvjqyvWR4U
X8lP6ECfnN4Z/kGwGFeH6bhQjws1tyEwMt/ld9V4GQvsF3FVTlh/Bg7iu1J9
cdlgHLM1te/4dtxJ/1g+gqxlvBz3c11ck/1hnP6BC+pXeB0P4E6xK34lvKvn
mVbEYf+7eyLvCpMNd7bCecBtfBzyQ2qzjFW/F5c/uU5qZ/0cdBsuzBeHIT1N
PGeahvvEe5oDgY37sz6WezKBUapz4vUNamcXnA==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 126->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOw0AQG3FAfAPxA3hAxRfKC4oEp0pI5YC48XQobdNdj+2ZRGqT7E48
tsd7//qxfb+JiM+7v7/t7uv5cNh9v9weX952+6fH/XHz4fyL+NnE9b453dnv
UlOuGZxofhvn/eUeA0fzPGKz9UkrXPid8yP5RnDcOvLEdcZF1ate1p9qTqbP
8j32FbjMg8C9op7NV3mF2XF5VdxVb+TmzgXWdc5OlTWmSXngOEkfRl2b/Iz4
WM/WXZ7VTDr+sMvls8uFYU7Ypu+EJTRWujp5UB45bPQjecZ8Ml45vYxnxzPL
JWod/xe5q4x3e3e8ZPlgtR0fUQ/NHs5IcFyTneQj5tjMY8IZahOueadchJ7k
C+GL/lSedHOB/FldjM8x76u54/zX4Ckd6B/FDv/ezc6Fp8s241xxYrNYvBK5
TLwIDvOtU4v1kp/QgT45vWv4B8FiXB2m40I9bvRcLoFR+a6yuPSGczP2kjpV
fqO5P/Sv9LC6SUORI+SN50jlhfGduLP5kXywNeZRNcsJj6yp2bPMqh5ruKB+
hYfed7JVYTK9rr+qZ1oRh72nNZVdgskuV9vhnHDJuaB1Qis7I1jbyV+IPda7
mmfy2HChvrD8FZlHrI6m9D3xnuZAZQv2016R885Z6H675nfi+gvXoBSS
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 127->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0tOQzEQG7FAXANxAzjAE1coJygSrCohlQVi16ND6YfEY3vmRUrTl0w8
Ho9z//qxeb+JiM+735/N9ut5v99+v9weP962u6fH3fHw4TwjDkv8r8tpZfMS
U+4ZnGjejfP5dY2Bo/k/YrP9qVYYeM/pkXQjOG4feeK+0pHFq1xWn0avnRbB
8kL/FNYlFu+6eNZfxnfkFiKO1km81+mzexcY596Cm6ibwkQNHKekw5Kxsd8T
F1J7iH3Gz/bEYLh6EpfQeR0Xhjlhm7xM08q7a6fi5bBjnEozppPRqvIz8uxo
ZrlEXhHvb5AV49fmVp5N+dle9HGpd5U/sUei32u8k3RcMq7qx4QzxI580U+o
FeUivJ10UTWDH/A+y1/5AvmzOOYFVofTdg2eqgP1o9jhv7veufB03macK06s
F8rnCovhMN06sRgv+Yk6lH6VtqUvTc8q3TtcqMaNnNchMCrdlRevuQceh2Gv
8y6UT8rzIX+npxg31VD4CHnjO1J+YXwn7qx/xB9sj2lU9XLCMzW4/qN+pT8N
F6y/4jLyrrzVxaz6zbRW+VVO9p32Cu+qPJ3YDueES94FjRO1Mn9hLIuvel71
vtId/ae4MF2Qz4ghNWWaFzWxfJQLDuUtOE9nhc87b6F7d808cf0BnAkWCg==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 128->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU1tOxDAQi/hAXANxAzhAxBWWExQJvlZCWj4Qf3t02Ee7jcf2TCN1000T
2+NxHt+/dp93rbXvh/+f3fTzejhMv2/3pz8f0/7leX/6+HR9Wjv2dpv7ZWbP
vCddMziteLZdvy9zW2k07wMOWT/2eFbhOT+CbwQH61FakNP5yPYrDak/Sa+d
F+jveZB6nTd4NtvPaqZ1QnZcXql2w019Acysr1m2XNZYTcoDpyn40CM29htz
7TLlPFH1Ka5KRkNPSM+qWhjmgG14g6fifKXvWd0qz1IL5Dt4xnwyXmV5Rp0V
z6yWFmfEOw8y4/6t3CqzgZ+ttTouza7KJ/ZI9HtLdoKPPeKqfgw4q71rvcwb
5suwR2Q7+KJqFjyoL+0L8S7VzngFF/M286+SL/SPYgu97p3VPOt02WaaM02s
F5hzlhMcWV+zPCi9IW+QO6Yry5bjdHcFsRivw3RaaD4LnMsQGJnvWRbXfq/X
KvdC5ST9Tv5X9Q7nQbvyGfPl7obU28d3mlNWG7lnzKOsl4jnMubqWutM82m0
YP2ZllC/wt6AmfWbea34FSf7H9aS7Cqeyt6K5oAr9jJ+lTGWBZdJ2XNxbsAu
9HOLFuYLZnD2KZw1WCzHqq8Uj+hahuKC74EzyXnlLlTPbnkuWv8Ad8UVxw==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 129->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0lOAzEQbHFAfAPxA3jAiC+EFwwSnCIhhQPilqdDJiHY7VraIzme8VJd
XVW5f/3Yvd9ExOfd789u/Xo+HNbvl9vTx9u6f3rcnzYfLiPiuMT/vJxnNP7O
2DWBE8W7cdm/ztFwFO8dDlg/LuNdhqf0GHQDOEgLxCXXVDqi84yD1cd4rbTI
+m5P8o1hIX6V86hn2GfKjsrrwJ1oNvQquDhfXbZU1lBPTAPFadDBZD8yF9B7
kHXEz3nCMFQ/A5fgdRUXhNlhi7rKO5WXmcF4KWykx6AZ0klo5fKceVY1U57l
OeNtD5jz+dnayteuPlqLOi7UjeUTeNv5VvDE1c0YmYvCGXQn2iBdujMk24Mu
rGdSJ/Ob9UXlVPXHaiFtnX6VfGX9IDbhq96h5xGD/o4L6kfV6u6DrDMshIN0
q5zN52GPQjOmn9PW5lJ45nSvcIH5LNS8PgTD6e6yGA2Pdq3yv2A5sfvgu8q3
u5+4M50Z77wXiu/Sv+fz2c9urRmOS9sb6qfFQT0q/5GmMp/kXKdBaLysr8We
wHR+I61ZfVYTfQ9rJrusTuVshTPDRVhsP2cMZYFpjvRtvbTaF/yc4YJ0yRnc
HnRXYKEcM18hHuB1fVittD/UNDmv/Beqd2fGmesPez8WDg==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 130->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyVU0FOA0EMizggvoH4ATxgxBfKCxYJTpWQygFx26dDaWkTj51kK213dybj
OLb3/vVj935jZp93v3+75ev5cFi+X26PL2/L/ulxf9x8OF9m67DrfZzu7GJ7
ak3h+PX/nlONnTH83RzH5DlwIOvrmM8yPGtwVFioZzYznqt0ZPWKA86j9JEe
IBZyI5p53xjWpYbwU73xnum4Aoe2/q426011sZ5+KkPVFXpX343TIOM06TDm
dfQbcz15ItYZv0wH1LyTUcY96EZ6ZBwRM2AnfTPvtvpezZ1pN50RGWZzVbmQ
vAqeXc0yz/COeH8/csf6rb0zX0N/tmZ9XKqbyifxNvjW8KTqixjIJcOZdBfa
MF1Cjcj2pIuaufBerVe+ZDnN5lO9mLaVfp18oX4UW/DNnqnnZpP+FRc2T9Yr
nCdZV1gMh+nWqcV6OmOimdKv0rbMZeJZpXuHC81no+flJzAq3assmuPh1zrf
hcpJuU/eu3zDeeCudFa82b7kO+KzQT07vw6j31nGxc/G5vE4bIbMf6Zpmk9R
FzSwHC9o28jsFszKb6a16q96svdprciu6tOp7XBWuAxL7WPGWBaU5kxf72Wp
fcNP3wuzNO0TXXxu2XPAFlg0x8JXikd4XX6qF+xPOhY573wL3bNbrhPXHzoG
E44=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 131->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1lUFOw0AMRS0WiGsgbgAHGHGFcoIiwaoSUlkgdjk6lJZge/7/dhZECpNm
PN/fz464fX7bvV6Z2fvN95/d/uPxeNx/Pl2ffrzsDw/3h9Pm3eU2W4b9reO8
ovs3JrxDcULHCr3gxS5a7lqGfvYa6P2kT7Rtg8eslXmqmvO5iiOKZx5yPeG9
qI1qZW+A2dovorXGAH8sd14VxyV5aPN3sSo35GI9fmyGqjvkLmbSM1CeJg5j
fs80/F6OR++RP8UhM+/MKPIeuIEcymPWDNoir+rd1r5XdSt25RwhZoiTYDXp
Fz67zFTPqjp+LrDm+K25OywzL+Z3a38N7IW60Bw0e1LltaSRvSidiTthg7iE
GDLbExfAi/Vka78Zu9I7yMtyIbYVv858ZX5Qm/hVz7DnZvD/hvKC6lG5wvl0
q/qQDuLWic3xci5BHYxfxbacS9GzinvHC5zPRs71IhoVd/pdDbfm+gpd1KeQ
o9pPdRk5w5hOZ5HHhm+0T/2O+BxWw+fXd6hGNhOuNlSP10E1qP4jpnI+Sdxa
e/E9TGwbM7tFs+o3Ys3ys5zot8wFOLM8ndiOZ6aLtNh+njE0C4w54ut7WbJv
9NPnyrM07QMufm7RMzxbMM+sMlf/jZT9IrOV96e9Ys4738J/3GevX8XTFJQ=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 132->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1lUtOA0EMRC0WiGsgbgAHGHGFcIIgwSoSUlggdjk6hBDidtfHsyBSpyf9
KZefPcrt89vm9Soi3m++vzbbj8f9fvv5dH388bLdPdzvjpt3vyPisMRlXk4z
GmiPrTGdvH6OOZ1JnuI8R1knz1kDrU/6RDuWcSiPVavyVDnXe4ojYqE8TPnE
rEVrLeLU+xOzmHOuPgL4Y7HrrDgeioc2/1xvEbt6Y32MzrEecmOIbd6bzEB5
ohxyXsoL64kGE8ehMu/0KPI+cCP5djUHbRFX1W5t3V3eip3tI8QMcRKsJn3j
s8tM1czl8fMBM+vxbuwOS9Qf6Oza+gbYG/ISdXc1cXGjaFQvSmfiTtggLsMZ
0tsTF8IBxV1bb8bOegdxWSzE1vHr9FflB7WJX/UMax4B/zeUF5SPijXcz/VV
7ALrIG6ds/X8mp5R/BxbG0PUzHHveIH92Yj59yEajjt9r1LtYyn7Rrd6qUzs
fskryB3GNOpAHs0ay4v6XcbnOqP7yCtjOPEi3rMOykHVHzF1jBjHzF7pDWwb
PbtG09UbsWbxWUz0W8YCnFmcztmOZ6aLtNh+7THUC4w54ptradk36plj1V6a
9gGX3LfoGd41zCuryjW/I7ZepLeQ7gHkoOrg3oX/GCevXzcAFNU=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 133->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k1FOw0AQQ0d8IK6BuAEcYMUVygmCBF+VkMoH4i9Hh9JCd732ePJBpDRp
duPxvHFun992r1cR8X7z/bNbPh4Ph+Xz6fr452XZP9zvj4t35zNibXG5ttOV
nb97hmdsX6ITRm/wEmet7lgb3MP+XoM9n/SFdrTxzDyuZC8+Vz1j/YwjY6H6
mfSRT8I/02LvT8xi7hl9BPGnauM147iChzL/foZJbfQmvwuyT2XInUNt8930
DDJPkkPfV+ZF8SwwcRyQeSWjzPvATfRb1Ry0k7rZ7LbO3fWdsbM5YswYp4TV
pG98VpllM3N9/BzkqjJerV1hyfLB9m6db5C1oa9k7m4mdl6ggV4ynYm7YMO4
DHtEticuggOru3Xeip31TuqqWmqeGb9KvpAf1SZ+A7yw/rNcpj0aPqwWzV4/
X8IXDzdXlwfld0tmMn6Ora0h8qeywjQzL8x/pebfITQcd/lddbOfsmp00Qsy
sevQF+ae7aXZBe+KM2Uv+pJ+23iPV5U59KoYTu8L770O6yGbP2PqGCmOPftM
D9la7Q2abt6MtaqvarL/aS3CWdWp7K14VrpMS61jxljmskxWZi77KMyzuj9A
H+8VO/quYY6skGv/jbh5qWyxfcOayXnlW/iP8+T1C+lPFlM=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 134->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk11KBDEQhBsfxGuIN9ADDF5hPcEI+rQgrA/i2xxd90dMKlXVHR3IZnbS
qVR/3bl9ftu9XkXE+833z279eDwc1s+n6+Ofl3X/cL8/Lt5dRsS2xO+8nGc2
fmLct2gG1Uj0Oi9x0WqebYF3iG81AtapvtBu97JcGLc27+x75zPG7xvsa3PF
eJbPoI98DH+nxfZnzFCrXW/3unhWX+Z3Aw8DQ7Gv22PORm/uXmCc6qFsIDe1
Dxk4T5JD4gn1nRfnz8Ui80qPDjUhNat6YZqdtjnX1W627lnejl3aR4wZ42RY
DfqJzyozV7Msj9ND5tker8QoTeapqku5qf4kvT5bk1K9hF6mM3AXbBiXLkb0
9sDFcRDn/Kcurk9dftKjqKfjV+kv5Ee1id8ALyx/15c2x4QPO4v2nuBFfRE2
jFslVp1X6RnHL2ObniH6T/UK03ReMsaO5+kRGhl3ea+WZsb8El30MuSRrUNe
2Pcslvau85h8U3lJv0v/jrOsKXBWDLNaYu7Z/XH3QJ0x4wX5Z16iqj2hmdW7
wkQxUrqZL8ZZnVOJrXhWukxLrWOPsZ4LkutMzWUehXpW4wP08V2xo3sT5sgK
ubZ3JKuX6i0W160tngurycw9+es4e/0Cs7oXWQ==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 135->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1VFtOAzEQi/hAXANxAzhAxBXKCRYJviohtR8Vf3t06Ismju2ZfBBpm93N
jMfj8fbx/WvzeVdK2T/8/myWw+tut3y/3R8fPpbty/P2ePh0uUpZa7nt9byz
6xrTvSPPRbzHeIbXcSkXrGatFe4hvsVo8xk/XJiX5bgCJn0v8LA+07J7JvED
96wOojeHxfK7Gs3cFFZ73ua6eDZfxncFDoOGIq/LMbWRm/wuSJzyUHShbioP
NXCcpA4BJ8R3XBw/F4uaZzw6zITMLMuFYZ5Woq6b3ezcbd/QYwYb9Rg0YzoZ
rdoY5rlBv6RmbmZRH3/awD7r8UyMwmScsrjUu8qfJD7lHeAl51XL+P8ZeJv1
2fJl2jBduhjh7UEXo4OqMzUXol3IndSVHMU8nX4Zf6F+FJvwLcCF9e98aXsM
9GG1qPeEXpQX0cb5NesjFes0U/pF2oY1hP+UVxim4xJp7PQ8LYER6S6/q9rs
2F+Ai1yGPqJzE6/4Uu86jsE71ZfkW/t73OVMITbiEvVz7Tv6ftx3oGrMcEH9
Iy6sf4o9gRnNO6OJ0kjhdjoGuAyTLReb4iy8y7DUOXqMeQ77xfx2hmzmso/E
PLPxBfDxXs2J5hrNh16Jru1cnDfYufLLrI5qNv99nXn9APp+Fdc=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 136->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytVEFOAzEQG3FAfAPxA3hAxBfKCxaJniohlQPi1qdDK7okju2ZlYiUZjeZ
eDweb+9f33f7m4j4uPv52S2fz8fj8vVye355Ww5Pj4fz4cPvjDi1mFY22VmI
98q+ytVziesasB9/eIz7OkgexGHYsYFjz0PuCzzMP52Bhiye1ZPpwHTJeKn7
Qw7GG7BQj0o86y/ji5pfZ3ZvuGNyIzf5XZA45aFsom7qHmrgOEkdEk6I77g4
fi4WNa94dOoJ6VmVC8O8jEJe17utfbd1Q40VbNRj0ozpZLTqY5jnJv2Kmrme
ZXWs2sC61eOVGIXJOFVxqXeVP7FHVe8AL9mvFvP/Z+JtvDtwFtowXYYY4e0K
F/QwPRf7Fe1S7iSvyoX9nHqe4Mn6jEaINwzmRYKhfGlrTPRhuWi/hV6UF9GG
6VaJVfkqnnH6ZdqmOYT/lFcYpuOSaez0ZHW5PmS8LqN1K9aX4KKfpjqycxOv
+FLvOo7JnqpL8m3jM66ypzAzLlk9PQ6Lc/0fMMTdKhfUP+OCOSX2Bsys3xVN
lEYKN+M16Eww2XCxJc7CuwxLnaPHlOcqmke3spiJWwG7Gh+Aj89UO3XXaD7V
SnTt++K8sfIwPce8VR1Vb/4rzn0Hp/YNelAWVw==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 137->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytVEFOAzEQG3FAfAPxA3jAii+UFywSnCohlQPi1qdDgW0Tx/ZMJCKlaZOJ
x+Nxevv8tnu9ioj3m++P3frxeDisn0/Xpx8v6/7hfn86vPubEcclLuvyu7LJ
znAvTCzubzmHmIZTbGvAfsMXa2hjguRBHIYdExxbHnJf4GH+4Qy0Y/GsnkwH
pkvGS93vcjDegMX4udzqHruDmm8zu9fdMbmRm/IIi1MeymaXO/Fkq4HjJHVI
OCG+4+L4uVjUvOJRrJ35s8qFYkZfM4uhWMBlpu+2boKbYaMeyJ3qZLRSnqB+
LGpmuURex1kbWGc9XolRmIxTFbfVHH031Iw9qnoHeMl+LTH+f5p+MH92nIU2
TJcuRni7wgU9TM/FfkW7lDvJq3JhP4eeJ3iyPqMR4nWDeZFgKF/aGhN9WC7a
b1K3wkLOqv+VWJWv5Jnmjbg4l9O9FcRiXLtR4MxyZh7K+Ks6q1pu3M8r1pfg
Mv27HNm5iVd8Bx8IDztvtXuqLsmX+cD4UXHNuGT1bFjZ+3HvQOWY4YL6Z1xY
/RR7AjPrd0UTpZHCzXgxnVWeSmyJs/Auw1Ln6DHluYrm0awsZuBWwK7GB+Dj
d9UnetdoPtRKdG374rzxM4ReDHdGR9Wb/4pz7+C4fAFpUxVZ
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 138->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOBDEMizggvoH4ATxgxBeWFwwSnFZCWg6I2zwdFpjZ1rWdjESloUuT
Oo7j3j6/HV6vIuL95vvPYf54PJ3mz6fr8z8v8/Hh/ngO3v19EcsUl3363dm3
5mRnDCfIubzbcIp1Dzhv+GIPbU7gefvBwntVjgvg0XOBh/WHGGjI8gfuVR1E
bw6L3e9qMN5BciDmauPudETN21qZ/rjonCHu3gXrrfJ2Ku/BzWzVwHFyOpS4
FN+H4udyUfOKR7F35s8qF4oZMXg202xbiXf3fhum0S71EeFOdTJaKU9QPxY1
s1wi72PTBva9Hq/kKEzGqYpLdVP+xBlVvQO87LxgrshF4jS5HRbRhunS5Qhv
V7igh2lcnFe0S7mTuqoWznOYeYIn+zMaIV63RC9VX9oeE32wlpy38BvlFYKT
qO9yMd/5kvWBOrE8V9O9FcRiXLtV8DmrmXko46/6lN4hNXD+XTzBlf6NYtzk
K76DD8jMnEZMe9aX5Mt8YPzYcYUzxyXrZ+3beUzNv+Mu7la5oP4Zl6hi78DM
5l3RRGmkcDNeTGdVp5Jb4ixwGZaKo8eU5yqaR7OznIFbAbuaH4CPv9Wc6F2j
+dAr0bV9I84bP0voxXD36Khm81957h0s0xcpDw/h
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 139->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U0FOAzEQG3FAfAPxA3hAxRfKCxaJniohlQPi1qdDVXZJHNszObBSCM1M
PB6Pc//6vj/cRMTH3c+f/fL5fDotXy+3lx9vy/Hp8XgJPvyuiPMu/vbddWdr
zcnOGE6Qc3m34RTrHnDe8MUe2pzA83bBh/eqHM+AR88FHtZ32jItBr1ITOog
enNY7H5XA/plWCzmauPudETNg9RTtfCjc4a4exest8rbqbwHNzPUWPU6yxd9
XXkfip/1eXhsN7tt/mRmVS4UM/qeWY7ESrw7uzZMo13qI8Kd6mS0Up6gfixq
ZrlE3semDeyzHq/kKEzGqYpLdVP+hBmVvQO87LxgrshF4jCNhDZMly5HeLvC
Rc1kdt5Ku5Q7qSs5ink6/Sr+Qv0oNuEbopeqL22PiT5Yi/FutQqCPfAKwUnU
r/oIc5kuin+Wl3mXvRXEYnUdpuPC+CMWq8lqOQ3SPtcP5t/FE1zpX9K7ine/
C3wH75KZOY0yH6EHBg7MBxBTveGZ45L1s/btPKbm33EXd6tcUP8KlxL2JKab
Z0UTpZHCzXgxnVWdSm6Fs8JlWCqOHhvmNaF5NDvLGbgVsKv5Afj4v9KO3k00
R61Q1/aNpPMS3mK4Mzqq2fz3uvL6BsjOFOU=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 140->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk1FOwzAQRFd8oF4DcQM4QMQVygmCBF+VkNoPxF+PDiUkxJOZ3XGx5CaN
1+PZt+u7l/f9201EnHbfP/vx4+l4HD+fby9/XsfD48Phsnj/OyPOQ/w9h+nJ
5hzTfFOxxnem13iJKX49zgO8Q/xaY72fecCB+1yPqIU8Mz3cl/FmLDIPGQfG
pfLFvCtmWOeGDVnLzsZnxhGZBzlPnYXDqbO8FySuqm8Vt+Qk9iGDzFPGwfJi
3g/lL+3zyLWz2rH+zvJ1NX+GcS7VKnq3dy6aCbuyjxgzxilhVdVrw89glnqJ
Oo9mLalb79kOS9ZDLNaqL+RB+5P0eq+2VS/oB6vujJFgw7g0MaK3HS+qJr31
VuxK7+Rc6VHUUw3Vi1KXMEK9Zohcst6Z90mG/7w/m5zX/Ub44qjqWvWD8os5
BtFK94i4qnfZXUEtxibTzLww/6jF+CxDaFTc5b2CHDFvR1f1icwBPcz/Db+b
3iU1U5wVe3bHpF/WB7CmcsNvmZcqH9aT1aT5iL2uF+TveLG0OzWzejpMFCOl
W/linNU5TqzjWekyLbWOPbap1xXMQ8RsvBnabnyAPr4rdnRvwRxZIdf1HSnr
JXqL6fZwZDXpuSfXzsnXFxRKF+c=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 141->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0FOAzEQG/WA+EbFD+ABFV8oL1gkOFWqVA6IG0+HClgSx55xdqWwJZl4
PLZ3/3w+vu4i4u32+89xeX+8XJaPp5vrPy/L6eH+dD28+10Rn4cY3myFuefu
q14tl/h7B+zHPx7jvj6kT2ANwY4JjojV7TdzMDy8x3q0vFm94pDpwHSpeDHu
SjP0udOGnGW98Z3piJoH6ad64eP4rDLC6ip/q7p1JnEPNcg4ZTpYXMzvQ/FL
cx45duodyXc2r4OJmVY1HQ7mMPS8swu5uJlCPZA71SnRqvJr0K/QrPIH+zA8
WrMh406Nwsw4VbhUN5VPkvVZbMsvyIPje1vb4jBtmC5djcq6waXLsThn/V3t
Su5kvowj83PVTvDNuDD9BmzBN8QsqH2WF4cLmwf7Sr+FPpRXCE6iv6wVXDBr
KjP0jqhTGg39UI/gfLt9gZlxYfwRC3G7J9MtmZHxWmdrZsS5HVyVE+Yj5dDU
V3yH7BpeqOwrfxBTadLlozlTszGe2e9qHuRSLTqPuOtycTzYhD2JmfnpaKI0
UrgVL6az6uPUOpwVLsNS5+yb6e5v0DxEzcDNwHbrA/Dxt9KO3i00R61Q1/Yb
Kf0S2WK4MzoyT2a+k63rh9cXZLca2w==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 142->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0FOw1AMRC0WiGsgbgAHiLhCOUGQYFUJqSwQO44OVWnwn8yM3WyI9Js2
8Z//PJ7ePr/tXq8i4v3m52M3fzweDvPn0/Xxx8u8f7jfH1/e/a6Iryn+7tPp
zhZ7p+o7z89nrmoSU5zvAc/F96yR9zMGvHBflxG10E+nh/vYGZmb1SsG64/p
zWnJOUGPOGfJAbXWy4JlqcPsOE/zNaUlzkY2lRFWV823qss9uZnljMtejQ8t
lub/Q/HZnIfXVv0MMyEz67IwzUHbnDtoiZlVfXXyoPx32ujHyjPmk/Gqmhf6
1/HMskTdB63ZkPFOjdJ0TJUuza7KJ6lvZQe47LwmOL8591w7aBFvmC9Djcp6
g2XwVLxn53e9K9lJf46RzXPxTvA6FubfSlvwhugFvVe5tD0W/uC5ct7CH8oV
gkmcL2sFC2ZNZYbuEXXKo9V56Edw3uG50HQsjB+1UHe4nG+mR8a19JZ6xL47
uionbI6UIdVXvDS7oMN8Vr7RPY6X5QDeqd7yqlg6/SBLtSiT2NtlyblRdZu0
L9R08+x4ojxSuhXX4DPRZJer7TArXaal3mPGVvPa4LnK2Yqtod2tD9DH78o7
urfwHL1CX/N/pJqXyharu8TH/1onrm+nZR+U
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 143->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOw0AMtDggvoH4ATwg4gvlBUGCUyWkckDc+nSoSoI9O2M75cJK26SJ
dzwzntw+v+1er8zs/eb7Zzd/PB4O8+fT9enPy7x/uN+fXt79bLPjZL/X6Xxl
m71T9Z3nS8+hxnGy5WrwXNx7DH+eccCF57ocEYs9V5rxHOvheQ99/CZYjJPH
krMWWHJOBjwSrIFf0VudY2eOwIFxUb1QQ2fOKiOsrppvVec1ZTPzGc+0buUb
uDS/D8Uvzbnl2HJ2fiZkZl0uDDNgJ30DVjO7W7fiVWGjH4NnzKfEq2peyLPj
WcrFah205oKMd2oUZsapwqXZVfkk9X/NzqBrgv7NufvagEW8Yb6EGthbuAQ8
8Z7173pXcif6JEcxT+8f65lxwTlgf+QXltCC3qtcphoLf7CvnLefLfEXVzXX
Kg9MI9YiF9ShvhlWl30joR/64bCYNxlmxoXxRyzEDSvzLdHIeK3anEbU3cFV
OWEYlMPyv8F3az4ZNp5Xeaj0hHxAf6ZtrW1w6ehBLtVWnLr5pHjErw6PEnsj
ZjbPjifKI4Vb8Qo+E0y2stoOZ4XLsNR79s2E8xd4znJmTEcDu1uP+HivMkzP
Fp6jV+jrgE94rUtki+FWXP7DPvP6AqquG5o=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 144->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOQ0EMi1igXgNxAzjAE1coJ3hIdFUJqV2g7nr0tiqvZDx2koFNnzR9
n/E4juM+fXytNw9mtl+df9bz99tuNx/eHy8vn/P29WV72Xz+WWbHyX7v0/XO
FttT+Mr3pWaHcZpsuRt8F8+ew5+X/IKbcSqO6Jz/xvjwHKvhvevqBD5FPjBf
Ml1Me1fD6VFcC+5IsJmXmY/Uk8hTvMAbdve1VEYYLptvhvM9RTPD/5nqdVRv
oyXpIfIkzbnF3HJ2fiZkZlUtjLPhDurKeZjud3Qp3owb/eg8Yz4FXmXzQp0V
z0ItlvehMKMZr2AUZ6Qp46XZVfkk+P9mp+trgvrFuXtsw0W8Yb40GFgjWho+
sc/qV71LtZP+pEbSD/rHakZacA6SW+iVz8IbrzPqMfMH68p5+9lG3glvlJ8Z
Vs3K51Vlxucxypbyg3na+WFtnYrvFS1hPq0/H2VD9SmzQ2rg/LHvCq/KCeOg
Gpb3gt7RfDJuPK/ykPXT5APqs95u2IKWSj+oJVtKUzWflI/4VdFRyewIZzTP
iidZTfYe1Wp8JpzsirAVzYqXcal99p9pzv/Bc5YzY30UuKt45MdnlWF6NvEc
vUJfO36i63aJbDHeTMs9rKuuE5QvGp4=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 145->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOQ0EMi1ggroG4ARyg4grlBEWCVSWkskDsenSoyisZP9vJsOJJ836T
OLaTuX1+275eRcT7zfdtu/t4PBx2n0/Xp4+X3f7hfn/avPtZEcdN/D435ydb
bG/Jq2KD/Je5iVMsz4D/4j1j5PzM47LgOopaFUeXl/8xPMxb7YGHqzqGQ+mD
0Eb1MD5YF94tltBYeVn5iFwVZ1YLNXT6rGaExXXOU/c8uJ4pbLyQSzUTAxfl
Z8MThdnBsL2LESNrWtUwXBjmgG3qyn6E1ju7FG6FnXOoZ8wn4xXDdTw7nlku
UeugMaRvs7U7XrL5GGLTbFtswX+lmcRPzU4xV0uNAG6dvufYAYt4g/4xnnnN
cBnwxD6rX3oXOrfSJzkSPegfq+m4YB8ktuAr34U3mafTWPmDdWW/c2+dd8Ib
5WcVi/GokfXK1VBx7owM9dCPhMW8cZiOi53P8NoWLtI3o1GeK9CIuju4ak4Y
BuWwfDf4zs4nw8Z8NQ+VnmE+oD7TdoltcOnoQS7VUpy680nxiF8dHp2ZncF0
/ex4UtVk367W4DPBZJeL7XBWuAxL7bMzM+T/wXM2Z0F0dPrZ5YL4+I4zbHML
z9Er9DWfkbJfwheGW3H5D+vM6wvQthlZ
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 146->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOA0EMizggvoH4ATyg4gvlBYsEp0pI5YC48XSoykLGYztZTlSazu5s
4thO5vrxZf98ERGvV19/++Xt/nhc3h8uTy9Py+Hu9nD6ePO9Ij528bvvzjtb
a0x1xnCCnMvcxCnWPeBcPGeMnI9cEBfxGKbi6PLyGcPDvOkb8sY6hoP1x2ij
ehgfrEv0SiyhsfKy8hG5Ks6sFtPAdtSImFVf1R1xvcD74HqmsPGn7kSLi/Kz
4YnC7GDY3sWIkf2aahguDHPANnVlP0Lr3boUboWdc6hnzCfjFcN1PDueWS5R
66AxpG9ba3e8ZPOBdyYMJnqO/CfNJH7T7BRztdYYtBV9j8SZ+Y780SvFMxK2
4pLjMIZpYblt72I+m3pk5kP1nfUz47Gajgt6MPUL+Kn37uxknlajqKc4yNkT
80Z5EW+Un1UsxqNG1itXQ8WpmvauABbzxmE6LkwzYilt7Nz1oeL1oy1pRN0d
XMWRYVAO63uD79b5ZNiYz+5YR88wH1CfacuxFZeOHuRi+2M4deeT9lxgWx7A
3XHoYCre3XimFXHYu6s1+Eww2c/FdjgrXIalvrM7M+T/wXM2Z0F0dPrZ5YL4
+IwzbHMLz9Er9DUSRtkv4QvDrbj8h3Xm9QmaJBOe
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 147->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOA0EMizggvoH4ATwA8YXygkWCUyWkckDceDpU0CrjsZ0MJ1babmd3
4ji25/rpdfdyERFvV98/u+394XDYPh4vj4vnbX93uz9+vPm9Iz7vY3qym31T
+0Oso1ObuMTpGfBe/M8YuZ5ygQvfdTm6uvyO4WGd05ZqYThYfRpesz7Mv/NF
5lXaoAfVfuYvq0GuijPrxWZgT+SMmJWv6ow4L/A8OM8UNl5TtopMDFxMRitN
OjlXGNa7GDGyXlMPw4VhDtimr/Qj9Lyrt8KtsHMN1YzpZLRiuI5nRzPLJeo5
6B7i22rvjpYsH3hmwmBK3VQ+waPl7FR9Y8ZGLlO2E2emO9MmrxXPSNiKS+6N
e9gsU+2iLy6nAx/YwzgMXHFOoZnKosSNub/CZphsfpdLO6Popzio7DH/FBZy
Zr46HR1fnBGzr3i5bLme9qwAFtPGYTouUn/sKb7je+dDxes8W5oR5+7gKo7V
DNO6wXc1nwwb69kZk3xZDgrPBkzTn9W7eZDLsj+L+aSYRC/Lg3B3HDqYind3
P5sVcdja9Rp0Jpjscns7nId68GXKD+nNMjZl4Q+aB6lj3Dp+drkgPv7HDLvM
Kx0ZF6Zr9sJl48SF6cJwKy7/4f7h9QV7iBVj
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 148->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOA0EMizggvoH4ATwA8YXygkWip0pI5YC48XSoKCjjsZ0MF0babncm
cRzHc/30sttfRMTr1dfPbnt7OB6398fL08fzdri7PZwOb85PxMd9TG/2BNsT
8RgbZF/mJi7x8w7YF/8zRs6nXGDhXpejy8t7DA/znLZUC8PB6lPN2tShc4qR
n8U6xzJ9Ki0rHakmTlNcQrOpV8Olmqu7T9374GamsHFN3io8MXAxHq006fhc
YdjZxYiR9ZpqGC4Mc8A2deU8Qve7+ijcCjvnUM2YTkYrhut4djSzXKLug8aQ
ua3W7mjJ/KG4rMw3yNlQb8FTA3ZVNzw29jf4JeGr5WaCPJkPJ12YXuT8L/Nm
+jifDnyQt6gV6Y3xTDPlRYkbc32FzTBZ/wzHeZxxYf2wWjjvafbqjNRw8+/E
Yjz2iN5XnJ23XE17VwCLaeMwHRepP9YU57jv5lDx+u0t9Yh9d3AVx6qH6bvB
d9WfDBvz2R2TfJkPipkNmMCpuneuH5a3NB+sWfiTYhK9LA/CXeV0MZk+K/Gs
V8Rh31lHh8sw2XKxLc44CxGr/MA8NnlhQfNIb8xj3Drz7HJBfPyPHnaepzpC
ffTzlE+0l/FEFxbHelC6/NfzzfUTWW4WIA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 149->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylVEFOw0AQG3FAfAPxA3hAxBfKC4JET5WQygFx4+lQUdCux/ZMSqQ0yWbW
47Gd3j6/7vZXEfF28/2zW98fj8f14+n69PCyHh7uD6eXd+cz4nOJdGVnsDVR
j7VB1hkeconfa8C6uB8xxv2UCxy4ZucjurF94xrDw31OW6qF4WD1qbw2fahP
MfOzWOdapk+lZaUj08RqiofQLM1quFS+VvnvfA/OM4WNR8pWkYmJi8lopUkn
5wrDehcx/c9MumEPw4XpNNaqGqcn7u/4Xs3dyffEJzh/p0mIdZVPx7PSrPIH
+zA8WkN829rbzYz1jlMYTKmbyCfzdhN21Rf4d3yPgTPTnWmD8zCeLIeoC9Vr
mdfZLKx/xxeX07Ff4i16xXDFeqaZyqLEjdxfYTNMNj/DcRlnXNg8rBfze/JW
vSM9nP+dWqzHGTH7irPLlutpvxXAYto4TMdF6o89xXtcdz5UvP5mG2bEuTu4
imM1Q3pu8N2aT4aN+9k3JvmyHBSepe8soJfJhJuH7dvkz8Z8Ukyil+VBuDsO
HUzFu1vPZkUc9jzq6HAZJjtcbYsz4opalQeWsZSFCzQPso9x6/jZ5YL4eK8y
rPxNOgouTFfEZ7wUV5WX9G7xulx6/hfrh+sXAeYXoA==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 150->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylVEFOw0AQG3FAfAPxA3hAxBfKC4IEp0pI5YB669PbAoFdr+2ZtJHSJLsz
Ho/H2/vXj837TUR83p1+NvPX8243719uzx9v8/bpcXvefPi9Iw5TDE92B1sT
8RgbZJ3hIZdYngHr4r3FaPMpF7iGten/dhwxj60rvTDPaUu1MBysPtmsTR06
pxhzJJbgl8VjHstxPWf6f18in/XqzgCLq5yn6nlwM1PYeA3eSjzRcTEezTSp
+Fxh2NlFdP8znW5Yw3BhOrWxKsb1gPmVuWd9V/zdzRf0QO5UJ6MV86fjmWmW
zQfrMDwaQ+a2trbrGeMdpzCYUjfhTzbba72DfVlPkf1oODPdmTbYz1Bf+BB1
oXpN/TrrhdWvapdyJ/2pWtE8MZ5hKi9K3BjrK2yGyfpnOM7jjAvrh9Vi8+5m
q/ZIDTf/SizGY4/ofcXLecvVtGcFsBZ9Mt0rXKT+pGY2A9Vn9fwtff09sb8i
ruKY9TB8F/iu9SfDxnx2xiRf5oNkZsM5i76W84TrB7msns9Kf1JMopflUcRW
Glb6rMay+qom+251dLgMk10utsQZcUWs8oM6M13+BZoHyWPcKvOsckF8fFce
VvNlOjIuTFfEZ7wUV+WXYW/yulx6X4v1w/UIHXEXpg==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 151->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk01KQ0EQhBsX4jXEG+gBgleIJ4igq4AQF+LOo2vExEnNV939kgcvkzc/
1dVVNbfPb+vXq4h4v/n5WW8+Hne7zefT9f7jZbN9uN/uF+/+3oivVUwjvUFz
Zr/uDZgnPOUShzFk3vwfMcbzyEWeaW71/2Yc9RzNO730XKYtamH6UfxJn8pr
qgPcJ63Je6MN6VNpWemoXJVPVuvYQ1Jbubk7MOph7wSc696HzDOq5fJDay0u
SUZTTcx8FyP1Lk4x1LMuF8I8wU7quh70fMf3qm+X51aOSDPSqZGLjIurWWmA
XKLuw+3R/Utrd7SkfEx7z/A3YO2k3oJMEa/MryxTtB4D5wDOpI32M9U3OVRd
Mu9cna7fTpOSO9R1tWIYdT9htnvP/DLYhEn9E06WceJC/VAt8nu8I4pN2at8
rfLg+GZ9kmZZTcVbwl/vyfFp6N7hYvWHmpUHrs/u/Tv0dRy1vyau41j1MH03
+C7NJ2Hrecqe5Us5KDxL54pMZP0ol8X+LMwnYoJeKY8mttOr02d3L9V3Nel7
1DHDJUx6sr0tzopr9lb3Rvs6OX+G5gHniFvHzy4Xxdf/TjvnL+lIXEjXGDCy
bNC6y8u0dsEdqLy76Pwvl2/cXxjl
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 152->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk1FOw0AMRC0+ENdA3AAOgLhCOUGR4KsSUvlA/HF0KCJo430zdmikNE3W
Ox7PzF4/ve5eLiLi7er7Z7d/fzge9x+Pl6eX5/3h7vZwWrz5vSM+72N60h30
TdRTbf4u9w5cYnlG+h5cP34b9xOHfE3fmhwXzEjYjuvEE/oQ74mvmCfjT/pU
XlMf4D5pDd5PWIJfVZ/30Z7MNfNxvfKFPqd1leO/y5wJ2tc9D84z6qXyQ2st
LiajlSadnHf0oYvyjfMaLoS5wjZ9nXdbfa/mVnlu5Yg0I50auXBcVM9KA+QS
9RyqJtdv7d3RkvKhuGzxN2Bt1W9DpoiX88tlitZj4BzAmbQhXVY1wpesi9NY
9TnHF5dTN5/qFcMz1xNme3bnl8AmTJqfcAJmc1xoHupFfo9nJGNT9ipfqzwo
vm5O0sz1zHhb+AdgLfpUune4SP2hZ+WBmrN7/pa58v8xEx1cxbGaYXpv8N2a
T8LO+yl7ki/lgDwbbpv9IhNunszF+iP0Vnu7XEJgVzw6me1iKt7deuKTceh9
1NHhEiZdrrbFOeOKWuqvMjZl4R+aB+wjbh0/u1wyfv6vfFL+ko7EhXSNAcNl
g9ZVXqa1M85A5d1Z+3+4fAF8axxj
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 153->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk1FOAzEMRC0+UK+BuAEcoOIK5QSLBF+VkNoPxB9HhwKBrPPGdtqV2uwm
9ng8ntw8ve5erszsuPn62y1vD4fD8v54ffp4Xvb3d/vT4e3vz+xja//r9mel
H521vEqs35e5HSdrq7l94/h+r88nDv4Z9oocPddhH7gOPKEO8Y60ICx/7rHk
rH0dwR01y7A8v2K8z6Mcz9XzUXk9dzXHSGOpX3AnKK96H6KZUS3lHzorcUl6
iDSp+LyiDz3kb+w34EKYK+ygbjS72blnfSs/l3xEmpFOBV9EXFTNTAPkYnkf
KsbH093IvJFpSf5QXCQueVf4k7x+qXeGvgJswrGOswFn0oZ0WcWIuXhdIo1V
nepclHYpd6iralm3+njCLPcezUtgEyb1TzgGvUVcqB+qRfPu74jHJu9lc838
oPhGfZJmUU2PN8PfAKvpk+le4SL1h5rZDFSf1fvX+vLvvScquIpj1sPwXeA7
60/C9vnkPcmXfKBmBnWHuMQTUT+eyznzUblVLo0H9RZxqXh2BjOaZ0WXrCZ9
97OIcAmTnii2wnnAFbHKD+rOrPLP0Nzfg789qJ1hV7l4fP+utFPzJR2JC+lq
HUY4LzhXfsn8MHMHstldlP/N5RNBjhum
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 154->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FOw1AMRC0WqNdA3AAOUHGFcoIg0VUlpLJA7Dg6tCKV4//GdgpfStP8
OOPxzPy7l7fd/sbM3jc/P7vp4+l4nD6fb08Pr9Ph8eFwenn/e5l9bW2402XN
vezy9aqX5xKX36d6v3de0MdiDWBXepBupvaB68AT+hDvTAvCUjqQLhkv1BH6
GmQiez/vpb1t1IO4oCZF5ohb1jtyUxnxmJnGrTPjexeZ9HNnng46QFZTLsUM
mSadnHf0oeU9X+gWeyRcENPqmgFLzFLN1ckD8aqwox6RO+rUyEXGRfWsNEAu
Vs+hamI9eVVlo9KS8qG4SFzKrshn9Og/sjPMlWATjjnOBpxJG9JlUSN8ibqQ
Xplua/xW2nW4Rw1VL3P3WH9ZCZ6cL94FdvYs5xccs3wT54qT8tt7Xs1H2mCu
GrWxPpszzlH1jHhr+BtgzfpUune4SP2hZ+WBmlNmR8wV//tMdHAVx2qG4bnB
d20+CTt+T9mTfCkHyjPoO9QVmcjmiVyu8Ud92+Uy86DZMi6dzK7BzPzs6FL1
pGfvRYZLmLSy2g7nAVfUqjyoM7P4/grN4zm47EHvCrvLJeLH/0o75S/pSFxI
V3MYqV/wXuWlysOaM1B596fvz1y+AXECGuM=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 155->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOw0AQG3FAfAPxA3gA4gvlBUGCUyWkckDceDq0otGu1/bMpkRK02Rn
PbbHe/vyvnu7ioiPm9+f3fL5dDgsX8/Xx5fXZf9wvz8u3v3dEd+PMTzZHcVv
7m7rVa+WC17td1bffjtdpE9gDcHO/GC+sX2K68CT9GG8nRcMa73Qn2zW2Edw
X9fgzrC6taw+Rj8YF8YV+ah9q0fEUzdnlZEW03lcOjNt7ySTrW43U+dDiUui
wXmS5jw8ttLTcgvAUXrLmJHXDFjCp0xXJQ/KI4eNfiB36pPxKpsX8qx4ZrlE
rkPVzGa8UqMwHacUl3EW+cQ9/5GdQZfBZjjRcA7CmXnDfOlqxFzQF+aX821m
3sq7Ge7Ilc2ezbO7xLrTEfgU2O5d6hccXb43nx8y73bmmT7mDc1VoRbrnU7U
wXKq6rLssrwhFuPqMB0X6X/Sk/VTOmV2SI8Q+Oe1Cq7imGkY3gt8Z/PJsHE/
y17Fk+7sQP/1e5b9JBNOD3LZMh+1t8rlzINpc1wqmZ3BdPOs+JL1ZO+uF/NZ
9anUVjgPuKJW5UGdmW7/Bs+DaWDcCtgh/jPuzBeXv25vktMQXJiviMd4Ka6o
BdfW+gvOQDa7i/afuPwA0HAdXw==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 156->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FOAzEMRS0WqNdA3AAOgLhCOcEgwaoSUrtA7Dg6tKKjxHnfdloilTJN
8v38/efu9WP7fmNmh83vn+3y+bzfL18vt8eHt2X3+LA7bt7/fcy+n2z4pg/t
mTgrNRI9z+JX+zudb387Lahj/gxoZ36Qb3RPsQ6cUIe4Iy9Ia13en8KsO23B
vu6d70AmSKvby87b6AexEKvnUfdaj6Lafl++F41m5V0I35m2dpLJtu9opoMP
kNWQJeg986SS80hb9dOydRmgfgMW1LT8TDa7yJuZj+LKtL0fnh19KuQiYlE1
Mw+QxfI+1Bl/frZ2xUvKh2KRusQs8unv/Ed2lG/lbDfMBszkDfnSnRFz8b54
vzLfZuatPKmwkx9q9jTPbon9qA9fV2lHz7J/wRjl++L3B+bdzpz89Suba5YH
xRv16fvIanq9GX4DLWKNNCMW6X9Sk+qpPmV2oIYJ/fNeRVcxZj0MzwXe2XyS
tr9P2at40r07rv66vK5nSTIR9eNZpuczmU/UBL8qLJXMzmhG86z4ktWk56hW
5zNo0orOVpgHXXFW5YEyNszrAs8pZ8RWmaeJ/4mdfIny191NcmqChXz1esSl
WFVehr0r3oFsdlfdP7H8APsDHd8=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 157->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k1FOAzEMRC0+ENdA3AAOUHGFcoJFgq9KSOUD8dejQym7JM4b21sgUrpN
4ozH48n148v2+cLMXq8+f7bT2/1+P70/XB4XT9Pu7nZ3PLz5nmaHjf18N6cv
zTmm2wviESPB67jAaPcpvt37GpDHfAxgE6biGN1TXAeekId4R1oQ1jK8PkFt
WI/gvpzNd8ATSptDc6cS7+/RneF/4rluFHL7c/kuIO7ct9PlTjzZ1h1xGnQA
r4ZcgtozTSo+j7BVPS23ViesN+CCmJbHZL2LtFkzFa8M2+vhuaNOBV9EXFTO
TAPkYnkdKsbHr81d0ZL8obhIXOIs/Onv/IV3lG5lbzecDTiTNqRLFyP64nUh
vSLd1vRbaVLhvgzHlXpP/eyGOI/q8HkVdrSW9QuOkb/Pfj/Qb8UFtTPBSeSP
Yim/qtPXkeX0eGv4G2ChVgFmxEXpn+WkfKpO6R3IYQJ/PqvgKo5ZDcO6wHet
P9WdzHuSL/lA9Yxq8u8w8YSsx72RqDdUU7tX9Sf2XGBnXCqeXYMZ9bPi2ywn
rVsdI1zCpBHFljj7XohYyq88Rl6oam7Nd8iR9F7WLv4Td9I18na3n7wBE1xI
V3N4xEtxVX4Zzn7xBv5znrh8AA72HqA=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 158->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FOw0AMRC0+ENdA3AAOEHGFcoIiwVclpPKB+OPo0Aoix/vG9qKulCZp
vOPxzOzt89vu9crM3m9+fnb7j8fjcf/5dH16edkfHu4Pp493v5fZ12LDnS76
ltUjhngmTFr+f6r3/50XcLRYA9iVHqQb7VNcB57Qh3hnWhDWuqI+Da832IL7
WuvvFRbw69THfbRn5bqMz5X+St/M5+xc0GzqLKRnxvcuMuk1yDgNOggvJJdk
9kqTTs4zbDWP5+Z1wnkTLohpdU3lXabNzKV4VdhRj8gddWrkIuOielYaIBer
51A1sX62d0dLyofiInGJs8hn3HOJ7Cjd2tl2nA04kzaky6ZG+BJ1Ib0y3Wb8
Vpp0uK8rcCXvyc/NEt+zOWJfhZ29y/kFxyzf/z4/4LfigtqZ4CT6Z7XUX80Z
56h6RrwZ/gZYqFWCmXFR+lc9qZ+aU2YHepjA//vWwVUcqxmG9wbfmXyav8Ke
KnuSL+VAeRbPXMCIM9NcKjcem+qqmSpfu1xMYFdZ6WR2BjPzs5Pbqie9ey8y
XMKkldW2OEcvRC31Vxkjv7qam7sPPYhbw08Tz8SddM3yt9lb5NQEF9I14hGv
dVHvhl+2jBpc4iKNp/afuXwD1ZYaIg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 159->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOQzEQG7FAvQbiBnCAiCuUEzwkuqqE1C4QO44OpfA6mdieCWJBpPST
N/F4bL+bp5ft7srMjpvPj+3y+nA4LG+P16c/z8v+/m5/enj7vc3em12+2/kb
7Z+a7ExtK9z1nOLy56jen30t0MdiDcBGmIyjuse4DjxBH8RbaYGw1tUu22Mp
rztswn2YFWQIcm4jf1WP/EV3Vq5t/J3pz/RVPqv3As3G3gX5zgTdGGbUQHEa
dCBeUC5i9kyTNOemsdk8npsFHNRDcRwwLa/JvFPazGzGK8OOekTuUKdCLhQX
1jPTAHKxfA5WE+tne1e0RPlgXCgu4kzyGe/8RXaYbuVsO84GOCNtkC5dDfEl
6oL0UrrN+M00qXBfV+CKvEd+dos8V3PEvgxb/VfzI44q379+f4Df6DnD8ufK
/0ot6l/NDMopq8uyq/LGZpt5H1TPLEOZB2zOqpZolu6siKswsucKW/Gt5tOc
pyr7w52CJv4s9l/PEW44U5lgufHYTD81U+ZrlYsR7CwrlczOYCo/K7nNeqL/
3otKdlmfSm2Jc/SC1KL+LGPIr1nNTdzrsAt+GvmNuCNdVf66u0lOLXIRukY8
xGtdqHfBL8TlP+wzlw9sBBzj
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 160->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tOBDEMi/hAXANxAzhAxRWWEwwSfK2EtHwg/jg6LMt0Oxnb8SA+qNR5
tGni2O7148vu+SIiXq++Hrvp7f5wmN4fLo8/T9P+7nZ/3Lz5mREfLc7vdnqj
ifbmc+4M4+yIKY9xHcWPa98D1GH585qLUZ1jWFc4QR22hvCyXH2085x1YL3B
OgWP/QzwCcTc1vhVPNIXnelY2/q74j+M2nnf1Ul5qLwziTd2zqnHcIVxfoGl
6EFxUsVmzt1+RmyR8qAaCuMqZ9QxlXZbda/6VtyVPgLYIU+mrxgWVrPiAGKJ
ug8Wk+O31na4RP5gWGhehJn4M5/5C+8w3mxvD5gDYEbcIF4WMUSXzAviS/G2
RW/GiYO9j4QVaY/0XAyyr/rIdVlu9a/6RxiVv399f4DezMeQuyCYSH0Vq+pX
nkE+ZXGVd5XfWG9b7oOqWXmo0oD16XKJelmsmXlVjmpf5VZ4XX/GoKnj/ewB
xcm4luv3YdwV5Qnmm7mv6v6wnipdXSxBcldecTy7JafS0/FtVRP9j1o43mV1
nFgLc9ZC+A3VRh6z7gtYQ94ruTf0DPKNsCNelf8yFhY3et/hNVI+hAvlz1hQ
nMLyH+YJyydbsB8o
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 161->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFVltKA0EQbPwQryHeQA+weIV4ggj6FRDih/iXo2uMJpPeeq0IDkx2Z6an
urq6FnL9+LJ6vqiq16vPn9X67X67Xb8/XO4XT+vN3e1mf3jzPat2U52e0+GJ
5k+M21Ozgrsjpz7GfRQ/7n0NkIfh972Uo7rHuM54gjxsD/FlWMcxnZ5J72Z5
jI67Ab97iGmD9HFaOh2PXKf5u9O/j6TPaZ/S78l+D8aTLh/jlfA942JqUJq4
2K55Ws/IrRoOqzfGLB/jere0765upZ31EeAOdQp9xbiwnE4DyKV8HSxmqceT
GIapOFlcxJn4s9/5C+8w3WJvD5wLcEbaIF3OYkhfui5IL6Xbkn4zTRLux9G4
ot6jfs40A+eqjp5XYpO1qn/WY+PvX38/oN/Mxwirx7H+J7Eqv/OMy4nqSfkX
WTOvIEzFxWlMa5sq/i+WaolqOdsLcRWGO1fYim/qT3ZHea8UX+QD4ccSNTle
sp7BCyjO1eT6mnIpgu28knh2CabqZ+JblxOte2+dd1meJFZy7vNnCL+h3Mhj
yqOp5iXu9TocdpF3xB3pqvw305TEsZ4wXavhIV4Kv0Qc8mI//8954PIB6ZAi
Zw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 162->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytVkFOw0AQG3FA/QbiB/CAFV8oLwgSPVVCag+IG0+HFkg3s7bHAVYKIZtZ
j8d2pN48vWx3VxFx3Hz+2U6vD4fD9PZ4fXp4nvb3d/vTy9vvK+K9xeXevu7o
+qmp9tQVxtmeU179Pqrv984L9GH4ec/lqM4xrgNP0IftIb4Ma17tcne8G/pU
OvZ3g3N+59Tnc/BMiwWHzEf1ysvx2fXJ/Z7crCnPHE+VDhaXYgalSVVbzam8
6z3vcdi8NmbUNY53a3yv5lbaVVwQd6iTmSvGhfWsNIBcop6D1azNuFPDMBWn
EhdxJvnMZ/4jO0w3O9sFZ6QN0mVRQ3zJPZBeSrc1fjNNHO7zSlyR98hPphnL
IsWNsT/DRphs/sHjIt+//n6A3yzHLHuVr1UeGN81mal6onlc/kGeWVYQpuIC
NRY5mZ9b2L/FXC2HWVK+wsRlORlmAO8VtuLr5pOdUdkLxRflQOQxxEwVLzlP
8kp5U+lf5lNwmXMZGm8ttpOPCtutR3wyDnrO3lbZZX2c2pIzwhV5Q71Rxqzv
Bewt3qMZEDfDzyD/I+5IV5g/wHF4Jjo6umZ8xGtebXkmz5J5ONz+eqmcl2fP
XD4AolggZw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 163->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1FOQzEMi/hAXANxAzjAxBXGCR4SfE1CGh+Ivx0dxhjLS23HlZjU9bVN
Hcdxb5/ftq9XEfF+8/23XT4e9/vl8+n6uHhZdg/3u+Ph3e+IOGziMm9OMxrn
mByX95wRBA/lQb+8f8b7G7HG+PmBPAy/7rkc1b28h/DqPaY3i1fc4bmhP8zT
6Zhng/PqzIyv9+Cd5IdD+e70R15Cc+bm9ql7C/LNCB1QTqengw6kx5RL4yGl
SRfbYbN6MrfawyGH4AIxo49xeufU5fgB4XbYVY/KHepk+opxYTk7DSCX6OuA
MaBvs7kdLZE/VrHJ2xQX6Ub8We9Me6fxVeVvebvhjLSp9TCeqG7YD1E3qoXt
S+2ATq3vC1fUe9RPphnzIsWNMT/DRpjDd/I0qlPWSPJ172eouQxVX95X/Xdi
a/yMZ7qcFW+Gf5A18wrCVFxQzUNOVJvg4ujeejHlyDkdXOaToQZwrrAVX9ef
7I7yXii+yAfCjyFq6njJekqvVG86/Vt/Ci7ZlwpvFtvxR4ftxiM+FadbO95l
eZzYlrPARVjsvHrMei9gb3Uu7q2wjX4G+Ubcka7Mf5Uj0m1Yo7xA1ygaIF6Z
R75Ta6k8MhfUr/8YSGc3/sTlC4jGHxw=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 164->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOA0EMizggvoH4ATyg4gvlBYsEp0pI5YC49enQloVsxna8oiNNt7uT
OI7juX1+275eRcT7zffPdvp43O+nz6fr48vLtHu43x0P7352xGETf8/N+Yn2
HJPj8jdnB/mP6qCVv88YvzuWGKcFODL84VvCVhxrHvqONER5TO9D6pFqAbCG
c4GveNk6Ar0Q58WZGV/zYE6ZWeVD82o+qV25MR1RnLoL8s4IHVBNZ6aDDmTG
lEvjIaWJ4/POn3B2iVud4VBDcIGY0cc4s3P6cvyAcDvsqkflDnUyfcW4sJqd
BpBL9H3AGDC3tbUdLZE/FrHJ2xQX6Ub8WXMu4Z3al/IUOo+GM9Km9jPUJ3Op
NdTsWB133kyTljuoy2pFetZ4hGn3ruZFsBHm8D95erEaf//n/gw9A88xrPxd
zd+JrfFrPNPVrHhr+Ad5Z15BmIoL6rliwd4EF0f31otzjVjWdHCZT1iPQ12C
rfi6/mQ5yntosbzTEn4M1VPanb+HuiRv7XwWNRt/QsxyZ1wujmfXYKp5Orp0
Nbt3x7usjhPbcha4CIudV4+590VqIfLa3MqN/Efcka7Mf5Uj0m14R3WBrlE0
QLwyD9QnwnXmdYmNdHbjz1y+AAFJHWE=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 165->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOAzEMtDggvoH4ATxgxRfKCxaJniohlQPi1qdDVTYk4xnbEY2Ubndj
j8fjyf3r+25/Y2Yfdz8/u/Xz+Xhcv15uzy9v6+Hp8XA+fPjdZqfF/p7L5cn2
FtPH9d+ibYvHV7k9J1z99w2PcWmL8G47wG65QhOnG8FBrqxnzFN6nwhnpwXB
cucF/Wk/grvSLMRCfsV4zGM5zhOZpriIZtGclY4sTt2J9O4EOigNspk6HcSM
JZfEQ5EmFZ9n/qSz67j1vdB+Ay4U0/KYyuwqfVX8wHAzbNQDuVOdir5SXFTN
TAPKxfI+aAyZ22ztipbMH0Ns522Jy3QT/sSca3gH+4o8xc4t4cy0wX5cfTEX
rMH0inSbmbfSpMId56NqWffEeKaZ8qLENV9fYTNM9x/6ayvx93/uj+uZeE5h
9d+j+VdiMX7GM1lNxJvhb+JdeYVhRlxYz4hFeyvcg6jH1IuMQxE3wsjOI+yI
b9WfLSfQPutF1R1mY/58OxuwOy7uSfKjflje7HwMuEX+pJhwZ6pcKp51fBPc
qhbKY5EnhxjQv+pdVacSm3IOcBmWOkePKd/PaG5BXporuCk/OF2M/3dzSHxJ
35lmRNfmF8FlWKQ3E7gVja6xI59n8Rcu31iBHpw=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 166->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOAzEQG3FA/QbiB/CAiC+UFywSPVVCag+IG0+HUnY7mdieWWikdLfZ
Gcd2nLuXt+3uxsyOm++f7fT+dDhMH8+3pz+v0/7xYX/6eP87zT6bXZ7t/ERz
rvF1fk1NayM+6/Wc4vDrM17UgHo9D4Y/rLXLVBxjH1pnmhFHWkv2YRzg94L/
UA/hzjyTWJFfsT72oZ6FK8hb5v/CX+wduTEfUR27E+ndET4wD7IzHXwgZ0y5
JBlSnlRqs3zCs3PcvBaoV3CBmJbXVM6uoquSB4SbYUc/InfoUzFXjAvbM/MA
crFcB6wB57Z274qXKB9dbbP0zke/Pf9sv2tkJ+pSmULfLeGMvEH8uxqiM+6B
/FK+rfUPeVLhbq2vYXshPSxPCI/qU+dFsBHm8B70LSPJ93/uz6AZZI5h+XV1
/pXaWL8mMyinrC7LLswb+M+ygjAVl7/mM/JSOqteIi3dWhFXYWTfFbbiW80n
61HZQ4P1/QxxByxit3FNZYLqcTjMv8r5WOC2lsvMI2JnXCqZHfgmuFUvWMZU
Jrsap5nxGnwW+1RqU86BF8IecptoRfmKtcpzc0/Wx3qVdpTXLFvxndVkuYie
V3wd8gJ4LYNoQ7gVj64xkc/V+jOXLwX0H2E=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 167->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOAzEQG3FAfAPxA3hAxBfKCxYJTpWQygFx4+lQlW2Tie3xIiKlu01m
PB6P9/b5bfd6FRHvNz8/u+Xj8XBYPp+uj39elv3D/f54efe7I75aXJ7t9ER7
jenj+jO1o834LLfnlFd/vuLlHlBuz4PhT2ftshXHnIfOWc+II40ldRgHdD9g
iXlPdQh3ppnEyvyAL1B8zkM1+t6Qn1keWs6cmY9RXDXfKg7pwDSoZjrpYOQP
HIoelCaOzx190Bq8Hbyu4jIs4H1W15ndlrlPWMjroC+HC+IOdTJ9xbiwmpUG
kEvUfcAYMLettR0tkT8YFzXjnBuAG6pneQjwUvNSnkL3UXBG2iD+QwzpM9dQ
GrM6w90ftHO4T7wBh6HPbjM/ITzan5oXwUaY0zvhqHREXFA/uRadN/Acw+rP
2byq74nx3eKZqmbG28I/+y1AXfd7kF4F3DP2cG98B6rH0ouIg4mrMKp7ha34
uv5kOcp7aLE8Vv+8Mnabz5QnaD8dDopz58NyXS4rD6SB4uJ4duJb4LpaMI8p
Tw4xXc8OLsJES8WWnBMvhO34NnuM+d7RPLony2O5qveM73grv7OYyhdZc0fX
7BfE67yKmWcelUb/sZHObvyJyzd6vhtn
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 168->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylU0tOQzEMtFggroG4ARwg4grlBA+JriohlQVi16NDxaeOM2OPRaT0k9jj
8Xhy+/y621+Z2dvN18due388HrePp+vzn5ft8HB/OF/e/Wyz07DL9/j+Rvs3
xsf5s2zbWPFZrucUlz9H8f4s5lX4y9m47IxjzEPnrGfGEcaSOowDup+wknkv
dQh3plmKFfmJ8TEP5fjekJ9ZHlrKnJmPUVw13yoO6cA0qGa66CDkd7mo/BAX
RR+0Jm8br5txmRbwPqur6NWZ+4KFvA76Urgg7lAn0VeMC6tZaQC5WN0HjAFz
69ZWtET+YFyyGcdcA9xQPclDgFc2r8xTKQ7hjLRB/KcY0meskWnM6nT0Q5oo
3BfepJaNkJP4CeHR/pJ5MWyEufwGs/G80x5JvfT9oHkTvZj3qrlWfmB8O56p
aka8Dv/oNwN1O+8hq1l5aLoX3kHWY+lFxEHEzTCq+7/V5Kv40/wOOVTD4IGs
blYf9YW4lJ4gMf6O4Snz6XCBmEAvhYvi2YVvgatqwTyGalKfFL0inVkdJbbk
nHgXYbH7KUZ4L4rmzPOodoU9cWl4K/5mMZUvouaKrn4umTc8Juo74k7Y/3gD
5RtpxkadTuMTI9wZqg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 169->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0tOAzEQRC0WiGsgbgAHGHGFcIJBglUkpLBA7HJ0CJ/En1fdZYilyWfc
rqquLl8/vmyeL0opr1efH5v17X63W98fLg9/ntbt3e32sHnz85SyX8rpe/n+
pue3pq6L6puzUF/jEQ+t+j3V1+/6cxn+8M7wgs7Re9Wz0oi1gkdpoP0GK+mv
OSu0k2c9rvKG/Mm8zHzseyMtiqtfzpxVjqkum+9M1qKZOTONfDiXFlffoMX0
h1Y9/1qj6jfFhOwrXsevmbkPWJR16MvRQtrRJzNXSovizDxALSXvA2v+kHGn
RmFGmkqASX73ZyI+K0OgK5pXlKkQR2gmb0h/UyP67DkijxXPjH/kiaN90C24
Bs+CPBGe7C+Yl8ImzOE3zKbWHfWo+ML7Q/OuPQZ/+5XNNcuD0juTmeiOyPtk
6u/zVoB35j5EnPVM+zPUK72P5pDpGnrp82jiqpwMPcB+zU1ZV3qdfPb9oPfi
jNNPxE99la6nMBPCl4bXuD+O/64WxAS/HC1OZmcw1TxdXzJO+h9xkc+Kx6m1
NIvsEpbab2qM++J4rjI/aDPmOVNPvmY1R71JTr8WeQa+9nik67hEn4Tb7P/j
DpzzId/2ywdETR0m
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 170->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOw0AQG/GBeg3EDeAAEVcoJwgSfFVCaj8QfxwdyiNsZm2PN+pKadJk
1+OxPTdPr/uXq4g47b5+9vPbw/E4vz9en/88z4f7u8P54+3vFfExxf99+rmj
K8Cz2o/OIoxub8Mpr/Y92t++y+cq/PxO9pN1AziKK+LJarR6Mb4Ma1lZn8rr
XIdw73QEuOh7TD1/Wjt6PdiZ3BviQrml5fiMMN0cqW9V1pRnjqdKh0txcfmN
YFTetf63HFm/DmbOPqvr6DXie4eFsg76crgg7lAnM1eMC6tZaQC5RN0H3LMh
484ehqk4hcBEeuczqp6VIcBL+aUyJXEI59USnqzqkz5zDaUxq9OeKb0Bmjjc
O96Aw6rPIrcMj/Yn/GLYCLN7JnOgdERcUD+5FvWb6MWyV/lazRPjO5IZNSN0
nkz+OW8B6lrzQLignjMW0seZA9VjmcW/GkDfCpflhPXY1SXYaD5G8pnPM+2r
XhQGq7+szGdjJmBdY34c/V0uEDPNjMvFyewIpvLT0cXV3eGN8qrqOHstzsAL
hsW+r/YMzIvUWJxbYRt+juxHulZ7Fr5FTr8X0gzomvEQr2UVnmceLf7WGbjk
hbl8AsQgHGc=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 171->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FKBEEQKzyI3xB/oA8Y/ML6ghH0tCCsB/G2T9dVWburk1R6EBtmh52u
TqWS9PXjy+75IiJerz5/duvb/eGwvj9cnv48rfu72/1p8+bniTgu8ftevt/o
QXuqHtWFcbbllFf7HdW33/K5Cj9/k/Nk3QCO4op4sh6tXowvwzovgqfm67AJ
90FHgIv2Yxn5094x6sHOHDN+palYjs8I082R2quypjxzPFU6/BUXl98MRuVd
63/Lkc1rY0Zd4+g14/uAhbIO5nK4IO5QJzNXjAvrWWkAuUQ9B6zZkHGnhmEq
TiEwkd75jOpnZQjwUn6pTCkchDss4UnXn8yZdVEasz7d3gbtHO4Db8Chm7PI
LcOj8wm/GDbCZPMPHhf53nx/SMaQXix7la/VfWJ8ZzJT9cx4M/xz3gL0de+D
zCrgnrErD9icrpbDLClf+f4wXMaxmgHNlLPO+Lr5ZGdU9tBi51j/r5XunHM3
utnJeeSP8ibnOnO38sk8J9gVF1cPF1P56eS26on+q15IZ9bHqbU4Ay8YFtvv
akgWZjUPca7DNvycqUe6VjVnvqKuzb6ja8ZDvBA+uwvDXtIi7//ng7l8ADT7
IaQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 172->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOAzEQG3FAfAPxA3hAxRfKCxYJTpWQygFx4+lQoG3i2J7JChEpu9qd
icfjca4fX7bPFxHxevX12C5v9/v98v5wefh4WnZ3t7tD8OZ3R3xs4vze/LzZ
ZjGXz/La/GPNIbfhhKv9z/Lbf3guw8d/th/UjeA4roynquHyM+6nhfo0W/XX
YQvug44Ek2K1MeIL7IvNl9UY8BNNGfcgNVmvM3NyHkrvjtFBaZDN1OnwV1yq
/GYwXD8nTmSGqt8yZuQ5Fb1m5j5gMa+TvipcGHeqU9FXiouqmWlAuUTeB81Z
4fFKjsJ0nMJgMr3xjKtX8hDh5eblPOVwGC4uN5MuR/SJujiNVZ0utkK7CveB
N+HQ9Zn4VuHJ/sy8FDbDVP0PM078vfr+ZB4jMVzZXLP7pPjOeCarSXsr8ke/
BalbvQ/Wq4Q7YuNsjtvOUNTLvNjWcLkZtupdxR12q/0MLtMZzzjvsaXOqfrf
C+ZVuRuV8208uz+oJfYzw4XqJLAzLlU9qphunhXfZjXZt6vFdFZ1KrklzmQW
CkvFuxzhhVnNg/XA+ijMcyaf6aq8jRyZbuxcRVfEZ7wYvroLQwy0wPh/bs7l
E/5eIqA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 173->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytlU1OQzEMhC0WiGsgbgAHeOIK5QRFoqtKSGWB2HF0qEofifON7RQipe8n
zng8nrzePr9udldm9nbz/bPZvj8eDtuPp+vjw8t2/3C/Py7e/Uyzz8V+r8vp
StPg/rwvm0YYYm/LyY/2/RlvndZj+H0Zvn8X1uN1AxzPlWqO8ql3UgvAWofX
J+ndkEdwH3QEDyHnpb/3vvDxXg/i0nEFv2X6t1xUbs+t2qfIQ+nZCXRQGmQ9
jXT4Ly5VfjMYYe/OnKCHqt4ypuUxFb1m+j5gkdehrgoX4o46FX2luKicmQbI
xfI6VMysxysxCjPiZAEm6e33RPlKHgJeUb8iT9G6NZM4kzbEv4sRdfocqFeg
28DvAu0q3AfewKHj6upQmikvSlwb8ytswuxGw5PWIn9ffH6g30ov5b2sr9l5
UnxnPJPl9Hgz/L3fDPJWz0PoVeDusbv1xfC7EPUh4zXUUojNsFXtaj3CpvMx
6891T6B9VovKG+VfB9UUaEg9x3oabKUfaenrmeGCOgnsjEvFszOYUT8rvs1y
0nOUa9A5yFOJLXFue7HY8B9T8W0XI7wwqzn6mOoo9HMmnnRV3iad0mfSDHT1
+MQL48VZaHmQvn79r5N0rvb6xOULRlke2w==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 174->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytVkFOA0EMizggvoH4ATxgxRfKCxYJTpWQygFx4+lQlS2ZxHYyqCtN293N
2I7jkXr7/LZ7vTKz95ufj9368Xg4rJ9P18ebl3X/cL8/vrz7XWZfi/19L6dv
tLYaX+efqWVLxmdcXlO8/PMN47xsxIj7Kvz4TPYTfQM4USvyS/GxZ9QLgIU0
nX0TPSYeoj35COYKNS/jbyvqk36gZdBKMsb2ef1svsrjyr/qPM1mTc2sM1Pl
w6W0dPXNYMjZbZpCXlW/bUyrazp+zcw9YaGsg746WpB26FMzV0wL46w8gFqs
7oPVzGa8U8MwlSYTmMjvuEfxtTIEdKl5qUxJHKIZeYP0DzWkz8gBtQjfZv1D
nnS0J92Ey5awR+QJ4dH+hEcMG2EOl9OJ3ql8//v8gHkzv1j2qrlWeWB6ZzJT
cUa8Gf0xbwZ4Z85D0lJ4THtbbPhfpvrseukzuN3TWoHLcsJ6jLiRu9JQ4Q65
LnxDfaGL7WP8qC+kJfKq/Ym3cX4GbtBPWwubD8GutHQyO4Op5tnJbcWJ7hVX
8lnwdGpbmv0sirwj7lQj9s94bg4L5RHlQvXerUe+shoTe+k98gz46ueispHq
yVnwOpSWSy3kc3fWJy3fkjIeng==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 175->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOw0AQG3FAfAPxA3hAxBfKC4JET5WQygFx4+lQlZTdWdvjRUTaptnM
ejy2c/v8uttfRcTbzffPbn1/PB7Xj6fr08PLeni4P5xe3v2siM8lfu/L+Y7W
VtPWtXtqxTLis14tp3y1+xvGZUWPkc9V+HlPzpN1AziZK9JL9WN7VAuAhThd
dBMzDn0I90FH4CvkvPT/o6gf+AMuHVeSMXau5c/8VRpX+lXf02zWlGeOp0oH
i0sxg9LE1cHhsnkdiVv3LOatNEKasxrHuxnfByzAHc3lcEHcoU5mrhgX1rPS
AHKJeg5WM5txp4ZhKk4lLuHMsF1c5knll8qUxAG4+VKedDVkztyj4sp0cvVD
mpTcQV/KMWdA5Anh0fmERgwbYXZXwxO9U/n+8/cD/GZ6sexVvlZ5YHxnMlP1
zHgz/INgs6wgTMml0JjOlvKi5nS1HL6PZdxzcFlO2IwZt+XSZRLoPZPPSEv5
qWbZ+KFzrD+aC3HJfdX5oa/x/XS9E0+ET7kwzwl2xcXJ7Aym8tPJbdUTPate
g86ij1PrcO58LvKOeg814vys5kOO0RyGnzP1SNeqxtG4zb6ra4AaWQ/wUZ3i
8l8L6ezWn7l8AYyZIZ4=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 176->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOAzEQG3FA/QbiB/CAFV8oL1gkOFVCag+IW58ObdmSndgeBxFpu206
8dge5+7lfft2ExGHzffHdv542u/nz+fb04/Xeff4sDv9ef/zRByn+H1Plzd6
lpq2rt1zniB4qA9a7f6Cd16ZHzhX4ec9qSP7BnAyV6RZ9WN7iC/DQpxa35S+
1VnCvfMRZAhyntbfcy4Q76wL9bhyBXmr/M+8nDm7c6ru02jW1MycmSofLC6F
BuWJ64PD5bxSPrvfQm/lEfKc1TizG5l7h4WyDnQ5XBB36JOZK8aF9aw8gFyi
1sFqRjPu1DBMxanEJZwZtovLZlLNS2VK4gDcvNRMVjVEZ+5x9U/oRlpc/5An
inuQvqxXNO/lPMsTwqP6xLwYNsJcrYYn+k/l+8/3B8yb+cWyV821ygPjO5KZ
qmfGG+EfBJtlBWFKLoXHSpviVfkOs4juG6sVuIxjpWG1SNYRhwoX5TraPTIH
hsn6VrPJunLvY/5enO/6Gven8yIwBvKgylXrLfJAZcXJ7AgmuxNOPfQ9NG7F
q/NZ9HFqHc40dwAL9e5qxPlRz7seSIdzbqAe+VLVOB632Xd9DVAj6wE+qlNc
/utBPrv1Fy5f59Eepg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 177->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOA0EMi/hAXANxAzjAiiuUEywS/aqEVD4Qf3t0qErLTMZ2PBIrzT5m
HcdxMvev77v9TUR83P3cduvn8/G4fr3cnj7e1sPT4+H08+F3RWxL/D2X8xOt
C6bFtXvOCvLe7l0XuLYlvS/9fqs1x+U6FHdV1+Ab4MlakV8qH9tDehkX0pR9
Y/V1sUT74CPoK/Om+2fgcxzK0c4QmjEWl3Ww3Fmb26fqPM3OmuqZ01Plg6Wl
qEF5UmErbjQ7kbR136LeyqPMBTFCZ6thtu8DF9CO6nK0IO3QJ3OumBaWs/IA
aom6DoaZnXEHwziVppKXaGbcLi/rSdUvNVOSB/DmS/Wkw5A6c46rf6JuVIvr
H/JEaQ+Sl+WK5nmJZ/OE+Gh9ol+MG3EOFzkHyH+lBdWT87J+M7/Y7FV9reaB
6Z2ZGXVG6Hky9Qeph80K4lRaGGeOYf+Zrsp3OIuIn2EFL9NY1YBqknpN3oGj
PTdL+mYxRj1Vby65N5J7y+9F/JDXOD9dblAPi0ValLfIAzUrzszOcLIz4eCh
76F5K13IZ5bHwTqa6dwBLpR7wIj4Wc+HHKgOJ24Cj3ypMI7H7ey7vgbASDzg
Rzil5b8W8tnFn7V8A+SgHuc=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 178->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOAzEQG3FAfAPxA3jAii+UFywSPVVCKgfErU+HqiwkE9vjICqlu5t4
Zjwe5/b5dbe/ioi3m6+/3fr+eDyuH0/X54+X9fBwfzgf3n2viNMSv8/l8kRr
w7S4ds9ZQd7bvZ8FfqclvS/9fss1x1X5c5zsI+sG8mSuSC9Vj+1RLVC/gFPW
jfXXxRLug9Zgrkyb7szA5zhUo50x8hiLyzxY7czNnVN1n2a9pmbmzFTpYHEp
elCaVNgqN51dw637Fv06ObP3WV1ndjNzH3Ihr4O+HC6IO9TJ9BXjwmpWGkAu
UffBMLMedzAsp+JU5i28q+pZHgK81LyUp1QelDf/1Ew6DOkzEJeib9SLqx/S
RHEPUpfViua5xbueUH0EwCmvslodp6a/YcaFv/98f4jHBr1IrnZfzd/BZvyM
Z7KWCld5F90Vxa+twXIqLixnjmHnjFele+nFwHtOXsax6gH1JPmaeYcc2fvg
HqleWN1qNlvtXDfvSU8Q37RnqAd3PiwWcVHaIg0UF8ezMznZnXB1qWqib1UL
6czqOFiHc/ZNXo5vOwyZ16zmkAfqw5jnDB7pUmEcjVvvD5oRXQNgJB7kRzjF
5b8W0tnFX7h8AuPBHSY=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 179->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOw0AQG3FAfAPxA3hAxBfKC4IEp0pI7aHilqdDKaG7jj2elYi03aTx
ztge5/71Y/d+ExHHu++f3Xx6Phzmz5fb88PbvH963J9fPvyuiGWK6z5ddrZW
TIcPjac1RD3sE+sO1zLBveDCzrn6eC7Vgb6ROsiVac76qf8YX1WLcULf5Aza
s4L7xmuSIeVN966Ax3Osxx9Xkjfnf8tD9UZu1Tm572k0a9nMKjPNfChxMRoy
TxzW1Zaza7h1z4neSk3Mvupbmd3I3J1ulecKF8ad+lTMleKiejoPKJfwOhRm
NOMVjKopOTXZlnVNdrN+w9kxuUL+I3NndfHKZsJ4bnQzLkY301L1j3liuZO+
qlc0+881kIlMRxBcllXVa3MvvoMs44wL04O91LypX6JW+382/woW8ZlO1LEA
3wznsuvyFs1yvle4UP+xJ/GH9VM6ZXawB6ufeKLqKo5OA9Pk5jKaz1VTd4bM
M9Oi+rrZYG3M0oL3TJfITfuOaajOR511WjpvC7McrV3Jh6tdxVPfI6/reDGf
VZ8KtsIZc4OrktsOI+Y16jnlwXQU5jmCZ744TMXjNvsbz4SvQTApnuhmuIzL
fy3mcxV/4fIFT88d6Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 180->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FOAzEMRC0+UK+BuAEcIOIK5QSLBF+VkNoPxF+PDqW0bJyZ8UQi0nZ3
G8d+Hs/evbxv324i4rD5/tkuH0/7/fL5fHt6eV12jw+70+b97xVxbPF3b+c7
ui4xbjzMQZ5znbjc0zq29Nz6/7sc6dzALnLnM0wLdg6xZsaqHvsP8bJc1wW0
Vz0OdQj7oCOYK2QGfCqe+S+fubISj7FzmYPVzmzunKrvadZrambOTJUOFkvR
g9Kkiq1y09mt2Lp30a+TM3uf1XVmNzP3qm/mZ4cFsSudZntEnK5miqXqg8XM
etyJYTkp08rbNG/hXVVv2juFrzL/zNyZh5A2iB9xDn0bLI6PXf2QJiU7qEsZ
iYaOJ1QfAeKUV1mt4Zl8B8rjiAX1k2sh7kEftJdWNdfKD4xX9cn487xRXOXd
ym+xuirdHRaof64J9EH1WJ/UO6QGy814qrmi3tm+yq14XX/+LOR35T2w2PfD
6iOe7CXLEyRmvYd6cOfDzla9dNoas5zN7fijyu3GQ91D5624kM6sjhPrMA95
gedgHOkV+Qv1rHTIvo/G+3Dm2bFMeCs/sxhH47X3B82IrgFiZDzoG8Uplv+6
kM5u/JnlC/MFH+s=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 181->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOw0AQG/GBuAbiBnCAiCuUEwSJflVCKh+Ivx4dqpKy47XnIREpj01m
PbbHuX993+1vzOzj7ueyWz+fj8f16+X2vHhbD0+Ph/PHh9/T7LTY33253Nm5
1bh60/UUQzxjH9vucJwWeBZc2D7GXWFnuibfCA5yZX5F/dQ7xldhXQ/0J5nd
1Edwn3wkc6WcCb+oXuUP91y5ioypfchD9UZu1Tll/1M3a9HMKjONfChxSTRE
nlR9qHBhmgx6RXormJh91bcyu87cM90qzxUujHvkU1cj41n1LOKS6VA13YxX
ahSm5DT8N5VMMy5Rv3Z2klwh/87clSalT+0ZeU66sX64Z77Sbx3viE8Mj/Vl
HJxOyIqR3gxP6gvmhfzUmj6L/yDykXFherAX4z1ijn0V1vhezTX7nxTfSKfi
r9aIR3sGuXRrzJKoy3LOahw+4ZDNQOmU2RE93JHUZthKu/oeYUd8q/ncNLk9
ZJ6RFtU3mw1iY5ZUJhyuys3wjWmozkftzbQ4bwuz7GJX8pFhV+up7xbjZryY
z6pPpbbCecIdZlPNrasR8+p67jIyviO9M2zHpZEtfJ7mkOSSrplnwlcjNTQH
ycwRN+LyXyfzuVp/4fINjdkZ7w==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 182->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0tKxEAQLVyI1xBvoAcIXmE8QQRdDQjjQtzl6DqM0e7q96kGA5kk09Xv
V9W3z2+H16uIeL/5/jmsH4+n0/r5dH3+eFmPD/fH8+Ldzx2xLfH3XC5PdLdr
eV/1DvK+JezYn+nalv6daUH7UD3Ddr6G3ACO0op0Mg5V77QjTXv2yuPAQ7QP
OYK+Qs15zdSj/iKOX61kxti+rINxZ23VPqkZsmdG5MAycD1VOZS0GA8qk2oO
FS3IUyQu5beMGb6m0ruZvjvfbJ4rWpB2ldOsR6SzmpnS4nywmtkZr9QwTKUp
BCbbq7CremFPzFxl/TN9Z56YP7an1Tn4zvUiY8bTrc1kB3JCeIgXaeh8gv9R
ZmwWKW6M/Fkf+4bv5ByoHJEW5CdzoX4P+aC1dLm+uvPE9Cqf2YfjzHiQU8xl
902yUZkoLcPMFecTeiA+6ewQju4ytQ6beWfrClvprc7n7qnbA86R8sJ4XW8y
diRuNhMdLpubZg15qPaH7XVekAaFN4s9i8nORDUXx4m+FRfKmfFUaiuaB9x9
3gAW4h5qSL9mM291RPtf9lHo50w9ysXVZL0yc5QZyTVADZwD4pPhKi3/daOc
q/UXLV8fjhwu
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 183->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0tKA0EQLVyI1xBvoAcYvEI8QQSzCghxIe5ydA1xYnf1+1RLBjozk65+
v6q5f33f7G4i4uPu52ez/Xw+HLZfL7enl7ft/ulxf9p8+F0RxyX+7sv5jla7
l89VV5DnY8KO9Z6u49I/My3oHKpn2M7XkBvAUVqRTsah6p12pGnNXnkceIj2
IUfQV6g57y3gvxh5XI4XrWTG2Lms47KAhpar2ic1Q/abETmwDFxPVQ4lLcaD
yqSaQ0UL8hSJS/ktY4avqfRupu/ON5vnihakXeU06xHprGamtDgfrGZ2xis1
DFNpqnKzM4rvGrPDcpvtu/umMo/UQnwG0RJEK8vpcv0jO6sd8CINnc/sTfSm
Ml8B6ty8de9MA/kOVI5IC/KTuXIuXX3qO8Nq/2f9ct8T06t8Zh+OM+M5znwW
Yhdyr2gZZk7MkOsB80lnh3B0l6l12Mw721fYSm91PldP3RnQB+WF8breZM52
qZnocNncNHvIg/Vk+qq8sO9C4c1iz2KqflZycZzoXXG1+wgTXaq2onnAXecN
YCHuoYb0azbzVkcoH4V+ztSjXFxNp5nU5dmv5BqgRtaDs6hOabnWQjlX689a
vgEHlxsw
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 184->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0tOQzEQG7FAXANxAzjAE1coJygSrCohlQVi16NDKX1NJrbHYUOktO8z
8dgev9vnt83rVUS833z/bLYfj/v99vPp+njzst093O+OL+9+d8Rhicv/cvpH
O8D1+Zy7EcZQE6d3aB2W/rrjnp7lc6ieYVe6Bt8AjuKKeLIeqr7ivq7G17P3
SuPQh3AffARzhZwRP1GP5ot6rFxJxti5zGO9BhzaXu6cVIbKb0b4wDyoZqp8
sLgUGpQnVW2FTWfXcOvuhd4SE3BhfZ3Zzcx9wEJZB7ocLoi78mlWI+Lpeqa4
VDpYzWzGnRqGqTi5vdkZ1c/KEOCl5qUypXCYJqZPciE6g3AJwpX5tK4/eFdy
B30Rh05n1iZm4+QrQF2Vt+6ecSDfgfIRcUF6cq/sS1ef5s6w2udsXtX3xPgq
nVlH1TPjVT3z2arW/R5kVuOiM2MxbYpX5TvTWWXIwWUcKw2or8vXzefPAnmX
2QPLyQHilTOduaBMdLgsN807hufMZ4YL89aZ5Sz2LKaap+NL1RPdq17IZ9bH
qXU4D7ggb7COaEX5QpqVDxknmmeDDmOeM/XIF1iDfCpy2mpxfA1QI+vBWVSn
uPzXHrl8AQiDG28=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 185->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOw0AQG3FAfAPxA3hAxBfKC4IEp0pI5YC45elQCmXXa894uRApbbLr
nbE9zvXjy+75IiJerz5/duvb/eGwvj9cHl+e1v3d7f64efN9R2xL/P4vp392
s70M79YYMHHCsWtb+ueOO6zhOYZXtfEM46hqsXU8x3iqHhm+4s44/cwh0zj0
EdwHH8mMKWfcW8hajH0qH89cRd7UOeRxfiYc2l7unLIMOd+D8kF5UM0088Hi
UmjIPHF9cLgwTQG9Mr12zagxzuxm5j7UYlknuhwujHvm06xGxtP1LONS6aCY
P2TcwaiaklMzQyfTjEvWz8pQglV9M/yQbfBczR77YI8OI7hjD5w3O8u0nK8J
75hPVe6R61C/9XAyE9lsg+Cq2t17O1dcJ+cyHxkXpgd7oS8dHuauarXr2Tfh
YBGf6UQdVU+sV/XEsxXW/R7SrJL+WLuagdLpfn+VZsWnmivTrvaz2hlfN59f
F8l7mj1yOTlgvDDTyKXMhMC0e6qeM58ZLtJbY5aztZ18DPjmdvCsv+rJ3jNe
zGfVx8E6nIe6JG8UJ7SyfDHNmQ8sL1vDq6tdZGXgMpEtfGZasbaqhVocX4Ng
Ujw5y3AZl/+6Ry4fvTwd6w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 186->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOw0AMtDggvoH4ATwg4gvlBUGCUyWkckDc8nSoSkpiz4wn5cBK26TZ
sT0z9t4+v+1eryLi/eb7Zzd+PB4O4+fT9fHPy7h/uN8fD+9+dsQ0xO9zOD3R
RmcK7+YomDjh0JqG9fuKe/qW4xCe5c4xiCPLhb7nOMST1VD4jjviNPdBaSx1
CPfiI+gx5JzPBvAtap3OxzNXMm8sLvM4vwMOy1pun9QMOfeB+cA86HqqfLC4
NBqUJ64PDhekKVItpdfOGT3G6d2WvpdcaNaBLocL4q582qoR8XQ9U1w6HRBz
wYw7GJZTcQqRk8Wq3C5fB8vqKjztO9HE9MEcM4ZwzzUUhtVZnW3wjtVTc5+5
lvyLJ/OPzYTqbQBcl3v1f+ZE9JceKw//cn9A/LTkhs7Scu4Ew4bgq3RmHV3N
nK/4AbxYxip+CmdxyXnM+ex4Kd/pvcr1G09YXsax07BaYlacOWAcz7pSjJw9
sJw5QLyKJlJT6UKYWRfT4PZnCxfqbXMfLsnd3TGIT75YMSl/5zuKo94Ez4mW
wlqcQS/Y7KPaBbPhvrB+oN5kngivtLt46OsgdlS+0nPkGfE1AEbiQSzCKS7/
tSuXL3HyFaw=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 187->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOw0AQG3FAfAPxA3hAxBfKC4IEp0pI5YC45elQlZTdWdvjlAOR0rSN
x2N7Zm+f33avVxHxfvP9sZs/Hg+H+fPp+vjjZd4/3O+PL+9+7ohlit/ndHqi
G71TeJdjwMQJh65l6r932tN/uQ7hGXeuQRoZF/o/1yGdrIfCV9qRpnUOyuPQ
h2gfcgQzZtl075o6hs91qMdZK9k3Vpd1nL8DDW0vd05qh5zzwHJgGVQzVTlY
WgoPKhM3B0cL8hSpl/Jrc0aNcWa3Ze4DF9p14MvRgrSrnLZ6RDrdzJSWygfE
XLDjDoZxKk1ub1aj+lk7JLCsr8LTuRNPzB/kWDFEe+6hMKxP925Ddqyf2vus
deBvnhmPOCvvKIPcn3F3vxtNyP8wY5XhX84PqG/zgu/S5ZwJhg2hV/nMPtQZ
oeepfQ+yaGuVPoWztGQecz8rXSp3eq5Af5UJ42UaKw/Ik9Rr8mYONkO6e+By
9gDpGvaf9FS+mJ+8S5fMZ4sWyEl2uNLi7KziDIRPuTh35q9yh7sJ9KCcWR8H
a2kms0BcqPeA2XBeYLZkNlmnnCnR5uBRrtnfqglxM64l1Tm5BsBIPKhFOKXl
v+5RyxeIjRfv
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 188->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOA0EMizigfgPxA3jAii+UFywSnCohtQfEbZ8OLXSZZmzHAwdGms5u
N3FsJ3Pz9Lp9uYqIw+bzZzu/Pez38/vj9fHled7d3+2OH2+/d8Qyxc85fZ1o
B3hW8SjXiT+t85nWMqXndkfCSHktF4Sf8yqO+cw4meuSOFb12H/UC4CFOK0e
CI1dHcK98xr0mHmDcisvKx/b/qJ5Y3mZ//oMOLS13D6pGXLuA/OBeVD1VPlg
cSk0KE9cHxwuSFOkWkqvjRl1jNO7kb53WGjWgS6HC+KufBrViHi6nikulQ4Y
84sZd2IYpuLk1mY5qp41Qy22+gb4j/SdaWL6IvFBPDvdoh/sziAtrn/IE5QL
9UXPtcNvzhyPMCvtyINcn2FfvDeckP6ux8rDv9wfkN/6Bb+lVfW18pHxVXcj
61gSXxUH/VB3peCn4iwuGcecz4qX8p3qBPWDxQpcxrHSgDRJviYumyPVT6VF
YbD6iM9pkZpKF70XQoPbnxEuEJPMcMXFmdkRzMxpKH7AdzibU18T+czqOLEO
55ULwHTn9iJm4L5Ab1k/E08Wz7S78cjXrO/MB2EzLDRnla8BYmQ8yEVxist/
7Z7LB1SHF7A=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 189->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOw0AQG3FAfAPxA3hAxBfKC4JET5WQygFx69OhKrTJjO3xwoFIS7rE
67E9s7fPr5vtVUS83Xz92czvj/v9/PF0fdy8zLuH+93x4933ijhMcXlPpzda
P5glTuEhh4OJEw49hyn9TvgVRzpXtAvufIZlwc4hrTnDrh77H80CcJ2f6bKW
uckeLLmJ9pIj6DHUjHog8GX+gJaVVjJv7FzJKWLlGXkd6VN3n0ZnTfXM6anK
wdLSeFCZuDk4WpCnSLWUX5szeozTu5G+Fy4068CXowVpVzmNekQ63cyUls4H
xPxixh0M41Sa3NrsjKpnzdCSW30D+kf6zjwxf5H0IJ3Ft+gHuzPIi5sfygSd
hf6iai38i3fGI87OO8og12fcZS/8lx6rDP9yf8D5ZV7wW3q6vsocCRfDqnuU
c2I4mIe6K40+hbO0ZB5zPjtdzj0sNUD9YFjByzR2HpAnqdfkZXOk+qm8KA5W
v+xNv2xmYV3hwe3PiBbIaXob5Xbmg54xsbBPTe5wNqdaE+XM6jhYRzObM8SF
ahfMwH2B2Y5m0sxK0TIwWyiPc1bGXMI9yozkGgAj8cA3wikt/7Wqlk/uJRY2

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 190->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOA0EMizggvoH4ATxgxBfKCxYJTpWQ2kPFrU+HqkB3EttJemGl6bbd
xLEd7/3rx+b9xsz2d98fm+XwvNstny+3px9vy/bpcXt6+PBzzI7DLvdxvqPz
W7OuU/UQo1Jj5zp0HYf77uonDNcXuAts38O8YH2Iq/cwm8f+o14ArL9rXI7C
p3MI9+Aj2DHkjHYg6kP+AJeJK8kb6ws+mU2akdbOnrL3qZs1tbPKTpUPJS6J
BuVJ1YcKF6TJ3Cylt4xpeU1ld529Z7pZnitcEHflU1cj4ln1THHJdMCaKzJe
qWGYilN1NutR89rZSXLl+Xf2zjQxfeb4IJ5Bt9hH5mt338wT1Av1WeQa8Fd3
X48wy9rFvhg2wmT6w46Vh9e8P2LfzC+WvWyvmY+WzFM7CTOSbCk/VC/Sw3gx
7pSLxynmM+OlfJc6SfYUH4XNtLPnCptxyHBZjtQ+lRaFweYjPij7iKvyZpor
NJT20+QCMUmGMy6VzHYwPadWfcN3mM0RZ07PASa6VG2F83qnHrOa26mm8b5A
b332M51JVgKXRrYMHJ8X1kt/I8+Ir7auqdQD3ahOcfmvE7l8AU2xGyw=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 191->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytlEFOw1AMRC0WiGsgbgAHiLhCOUGQYFUJqSwQux4dSkmbb8+M7apfCk1T
//nP4wn3rx+b9xsz+7z7/bOZv553u/n75fbw5W3ePj1uDz8+/F9m+8nOn9Px
E11LzfBM1EONSo0d69DaT+7e1Q8abp9nUNqoV+QF24dYkYfqPPaMegG0Tms6
X0qfnkPYg49gxpAZzUDUe17EMrCSvLF9wSezoWfUa2dO1fepmjU1s8pMlQ/X
YqnydTTk7BYm8l5UWaCm5TUVvzpzz/pmea6wIHblU7dHxFn1TLFkfcCaCzJe
qWGaiql6NtujzmtnJ8mV5y9lW+j6Nfzm9iHO0LeYh69BvnX9Q56gvbA/i6xB
H/RTzYTqw0Bdpo00w/1q3sNSHl7y/mT+rHhUf+vnav6s1ver5sk8G85IsqX8
UHtRP4yLsTOWoFPMZ8alfJd9Jhmq6DLGrAd0bsbbzSfbk2Wv0k82G6+Nso9Y
lTfDuaKH6nw6LFCTZDhjqWS2o+mZWvUN32E2Jwv/Y5HP7JxKbYX5xLIskDfP
p3pF+fK1Kn/m7gOnq8myElga2TLPAfLC9tLvyDPi63oOltQjb5iuYrnWlc1I
zv2P5QcSXhpn
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 192->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOAzEQizggvoH4ATxgxRfKCxYJTpWQygFx26dDVQrJjO1xUCNtt5tM
HNvj3D6/7V6vWmvvN98/u/Xj8XBYP5+ujx8v6/7hfn9cvPt5WtuW9vdeTm/0
nGuGOVEPMZyadqpDY1vG/7F+mGu5tuegsJFW5AXbp7gmreQ8Nse8QFjDevBf
aUznEO7JR9BjyBn1QNRHvogL0om4MG49f8Whn3f75N4nN2uqZ05PlQ+X4uLy
m8GQvTtzIvfC5QIxW13j+DXT90o3y7PDBXFXPs1qRDxdzxSXSges+UfGnRqG
qTi5Z7M96rzp7BS5ivytbAvcOIa1sA/xTLpFP2IN8i3xq7wTGXRyH7kifORh
8szUjjxI/YrY5Bv+77gMo/Bw+v6I7PV9idgoe9WdqHzs9ap+Ms+GM0Rm2P1R
+XDypuocLgmnyIzqAdNJs4N0kuwpPgqbaWfrDDvmZAaX5ShmUGUvDSMHiJfS
tHU8lC56L4QGtz9sb6UFcVB4s9izmIiTXT/hO9rX5wmuA0w0VK3D+ZfLeYi8
obNTxki/VD9j3ofsR55Gdhm3iF9lq4UzBx+MXMJv5BnxtdeauLB6cheQJ4jL
pR7ks1t/4vIFj1sZog==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 193->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOAzEQizggvoH4ATxgxRfKCxaJniohlQPi1qdDVVqSGdvjgESl7WZ3
Jx7b49w+v262V621t5uvv836/rjfrx9P18eHl3X3cL87frz7vlo7LO3nvpzu
6DrXDO9EPcRwatqpDv0Oy7iO9cO7lmt7DgobaUVesH2Ka9JK+rF3zAuENXwP
/iuNqQ/hnnwEM2beoL2Vl5WPUSfiwrj1/BWH/r07J/c8uVlTM3NmqnywuBQa
lCeuDw6Xy7wCt76X0lt5hDxnNc7sZuZezZHl2eGCuCufZjUinq5nikulA9b8
IuNODcNUnNzebI/qN52dIleRvz13oYnpa2Ef4pl0i3nEGuRb4ld5JzLo5D5y
RfiXPioTpnbkQeyfsMkzXHdckE6psfAn6mXZ6+cSsVH2qjNR+dhIvTob/Xro
ITLDzo/Kh5M3VedwSThFZtQMmE6aHaQz4otamUvAsdKANKW8AA4VLstRxFTZ
Sz8jB4hXwgVnj+WMYcT8Iw3ufNjeSgvioPBmsWcxESe7fsJ3eJbCHFFeVR+n
1uHc5/vsA8sb6q36VecFehvWiaeR3b9wYf1SjZFLta/fy3zttTbAB+GzswC/
GfP4rytz+QSLHh2k
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 194->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOAzEQG3FAfAPxA3jAii+UFywSnCohlQPi1qdDC22Tie1xOLDSdrPd
icf2OLfPb5vXq4h4v/n+2awfj7vd+vl0fXh5WbcP99vDx7vfO2K/xOW5/DzR
farp/hP1EMPYe7xOz3Ttl36d67v/Yqxt+3bXMvaUOrJvgCPjOmjNNcpv4QXE
ar8b86R9CHfmY8VZ6if1uQb1OHMlGWP7Mv+sBWmV5wLUsQyVZyZ6LWyf04/x
cvjOcnH5zWAMeO28Gm7du9BbedRiVDXSr/B1OXlAuBV29iNzVz7NakQ8Xc8U
l0oHrPlDxp0ahqk4ub3ZHtVvOjtFrjJ/e+5CE9MXaR/iOehm8wBckG8Dvxnv
gE+MeySPEIeOK/GiwwR4VB/wosobwhzWSR/rD7mQfkwvy17rR6WPcWP9Efcg
9epstOuuR5EtOX+xV/FTdQ6XAafIjJoB00mzg3RmfFErcwk4VhqQpiEvgEOF
y3KUMVX2HD3VbDL28TIy0dWqcyE0uPOxuTCfyBmruDiZncFEnOx6wCf3RO9n
H8mcss+sj1PrcG7zffJhyLvIg+pXnRfobVoznm5WZrkM/Zh3Ri7VvnYv87Wd
QwA+CJ+dBfjNmMd/3SOXL7HaH54=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 195->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0tOQ0EMi1ggroG4ARzgiSuUEzwkWFVCKgvErkeHAg9mEttJumCk6ftl
HNtxrx9fds8XZvZ69fmzW9/uD4f1/eHy9PC07u9u96ePNz/b7LjY33X5vqK9
1UzvRP25+2ttV7eOy3zv66d3FmsnreNaYs+MI8NC75mHqh97x7xAWIiTwqd9
xPlpgUwwbzLOvt7XoB6/XEk+2TnP32tBWjtzqv6fZNaSc5V+jFeFb5dLlV8H
I+CN8xq4Tc9Cb+bRiJHVSL+srquSB4SbYXs/PHflU1cj4ln1THHJdMCaMzJe
qWGYilO1Nzuj+rWzk+TK8+/MnWli+szxQTyDbjEPX4N8C/w63pF+iLs5TxAH
pgdmguBRfcCLLG8IM9w7faw/5EL6Mb0se6MfmT7GjfVH3Blf9d8Y76ceSbbk
/MVZxU/VVbgEnCQzagZMJ80O6TGtpDbDZtrZd4VtS6zt5tOfMXA+08L6dmZT
0ut1kRn7/DO84GVjroEL01PU5rlUMtvBRJzK9UAr8x2d27yl3wEmWqq2wnnM
9+ZDyDvpn2nNcp3OWfDM5nMul9CPeVfIfOVZ+TrOwQAfhsfyojKPfPnPHbl8
AC/lIWM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 196->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FOxDAMRS0WaK6BuAEcoOIKwwmKxKxGQppZIHY9OgxQ4Tj/fzsFEalN
mzj2+7Zz8/SyP1yZ2Xn38drPrw+n0/z2eH35eZ6P93fHy+bt92O2TPYzT18z
elabZk3Yb7Fb49g6h7FM7Xe0b9YM2PrHD3AuY4xzZGSsnVYSj62xXEC9Th+K
LWvgfYvzzQC17vYRn1iLs8qjrzHqO3Yu8kctSOtInVQPVe7DAlhYzEpNVR7+
iqXK17EU89PVy7E1/0JvliPvn9oITs8wWvfOF2BHuiosiF3laVQj4qzmTLFk
OqDNhh6v2DCfiqkam51R8Uo95H2rPcA/UnemiemzwIM4O92iHuzOIC2eoZw7
Eg+xW8gJYmB6YE8Qf1QfyEXWb8hn9x30sfiQhcRjelnv+Xxk+hgbi69so726
G/678ZP0lqy/OKv4lF2FRflBmlUNmE7aOyQG8814sroi7Uon821Tbzvan/GM
gfOZFhaX6gI9VtJLdNG+ERq6PDrtkb3KsoWX8VR6dsRn9Q5k9lne4f0QtWY+
0VC2FWbf358D9DuLn2lle6r/ZE6KtfoNSxeP5a7Q85V/lVdfBwtr0B7oRnZR
g6rHfz09yzuwIB9j
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 197->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U0FOxDAMtDggvoH4ATyg4gvLC4oEp5WQlgPi1qfDAguuPTN2CkRq0yaO
PTOeXN4/7R7PzOz54v21m19uD4f59e78+PMw72+u98fNq6/HbJnsZ54+Z/Sg
PRW/Je6ExU5zGMu0/o7xqzUDsQ7LaoC1CmOcI0aGNXEl9dga0wLydfxQbdkD
n1ucXw3Q67SP8Im1OCsdU48LTdNwXKNXFN5KP+Whzn1YABZWs9NTpcNfYeni
G8kBMRf3QPGtNPJ+oDECp8cw2veUC3kd8OpgQdiVTqMcEc6uZgpLxQPGbPB4
J4blVJi6tdkZVa/lIZ9b7QH8I31nnBg/iYXwNIIlalP1vqsf0gSdjdgtaMJq
IT7QEyQf5Sf6lXKTf/gd+LH6FZZ4DmFg3vN6xNzIe1VfKz8wvOpuIB4er4qj
/RdnFT4V18Ii8iDOqgeMJ/VOrCG8p/BUfUXcFU+W26YcO+rP7zMgp/Jeh4/s
TfBY1JxpqO5Jqis4JB1Dr9EdqrBswcvwdDw7krN7B6r4Snd0jvbaeE40VGwH
s/f3xwB+Z/UrrmxP+U9q0uzVb7CkepV2ZL37r3T1fUD+Z/m6/Yo5u/7/jydj
eQONOCFj
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 198->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOA0EMizggvoH4ATxgxRfKCxYJTpWQygFx69Ohgi0zie0kPTDSdruz
nsR2vLfPb7vXKzN7v/n+2a0fj4fD+vl0fXp4WfcP9/vTy7vfy+y42N99+bmj
a8NMewJ/CW7rY9vdreMy//f4ac8AduAyLbCXcfR3z5FxDVpJP7bHvIB6B32o
t5zBWFucn1ZBI+Qn9tg51CPMOPE0rEGrz4rim/lX/Z5k1pJzlX6MV4Vvl0uV
X6eGnB2ZkdLbqZlhpF9W10VroawDXRUuiLvyqasR8ax6prhkOhimm/EKhtVU
nKq92RnVr5QhgWV9Fb6SQbYUnwlDuBvh4r3JZn9eDe8Uf8/dnCeIw6RzuGAm
SD2qT8wr1CbP8L/Tx/pnXPw5xIFlb/TD10bZq3wTFazHq28D6VA9fb3gB8i+
78f4KVyFi6qDNKsZMJ00O76HyJ7ik80VaVc6WW1bIrabz/MZUFNlr6JHzsZl
zHuuMqG8mfoKDcFHN2tfo8LlEr6MTyWznZrhTBNf9R2do7Me34s+Exb0V71V
r82HCUv6Z1rZO5W/ridZDrtcQr/MO7JffVa+jnNA+Wf1Mtz5XWEe/3VFLl9v
syAo
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 199->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U1tOw0AMtPhAXANxAzjAiiuUEwQJviohtR8Vfz06VJCya8+MvZFYKU2z
mfU87Ny/fuzeb8zsePf9s1tOz4fD8vlye3l4W/ZPj/vLy4ffy+zc7O/efu7o
WjHDnsBvwa08tt7dOrfxv8cPewawnZZhgb1Mo797jUxr8Er42B7LAvrt/CFu
2YO+tjiPVqZZ+Wd4j0EcvsdZpmF1Xv2sKL1ZftXvqapZ9azSU5VDae4LWqr6
ZmrI3pEeKb8zNTOMzMvqvmgtNOvAV0UL0q5ymvWIdFYzU1oyHwwzO+MVDKup
NFW52RnFV5ohgWW8Cl+ZQbaUngFDtBvR4rPJen9dE9kp/cgf0hTqd3frn31m
Ddej/kS/Qm3yDP/3WoFP6THJx3Ox2UP9Y7WYNsavsB6vvg3kQ3H6epBz47wp
XEWLqoM8qx4wn9XvT82e0pP1FXlXPlltaxE7O5/XM6Cmmr2Kn6w3huq2uC+/
SSN+Eg8hR6+1269q2aKX6QnnkpnKala/gQyf5Y7OoRzDe8EzYAG/4lZcfU2f
PeJWfGrW0J7vcyWTbA5ntQS+LDuArWQ+nCW5mqvP5gD6KPTL16zO/39cUcsX
RbcgLA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 200->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0tKRDEQbFyI1xBvoAd4eIXxBE/Q1YAwLsTdO7oO+jTpVFVXXBjIZJLX
6fp05/rx5fB8ERGvV58/h/Xt/nRa3x8uz5un9Xh3ezx/vPmeEdsSv+vytaK5
x3RnIv4vcTtO7Gsa29L/z/HdWYDYhks3wFnFMa+ZI+M6aCV47KzDERy6M4It
a0BwkActRqUR8hNn7B7CyDWuPB1GozX3iuJb+edwcePYPQeP8XL4dj4YXFx+
Mzlk7UiNlN6ZnFWM9Ct8XTQX6nWgy+GCuCufZjUinq5nikulg8XM9rgTw3Iq
Ti42u6PwrB7aR6Eb8Z+pO9ME9TW9DbkQnUG4tPd+JvANeYJ8Yf5Ub2bQTvzJ
elresCdSDsUl+5fxh9xkD/+b/lZc8j3EgfUe6mmWi3Fj+PL9BOYi+1FgKL0Q
0+g35hWLc7ioPEizqgHT6b4/1XuKT1VXpF3pZLkZhyov9Lmpe75faWG4VW0C
5V3Gc/omSY0ZF1ob5v8MF+GtU8vMZ7hX9FSV030DVTzDRHvl4/Bd4HSxAF9h
K6w2Z/YeYSs81WvoLNfZ8aTqw1kuTBv1LvmkcqG98rXNB/uf5EM1VZ6oevzX
zPq25QMT/iBp
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 201->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tKA0EQbPwQryHeQA8weIV4ggjmKyDED/Fvj65RB+dRVV0THEh2d7an
Ht21t8+vu8NVRLzdfP3t9u+Pp9P+4+n6/PCyPz7cH88v735/EVuJv2v5uaJf
ren2RP0ldZUn6nVYW+nvx/puL0Bt67Vd4FymcbyOGpnWySvhY3sdj9DQ7RFu
OQPCg3rQcmQeoT6xx84hjtUMT6vxGg3W5FVocXOk3mWa1cycmao+WLk3tLj6
VjDk7MiMlN8VzKxG9it8XxQLZR34crQg7apPqx6RTrdnSkvmg9WsZtypYZhK
k8vNzig+K0N1Jb6R/pW5M0/QX6aF+AyiZbyPZPZdnZkLxJflnvVn9FN1MIwo
GI/6E/OasMkzvB+0Mv5MC+rPyMWyhzLNsJg2xi+/n8Basjw6nCMe5Lwwb6rO
0aJwkGc1A+bT/f5U9pSebK7Iu/LJsJmGDJflfGv8Ztlz/GSzCYRb5n2Ys4Jr
lRY6G9Z/VwvwouagtLBzWaYyTPcbyOoZJ3pWfZzeC56uFvArbsX1vcyMZ15V
1tBe1TLlWfjMsrKqhXmrfZl6F4NegYWeVV8778Yc0FmKCzDd/P/3D2v5BGEg
ICo=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 202->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylU0tOQzEQG7FAXANxAzhAxBXKCYpEV5WQygKx69GhKq9M8myPUyK1+byJ
x55x7l/fN7ubiPi4+/nbbD+fD4ft18vtafO23T897k8fH35/EccWf3M7z+i3
xHRnIv6auCVPLPMwjq1fj/HdWYDYrDUPcK/iOM4jR8Z1pZXkY2ddHsGhOyO5
ZQ9IHlSDnGPsNatNyTnWeao6jl5DXBi3i4bWr1Wf3T4pDznvwbnn5GO8HL5d
HQwuLr8ZDNk70iOldwazipH1Cl8XxUJeB7ocLoi7qtOsRsTTrZniUulgMbMe
d2IYpuLk5mZ3VD7LQ8sodCP+M31nmqC+igvRGYSLWiMtuSaIC6tP9WZUvyB+
mkN4LBrGo/pEv1bYZA/XA1eWv+KC6jPmYt5DnmZYjBvLL99PYC6VH52cIx7M
eaXfVJzDReEgzaoHTKf7/gLgq5pIX44jebvSybAZB8ST4VzupL6P90stJO9M
b3LNo3G92Z8oVnGhvWH1d7kEjsvnqAbKK45npzDNN6A8pnKivapj9x1goqFi
Hc6w16bHK62Vr1VP3JpUXpnlwrQtdUGcMneFhfaqrhkvEJ/ov2dPrXo64gJM
1//WG/lH/JnLNx9oHmk=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 203->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOw0AQG3FAfAPxA3hAxBfKC4IEp0pI5YC49elQIGF3Ynu8RWKlNEnX
67FnnOvHl93zRUS8Xn3+7Oa3+8Nhfn+4PL08zfu72/1p8+bnijhO8Xufvu/o
WjDdfwJ/7vW1lntax6l/zvjuvwDY1mu7wLlKY75njUzrxiupx/5jnGxv8Ydq
yxm0fsR5VUP1ptQc2zpVH3Mmcz7Zuc7D1D87PXbm5MzXwbFzTj2my9Hb9cHQ
4uob4ZCzIzNSfkc4K4zsV/i+KBfKOvDlaEHaVZ9GPSKdbs+UlsoHw4xm3MEw
TqXJrc3OqHpWhgSW1VV4J4NsrXuVFqI9iBb1jLysK3FW/am+GTUvyN/cQ2Qs
JsxH/Yl5bbjJO3xOWln9SgvqT67Fspfnp/wxbay+wma8+jaQj1avwtGaZ+ZN
4Rwtigd5VjNgPt3vLwC/6onMJfKR8sp8Mm6mAelkPK2WVVNs95UXVndkNiiz
TGvbu4xXWv4yH6lF9FZlyPIpzoxwut9AhWc10bvqY7cPONFSWEdzm+91mRmv
vFa5hr0d7EmVlVEtzBvtXfTaFRd6V31t+QLoYXwlDuQP9eU/r62WD3AdJKo=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 204->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FOw0AMRC0+ENdA3AAOEHGFcoIgwVclpPaj4q9Hhwo2eL0zYy9IrJSm
yXrtN/bk9vlt93plZsebz5/deno8HNb3p+vLw8u6f7jfXzbvvi+z82I/9+Xr
jq4W070T8b+Ja3Ws3cM6L/3/GN+9MxDrL7/AuYwx3iMjYx20knrsHcvJ9lgN
pXHQQ9i72CIz48vikeZ4ZtbDw/LecLkGrYKl6iO1lzGrmVVmqvpQ8n2Bpco3
k0POjsxI6Z3JmcXIflldF82FvA50VVgQu+rTrEbEWe2ZYsl0sJhZj1diWE7F
VK3Nzqh6JQ+JWFZXxVc8yNa2l7EQdiMs/lx8j7RsK+TM+pN9M14fYqV1EnYL
ORRL7B/q28ALnum35HhYfckCziEG5r3IQvcEG6uvYmO8+jaQDs+r4mhN5TfB
p+IqLCoP0qxmwHRS78QayUwYTzbX7VzwK9PJcrfvIvWByONZYk7lvWEVfBB1
G8qb9LDTTmbMPPmX+UgW0VvloZJOcWYmZ/UbyOJZTfTsZ1HZZ3UqsRVm7++Y
s+IHVU95Db1rLDM9ybwyy8K00d5Zz65yoWfVV5/PAA/Ll8a5K5vHf10jywcW
iyQo
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 205->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOw0AQG3FA/QbiB/CAiC+UFwQJTpWQ2gPi1qdDgZTNrO3xAiJSmmbX
8die2auH5+3TRUQcNu8/2/nlbr+fX+8vTy+P8+72ZnfavP66I45TfD+nzye6
F8xqTeB/glvqxPJM13Fa/8/41VoAbOtVcCOvKAv2ndLaeSX12BrjZHsfF+iB
8tj5IdpV1oqr8rPCR68XaUH8Vabd1XhtM0NeR/vk9NfVrHrm9FTlYM29ocXV
N8Ihe0d6pPyOcFYYmVf4vigXmnXgy9GCtKucRj0inW5mSkvlg2FGZ9zBME6l
ya3NvlH1rBkSWFZX4Z0ZZNd5r9JCtAfR0n6X15GX85U4q3yqM9P6Q1ppnUJ7
JA6lJeeX63fc5J2epUYPq/9X54fNWKtF+WPaWH2FzfjKH9RVzJasqeZN6FM4
R4viQZ5VD5hP9/wF4FeZVPPY+Uhnh/lk3Mu5KOdA8FRrbJ/ptfqXvI/0J3vP
eKXlN/2pMnJyrPyNcI9yuhlXeFYTvbe9cPZZHQfraM5z03I686DqVecFZpuf
hc9qVka1dDk1+bA+rbCKC7yrXFu+SGsQD3wr3pj4t/9991reAI/WJOs=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 206->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOAzEQG3FAfAPxA3jAii+UFywSnCohlQPi1qdDW7pNZm2PUxEpTTdx
ZmzP5P71Y/N+ExGfd78/m/nrebebv19uDx9v8/bpcXs4fPibEfspLut0WtFE
Zwp/7d3jOK9p7Kf+f8Z3ewGwrdZ2NGf5DuOY18yRcV1pBRwRluIJh24P+K00
rvQQ7sprxbnS0+WONV/EpeVa1Y31Set96xnSqnxUmh3/K86qZk5NlQ9W3xtc
XH4jMWTtSI2U3pGYFUb6Fb4uGgv1OtDlcEHclU+jGhFP1zPFpdLBMKM97mBY
TMXJzc3uqHxWDwksy6vwTg+ysZxVXAj3IFzUf6RlGSlm5U/1Zlp9iCvNc56E
e6QYikv2L+dfxSbf1E/Rl//9fliPKXwezptwsBlf6YO8it5SOWW/CX4K53BR
cZBmVQOm031/qvcUn6quy73qHOTN7w5xQDxZnGqPnTO+Vv2aOVqfrD3jjwN4
q2pT8Sy5GN7m2BUXx5ORmK7HFZ7lhHUInhOdszwO1uGc+6aN6fSDyle9F+ht
XgudVa+McoHaBKbbL2Khb+VrGy/SXsZHg6nqtcQw6nHtzFxG8CcuP6+kJWk=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 207->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOAzEQG3FA/QbiB/CAFV8oL1gkOFVCag+IW58OpRSSWXvsLKyUpkmc
GdszuXl63b5cRcRh8/mznd8e9vv5/fH6tHied/d3u9Ph7feIOE7xO0/nGQ10
VuHX3v36LnP6jlP/P+O7vQDYVmv7NWf5DuOY58yRcV1oBRwRluIJh24P+F1p
XOgh3CuvaSzEr9hj91AO2cNtDFDz1vvcK8p/VaeKi3oPTt2cfIyXw7fzweDi
8huJUelhNar0jsRUmNKv8HWpwXip2MgfpGttH1cej3hWcVE6GGa0xx0Mi1lx
cnOzO1W+0d5RfZX5j9SdaYL6FBfCPQiX6j/SgnI5/qg30+rreAMOTi1ajige
1VfUaxGbrKmuoi//+/2wHrvwUPoYN5a/wma80gd5id6qcrq9gvIOvYciJ/MX
5Ve8lO+s/1QPOXGpDnUO8uZ3hzggniyO2mPnjK9Vv6R9pD5Ze8a7Gt36IJ7M
YwfjcnE8GYnpeqzwLCda//iYPGXnLI+DdTjnvolm7fRDlW9N/0Uz535muVXs
ES5QW4Hp9kUstK58beNF2mN4p16ovsiXv4zMZQR/5vIBREQmqA==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 208->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOwzAQtPhAvQbiBnCAiCuUEwQJviohtR+Ivx4dSkmxtzM7sy2R0tTx
el67uXt5X7/dtNZ2q++f9fzxtN3On8+3h8XrvHl82Bw273/v1vZT+3tOxye6
0V5Wf+nZn2t5hms/jf9j/fCugdrea391e/EM0xifUSPTeuaV8LF3DJPt9R4V
PuOJ+TJeRzPTp+qR53hGznA8RzJa/iMNSK/TJ0eLVUcwHT6my9E75GBocfVV
MDI/rEeZ3wqmqknzar4vdTNdChvlg3xdOsdZxpXMMi3KB6upzrhTwzAzTS43
O5PxVWdHzVXUX+k78wT9KS1EeyNasv/IC+Jy8lHfTO9v0A00OL3oNSK8zB/r
1xk2WVNfyVz+9/eTzpjhj2lj/FltrFf+oC4xWxmnOyuIt/Q9JJwsX8SvdKnc
2fypGXJwqQ+1D3hVX6rzSbHF7DE/8Rzjb8IPqovnG8DptSiPTn+QTpgxyC/m
wXogsVmPKpgGnpqxjBOtTzmGTNk+43FqHc2nvixXt3bmIePLZg29G7IIuiq9
vUYL9JbUDO8FFlpnufZ4cUZYvdMv1F+UyzV31FKpP2r5AmDdJiY=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 209->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FOAzEMRC0+UK+BuAEcYMUVygkWCb4qIbUfiL8eHUpp2HhnxhPA0nab
jWO/sZ2bp9fty1VEHDafP9v57WG/n98fr0+L53l3f7c7bd5+PxHHKX7e0/mN
HrSn/H979ssu72THqf+f/btvsfbttC4NnJN6ct0AI2NdaSX52DcWk+1ljSo+
y5PrS+toMDO+yh9pzmfKGc7nFIPR55E+OSyWH4np5GNcDm9XB4PF5WN1cFiQ
JrZ2WToDs8/yynoF1+s+AdiRLocFsas6jWpEnG7NFEulg/mMzrjjw2IqJjc3
O6PyWTMkfFle5e/MILO2V7EQ9iAs6j/S0izFrOpT3Zmlvo4bMDi9WNYDxVP6
WL9Wscma6hJz+d/3R86YoY+xsfzKN/tX+hiXmi2V050VlNe9D2pWURykWfWA
6bTvRNETxlP1tZ2r9kHeqi+j8+lwV1o6BqN/VVyHpRmbmwGNqj85PmXJ++k8
qsGIzoq5iunWuPJnOdG61THVlO2zPI6vw9z6crHF2pkHla+aa1jbPCuFzmpW
RlmgNuHTfS9iobWq6zJenhHm7/QL9RfV5S9PZhnxP7N8ACaZJio=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 210->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0lOAzEQbHFAfAPxA3jAiC+EFwwSnCIhJYeIW54OCcTx0rWYC5Y8Mx5X
d1e1y/evH5v3m4jY330/NuvhebdbP19uT4u3dfv0uD1tPvzOiOMS1/fy887m
BdP8I3iFQ7HncXl347i03z2++RcjttFKcmdaUY4sjnEdtIJ66B/KifbKMPKj
On1/VR9pLsBP4TPNfcysh3ufIU9lWmfPyeFi4UBOpx7i5fBt+mBwcfmhPjhc
Mk1o7XJpRuJ9VJf2K7Bed0bCPdPlcMm4sz7Nasx4uj1jXJQOhJn1uINBORkn
tzaKYfUsDxEsqsvwjgfRKHuKC+AegAv7zrSU0eVU/VF3ptbX8E44NPGCO8qX
cqlnjPWH3PVI4gZdxJdI25/vD/OYoQ9xQ/UZtsezu8F4MW+xmtRvhB/DOVxY
nkwzOwOk071/SjPio861xKn9pK7L1/Wnw1tpQXVnzsY9H+XZUndCIzufcLn0
+4aHZnQqziqn22OFV31X3mT7qI6DdTj35xLV2vEDq6d8nfa284/SqbwyyyXV
RjAs1lmzvtZ1Y8mxTBvCqR79x4z6+8zlCydRI3E=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 211->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylU0FOw0AQG3FAfAPxA3hAxBfKC4IEp0pI5YC49elQoGEza3u86Uppksbj
sWe9t89vu9eriHi/+f7ZzR+Ph8P8+XR9enmZ9w/3+9PHu78r4jjF/336vbvX
KN6p/Vnne1rHaf2c8av/oseuvAruXIM0Mi70f65DOlmPCq+0r5bBz/rk+VZz
lFxEX4VHnnNNlUlWBzUY+zyyT6WWAc1qz5w9VXOwcm9ocfWNcCg/bI+U35IT
ZJ/1lfMK3xflQlkHvhwtSLua06hHpNOdmdJS+WCY0Yw7GMapNLm9WY3qZ2VI
YFlfhXcyyNbyrdJCtAfRop6Rl2Ulzmo+1Zlp/a10Aw2r+kJ7Nwelpb2i78+4
23kg/vb7yNm66PyojBn+mDbWX2EzvvIHdRXZUj1l3oQ+hXO0KB7kWe0B8+me
P6ihwFbcLQ/LN+rb8RVnx83nUlOcI+nl7CcAL+mveNUMq8wiP4pTzSkST6Wl
25+Wi+jdwl3NwPG5FV/NHdUxvJoNWgrraM77EqRe5Zb1q3INZ9v22piXS7RA
bynzWZMzY/au5hotJmnpZiN0Ql6AdfNvnZFBbK/lC9Z9IWs=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 212->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk11KA0EQhBsfxGuIN9ADLF4hnmAFfQoIyUPwLUfXEF1neqqqa8CFTfan
p/qrntr714/d+01EHO++f3br6flwWD9fbi83b+v+6XF/efnwc0acl/j7X67/
7jlbb2nGVRcd56W/zvXdsxhrO69CO69BjEwLPc/rECfrUdUr9u4w9FmfPN9q
jlKL8FX1yHNeU2WSrYMMxj7P7FPJMsGs9szZUzUHK/cGi8s3o6H8sD1SfktN
kH3WV84rfF9UC2Ud+HJYELua06xHxOnOTLFUPljNbMadGqapmNzebI3qZ2VI
1LK+qt7JIDu2dxULYQ/Coq6Rl+1ImtV8qm+m9ddxA4ZufcE+zEGxtGeM/Zl2
y430t/cil//+/aiMGf4YG+uvanN95Q9yFdlSPWXeBJ+qc1iUDvKs9oD5bPe0
8okyq2pVHtHRfUPEJ9POmWyv3Xy2DGgubA30EUBX+S2+E8Zaahge0BwZZ8kS
gCOxZO0qK85MZjTdGVf1rCe63+ZI6vN71sepdZiHvZ7IeOVVZQ09+2XpMlv5
LLIyywK9pT6Zqa1RWuhezTXr5T4dh+CEuqDWzb/1jUzWjixfGGUf5w==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 213->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytV0FOAzEQG3FAfAPxA3jAii+UFywSnCohlQPitk+HqrQkE9vjIFZK2911
PPaMc+jt89vu9Soi3m++P3brx+PhsH4+XR9vXtb9w/3++PLuZ0VsS/x+L6dv
d83iLc448aJrW/rfGd89ixHbeW2vZaxZaWRcbV+Q1sFrxhAsxRMNZ652IQ90
BskP0l71GnJF7Qfhkee8p8ok2wc1GHOemVOpZUKzmpkzU9UHK/eGFlffDIfy
w2ak/JacIPusruxX+L6qlb25PUP9Qb7+mmPV45meKS2VD4aZzbiDYZxKk1ub
7VH1ZrNT5Srrn5k78wT9VVqI9iBa1G/kBdVy+lOdmdZfpxto6PYX2oc+KC3t
irE+484X7afI5X+fH5kxwx/TxuorbMZX/pgulS1VU+ZN6FM4R4viQZ7VDJjP
dqaVz4G/wKo8ogudSVQXck7kgPFc9iTeKnuIN9el8zs/L86JOpNI99bwVh4q
TxedphaEa7Vk7kqL05MZTrfHFZ7VRPeXPhJ8fs/qOFhHc5e9CPt/sONVZQ09
a7N71lL6LLIyqwV6S3WyphajuNC96mvmy3U6HUKn68nNv3VGJrGjli81aCLn

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 214->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOw0AQG/GBuAbiBnCAiCuUEwQJviohlQ/EX48OVXlkZ2yPF7FSmjTx
euwZ7/Xjy+75IiJerz5/duvb/eGwvj9cnv48rfu72/3p483XFXFc4ve+nO/u
NYu3OOPMi9ZxGZ8zfngXFTt43a6l1uw0Mq5tX5DW4jVjCJbiiYbSS+KBziD5
Qdq7XkOurA9pBnjkOe/pMsn2zWhAWGdOnZYZzWpmzkxVH6zcG1pcfTMcyg+b
kfLbcgItrK7sV/i+nDwg3o4b9Qf5+muOVY9neqa0dD4YZjbjDoZxKk1ubbZH
1ZvNTperrH9m7swT9NdpIdqDaFHPyAuq5fSnOzNbf4NuoGHY32gvfVBatlfU
+ow7L9pPkcv/Pj8yY4Y/po3VV9iM7/xBXU22VE2ZN6Gv4MycO/NDntUMis90
/rI2VoNxMz3dXL/7MvA1ZwVyujkQPPBd9x2sNgdbHMin00fGXzgMD50nlBel
heaczLbT4vRkhrPsmcR3NeEcAnNkHdHUQVwZ62guvKjfIg+qnsoaeldqCZ1u
Vma1QG8p81nTDyY0F/qv+hrIS6o11BdnwfHknhfrjExiq5YPR0QkZw==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 215->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01Ow0AMhS0WiGsgbgAHiLhCOUGQYFUJqSwQux4dCrRN7Pfj6YJI07Qd
j/29Z8/t89vm9Soi3m++Pzbzx+NuN38+XR9+vMzbh/vtYfPub0Xspzi/p983
WmhPxV+6fp7jOz2rfRC/ypHOLfdKzFRrOkbGus9sUc8hzuwpYoDxQA/0kmig
PUh6ELvzGubKfIgZxCPN+UxnthhblwHFdvrkWEaYVc86PVU+tOa+wdLlG8mh
9LAeKb02J2BhdaVf0dfVmQeU1+VG/iBdl86x8njEM8XidLCY0RnvxLCciqlb
m51R9UZnx81V5h/pO9Pk9EEWwh6ERX3v1ur44+7M6XvyBDGszhv24oNiWa6o
9VnuEBw5buRuXXR/xPnsmdLH2Fh9FZvjnT7IZWZL1ZTzJvhKXHPOO/1DmlUP
is7U68zGarDcjMf19ejLKp+6KyS34u3OJ/zP7YPHzsEyDsxnx0eWv+RoaHCa
0B1SLNQnkL/D0vFkJGc5MxjvasI+BM5R9k0dlCvHdphLXuS3mAdVz90X6G2e
WaPTzcooC9Qm+n96G4/Zb+VrIC0mnt0F5ElM2IP/XpjlCyeVJSo=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 216->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tOw0AMtPhAXANxAzhAxBXKCYIEX5WQygfiL0eHFtpuvPPwVohIadrG
Hs+MZ2+f3zavVxHxfvP9sZk/Hne7+fPpev/jZd4+3G/3L+9+74hlivNz+nmi
G71T9Zfeh+v4TNfS/g/qVxipr33X1YA+x5Fhtb5kLMSlqyG1tJ5w6LwkGugO
kh7E3XkNsTI/xBnUI825p5Itxq3KAdVW9uS4jHBWO6vsVPlQyn2BS5XfCIbS
w3ak9FpMwIXNlX5FXVclDwjXYSN/kK5Lc6w8HvFMcXE6WM1oxis1DFNxqs5m
PWreaHZcrjL/kb0zTU4f5EK4B+GivtNZANP5485Mi73iDTis+qd1j/NMcmkx
o5/PsE+83VkSufyz8yP6lwF9jBubr2pzvdOHeLlsqZkyb4JfV4eyJ7io/SHN
agedzpzXtHs2g2EzPm6vR1+cBjRXZbL9Xs1nhbfVQvRQXdO5R50TxQVpXRrc
vFelUfpf5EJ9AvgVLhVPRjC7nsF6NxPuITBG997MQVi5tsK5w0V+izyoee68
QG9zZo1Ol5VRLlCb2P/paTxmv5WvgbSYenYWlCdqH/9xH66Oyxcv0yZp
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 217->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01Ow0AMhS0WiGsgbgAHiLhCOUGQYFUJqSwQux4dCiSdcd6PpwsiTdMk
nufv2Z7b57fd61VEvN98/+zmj8fDYf58uj49vMz7h/v96ePd34o4TnG+T793
tNA3FX9J3MLCru57G994QBotx7qUdnjGfO90EkfehzhZDhev2LuroM/y5Pqy
vBVmxufikee8pzJbatYqDCi20qdKf6vMqmfVczXK29WhwFLlG9FQfliPlF+r
CVhYXlmvqPuqzAPSddqoPsjXpXOsajxSM8XifLCY0RmvxDBNxVTNzfaofKOz
4+Yq84/0nXly/iALYQ/Cov7TXEDT1cedmVa74wYM3f6p3+NqJllazdjmZ9or
d/Es5efKHJbPj9h/HPDH2Fh+FZvjnb/uXbPUbKmcct4E3yYucxgW1T/kWfVg
4xOwOJ9uhlw/GWMkPuWTaauzU53PCrf1QvJSX8t7c04Uy7I/x6/vBzxW58yy
IE2gX2Gp1IRpZg64xzCw/DQn6oOoY/fd5EFaObbCvNFF9RbzoPK58wJrC2ZZ
+jSzMsoCvYn+r3dTY/as6hrIi4oHe1Gcq9F/r59rw/IFUsAiLA==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 218->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01Ow0AMhUcsENdA3AAOEHGFcoIgwaoSUruo2PXoUBVKxnl/0wWV0jSN
/fw923P/+rF5v2mt7e++vzbz4Xm3mz9fbk8Pb/P26XF7evnwc7V2nNrffTrf
0YXeqfhrL/Xp3i/jFx6QxpK3kRo1zzHWe6dTOGoe4mQ1XLxi7z6BPqtT+8vq
JsyMz8UjzzUn2S21awkDik3mlMw3ZVYzS8/VKG/Xh4Al5RvRUH7YjJRfqwlY
WF3Zr5b7SvYB6Tpt1B/k69o9Vj0e6ZlicT5YzOiOJzFMUzGltVmOqje6O26v
Kv/I3Jkn5w+yEPZGWNRvWgtouv64M7PU7rgBQ5c/9TmuZ5JlqdnW9Zn2hTs8
S/U52cP4/Ij844A/xsbqq9ga7/x1/wFPKE7VlPsm+FBcd44Mi9QBntUMVj7N
2VjVKLyoppsnY6wsyifTVmcn3c+E23ohdd1s1I46lt/8Gn/5f8BjumeWBWmG
Z0xqC4ZUc5UzGO9qwjmIPqL3rE4SmzCvdFG/xT6oeu68wN6CXZY+za6MskBv
Yv4qN3lWfW3EC40HuSjO9ei/r1Z6fGb5Amz4I+8=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 219->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRJt8iNcI3kAPELxCPMEK5isgxA/JX46uIRJneqqqayK4MNns
bk/1q+6e9ev7dreKiI/775/t8vl8OCzHl7vzw9uyf3rcnz8+/KyI0yZ+75vL
HS30TcXfutTVfW/jGw9IIzNfF9OOmjHfO53EkfchTpajilfs3WXoszy5viyv
w8z4qnjkOe9xZkvNmsOAYp0+Of11mVXP3HM1y9vVwWBx+WY0lB/WI+W31AQs
LK+sV/i+nHlAupU2qg/ydescqxrP1EyxVD5YzOyMOzFMUzG5udkelW92dqq5
yvwzfWeeKn+QhbBHji88yFxAs6qPPDOAi9VnyFOwD3UQLLl+OT/TbrmRvtrn
zqF9fsT+XDPlj7Gx/Co2x1f+unfAE4pTOdVexYfiunNUsEgd4Fn1YPBZnI0h
R+JFOat+MkbHA4pTM9n+d+fT4Xa8WHMQDbeY0fyezRnq5/X9jMeq/i4L8mOe
Mand1I31odJ0a6zOhMoJ+xBYg31neZxYh3nQRfUm+Suv1Xlhc5dnWfosZmWW
BXoT/Vd7nWdVV8gCLujjD/367xWpxheWL+aRIe8=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 220->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tKA0EQHPwQryHeQA+weIV4ghXMV0CIH+KfR9cQE3d66zURXJjsTqam
u6q6+/b5dbO9aq293Xz/bOb3x/1+/ni6Pmxe5t3D/e5wePezWvuc2u97Or7R
QmcKf+lSz/K8w0/gv7bGnjg3gmF3EMf67uJMnCvTynI4vOLePUF8lqf6y/Im
nBk/h0ea652kt1SvJRwQNqlTUt+Us6pZOlejfDsfAi4pv5EYSg+rkdI7EtNh
pF8t15X0A4rrYiN/kK5L+1h5POKZ4uJ0MMxojycYFlNxSnOzOyrfaO+4vqr8
R+rONDl9kAvh3ggX9Z3mSvxxM3P+Lp4gDt19w33lg+BS/av5WewlbxRf3Uv7
MJ4fcb96pvQxbiy/wla809f9BzQhnMop+03wQ7hujgwXGQdoVjVY6TSzscph
asL4yLoCD5xOFrv25PI77U/U+2oOUEyW1+oyc6K4nO5X/DmH0eA0Of8hFxQz
nDEZG2gajYn6cATvcqJ99dGdszwJNuG8iov8DuZG7euZ6r8uV+CJ65VRLlCb
qL+6m+yVr5ALeKCOP9Trv1crHh+5fAFyTyRz
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 221->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOAzEQG3FAfAPxA3hAxBfKCxYJTpWQ2kPFrU+HClo2E9vj9MBK291m
nbHH49y/fmzebyJif/f9s1kOz7vd8vlye/rztmyfHrenjw+/d8Sxxd+z/Tzd
exbv7FXX+nuHb2AtRuyZNzIGrEnt2bessXGtrFfGUeGZhsEHoz7jyf4yXkcz
01fhUc95T5k5sm9GA8I6c3Lm62pWM3Nmqnywcm9ocfXN1FD9sBmpfmdqVhjp
V/h9OXlAdavayB/U17U5Vh7PeKa0VH0wzGzGHQyrqTS53GyP4pvNTpWrrH9m
7qynqj+ohWgPokW9u1yOP9WZubwnT5CGbn+hffBBaKnmxWqvdaP6ap+bQ/v8
iP3ZM9Uf08b4FTbjq/66NdATwilOmTehD+G6c1RokXVAz2oGQ59Za/Jp4Chm
wvTIuSIPGlkHvCqT6/eOl2SCZn+1jrjRZeUgRt3qnLBMKG9YXTWbKmdVzcuF
ahZ63T7RrGZquh5XeNd35GP1nfE4WEfzUBf5LfKg+K7JX8dleFJlZVYL7E3M
X+11/itfoRZwnTXGSmuIupVH/30jf4/tC9fgJG0=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 222->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tKxEAQbPwQryHeQA8QvMJ6ggj6tSCsH+LfHl0XX8lMvSYLDsxmM+np
rqquvn582T1fVNXr1efPbn67Pxzm94fL08vTvL+73Z8+3nzvquNUf8/p65nu
0fjkrlrL76v4CZxVH/tTt9oYcCaxt7q1GCeOlXFlNVw8w9DpEORndVp9Wd0E
M8Pn4hHn9o71HLk3ggHFJn1K+ptiVj1Leqp0iHwfYEnxjeRQfFiPFN+RnC5G
6lU5r8QPKK/LjfRBvLb6WGk8opnC4niwmFGPJzEsp8KU1mZ3VL1R7zhftfhH
+s44OX4QC8FeBIv6n9ZK9HEz8/u/0QRhWN032Fk+xk/1q8u9XE5P0BvH7Zz5
kR5rsDDvJTORxLbxjt/qTMyIm5/ElwofilvNkcEi8wDOqgcdzxbroqfMf85D
yVxY3y83yMtyMwwdToGRnSGvM71Z3bR/yVx0+UH/3KzE/QHYJZbiWJJcNje5
M5KzuzMY72qi95Y7w4H8iRarr2qrPiCPF6nvuG7x36rWRr+cgwVyMx5ONGbv
SleIBayVXgvMLK/T6L830vc4fQC6UCNv
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 223->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k11OAzEMhC0eENdA3AAOUHGFcoJFgqdKSO1DxRtHh9KyTbwz40krIqXb
3Tj2N/65f/1Yv99ExO7u52c97Z+32+nz5fbw8jZtnh43h8OH0474WsX5uTo+
0UZnyr7a7K5a83lzf34P7iPHjWwDvkn2nLfMmDjyPcTJYlT2jGGRB8M/i5Pz
y+I6zIyvskea852y58i9EQZk69TJqa/LrGrm1FTlwep7g8XlW7CY+UGL1Y7p
LX2C3mdxZb6C63V3AHaky2FB7CpPoxoRp5szxVLpYDajPe7YMJ+KyY3N7qh4
Vg8JWxZX2Ts9yJbi6WwIe4gYI7VHsZz8yJk5+Zr/R38ua1SwM39Un6gXy1nL
jfy3Gkdm65r5UT3m6GNsLL6yzfaVvu6bmJFqfpy+VHzIrpujgkX6AZpVDRY6
M2vTX6z/qh6q6gkZkQaSG+WbMSw4BSP7FtV5WlYfAFY1J4o1mu3oUbWpOCuf
f/lCLI6v0je5M+JzcWfQvoqJ3jvtg7lBS9k6zLlvUI8HiV9pvaT/ulgX9ss1
LK62lsnJMXtXeWUsyP53iVlwNLnz8t/7yPINK/4jLA==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 224->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk01OQzEMhC0WiGsgbgAHeOIK5QQPCVaVkNpFxa5HhwJ6JM7MeCKIlEav
sT2ff3L7/LZ7vYqI483nz249PR4O6/vT9eXjZd0/3O8vl3c/O+K8xO+5fJ9o
oztlX23mq9Z23/hv38FjZN1AOgv3QYz57BgTR/ZDnEyjsmcMQx2M+Ewn15fp
OsyMr7JHOWefcuaI3wwDsnX65PTXZVY9c3qq6mDNvcHi8g0sZn3QYr1j+ZYx
AQvTlfUKnq+7A7CjvBwWxK7qNJsj4nRrpliqPJjN7Iw7NiymYnK1mY/Ss2ZI
2DJdZe/MIFuKp7Mh7CE0ZnqPtJz6lG9m6U9WH3cGWkYUj+Wn+qW0YsF35zYv
MZf//X7UjDn5MTam7/TGYclcuX/Ve5vhr/iQXfeOChYZB+SsejDkmVmb+WLz
5zBk3aqvkJXUhsWOlE/263QFI/svqvu8nDkArOqdKNZoNmNXOVY5lfWPUZOx
RBGrjE18ZmK6Na7smSb6znWs7pmOY+sw57lBMx5Ev8pVzRr6b9ByalLMyiyL
m1vL59SYfau6MpZhpd5tPSVxqxr9daOeTPl/sXwAiLoe7w==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 225->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk11KBDEQhBsfxGuIN9ADBK+wnmAEfVoQ1gfxzaPrsu7spFNVXQHBQGaY
Sf981d25fX7bvV5FxPvNz2O3fDweDsvn0/Xx42XZP9zvj4d3vzviq8Xl3U5v
tNGZsq8281VrPc/2Gw0oBspLYwMfxJjfXZyUI/shTpajslfs3TLiszy5viyv
w8z4KnukOfuUM0f8ZhiQrdMnp78us+qZ01NVB2vuDRaXbyaG0sN6pPSWMQEL
yyvrFb4uGguwI10OC2JXdZrViDjdmimWSgezmZ1xx4bFVExubuaj8lkzJGxZ
XmW/nUs2g2wpns6GsEe2b5c90/uzL9Ki6lPemda/WX2GPK33qWqmWNT9UbFX
bnWXinvw1/dHzZijj7Gx/Mo221f68n3JPkrvDH/Fh+y6e1SwyDhAs+rBoDOz
thjvOMhRMeS8VV8hq1lrpif7dXkFI/sX1XlezhwAVnVPFGtsNmNXGitN3b+K
5ax/sueWTuEzE9OtcWXPcqLvXMfqnOVxbB3mPDdoxoPkr7SqWUP/hlxOTYpZ
mWVxtW2ZnBqzb1VXxjKs1Lu1pyRuVaP/3ieWb49oI+s=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 226->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0FOw1AMRC0WiGsgbgAHiLhCOUGQ6KoSUlkgdj06VCXt/87MeH6FRKQ0
Sjq2n8f+96/vm+1NRHzc/fxs5s/n/X7+erk9vrzNu6fH3fHPh9874jDF5Tmd
nuhG/yn9tbHqalk7ffqO4paarR7lzjGMMT+7PIkjxyFOVqPSK/buMvKzOtlf
VtdhZnyVHvWcY8o9JHEjDEjrzMmZr8usZubMVPlg7b3B4vKN5FD9sBmpfkdy
VhrpV/h90VyAHfXlsCB25dNoj4jT9UyxVH0wzeiOOxqWUzG5tVmMqmftkNCy
ukrf7iXbQXYpnk5D2CPrp8s9Mvsl1jk/2ROU83xN/ZP5s6oz9TGVZ4pFnR+V
+8ytzlJxDv76/Kgdc/pjbKy+0mZ91R/iqnZL1VSxig/punNUsMg8oGc1g1Wf
mbW5WZ8OQ64r5wrO3yF9Q3XducD9FIzsG2Jkfrc1rpmfcy5WfRG+haXqseop
z0yyNH6VPpksjicjOV2PKz2rCecQvCb0mdRxtA5znmmA+CD1q17VrqFvq1qO
J8WujLK4vbVMjsfsXfnKWJC+nd35neStPPrv+8TyDblFIW8=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 227->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFllFKBEEMRIMf4jXEG+gBGq+wnmAE/VoQ1g/xz6PrstpOZ6oq1bjgwGyz
M9XJS7oCc/34snu+iIjXq6+f3fJ2fzgs7w+Xxz9Py/7udn98efN9R3y0+F3b
ac13kHdM/5dbXoClPw8eY6gjuAbtYYx5HeIkjrwPcbIclV6xsz6w+CxP7i/L
6zAzvkqPas57HG8przkMSOuck3O+LrM6M3euZnmHPhgsLt9MDFUPOyNV70zM
SiP7FX5dNBZgR3U5LIhd9Wm2RsTp9kyxVHUwzazHHQ2LqZjc3GyPymd5SGhZ
XqVf+5J5kF2KZ9AQ9sj6FsO3AcpT5hJ9RDoUs19tXFl/Nnla0O8U5gnHB6hG
Frtzq1kq5uDc86M85tTH2Fh+pc36qj7E5Xpwhr/iQ7phjsx56O9Nf1Zc61h5
DlSdm3krtMqPPcZqzSwwL4mteF1/smdRvc+X4wPAquZEsa77xdhVjVVN+cwk
y0/91ZkX9dHYZM9MTOZ5ty9VTngOgWMgj6k8KFbWOsybMyG+Yn5Q+ZTX0LNN
LsYJ2M7F4ta2ZnJ6zP6rvjIWpA/CguJWPfrv+8TyCW2OIu0=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 228->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U0FOw0AQG3FAfAPxA3hAxBfKC4IEp0pI5YC48XSoWpLNru3xVBBpu2ri
9dgz3tvnt93rVUS83/z87OaPx8Nh/ny6Pv55mfcP9/vjx7vziviaYt2n0+6u
Kt7iVM+07ht84wFx9PwMw84gjYyr7UvPhbSweuwd42Tfsj5kM/j1w86rGpCL
6MvwyHN/xsmWypqjAWGdOTnzdTWrmbn3qqp30wdDi6uvwqH8sBkpvxXODCP7
Fb4vJw+IN+NG/UG+Ls2x6nGlZ0pL5oNhqhl3MIxTaXJrszOqXjU7Wa56/awH
2Xv2KD0bDNEePX5aV2X2jleGQ5zLM233rG+tL6V96IPQou6P4l50m3ep/+/k
sHp/suxl/pg2Vl9he3zmD+lyM1jRn+lTuMp9WL6b+cx0wXPnpXwO9y3Bqjwu
HM2++W70OptLNZ/sXWTfAW9fl9VXWpjXgb/JBtOuPGae+plJLRFDluDME3+U
m5ypcLLMu33JasI5BOZAGVN1EFePdTQPMyG5YnlQ9VTW0LuhFtMJtP2VFtdb
qwnNL+t5e5b1lWlB+Oi1XJBNN///vU5avgFQDSbv
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 229->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOAzEQG/GBuAbiBnCAiCuUEywS/aqEVD4Qfz06lMduMhl7PBWR0u1m
HceecW6fX3f7KzN7u/n62S3vj8fj8vF0fX55WQ4P94fzx7vfaXZqtj3bz1Od
VbzESUavdcC79Whf/23CtI0j2hNpRFx9XTxXqB2ch9YQJ/qW1SHrwZ8ftJ+d
EXIBfRk+8uz3KNliWVM0RFilT0p/Vc2sZ+q9quod6iBoUfVVOJgf1CPmt8KZ
YWi9TPel5CHizbij+kS+Ls0xq3GlZkxL5gNhqhlXMIiTaVLPRnvYedXsZLny
+lENsnU0mJ4BA7Sbx7dtVnqveEW4iHMdbXxmdet9Me1THYgWdn8Y9/ou3iX/
ruSwen+y7GX+kDZ0PsN6fOZvWHM5zTJY0Z/pi3DoPJbVwYvNe/yZmS41v9EZ
6+hqyvRkfV25vAeh1qreidflIcuWZd/dqOTAe6/0Z/0PeHrtzGPmKas/qnHI
KfSScoM9Fc5hXwVrsZ6o7ko2UcbYORGXxyqap54UMp55ZVmL1k7ufEM6bcb/
lxbVW68JZX7SGryzuiItEd68ln6Knir35ZIZ9SrEfWv5BAdWJ+s=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 230->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk1FOw0AMRFd8oF4DcQM4QMQVygmCRL8qIbUfiL8cHSog3Z14PGNYKY26
8dpv7Nm7l7f94aa1dt59/ezn96fTaf54vr38eZ2Pjw/Hy8f7n6e1ZWrX9/T9
dp9qvJUzWT3rEA/70blf3vXpV3BOMeJ7YIR8eC7iZDVUPGPI+sDyszrYX1bX
YWZ8Kj7SjGccb2VecxiiWGdOznxd5mxm7r2q8g59MFhcvkqOTA+bUaa3klPF
pP1qvi7HD1FelTvqT6Trrz7OelzpWcaidLCYqsedGJYzY3JrszNZvap3lK+Q
n/VA7bOV8QwxhL1h/HR9KrN3tLK4KOe6pvGt+qY8wGpmLNn9qdZy4pS2/9wf
5T2lj7Gx+s5sHBbkQp8qD1b4FV8Ux+qFLJjH9Kficv071MD6wMd41FzXXKjB
6LWaS+jPwA/KWziHVEtfAxhwZf3KtG50Qb1Ib6ZRaVL9H1i6HoQ5jVmq3IpZ
5RzOVWJbzBP13fFm9p3VcWId5s1MCh5XWjOvRXsL1G+Ms5i7Eu9q6/kWZDZ6
3ufFpVg2awpYuj1XU+W+pPejuB/P4xM1YiIw
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 231->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylVUFOAzEQG3FAfAPxA3jAii+UFywSPVVCKgfErU+HqlAmE8/Y00ZKt806
HtuZqPev75vtjZl93P18bNbP5/1+/Xq5Pf54W3dPj7vjy4ffaXZY7P+5nJ7q
7OIlzmJ4rQM+rKN9f3rP0w+wj2mMz0Fj4Iv7kM6sBsNnGoZswFlVHpEfpL3K
OuWK+pBmgEee4x6lt6peUzQgrHJOyvmqmqszU+9VV++Qg6BF1dfhqPxkZ1T5
7XAyTJmX6b6UfkC8jBvlg3xd2sdVxp3MKi3MR4bp9riCyTgrTWrtbE9Vr9s7
rK+i/iwDtp6NSs+ASbRbxC82/M+hOrRWkSPCIc7zWMYny431gM8D8WX+svsj
1aq+g6yZt2vuD+s9A+/iUO6Ego145m9YC73LerCjn+kbcBdomXhIz1RnMPkk
d2OqEflBPyr3AmmMWvxa5M24I5ffB3mLnCde9h758RN4iGvsnlRaYx3YN4UH
5inmW2pJcEM2gZtpUTLpcMZ7IGMN68lyR/sy/JRzUkfBKpqnM2n0OPOavav6
z9e3TGeTu4NXvXlNh6hZyNzvzXLNtCC8RS1ubeJ1Wtl5XDLtyvWTlm8OHyUk

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 232->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0FOAzEQizggvoH4ATwg4gvlBYtET5WQygFx69OhQLfJxPY4G2m73V3H
4/E496/vu/1NKeXj7udnt3w+H4/L18vt+eFtOTw9Hs4fH/6vUk61XO/17+5e
s3iLU6xWa4cP79G+i96WB3HHPUxjvHc8QUfch3SyGhleaf9d9Xpl/KxO9JfV
dTQP+pBmgEc9xz1OtlTWHA0I68zJma+rWc3MPVezejsfDC2uvhkO1Q+bkep3
hjPDSL+K35eTB8SbcSN/UF9bc6w8nvFMacn6YJjZjCNMIVoiXmlya7M962r0
OLxZb8wrlSn2HT2jJb1uMUR7nMfFE4SPdd3zlOEQ57pqf2f+uBlo/UB8rD81
r7RW8p89OzmcPT8qYzEnLHvOmXCwEZ/1170L2c0yOKM/09fhNmgZeJLMqBkM
fSZnY6gR+ev4zjkXSCM6Y4XwMm6mgfIKnwfe7Dta4IzEpfxSvQ59kXmuNYCW
mfnEuUstBNf5ErgzLY4nM5zDOXCxBethvmfZhN4kdRBXxDqaUV2Uq/YMIK9U
7/Gbyt9QK+szycqslsjvzPEUNRuet3vjyrQofJdngmu1ZvPYcqGZqPd4Ht8M
UiTl
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 233->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOw0AQG/GBuAbiBnCAiCuUEwSJflVCKh+IP44O5ZHsTmyPtxBpG2Xr
nbHH3uvH593+IiJerj5/dvPr/fE4vz1cnj6e5sPd7eH0583PinifYn1P3++8
Rvf/suQzrQvhWY2Wb6s5Y9AZxjG/uzqJRz6nuDOs0irnkHSr+qwP4oj6Opw3
/BBngEea8xknWyprDgeEdXxy/HU5K8/cezXKt5uDwcXlN1JD6WEeKb0jNSuM
nFf4upw8oLpVbTQfpOvcHKsZj8xMcal0MMxoxhEmCJeMV5zc3uzM8jR8nLqV
NjYrlSn2P/pGj5x1iyHcsx+/M0H43Ne9TxUO1VyeqX+z+aCcBejBeioulV+s
9vJt3qX87eRw9P6ojOWcsOw5d8LBZnylr9tL2a0yOMK/4tfhzuCyqWPms+KV
s2bpzPWn7Z5zLxBHqMGYdeXLaD7ZHsp6pQWdQ/0VF6Z1o4t5HOv/SkOlKfsu
uRBcu59rV1ycmYzU3NwDFxuYD5t7lU04m6IPqpWxDmfUV+Vq4Sb8QX4pP7MP
ZfYAt//ikus7Pnb7QIPygGktM0LwXZ4JruVa+XHOQp4Mnf/i8gHB4yMq
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 234->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk01KRDEQhBsX4jXEG+gBHl5hPMETdDUgjAtxN0fX0THmdaqqK2IgE16m
U/313/Xjy+75IiJerz5/duvb/eGwvj9cnj6e1v3d7f705815RxyX+D2X79Pd
rv2Mrlo/WkHsmUbP0TbSBm8YYz4zY3+f3yl2ZqtilXkAHEyf+VHv83K03Nqh
XKs8Or2les1hQLZOnZz6usyqZu5czfJu8mCwuHwDi5kftGZ6VzG2debpbZlf
ma/g8bo7ADuKy2FB7CpPszEiTjdniqWKg9nM9rhjwzQVk+ubvWlrktexZX6V
vdODbCmejQ1hH3LQnTO1d2Jldkhz8Jt0lY8+NsY+5EGwVPVi2u3bnKX87fTh
7PyoHst9wnrPmQnHNttX8W3uxIxU8+P0peIb7NIcufOQY0EMVQ2GOIvZGHxk
/WW8c+YCaWSW9h/QZdqMAeqCOhzZXYpd9eiwWB/0fIWuymHmzvYbHyKGKqZc
M8lC7Pr7rF2xODmZ0RzmwLUNzMPyXvUmzE3hB2llW4cZ+VV91dhEfVC9VD1z
HcreA2z/xZL1nTpu7kEMqgYs1rJHcm5SXULo9qxVPf6yUX9Mvf9i+QBa7yPj

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 235->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0FOAzEQG3FAfAPxA3jAii+UFywSnCohlQPi1qdDgW6Tie1xiLTdJjux
PTOe2+e33etVRLzffP/s1o/Hw2H9fLo+bV7W/cP9/vTx7u+JOC5xeS+/b/dx
42dw1Tpjnf/neIbR6mhzHrDBHaYxv7PG9jzfU9pZrMpV1gHoYPiMR93Py8Fy
e4dqreroeEt5zdGAYp0+Of11NaueuXM1q7erg6HF1TdoMeuD1ox3lcZtAS2M
V9YreL7uE0A7ysvRgrSrOs3miHS6NVNaqjxYzKzHnRiGqTS53OyO4rM8JGIZ
r4p3PMiW0tPFEO2R45v3TO+3u8b85JwR5sCbcBXHOa8AHIxTaan6xbC3vTlL
ee/4cHZ+lMeyT5j3nJlwYnN8lV93Jmakmh/Hl0ofiosCT/bP9Geli9WlmqsO
fxnPnLlAGFnL9g3gMmw1OwNuox15etBaeK9by8iBctjOClxVw6w7x3ccIocq
p6r+Q42bmsGeCywHu9JcYTp9VxwVJ9rnOs7UBi3Gr7iZFuYPFaf42Dflv1hw
rjTPwiuzWjK+08fuHOSgesByLT2Sa9Pwd3uAe0yxqh//eZA/pu7/aPkCYoAj
Zw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 236->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJydU0FOA0EMi3pAfAPxA3jAql8oL1gkOFVCKgfUG08vBXabZmLH6Ujb6e4k
jp14Hl4/du8bM/u8//nZzV/bw2E+vtydX97m/fPT/nz4+P+YfU922ae/XX26
8UouW0ve8j/GIwxf02telzuLOYhj3CNH/z3mUe4glmmlfUh4IHxUh+XHpWCp
s8t6zfpYeg7kdThkscqcKi4dzmxmykxZHyTfC1xUfh0MpgfNiOntYFYxtF+m
64JYCfdMl8Il48761NWY8VR7xrhUOlBM1+NKDMJknNTaKIfVkzxEYlFdFq94
EC3G5yoGcLcY7/bO7Ncl3J+oOcMc6gZcVmPRZUkNVJNxqeaFsNd38S7Fd8WH
3fvDPKboQ9xQfRYb4yt9Ga/KW6wm9Rvhl8VZgUfnJ/qz4hW9JumM+NP4TbkX
WT9SDUKvkZ6YN+A67srd8TqpFo+f5MXF5sC0Mp9B3xANlaaq/0OPnXbYp0If
w644K3ON3pG9kGkFfc/yUPzSswwT9Q3FKpyHuoWvPL9KKzpj/rMp1wp1Fl7p
con4yhyvvos9T/taxFMPkPoQR5jHLY/30U35v1xO57Yi7w==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 237->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOAzEQG/UDcY2KG8ABVlyhnGCR4KsSUvlA/evRS3m02YntcQqRlu0S
x2PPOOvnt83rKiLebz//bOaPx91u3j/dnD5e5u3D/fa0effzRBymuLyn77f7
jOItTrHafYRnHJkfnQvCxTRWXEwr88pqVHim4fw/oIPxszrqfF4Olzs71GvV
RydbKmuOBoR15uTM19WsZubeq1G9iz4YWlx9IxzKD5uR8jvCWWFkv8L3RbmA
duTL0YK0qz6NekQ63Z4pLZUPhhnNuINhnEqTW5udUfWsDAksq6vwTgbZUnoW
GKI9Mr55j8z+vIz7kz0jzq5u4lU1fn0FqMFqKi3VvBg34nRwlbe/3B+VMccf
08bqK2zGV/6QripbqqbMm9CHcFHwyfmZ+ax0tVzu/eu8TCHvfpXHBQ/yYPTa
1dvVbbQ7d6f1KWfbcKNzeak5KK9dJghPxqiM0flk7UKLwrHlaHF6MsJ57ZP5
WU30nfsItRNO1jeGdTSz+7DAEn2VV7an8tfVanWmDB/S7//QkvvkzNHpMftm
XsuMoN4U2G7PmMdV94PMxT7/peUIYVwkMA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 238->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1tKA0EQbPwQryG5gR4geIXkBBvQr4AQP8Q/j25CXrM9VdU1IeDCuBmn
prqqu/Z587n6eIiIr6f9n9X0/bbbTT/rx8Pmfdq+vmwPh4vTivhdxvW9PL7R
QmcKf+tSz+W8qZ3PEUfmd+5VGhVX1pbvOfXY/xgn9QN0MH5WR93Pj8NV+UF4
5DnfcbKlsuZoQFhnTs58Xc1qZu53Nap31gdDi6tvhEP5YTNSfkc4K4zsV/i+
KBfQjnw5WpB21adRj0in2zOlpfLBMKMZdzCMU2lya7M7qp6VIYFldRXeySB7
lJ4ZhmiPjG/eI7N3vDIc4uzqJl5V4+wrQI22H4iP+VPz6rjJnvoSubz396My
lnPCsud8Ew424yt/SJebwRH9lT6Ei4JP9ThATVS/0oVybfnMvwW2yiPinJ0b
va70snyyHFFed7ZNX9C9/Kg5KK/QF8kyy5I9H6C91NJ4Z5yVP8VdaXbmesvK
/Kwm2uc+Qu2Ek/WNYR3NXd0iM62+yis7U/nrarU6m5Xx99KS++TM0ekx2zOv
ZUZQbwpsd2bM4z/WUcsflvgmLg==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 239->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FKA0EQbDyI3xB/oA8IfiG+YAU9BYTkELzl6RojcdJbVV29BFyYLJvp
qa6qrrl//Vi/30TE7u77Zz3tn7fb6fPl9vjxNm2eHjfHzYffFXFYxd97dXqj
hfZU/dKlnvM+qWcYGd85V3FUWJHw8jmnH/uPYVI9gAfDZ33U+fw4WO7skNfK
RydbKmsOB1TrzMmZr8tZzcy9V12+Fz4YXFx+HQylh81I6e1gVjXSr/B1OXlA
uBU28gfpWppj5XHHM8Wl0sFquhl3ahim4uT2ZmdUv252qlxl/p25M02VPsiF
cI9cP7w7sz+fNe5P1owwZ30TrupxGHgw7jMfBJdqXgwbYUJdIpfXvj8qYzkn
LHvOnXBqc32lD/GqsqV6yrwJfqiuw2WGY+az4jViqcww/j8PyKNzLyhe1mB4
XfFl+VReQ9zGbJknbDZsDkqr4kJrxP2p5lP5n7mMPrgzd3WyMx3MpSvjs57o
O/sIuRNM5hurdTjP+haZ6Whleyp/qlcMK9dfi4urbfTO8Zh9K18ZF+pNUTvb
M+bxH+vE5QsbLya0
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 240->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk11KA0EQhJs8iNcI3kAPsHiFeIIV9CkgxAfxLUeP+d/tqaquCQEHJtll
a6q//pnl+9fqcxER349/P6vx53WzGX/fHvYvH+P65Xm9//h02hHbIa7/w/Ef
bfRN6W/dak2/Iz3zyP7OuYpRecXAWVmuLEalL/MBHMyfxVHn83K83N6hWqs6
OrOlZs1hQFqnT05/XWbVM/de9fLO6mCwuHw9Hiof1iOVb+l5ynWqZXFlvcLP
i3oBdpSXw4LYVZ16c0Scbs0US5UH0/TOuKNhnorJjc3OqHjWDAkti6v0zgyy
pXhmGsIew/x5unt67+TKdMjzsNLzjFvEuOQi2Js6CJaqX8wbeTbPxT249/1R
M8a+5eXcCUeb9VV+DVfHDPbwV3yNrpMl8weIieJXXBevYmYYf6TziqfqK2MN
xkC8GQOqTTXTja/T28SHYkGdmGnFyFioRtyfqj9V/TPLYXX23M2TnenxvHVn
fxYTvec6QnbiyerGtA5zE7eYmbMG9bWaS6WHsXKe5w3Y7sWS6+T00akxe2e5
ljOSa2Nom29GP/5jH1l2lCAo6w==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 241->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0FOw1AMRC0WiGsgbgAH+OIK5QRBglUlpHZRsePoULXQxJkZj7vhSz9R
9Cf2G3/7/vVj834TEfu7n8dmOjzvdtPny+3x423aPj1uj4cP5x3xNeLyHqc3
2uhM6dX+zcfO2JqfIz2LgXIvloil+FGseV0QF/Oa64kYmFdZB8DRuQPkg9bR
YF7xIWagR57zP92+Y+yKAWmde+rMQMWs7sydqy7vog4Gi8vXiaH8sDtSfsuY
Z69zLcsr6xW+LxoLsCNfDgtiV3XqekScbs0US+WDabo97mhYTMXk5mb/qHxW
Dwkty6v0Tg+ypXgWGsIeWT8uu3P3jlemQzFXeVNclaOaHdYTTh8gjyw2iuno
HG/Xzo/qMXaWlzMTjjbrK38rrkYPdvgrPqTrsGT+ADlR/orrL1Z3JsZ6q76l
Psha5DZqXfHS/jT8ZxbrbguGSqfmhPV8jk81Yn5YbsSJapZZkI4th8WpSSfm
tTvHZznRd65jpzbsjGkdZjQPqmcizYLKx85U/8XAXnP+TuyOPtfJuUenxuyb
ee30iKt1a/Tf+8TyDTupJPM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 242->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk01KQ0EQhBsX4jXEG+gBHl4hnuAJZhUQ4kLceXQN8WfSU1VdHRcGJo/H
1Kv5urvm+vF5s72IiJerz7/N+nq/369vD5eHl6d1d3e7O2zefK2I9yV+n8vx
iRbaU3ql+z4PasVv3Ed65jFy/KziO1lP7ltmXDgrq5WdUekZg+pDZwaoDnau
w8z4Kj2qOX9T5pB812FAWmdOznxdZjUz9151eU/6YLC4fB0PVQ+bkarX8QyR
2apnI0N37pMXYEd1OSyIXfWpWyPidHumWKo6mKabcUfDPBWTezb7Rp1nZUho
2blK72SQ/RTPiYawR9YPz87snVqZDnlO5yZfdUZ1d1gmnBygGpk38nR0Tm3n
3h+VsZwTlj3nTjjarM8cLIMou1UGO/wVH9J1WKZem/msuEav1p1Y5qVyW3kr
1mAMxJsxTL6DN+vz5OvOtmCodHk2rFbFQjUkB858cu8qFqRjP4cFzVgxV57n
ruzPzkTvuY/t+wD2mNZhnu5DkZkYnlWtbE/lLxZcq1vnX1myvzNHp8fsndXa
yYirdXv03+vI8gG55iJ3
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 243->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylU0FOA0EMizggvoH4ATxgxRfKCxYJTpWQygFx4+lQimDIxI69rTQdrSZx
7MS5fnzZPV9ExOvV199ufbs/HNb3h8vjx9O6v7vdHx9vfk7ExxJ/93K61ePG
/+YFf0O/8b2KRxiZcwh5Cv/MKfexwkdalR4hzpv6QDROekg+q4Gw1NlVvWZ9
dH2HuDMOVawyJ2cHOs5sZupeuXz/9UHgovJzMJgeNCOmV8EM4tmuZyMHd+6d
bscbyMOVrq0+RrluzxiXTgeKcT2uxCBMxkmtjXJYPdc7na8yf2fuSFOnr+QC
uEeOH25n9opWFFdhTnUTLqvR7Q7yhOKDSiPCrjCVOEXb1v1hHss+Qd5TdkKJ
zfGZB/JgtyPd/rheQXVZXxiXqdeiPzteI5a1E0s6BYdKI5sr4hqIA8BGHCbc
ARv1ecI1Zss4dHF5Nkgr4wJjgA+U+XT9z1y+f+bMVZ0ox8HcejI+qll95z7a
+1C8oViF87QPjWdiuDut6I35L5Zaq6rzXC4Zn/UymlzlG2l1PZK5KLhBNJ61
H2fGn7h8AhRoIDw=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 244->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U0tOw1AQG7FAXANxAzhAxBXKCYJEV5WQygKx4+hQIDSZ2B5PEJFeo3T8
PPZ8rh+fd/uLiHi5+vzZja/3x+P49nB5+ngaD3e3h1Pw5udEvA9xfg/fb3RQ
TOHVmfKxGHt+4wTPOFDu6p6jf9Ky0pj4mG+Vj/3HOLfWoeoB8sHyOpqZvgqP
POc73blj2pUGhHX61NmBSrPqmbtXXb2LOhhaXH0dDuWH9Uj57XBWGFmv8H05
84B4K25UH+Rr6xyrGndqprRUPhimO+MOhnEqTW5udkfl685ONVdZ/wpPZg59
o0fpWWCI9khaYsIU89fZpwqHOCPHE6/KUe0OmwlnDpBHxo04HZzjbev+qBlj
85gfZyccbMYrLchHvqP8dvRX+hCuowX5zDwof6Ur743tc36X7ALyqPrKtAbT
QLiZhhXvjJvN0Yq30VulocKhPqsaIi0UI/an6k9V/6zl62n23PXJ7nQ4t57M
z3Ki71zH9j6AGMM6mlf7UMxMzN6VVxZT8xcD9ur6/KuWzA/5Zv+puwvtJM68
WjMyBO0ZreFci9GP/z55js5aPgBxfyQ0
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 245->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0tOw1AQG7FAXANxAzhAxBXKCYIEq0pIZYHY9ejQ8mne1PZ4gkSkR0if
x2PP5/rxZfN8ERGvV59/NvPb/W43vz9cHj6e5u3d7fZwefN9IvZTnN7T19s9
Lj7jVJx6fu8JnnEs8w48Ik76yXXLGhNfjnPysd8YZ6cOjJ/lUfEqB+Nye4dq
repYziGJ62hAWKdPTn9dzapn7l519Q51MLS4+jocyg/rkfLb4awwsl7h+3Lm
AfFW3Kg+yNfaOVY17tRMaal8MEx3xh0M41Sa3NwsRuXrzk41V1l/VQv1jR6l
Z8AQ7TGd/398ivnr7FOFQ5yR7xOvylHtDpsJZw6QR8aNOB2c423t/qgZyzPA
Zs/ZCQeb8UoL8pFjlN+O/kofwnW0IJ+ZB+WvdOW9ae8E2juip+or0xqFBkcv
nU+j1lmL21ulocKhPitdSEsX4/Snqn/Oc3yaPXd9spgO59qT+VlO9J3r2N4H
cMewjuazfUD1Tjvw8668sjs1fzFhr67Pv2rJ/JBv8ZuKHbSTe+a1NSPTeBh2
v8QVHv/r5Dk6afkA8xsktg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 246->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VEFKBEEMDB7Eb4g/0AcMfmF9wQjuaUFYD+LNp+uizM5WVyWVEWxoh95O
0lWVirfPr7v9VUS83Xz/2c3vj8fj/PF0fTq8zIeH+8Pp8u53R3xOcf5OP193
d+OdvGwt9yJe1cD6Tl6KH3VDjFAP85z31G+q5lYdqh4wHupdB7PCV8UzzphT
+k7kdTCwWKdPTn9dzFnP3Lnq4r3QwcDi4huwmPqw1fFuhnFZJFa9m+oVmm93
IzfXU0wfxmurj1VuV7MMS8VDxXQ97sSomhkm922Vk73X9U7lK8RfaZGd2crw
XMQI7KE4FP7rzFMVx2oG3kPd7I1qdpQnHB8wjqr2cjZnCc8Ov/b8JB5Dnyjv
OTPhxGJ8hgV5ZDNSzU/XK+rdTJcMy9AH058VLvSazXOCTTAwjllfFdbAuquN
umQYqDYFd6c/gzYxxmJeFcf6nOFiWLoxTn9QuwoLi1PLwcJ6kWF2+rplY331
Jjujju15IHcq1sE8zAPTe52z+lZc1V3mv5g4V5fnX7FgfVpv9VuW65wV15ZH
phj+L0oNDY3+c6OPzli+AE6VJXE=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 247->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9lU1Ow0AMha0uENeouAEcYMQVygmCBKtKSGWB2PXopUCbicfv+TlIRJqm
afzz+dlWt89vu9eNmb3ffn3spo/Hw2H6fLo5P7xM+4f7/fnl3e8xOzab7+3n
rp6qveLHrv59ZI9i+PiKH+X3unnGhllRrShHZq/Wg3TIehDVgfIqzIgvs49q
9j7p3AG/CkNkq/RJ6a/KzHqm7lWVd6GDwKLyDSzurtaDesTqTWO2+WR5qV6G
611zorhZ7Egfz4V0qtbo41U0YyxZHcimOuMLXUQtkWYRizLTA//lgHzq3CBb
mBfZg5mLnqOL8fi6lb5ctUnmL6tb0Y7xXxh6ngU3yZHtTqgDYWH7w2JHMRU7
pbbV+0NmDM2jv5SdWOQGtt6esfg62I7Q/Ql4lDmPvjNdGMt1z/rvNvr4nBlX
H6u0E82dgCGqEcVmrObjJsyIIdQmqV3pz6CNjbbeL7PzvWGMiKVqo/QHzTrK
830Ve67WiXwqMdceHx/ljJ69juV9CN4hW4V52IdI796HsGczx+zDXCvq/CuL
VFv3G/NVnlGtpRlpFv5PobiZRv95PPPMcgLD3COw
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 248->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VEFKBEEMDB7Eb4g/0Ac0fmF9wQh6WhDWg3jz6bqrYE+mqlJZwYbepqeT
SqWS7PXjy+75IiJer75+dsvb/eGwvD9cHi9Py/7udn98vPnZER8jfs/xfbq7
a+/4qTW/I3uGMcc9LcNP8s+6ZY6Dc2W5shiVPeOgdGD4LI7yVzEYlls7pLXS
sew74tfhgGydOjn1dTmrmrlz1eW70sHg4vLbcEmnmw+rkcrXwYzEhcWVegXP
95yNcCtspE/mxXTq5pjxOpopLlUezKbb4ytdTC2ZZoiL09OMC4vn9g2zZXGp
Pek5dEdL8VnZGHWJWZui/2Csyd/RjvGPvIGGKgaqcaUZ+77RiHBxYzl2VW5/
mh/RY6wf83JmwrHN9opLzkPNiJyfpAHzVfyQXYfLPC+5VzN2VYNN3GI2YJ5i
3hifqq6Ma2Rcs1eqPpix3dlhWCwX5lfZqTlB74hL18apD+t1Fue0mjV382Q+
Hcxzd8ZnMdE969ieB/DGbB3Om3lAes8+I+B/oso9v6n+i4FzpXkWvdLlkvEh
3vRN+Tp3lmurR0RNIC6wR7r8x+a99AmEwyFt
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 249->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tOA0EMi/hAvQbiBnCAEVcoJ1gk+lUJqf1A/HF0aHnsTCZ2HCox0nS1
XcdxEufm6WW7uzKz4+bzZ7u8PhwOy9vj9enlednf3+1PH2+/r9l7s/XZvp7q
reKVOHb67xEecfR5z0eIo/p937zGhrWiWlGODI80sD4gfpSHxbMciEudXdRr
1sfUdyCuoiHCKnNS5qtqZjNT96qqd+iDoEXVN2kR+xOdineZxuG09bK8tF+G
661e+9FQ8AbysNeF+lSt0fNVesa0ZHUgTNXjCgZxMk1qbhTD8kneIViUF+KB
56L36DA9AwZoN6el34vK7JVaES7SZE6P52U5st1BnoA7Q/aHcUecCk6p7ZL9
YT2M/OiPshMKNtViMxeLQbghp5un4hWUl/WFafn93vvd5hifM9PVc1V3Au0b
0pPNFWk1zyt6JfNBz63uDuJCtaC4DMf2BHne81cxynyQ11Ge8ynOXK0TxVQ4
/3o9P8oZvfs+lvch+IawiuZpH6J+k/9YPvSN+c/aXFOlzku1eP6Qr/uPxSrv
qNaSR0TsoN/N0Mf+1/U6Vi0fBsEgNg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 250->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0tuwlAMtFhUvQbqDdoDRFwBThCkdoVUiS4qdhydXyEvjmc8Thc8yUSP
Nx6Pf8vt9/prYWY/r+efdf+72u/7w+blcvnsdx/vu8vj25+ZHTsbvt3tq1oV
r/ix075HeMTRxr0ewY/q93XzGjusFeWKYmR4pIHVAfGjOMyfxUBcau+iWrM6
pnMH/CoaIqzSJ6W/qmbWM3WvqnpHdRC0qPpQfoqWKCd0V7VMTjcYi0vrZTjf
qtldQ2E20Ax7XahO1Rw9X6VmTEuWB8JUZ1zBIE6mSY2NfFg8aXYIFsWFeDBz
0T06TM8IA7Sb09LuRaX3Sq4IF3Ga0+N5WYxsd9BMMC1ofxh3xKnglNz+sz+s
htE8+qPshIJNtdiUi/kg3CjmjFlBcVtOz8u0PN5JTaL4ma52b2btRLBvSE/W
V6TVPK84K9kctNzq7iAulAvyy3BsT9DMe/4qRukPmnUU53qKPVfzRD4Vzrnm
+VHM6O7rWN6H4A1hFc2TfYjqfTdr3kl/0Mwx/NHxwjxdbIW7osXXKeRr/vNa
GFd0R7lWZ0TBev1ZHZ9lNy0ncGci8w==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 251->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1tKA0EQbPyQXEO8gR5g8QrxBCuYr4CQfIh/Hl1DTDLbU1Vd4wMHZpeZ
qa6uft08vaw3VxGxX31+1vPrw243vz1eHw7P8/b+bnt4vP3aEe9TXP7T8Y82
elN4taUfsc7vBM84Wr8n+8pO6k9amB3iZ7EyHxV+ocXMA+NnfpS98sG43Npl
P1Uey74jdiMaENapk1NfV7OqmTtXo3oXeTC0uPpYfI4WFBM7u1q6NV3+yq/M
V/B4R3cQ3oob5SfrYnkajTHzjeRMaaniYJjRHncwjFNpcn0zG+XP6h2BZX4p
nvQcOqOl9CwwRHskLae5QHiUNxa3kzulP5KezKt8VLPDekJpYfOjuBGng3Ni
+8n8qByifszLmQkHq7Tk+jv6GW7h8xu9wvy2nJlXaZH6ordXNeh4gBZ7Jpp8
q76tuJVWVE/FzTR0vA23OzuMi8XC7CqcmhPVF0hfhyF94NSnmousBeHa+9w/
lRYnJ1nvX+zMz3yic87j8DyAN4Z1NKOaoJ5Z4Buc8sfeVP/FhGM937WY5u63
tOQ8Qb7mLiZu65xZrKM94mC7ehr1+I991PIBpvYibw==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 252->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1FKQ0EMDH6I1xBvoAdYvEI9wRPsV0GoH+Jfj66l9nU3m5lMUPHB9vG6
k8lkktw+v262V2b2dvP1s1neH/f75ePp+vjxsuwe7nfHy7vvY3Zodnm301s9
57jqYXnYs94DPOLo8w48JE6p+6wFxUX8qFbFW6S56kPWOx/D4lkOxKX2zufJ
fKzOK9LONERYpU+VHcg0s56pe+W1GOGeei5oUfVFWrL5jOpBPQrrJVqmp13e
LC/1y3C91WOAN+OO/PG6kE/VGj1fxTOmJasDYdRa2GxkXiLPIi3KTEcxLJ80
OwSL8kI8mLnoO3yIniE/0G5Oy8qXzF+Yy+2V4g+c0zbzDbpJjkMXh7RPPhAt
bH8Yd8Sp4LLafro/ioeIC8Wg/AzLtPj+K/oRbsgpziXTN+HcHmVaqD6b41kP
Jh5hZlCdvd9sbjPuTOvES3QjDYo3FR+8f6iOKC7DsT1hcxHpUzFKf7K98Hki
3PC4+cm0KJ54vX9xPD/KGX17H6v7EN0hrKLZ98qCePP4DsfyoTs2f9biWtf/
ekz3329p8T6FfN1/LFb5RrVWZ0TBTndCP/7jnLR8AomPJSw=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 253->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFVEFOA0EMizggvoH4ATxgxRfKCxaJniohlQPi1qdDKd0OGdvxFBAjDavt
Jo7jOFw/Pq/WFxHxcvXxZzW/3m+389vD5f7lad7c3W72H2++bsRuitNzOjzd
e8wbvSpPneU7iWcYy+9tr0Wew//IheUhfNaroxHjXH4Ds1U9ZizWm9KaYg3M
LtepdBz1HeOuOKBYZ05dzJm7wjDLeqTX1h+VhosOBheXH+JS+RP1w2YE+xVc
ujOdnqqu1Ct4v6M3CG6FjfTJvJhOoz1mvBHNFJeqDxbj9qK8UWnJNENcHE+j
HFXP8o6IZXVpPPEceodH8PlWn3CPxGXBK/wHa5n7kzVBmJH4ZFxVY9fkMe6d
DoKL2h+FjTCduKq3H+2P8BjzXz7OTpSxxTzz/HMfakfk/pi+RP1Q3ZOuFRfJ
L/p8NYMOJ894oM9Wb+Vb5ZnutPMm80T6Kb7n+LPCzXqhw/KqOLUnyheInxvj
zId5ndX5PNXMB7g4mih+v3UzPquJ3rOO5T6QOggrxzqc86wC5AeKF/NhnlPx
bS3pvTbmD7hknSBe85vKdd5Zr7ZHpuj+D7PY7psxj/+4By7vWB8lJg==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 254->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOw0AQW3FAfAPxA3hAxBfKC4IEp0pI5YC49elQStLdWdvjDQdW2kZJ
PWOPZ+b2+W33elVKeb/5/tnNH4+Hw/z5dH16eZn3D/f70593v7eU41Quz+n8
dO8SN3pVnDrr/wTPcqzf61qTOEf/oqU5QBurW/Gxbywnrbe6W3qA6mC8juaR
3kWezMfRuWPalQaEdfrUYTbuCsuZ8pFamzlJPFx9MLS4+pCWbD5RPaxHsF6h
pTvT5al4pV+F1zt6C8mb5Ub+RF3Mp9EaY74Rz5SWrA6GcWtRs5F5yTxDWpyZ
RjGKz5odgWW8FE9mDr3DI/Q0/I72ai8QHvnWcJn7Ez1BOUvQE/MqjmMVx7RH
TqVF7Y/KjXI6uKy2P+2PmDE2f/E4O+FgIx71T+1RF0NwDac5l0pfhxvUIvWB
mlUPujyxxwN1lgnX5+wF0rh6E6/Q4PRly3xmeaNf6LC4DKf2JNs7NisZxulP
5n/k+TlOz00tjicjObfemJ9xovfoI/Wmmn3lHeNX3EzLwolmvMOL/rCZU/ia
S85ejTFzj2iJPsF81TcV67yzWq0ZqfxAXrC8qIfIl/+6Zy1fq6wlqA==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 255->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1tOA0EMi/hAXANxAzjAiiuUExSJflVCKh+Ivx4dqr5mM7bj2X4wUrra
buLYTubx/XO1uYuIr4e/n9X6+3W3W/+83R9ePtbbl+ft4ePTKSL2U1yf0/Hp
xrluNFSdOu13lM8wUO+qzuGvsBhXptXxiHGWeqZrLJkB0sH6OpzD0JN7Z76I
i9Lj+O9yQLnOnLqchXeFYZb9iNYzF8fDiw8GF5cf4lLtJ9LDZgT1Ci7dma5P
1Vf6FVzvaATBrbCRP5kX82lUY8Yb8UxxqXSwHFeL2o3KS+YZ4uLsNKpR/ezd
MXQj/gjL2UF6BPdZf0PnDK/YP1br3J/sCcKMNqLHVT32TR3jnnsqLur+KGyE
6eRV2m66P2LH2P7lU83V2jOQj+an7lFXQ/JmPc29VPy6vEEukh/QrGbQ4aQZ
j+iMCetz7gXiePEmh+Dg8B3dT+QHxRJaWF2Vl2fDtKo9G82x5lPci9wH5bHj
cEGzUJwrzKWR8VlP9N76z763vrE+CCvnOpzzrGBflC/mw3ZO5be9kFa0U+xu
3MIl+wTxmv9UrfPOtFo7cvIiEieW230z5vEfceTyCze8Jmk=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 256->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOw0AQG3FAfAPxA3hAxBfKC4JET5WQygFx69OhKml3J7bHSw+stImS
nfXYnpn71/fN9iYiPu5+Hpv583m/n79ebo8fb/Pu6XF3PHz43RGHKS7v6fRG
G52peLWXfOyMrfN5kzufIwyUu7rn8FdY7X+mW+Vj/xgm1UNqpTRmLKat8hpi
GXpy7swXcVF6HP9dDijWqdPIDFScVc3cuerOTA/PPhhcXH6Ii+MPWiO9qzh2
a7q8VV7pV3C9ozsIboWN/Mm8mE+jGjPeiGeKS6WDxbhaVG9UXjLPEBenp9Ed
lc/uHUM34o+wnB6kS3Dv8hs6O7yi/9hdZ36yJxRz2cBDlePQ3GPcc86KC5sf
hY0wnbhK21XzI3qM9V9eVV2tPgPxqH5qjlZ3SFyX0+xLxW8VN8hF8gOaVQ1W
OKnGIzpjwvqcuUAcz97kLTg4fGF/Cu3wH8MSWti9Ko71NdOL+mw0xqlPNRc5
D4pjy+GCaqE4V5h/3Rmf5UTf2UfHb+Udy69yMy7tPHSxqQ+X2EorO1P9FxPW
2uaNAucaLtkniNd6YXrMvplWt0daT6pY16P/3icu3/A5KaQ=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 257->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOA0EMizggvoH4ATxgxRfKCxaJniohlQPi1qdDW5bOZG3HAwciTVfb
zcSO49w+v262VxHxdvP1s5nfH/f7+ePp+vjyMu8e7nfHj3ffJ+IwxeU5nZ/o
oG8qX+UteDBXRPsd5bMamUsY92Q/WTeGBeqzXhlGla84nEJgOzNAfTBch3MY
/WTszBdxUf04+rscUK4zJ2e+Lmc1M3evVjthaPijg8HF5Ye4OPqgGPGu4tjF
dHkqXKlX8H5HT5C6VW2kT+bFdBrtMdcb0UxxqfpgOW4vyhuVlkwzxMXxNLqj
8GzvGH0j/qiW40EagnuHb/TZ1Sv8x+46+5M1oTWXAzRUGIfmHuOeMSsubH9U
bVTTyat6+9P+CI8x/+Wo5mr5DOSj+ak9Wt0heR2m6UvFD+WNcJH8QM8Ka1Un
zXikzyD9OXuBOJ4i8YqCg8MX+rN5ursDa4le2L0qj/ma8UI+G81x5lPtRcZB
eSwcLmgWirMz19+cXJ9hoveso6O30o7hK2zGJZKfswe7fDEf5jmV32KNeM+p
PcIl6wTrNf9lLqoWeme9uh5Z9AjEk9VNvNU8/uOcuXwCx3UoqA==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 258->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk1FOAzEMRC0+UK+BuAEcYMUVygkWiX5VQmo/EH89OrQFmnhnxhP6QaR0
tV3HfmNP7l7e1pubiNivvn7W8/vTbjd/PN8eX17n7ePD9vjx/ntHHKa4PKfz
092j8b/nQn9jq/2O4lkOxF2dc/gzUz6H8jOtTo8YM/0GWEdngHSwug5zGHpy
7cyLWJQep/8uA4p15jRyBypmNTP3Xo3ydn0wWFy+BYvZH7RGvKsYuzVdnqqu
7FdwvaM7SN4qN+pP5mJ9GtWY8430TLFUOljMqMedGJZTMbm12RlVz/aOoRvx
o1yOB+kS7F19Q2eXr/BfpdvxBeoT6jPKq2ocmnOMPdesWNj9UblRTieu0nbV
/REeY/7Lq5qr5TMQj+anvLU4Q+K6mqYvFR+KG2GRfECzqrXIY3iG6Qyiz7kX
iPG0hF8dzzOGRW+ap3t3YC6hhZ2r4pivnXvHvFLFOPOp+p/rnJYzc5MFzUIx
O3P9y875WU30nvvo9Fv1jtVXtRlLJD9nD1bsledUfFur9F6R5xoWS1vzX2ZR
udA70+p65KcfgThZ3sSt5vEf+8zyCa/OKm0=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 259->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1tKA0EQHPwQryHewBxg8QrxBCskXwEhfoh/Hl2XGLPbqdckiAO7y870
dFdVV9+/vK63N621t7vv13p8f9rvx4/n2+lnM+5Wj7vp8OHnae1zaKfvcPim
T298ck+t+TmKZzlcHbXH7tYvuofyOwwsVmF2fFjtpAeIB6ubYEb41B67p3R2
fXM+URhQbNKnpL8pZtWzdK568S50CLCk+HpyKD6sR4pvkrMNp6+qK/VqOS/r
B5LX5Ub6VFxMp16ONV+PZgqL48Fiej2exLCcClNam91R9SLvTCvgjfAjHyYe
pEtgX9QPeC7yGf853okvkE5VmzbgvKqGmx3micQHDEtaK4lLuF06P8pj7Kwu
p3XkMxB/1nuimZsROT8XeIXVVbooLBIf4KxqneVh/JKZELOAOKq+/q56TnrL
cjMMVJtgbqofai7GhWFwcWpO3Nwxr6C+xpwBTqRbxYLi5vu1tw5LoknF+xdP
zc9qov+qY6K3mhdWX9VmWI79QJ5JsDtfqnjkT8rT5LkGS8RttqfuJv+Ma+qR
ox4N4WR5Zzq7fvzHc8DyBRcFKu0=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 260->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOw0AQG/WA+EbFD+ABEV8oLwgSnCohlQPi1qeXUpJuJrbH2wsrpVG6
sx7b492+fuzeNxHxef/zsxu/ng+H8fvl7vzxNu6fHvfnzYe/J+I4xPU9XN7u
01vvnFOr3Uf1DAP1rs5J/tm3zHHgXFseAWpQbaVV6mn6KPwQfRBH1NfhvOKH
OIN6pDmfKXNHzvVwQLXOnJz5upzVvXHvVS/fhQ8GF5dfD4bSw2ak9DqY092J
oq/0K3xdZR4IboWN/Mm8mE+9GjNej2eKS6WD1fRm3KlhmIqT25udUf3s7Bi6
EX+E5WQQroYLwl/0N3TOmIHrkW9Mt5ML5BPyGeGqHtXdYZlwcsC4uL2cOkfb
rfdHZYzt5VV5beUM1K9mTzyr7oi8PzdkhfVVvigukh/QrHqtcJg+506Iu4A0
qrnOK+/n2TaPOxeZT6Gd5WGBJbQwDlUdyzXTi3JGa0gO7Pkk3orL71I+GvoU
dsW5wqS9TF+qnuh7+o/Vr/xpPESL9Ve9GZcg3POcXK1sT+WPaZ3/S/NxsHu4
WNqSF47H7JtptTIyLbM2z9OZx388Fy4nj5ko4w==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 261->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FKA0EQbHIQvxH8gT4g+IX4ghXMKSDEg+SWp2swLjO9VdU1i+DAZNls
T3VVTfX29X1/2ETEx/33z376fD6dpvPL3fXlbTo+PR6vHx9uO+Kyi/k5umPF
meqcWu13VM8wUO/qnOQfy2fHcce5tjwC1KDaSqvU0/RR+CH6II6or8N5wQ9x
BvVIcz5T5o6cG+GAap17cu7X5azmxp2rUb6dDwYXl98IhtLD7kjpdTB/ZyeK
vtKv8HWVeSC4FTbyJ/NiPo1qzHgjnikulQ5WM5pxp4ZhKk5ub3ZG9bOzc9tK
N+KPsJwM0tVkOfPp+hs6Z7zA9cg3ptvJBfIJ+gxwVY9qdlgmnBwwLm4vp87R
tnZ+VMbYt7wqr62cgfrF3RPPqhmR87MiK6yv8kVxkfyAZtVrgWNmBfY0ap15
61bFodnuvYzmE2ErLKaFnavqWK6duWNZqfIk76f1XfkW+KyD6XBxPFH8/mpn
fNYTvbd3xL53/jQeosX6q96MSxDu+Z5crWvyx7TO/zU1LvYIF0tb8sLxmL0z
rVZGwFK1an7y+3/uHy5ffGgppg==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 262->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1tKA0EQbPIhXiN4Az3A4hXiCVYwXwEhfkj+cnSNj2W2p6q6BoUMTML2
dFdX9dRsn193+01EvN1+/uzm98fjcT493Vw+XubDw/3hcnj3syPOUyz/aocZ
c7aqU2s5bzDyOcJAvas6yT/6/8yxjee6lgvrx2IMU+pBvclcmB5Wn1fFGfIT
MVaHepS+I3UjHFCuc0/O/bqc1btx39Uo39UcDC4uvxEMpYfdkdLrYP6+nSj6
ynmFr6v0A8GtsNF8Mi82p1GNGW9kZopLpYPljHrcyWGYipPbm9WofiP+qXQj
/gwnn6NvuJKXKRdD54IXOB/Njel2fIHmlGcTE8ZVPc5NHeOee1Zc2PtR2F8L
aKg4Vdr+9H6Ex5j/8qru1fIZyEf3p7zV1ZC8VU/Tl4ofyhvhIvkBzapXh2N6
BfY0cis/dqvi0GyJWfgAzcbh6t7tKk782eUBLjHheOUzmkN8UM6y4UK5BqgF
XFa4BEtiC/6K33/tjK+0Kg/J2bTzYefB+6vejEsQ7sy/lVZ2pvzHtC6xJsfF
HuFiaUuzcGbMvplW2yOkVuFWM7r2/ubyAXaTJ+k=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 263->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0tOw0AMtVggroG4ARwg4grlBEGCVSWkskDsenQokGjqvo+dDSOl6WTs
5/fsN7fPb7vXq4h4v/n+2c0fj4fD/Pl0fdq8zPuH+/3p8O7viThOsb67T2zI
cXlqrecDRj5HGKi2y5P84/KdOY7fc97IhdVj3xim1INqk74wPSw/L8cZ8hPf
WB6qYX1H8jocUGxlTpX5Vjmre1O9V12+XS5Vfh0MpYfNSOmtYC53J0xdpWGM
cbqsHwiuw0b9ybxYn7oaM16nZ4qL08Fiuh6vxDBMxalam+Woeh3/ON2IP8PJ
52gPV/Iy5VLQueIFjkd9Y7orvkB9yr2JCeOqGschj3HPNR0Xdn8U9s8ynlB7
60GRh7BZvsJG3nNzLfkMxKP5KW9d5ETI+zSeO18qfigO8hd9pvyAZlUL1WX3
wfpP3AWkUc11XcKv48w6c4H+nDSOw3WzzXydD87+E18zXogLjSlgsj4teSNX
xQXFna0NXFxPFD9bY4MXnNaKN2Fvlv6MusFi9VVtxiUI9zynqlZ2xr6NM6A6
05wq2B0uJW2pF5Uesz3TWvYIyVW4rkf//fxy+QIVRCoi
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 264->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0tOw1AMtFggroG4ARwg4grlBEGCVSWkskDsenSooCHPz/N56YInpZ/E
Hs9MxrfPb7vXq4h4v/n+2M0fj4fD/Pl0ffrzMu8f7venh3e/V8RxiuV79IoN
PWoeO83zoh5hVJxVn8O/4wTuM91oHqutMKmeAg/5gvSg/nwU55IfuYf6HA+V
p4g741DVOu9pZAcUZ7Y37l6N8h3lcknOHX+qM5JdxrE50983m8s0rGuULpkH
gKuwK38yL+TTqMaMN+IZ46J0oJrRjDs1CLPjNIhbcWbvw8FtsmPozr8RlpNB
eFKWGRelc8GLKP2ufGOzHH8Yp6xtXcNmqN1BmXBygLigWQF4qD4rh6Svwkb9
DLvKnvLayllR37174BndEbU/G7KC5jJfztl1vc841XzF67iaWe2SzB/ZhUoj
e6/LIXl1Mo84dN4kz53dQVhIC8oYrDv/JnvCclHx62rSrkjNU7oSb8alqmuO
mZPOR8Kf8ZMzNmRBaXWyCfeBeFph5VqHc9PPMmNwV7lk9fkdUJ0C5xIulrbV
Pdbr/Eda7YyAXoarPPrv64fLF4r2KSo=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 265->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0Fqw0AQG3Io+UbpD9oHhHwhfYELzSlQSA8ltz49DS3GHksajXPoguPY
ntVIWs3j28fhuImIz+3Pz2H42p/Pw+X14fbwPpxenk+3j09/V8T3LsZ794oV
e6p+as2+g3qGUfVR7xT/BSfyXulm/VQtwpR6AJ7SiPSw/Xk5WJ0zYPscDytP
GXfFAdU659SZgYqzOjN3rrp8u1zuybnjD1qd7CqOcBV9lYZpTaWrzAPBrbCR
P5kX86mrMeN1PFNcKh2spptxp4ZhLjg1cRFndR4O7iw7hu78n2E5GaQrZVlx
qXSOeBHQb+Sb6uX4ozhlbdMa1aOaHZYJJweMi9vLqXO0tecHYDo6UfYqr62c
gfruHME91fysyArrq3xRXCQ/oFn1WuCAGZrdhc7MV/IpznVcyY8wvO7kIMDl
zk7GUmcrOVR1Yk5ULhC/Rc3EU1dzpH2MU+aC6mbL0Ec1kD2KX9ljRRYqrU42
6TwITxFWrnU453NWflfcq1yq+nwGUmeBcw8XS1vi6XjMnpnWVkbITDDcyqP/
vn65XAFVJCiq
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 266->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1FOAlEMbPgwXoN4AzkA4Qp4gjWBLxIS/CD+eXQlolm6M9PpYuJLnri7
7XSmnS5fj9v9IiLeHr/+bIfz5nQa3l8eLg+74bB6Plw+Pl1vxMc6fn+7N2bk
VPXUufkO4hlGVUe9U/wnnMh7pZvVU7EIU+lBeEoj0sPy83GwOjNgeU4Pq54y
7ooDinXm1NmBirOambtXXb5dLvf43OkPOh3vKo4MW9VVGnK+M3eKSXArbNQf
pGuuj1lut2eKS6WDxXQ97sQwzAmnJi7irObh4Gb/VLrz/wonf0fP9BB8VF/p
HGOhfqO+qVpOfxSn+LkAV9Wodod5wvEB4+LWcuIcbe39AZiOTuS9qteWz0B8
d49gTrU/M7zC6qq+MM6VXqRZ1ZrgMH3OTohdmNQt5gr5X/NyzQA6XB/EGDvV
rHYnY6E+ZS2QQxUn9qTaO+aVMV/VP7YDQXgrLiju5jRmoDSpvehctgvKC5VW
x5t0H0RPEVaOdTjnOVPPGNwrX1rzI1odnn/BxdI2eqdynWemteURM9bt0X/f
by6f4EYqbw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 267->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FOA0EMizggvoH4ATxgxRfKCxYJTpWQ2kPFjadDRUGjjO04CyNNu7uT
cezEuX1+271eRcTx5utnt54eD4f1/en6/PKy7h/u9+fDu8uO+Fji97+7Y8Od
Kp9a4zmKZxhVHvVN8c+c2Helm+VTsQhT6UF4SiPSw+7n5WB1esDuOTWsasq4
Kw4o1ulTZwYqzqpn7lx1+Xa5/MXnTn3Q6nhXcWTYKq/SkO87faeY4wa6HC5K
11Yfqxp3aqa4VDpYTNfjTgzDnDg1cRFn1Q8HN/un0p2fFU4+R+90EXyUX+lE
WEiPm8upj+IUPxvgqhwO95zTqQ+aDYWNMJ04R1t7fgCmoxN5r6q15TMQ350j
eKeanw1eYXlVXRjnSi/SrHJNOEyfMxNiFqa8RV8h/8u9CVd4kXEYOTOO1exk
LNVbyaGKIx515o55ZeyDqh+bgVjm54rLqAn2vNEDpUnNRWerOjMvVFodb7J5
UDVFWDnW4Zz7TD1jcK986fSvqoXi+R9cLG3jLIi7zjvT6noklqAzSXGB11Fd
tu6M3Y3/5vIJ9dYraw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 268->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOAkEQ7PhhuIbxBnoA4hXwBGsiXyQm8GH88+iKAdztraquXphkWGZ3
ph7T1Q9vH5vtXUQcVr8/m+HzZb8fvl7vj4v3Yff8tDt+fDzNiO91XJ7dGQvO
VHxqjL+j/Qyj4lHvlP6sib1Xvhmf2oswpZ/1/+zWgGlEvI7msx63BvmJtDPu
6k6ZdqUB7XXq1OmBSrOqmdtXXb1dLdfk3LkfNDrZVRoZtuJVHvJ5p+4U8zQ7
9WAZRr6W5ljdcefOlJbKB9vTzbizh2HONDVxkWZVDwc356fynf8rnPwdrekg
+Ihf+URYyI/L5dyP0hTnCXAVh6M9czr3g3pDYSNMZ5/jrd0/ANPxibLH8ovO
qLrk/d0+mvwfTdk/C7LCeOW9EM2VX+RZcc1wrukJ0Qsz3qKuVL9x150cBNHr
9E7GUrWVGop9jNfpO5aVWe4N35cxOqPOZy1I+2Q0aqA8qb7ozEhPJwuVVyeb
tB+SFjQYv+JmWjLXJDOG9iqXTv2YV0fnLbRY3kbv1Flnzbx2MxJIZxO32y+3
mpHXf1p+AOlpKe0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 269->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k1FOAzEMRK1+IK5RcQM4QMUVygkWCb4qVSofiD+ODhVolXpnxuMtREqb
ZB37OR5vn4/7101EvN1+/+yn98fTafp4ujlvXqbDw/3h/PHud0Z87mL+785Y
caeKp8b4HdkzH1Ucdab4MxM7V3mzeMoW+VT5zOsVNWCMKK7DjPjUGbvnvGH1
poxdMSBbp06dHqiYVc3cvurydlmu0bnzPmh0tKsYmW8VV+WQ7zt1pz6J38o3
eh+U11ods7vdN1MsVR7Mpqtxx4b5XDA1/SJmVQ/Hb9ZPlXdeKz/5O9rTQfyj
+CpP5Avl48Zy3qdkIr2hYoz3GHuO6bCg3lC+573ZS3lfalDcQ76zbp08kfaY
ftEdpYFs3+2ji/UwZf+YulR8yK7iV+/r6rPiyvWt6rSIKXoB5ajquuBMGmQM
Tl2uYazqg7hcBoelYmQs1IboQNZnqMG4rlgQ+8Vo1EDlpPqiMyP9O1qocnW0
SfshsaDB4qvYjCXHGt/FYa906dSP5epw/gWLldtwpu46e5ZrVyOBOJt+u/3y
X/OH5Qsunivt
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 270->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k0tKA0EQhhsXkmuIN9ADDF4hnmAEXQWEZCHuPLomytDW/K9OtKEzmZ6u
v7563Ty9bl+uWmuHzdfPdn572O/n98fr48vzvLu/2x0/3v7s1j6mtjzVbuFZ
spWdWsv3TqN+RxrOjzpjtvVZGfvzaoc4mI+E2cXT503pMz+IEflNmBGfOmN2
SQ5dThm7YkB3kzol9U2ZVc3SuRrlHWW5pM+T/KA10ruKkWkrvyqGap/UPakD
iiuxUXGd28cqxyM5UywuDnZntMeTO0yT+Rnxjfidv7h3grjrf6WD4mQxndZU
NtBH/lWciy7JC8pbH4eL9Swmoqt89HaMvfpMWNBsKO3lneg7O9uDwg5pM3ul
jXrP1TXqM3B/dI5WNmaeTivsS8WH7jl+l/uqg/w7LlXTFsRZc6d4XF1XnOEM
JHW5hNHVB3GlDAmLY2Qs9I6pO63PtP7vWBA700xYor4lfqMal2fSCy7WpDfp
PIicIq16N2H+ZS96JmF3fZnUj8WacP4FSxRbd6Zsk3cWa9wjrdE5GtUdnZf/
2t8sn1JILS4=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 271->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk01KA1EQhBsXwWuINzAHGLxCPMEIZhUQ4kLceXTNRMJMp6q6OgHz4GUy
8/rnq+5+D6/vm+1dRHzc//5sxs/n/X78elkdXt7G3fppdzh8/NsR30Ocnv+1
VT61TufDcWd7FuMsh+Hn8C+Ygn9nugPYqBox5qoO87rJ+CQPYkR5HWbEp74x
P5SjO3eMXTEgW6dPnTtQMat7496rLm+XxeXrxFB6WI+UXidmtlVnTEP2d/ru
9AHpcnyUrkvnWNW4UzPFUulgNt0Zd2xYTJankxvxV/ns2TF05/8qDtLJNE1r
SBvER/mVzqou6Hyuo9J6EROJq3LM/Rg70unMAWORuUj8yq+cQeGHYjN/NNMs
FmNj+TtztuidqJniV/dpWuZcSr5sl2qnmCl7nPvknBWXuhdBuBbv4i7kvFVf
Gb9T66ov1zBW/UFcLoPDUjEyFmpT9L3qz7SMGc36YMxGD5QmdS86O9LTmYVK
qzObtN6ipihWtnWYF/5iZhz2ai6d/jGtrs5rWVxtcyanxuydabVnJHzbjsZb
7iPLDwcHK3E=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 272->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk01KA0EQhQsX4jXEG+gBBq8QTzCCWQWEuBB3Hl2TmDBdXe+nR9CGTjKZ
7qrvvaq6fX7dbK8i4u3m+2Mzvz/u9/PH0/Xh4WXePdzvDi/vfnbE5xSX77/a
LB9bl/fTaefzKEaXw7jn8DdMgf9HuqM4wzxCzNKHhV80PshTMVZ5HeYzj1O7
yuvSR5BbeYrYGUN11qnTyAwoZjY37lyN8o6yuHwjMZgeVCOm14mZz7J3SEO+
79TdqUOly7nDdK3tY+bxiGeMRek4LoNhNLfjpfJsJHeOz2I7cZschu78m8Wp
dCJNxzWlXcSv8jOdypfq/VKH0rqKCcRlORz2SqfTB4iF5gLx1T1Hnzs/Vcz8
X4B3eSmv1/YZq3ulo7yj5mdFr6C8zTL6nHof/Z2cU3GxuQjA1TyTWch5VV0R
v+O1qkvDCHid2cmxYG0Vw3kBn9mcsL6o+Lozou6wPlO/FUvF3sUU+mDfGsxO
XcueH+gFpdXpTTQPzNMqVj7rMOd+RD3jsKu+ZOdp7w3o/C2Lq23J5HiMnpFW
t0dyDOWhq/E/94nlC5RuLqg=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 273->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FOw0AMRK1+oF6j4gZwgIorlBMECb4qVSofiL8evRRB2Doz49mtxEpp
mmxsvxl7Ny+H3dsqIt7XXz+76ePpeJw+n+8uD6/T/vFhf9m8/7kiTtuY7/91
hdoTa94n37McqH4VJ/ljec+M7fschzhYDeYNYmF6kOfMF6ZnwQ7qOsyIT71j
cahGOXckrocBfev0yemvy6zOjXuuenl7WVy+nhxKD+uR0uvkzN+qPaYhxzt9
d/qAdDkxStfIHMf270L5ejxTLJWOlkUx9NZ2vKw866md86vcTt6rGobu/F/l
QTqZpnk184Lyo/pKZ+UL2m91VFpHmNDMVjUcdqTzFhZZi+Sv4hx97vlBOfO7
IHt5VV6PzpmaJ6QDxlTnZ2BWWF3lC2Om7LGMyTUrLnUuwtCZvVM8VV8pf86b
+ub05YqR8DpnB80K8qZkSNoUC31fsLAes3kv+9N4wPzPLIgd5jRZkH7F7PQV
emr64mh1ZhN6E8scaLH6qjZjCcKe++RqZXvO/I3qvJXF1fbrl4p1nplWd0bm
HIrTzNt7XqpzNBz/zXIGTtYt5Q==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 274->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FKA0EQbHIQvxH8gT4g+IX4ghX0FBDiQbzl6TEYl9mmqrp6Ay5slsxM
V1d11WxfP/bvm4j4vP/52U9fz8fj9P1yd/nzNh2eHg+XzYfrG3Haxfz9rzfU
nnjmfXKeYVR91Bqrzd/McVzPdeMcWD+2xjCVHjRziE/6II6or8MZ8VNrrA71
KHNH6joc0FnHJ8dfl7PKs3uvuny7XFx+HQylh3mk9DqY+azaYxpyveO74wPS
5dQoXWtzHNcX4XVmprhUOkYuikO3tzPLamad3hlfYTu4ix6GbjTTtRmEz275
rbhUOjN2x3tH6xpOOYdsPq4XrKfNBWhk2PN/gl/VOfrc+4Mw81qQvfxUs+7k
THFhM5M11f1ZkRXW9w9v7OveB8oPaFYeoBlUd4jpzLNTfCpfKf+Mm7x2fFlw
JHydu4OygmZTcijOqXuC/EFcWHZY3kt/ivwiLoi7q7vMv8HZ8RX1YNjME6XV
ySa7D2qmCCufdTgv6kVmHO4qC5WfMnsNnbdycbWNnKwZk32m1c1Ixi9nKM52
7wv17sazv1zOrZIuZQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 275->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRBs/xGuIN9ADBK8QT7CC+QoI8UP88+gaDGG3t6q6ehYcmCzZ
nel+1V19//q+P9xExMfd789++nw+naavl9vzn7fp+PR4PH98uOyI711cn/+1
Q30Ta/4dnWcxqjzqHbubn5mRsTIOlsNhrvSgmsP4JA9iRHkdZsSn3rF7Tg2r
mjJ2xYDOOn1y+usyKz+7c9Xl7bJs8blTH7Q63lWMLLbKqzTk+07fnT4gXc4d
pWvUx3HZKF6nZoql0jFnUQzd3E4tq5p1cuf4KrYTd5HD0I1qOupBuHbLZ8VS
6cyxO713tI4wsRqp89XsME9sYXFzOeccbd35QTHzuyDf8qpq3fFZ5XflLXin
mp8Br7C8qiaMudKLNKseoDhQnzMTYhaYTqZhxTnrzyqu4iYMo4yVV1BtXAaH
hb4vWKoeO7oXK80EmovMgthd3aX/DWanrygHi816orQ63mTzoGqKYuWzDvPi
Puulya680PXfqM6tLK62OZNTY/afaXU9co0hOFfnihpt3dX8VGf/WH4AcU0t
7w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 276->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tKA0EQHPwIXkNyA3MA8QrxBBswXwEhfoh/Hl1josx2qqqrZyEDm8fs
TNejqx92b9v9XWvt/f7nYzt9PB+P0+fL6vTndTpsHg+nl+vL09rXU/v/vtWj
8NTq36PzrEaGo/YU/8iJ7SvdDE+dRTWVnt/fTn2CgzgiXIcz4qf22D3Hw8xT
xl1xQGedPlVmIOOs8uzOVZVvlcuSnDv+oFXJruLIaitcpSHed/ru9AHpcu4o
XaM5Vh5XPFNcMh0uhyq242XmWQU71le1nbozDEO38rSaQblIfYSvdMaald47
Wkc4MY/UeSe3EXMpFxfLOedoq84Pqhn3GnkXV+Z1JWdZ3mlmumd2J5ufgayw
7M1WcR4oP6BZ9QDVgfqcmRCzEHGzvl7x7PoTMWMfyzkocMyyEn268ghx+FvE
ZzUnCBflDPU4Zt/SjBbxP3JB3GMNpi/Nv8HZ6avCyHxxtDrZZH4rT1GteNbh
HHsCe2lyV1moej2qcykXV1vPyfGY/Wda3YzEGqmHXT9Hsm/Nx8KzZy7fepQt
rA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 277->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk11KA0EQhJs8iNcI3kAPELxCPMEK5ikgxAfJW46uEaOTTlV19e7CJOzs
TNdX/bN+fd/uVhHxcf/9s50+nw+H6fhyd355m/ZPj/vzx4ffFXHaxN+/WlF8
7yylp57xOzrPYlQ6ak/xZya2r3wzPXUWxVR+UDwYn+ggRqRbMcfmf7k1QPyI
BWlXOWXsigGdderUmYGKWfWzO1dd3i7Lkj538oOeTu8qRhZb6SoP+b5Td6cO
yJdzR/ma28cqx52cKZbKh8vQ1XZyWeWso53jq9hO3CsNw7fKabcH5UPiI33l
M8fs1N7xOoeJ5Uidv9RHsWfNpSxMKwaWKp/5vexBcQ/FZvdRT7NYjI3pV31W
9bvqrUBxq/kx+1LxqXPuPFA+4FnVAMVh81D2n5gF5pN5uOEc6pM1Q3EHuRfX
cV3GqldQbm7yQHQv+4qF7hcsqMZZz/KMHjBLiAWx5xjMX9n/BrNTV2cWqpoo
r+yezE06p+rB9JU2YwnCnuvkelV5RXtOLiqfS1lcbyOTk2P2zry6PZJjlDkc
6jmn9635WHr/h+ULFEsrrA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 278->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0Fqw0AQG3Io+UboD9oHhHwhfYELzclQcA4htzw9DTUmXUsajX2oYRO8
ntFIWu3u8/t42kTEefvzc+wuh2Horh8vj5evrn9/6x8fX8cVcdvH9K9WJN8r
S81Tz/N3VM8wsjlqT/FvObF9pZvNU7UIU+lBeBCfzEEc0VyHM+Kn9lif42Hm
KeOuOKBa55wqdyDjrPLs3qsq3yqXNTl3/EFPJbuKI8NWc5WGtt85d+cckC6n
R+lammPlccUzxSXT4XKozna8zDyrzG7xFbaD+2eGoVt5Ws2gfAg+mq90Zr6g
72qW44/jPcJV9Q53pHMNFzYrxqwgfNVnZVD0IWzWjzLNsBg3Nr+Ss+o9CoSb
3Z8FWWHZU54wzplepFmdAcJZfCfEXWA6mYYZT6IhEmzGoe13OWbng7yZcWC1
Bhe6n+QMnXGQvsr5TLxJPcsnu1dMX5Z/h7NTv2aGo9XJJvNbeYqw2lqHMzqT
2VyTu8pC1eulOtdycbU9c3I8Zu9Mq5uRFiP10NT4n+uXyx3ROC8y
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 279->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk01KA0EQhQsX4jXEG+gBxCvEE4ygq4CQLII7j67BOMTO+6uZhQOdMDM9
Vd979fr25X3zdlVV+5vvn810eNrtpo/n6+PN67R9uN8eX96dVtXnY83/apV5
31mqn7rO36P9rIbro54p/pGJPVe6WT+1F9VUelA9WJ/0QYyob8JcgR7EjTQ7
D52njF0xoL3JnDpnwDGrPKfnqsvbZVmT88QfdHWyqxhZbdVXaRi/T+aezAHp
Sr5RupbmWHnc8UyxOB0pQ7d34qXzrNN7rK9qJ3X/9DgtpVt52s2gvAgP6q90
Ol/Qe9XL5SJhYh6p/Qk70rmGJe2V7Eu0dc8PqpnoRNlzXi/NWfccwby787Mg
Kyx7yhPG7PQizWoGqM7iMyHOAtPJNFxwns1n7KlqM4bx+5TRZQV5c8HA9gYs
jpGxoD0FZtadz8wdsCB26E/IEs8prLm2R6I1ySbzW3mKao17E+Yxj3CWv8uw
u1x2vJY6TZ01LKm2mSn0mN0zrWlGxhrWw1Djf64fli/BrzDt
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 280->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0FOw1AMRK0uENeouAEcAHGFcoIgwaoSUlmg7np0qKBR6syMx4kQX/qt
ku+M39j+25f33dsmIj5uv392w+fT4TAcn2/OD6/D/uF+fz68+90Rp8cY/9WO
4ryzVT61puconmlUedQ7xZ+Z2Hvlm+VTsUhT+UF6yiPyw77Pq9Rq9gDxIxbl
p/quw4BinT517kDFrHrm3qsub5dlzZw79UGrM7uKkWmrvMpD/t7pu9MH5Mv5
RvlaOsch+t2pmWKpfDD+7ow7MUyT5enkzvpK29G9ymH4VjXtzqBchAflVz6r
uqBzlcupj1N7pKviHXbkcw2Lm8uJc7x17w/SzO+CnOVV1XrpnE05gvQkx810
q/vzB7OCfDJmWnsjJ8qHdBbfCXEXmE/mYcY56U/OqbQZw1LGqj+oNrMcLJZw
qXui5gLxXb0HPev2Z+Q2WBA7rI/J0umTG78mh+PVmU1Wb1VTpJVjHeY8j7CX
l12wV3PZqbX0WeisYXG9XTgyi9JCz8yrOyMjhxHb8fif+4flC0KYMC4=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 281->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk01KA0EQhRsX4jXEG+gBxCvEE4xgVgEhLsSdR9f4x0zN+6tEsKETZqa6
6ntVry8fnjbbszHG88XHz2Z6udvvp9f788PD47S7ud4dPl597zHebsfvv9rD
fO9sVU+t+XcUz3K4Ouqd4q9M7L3SzeqpWJRT6UH5lEakh52vy+ZqzgDxIxal
x53rMKDYZE6dO+CY1czSe9Xl7bKc4vOkP2h1vKsYWW5VV2mo55O5J3NAupIz
StexPh5i3p2eKRang/F3PZ7EsJysTqd2za9yJ3kXNQLdqqddD8oVsjidri/o
u6r1J0zzXbjcfBQ70pn4AGlkuT9XYU+YnLZj7g/jZp5muRgbq9/xGZq58taK
fyzPKD7nyxVf2Pf0PjC+mhvOwORxnmH8tXeKx811xT+bz+I+hF5hPe0yOq+g
3qxqmFjF4hgZC4qpdyTSjFbxN2NB7Klu5/+EOYk/pUaiNfEm67fqKcpVYxPm
xXk2y59t2J0vO72WOk2eU1hSbXOmpMfsmWlNPVJzuB6mGv9zf7G8A73xMSo=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 282->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tKA0EQbPwQryHeQA8QvEI8wQr6FRDih/jn0TXBXTY9VdXVrgObsDs9
XY+uuX1+279eRcT7zc/Pfvp4PB6nz6fr08vLdHi4P5w2736fiK9dLP/qiWK/
8yg8tdb7qJ71qHDUN8U/c2LflW6Gp2pRT6kHzE9pRHpyPcJ1OK+5SM4x4jDu
DLvylHFXHFCtM6fOHag4q5m596rLt8tlS84df9DqZFdxZL0VrtKQzztzd+aA
dDlnlK6/5lh53PFMcal0uBy62I6XlWcd7Nxf9Xb6XmAYupWn3QzKZXKpdFa+
oH2F9S+cVl5nXuWMBHek08kB0sh6n9esAfRX56wMinOod85txmF7eVVe2zlj
eGDuWUfOxlJX3B/qZeVn4XvkfoQz9T7GM8hP5ZtzLxDG8i7uQuYj5xpj/exv
5L5mVpinaG7VvVFZQd4MHFCtyCzLGeOFuKCajGdpntdufCouSBP0x+Riz8ns
uRXD0epkE/odYw+0GL7CZlyCcF9mXnCvctnxWuos+mzh4mqbeaizzjvT6mZk
4aF4rvqo2u59obPbev7M5RvYqzFd
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 283->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FKA0EQRBs/xGuIN9ADSK4QT7CCfgWE+BH88+iaEIdNb1V1ddaBVSYz
0/2quvv+9WP7fhMRn3e/f7bTYbPfT18vt8fN27R7etwdDx/OX8T3c4z/6ovi
vPOpfGqN8xlPPkcxqjzqN8U/WADjPJ7SzfKpuyim1APqpzQiPfk+yuswd2qX
8zB2lrvylLErBnTXqVNnBipmVTN3rrq8XZY1fe74g1andxUji63yKg35vVN3
pw5Il/NG6bq2j5XHHc8US6XDZejmdrysPOvkzvFVbCfuRQ5Dt/K024OLdWZQ
zCi/0ln5gs5Vrn9hmnmducoaCXak0+kDpJHFHnsSv3rn6HPnZ85Ce4yc5VV5
bfcZywfqnnWM33PcYn6ol5Wfhe+R4xFm6n0s3yy0Ii4Q5+qZELOQ88q6Ik6i
IYrYjCG/dxmrXkHeLBjQXZOlYmQs6E6eEUvz35p7n/qbsSB26I/JcrE3mJ26
dmYB9pjoSaad6c5LeYpinZaRm7EEYXd6Ve3zmeO11FnEWcPiastslcds34kn
e8DkzLXs9r41H2vfn1h+AKZZL6A=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 284->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FOw1AMRC0WqNdA3AAOgLhCOUGQYFUJqV0gdhwdikqUODPjcYL4Uhql
/3/7zdi+eX7bv15FxGn3/bMf3h+Px+Hj6fr88TIc7u8O583byxPx+RDj+7+e
UHtijfvkPItR5VH/sbv5nRmn/+d7iIPlcJhLPcBzpRHpyedRXpe5U4P8Ruws
fuUpY1cM6GxHs+N/xaxq5s5Vl7fLsqXPHX/Q6vSuYmSxVV6lId936u7UAely
7ihda/tYedzxTLFUOlyGbm7Hy8qzTu4cX8V24s5yGLqVp90eXKwLg2JG+ZXO
yhe0r3L9CdPE68xV1kiwI51OHyCNLPb4TeJX9xx97vxMWWiPkb28Kq/X9lmu
eYBYixw5bjE/a3qFeTNbzXlgfDl2VQMUZ/VMiFnIeau6LjiJhihiM4Z832Ws
6oO8WTCwswZLxchY0Jk8I67mkRXMkGJB7NAfk2X2bTA7dWU+2b1QaHV6k84D
qFleqE5VbsYShH1ae8Ve9aU6L3tvmjfVx4ndYXG15dpUHrNvptXukd8Youbo
XKVxyxNb7/+wfAHl8DEg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 285->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1tKA0EQRYt8iNsI7kAXENxCXMEI+hUIxA/xz6VrMAxjTd1HtY+GzjCZ
7lvn1mP7eNw/byLi5frzZz+93p9O09vD1fnlaTrc3R7OH28uO+J9F/PzvzaL
x9bye3Ueaag47D/Gn5nQ/8w3isfOVprUT6HHPFZ+0P28HOZODfKzYkf6KqeI
nTFUZzuenfwrZlYzd666vF2Wn/S5k59qdXqXMSJtFpd5yPedujt1qHw5d5iv
0T5mOe7kjLEoHy5DN7aTS5WzTuysz7QdXbenqrhIG31HvqvlsiifKi8spuN1
iOmysy6L4bBXPp0+qDwi7fkd6Kt7jj93fpYssMfAt7xUrkf7LNc8Cq1VjKwr
5mekV1Buvq3mPCC+rK1qUOkMzwSZhRxX1XXFCTyE0EYM+b7LqOpT5WbFIM4y
FsWIWKozeUZcz6tlslTsrm/Z/wazU1eUJ7sXhFenN1G+q/6BZ5Iei41YArCH
ya76kp1XvbfMBeL8DRbXG2JhWtU78ur2yKzBOE3d7rz81f5i+QAc1TDr
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 286->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRBs/xGuIN9ADiFeIJ4hgvgJC/BD/PLpG3GW2t6qrehUHJiGZ
merX1d3XTy+7w0VEvF59fez2bw+n0/798fL843l/vLs9ng9vfnbEx33M39UO
cd7ZVbxqzecDTz5HGipO9V/FP7MAxlGvypvFq+4izTIfoFfliPJh7/NymDs1
yN+InekrTxl7xYDudnJ2/FfMVc3cuerydll+0+eOP2h1erdihEvErXIY76i8
rJ6YNsjLYUHslU/dHLNex7OKReXhMnRjO14qzzqxs36l7ehaPUXiMm12zvJe
rPG9waLyVL6g88UsTUwNfyTToJe5ttSCxXRYWL2Y9vyb6Kt3Tn7u/IwstMfI
WV7K6619lmseQGsVI+uK+dnSK8ybxTL6HNVO9ZCqAdLZPBPFLOS4qq4rzqE+
i3kwe4V5ymbLmR3UK8ibFYO4W7EoRsaC7uQZsXKe1vjWZEHsbt6y/w1mp67M
J8eX3I/Md9Wb0O/xHjnPWqNeFZuxBGEPk131ZXW/7L1YvmGcf8Hi5jb5lVmo
x+Sc5er2SNaXHpo5/tcO9N83yyeRoS+g
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 287->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KBDEQhYML8RriDfQA4hXGE7SgqwFhXIg7j64jTpOuvL+oGMgM3amu
+l7Vy+XD8+7prLX2cvH5s1te7w6H5e3+/PjwuOxvrvfHw6vv3dr7bVv/1W7m
fGaremqt5x1PPUc5XB31TvFvmBp/r3SzeioW5ZR6QD6lEelh39eVMM/MoP4j
dpbf9ZSxKwYUO6M56b9jVjNL79Us7yzLb3ye9AetGe8qRrhMXaWhj3G6Ik+c
NtCVsCB21SeXt3VMKN9MzxSL08H4Zz2exLCcrM5M7Zpf5U7yRp4idVluds50
b1bg1Zpf6XR9QedrXPHwnzGRHindm1o9G9DCvJh41vltfe5ZVFx5TvSl96dn
oR4jZ3W5uf7UZ5uZdzxIRz9f9DxoM32tNQa+sO/K52h2zkNuBiiPvROEv/ZO
8bi5Dpz9HSD+Snmrn2cY3XxQbwYGE6tYHCNjQTH1jqSaB9aQBbGnuq3/A+Zk
rqxPsReM1sSbrN/sGxbT51O1aV42y5Dd+VLFO++x+SS5Z1hSbad+qW9hjwEL
0pp6pO+Ji53R+F+7oXdfLB/OYS7l
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 288->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOA0EMizigfgPxA3gA4gvlBYsEp0pI7QFx4+lQiV0m2dhxuoiRpqvu
ZB3b8dw8v+1fr8zstPv+2U/vj8fj9PF0ff7zMh3u7w7nw9ufbfb5YMvzvzbr
x5Y7T+oRRtWHvWP8V5zAe6Yb9WO1GSbVk+AxjZke9H1cJVZzBvGZcUe9mac2
7yaHrFaZUzVfU+sAptIP8VL4drlsyXmVz0wPmhHTq2Auq+jLNIw1lS5lj9lV
Pcv8ibyQTxXuzAd53PGMcal0IP7djCs1CBP16fSO+AxbwZUyBfoibHSOdLsl
ZDXiM52VL9n5UkcyvIkT8Ijpdr0amVBygLgwn5w3rC78V/Sp92fkAjMGzuKq
5nppztzMBz6ZjjjfbN6MX5XLFT/Rd4gHZldlqJpBhqPcCct6kruAdCINK55A
Q7wTylxinhWOmf8RC812xaGoZVyWRTzMuGQ18Y6w2VBNIpdMk6qbYauclfot
PRStSjaR3+gbVBM5KZxRxlytyL3KZcdrpDPmT8HucFG1zX6xbx33YUfcTKua
EYdf1Lr3F2b/r3fk8cvlC9LoLqI=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 289->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKQ0EMRQc/xG2IO9AFFLdQV/AE/SoI7Ufxz6VrwTdmMrk3Nz5xYFr6
Xpqce5PcPr/tX69aa6ebr4/9cn48Hpf3p+vLj5fl8HB/uLy8+76tfexa//6v
y+qxM7wP4lGOrA57xvgnJvCc6Ub1WGyUk+rZte5XtQeIMaqrMFsWytzmOogd
1WaerhxVhihW6VPWX98fppX1TN2rKm+VZcucZ/MZ6UE9YnqVnP0kdZkGG5Pp
Uq6dXdWzyB/PhXzK8q48yOOKZ4wl04H4qzOuxKCcqE6lts/Pcit5pZkCdVFu
9B7pjo7KkunMfGE11z2KZngLE/KIxQ+1CjOxhYX5NHjD4txvRZ+6P5ZF8RDl
Qv9B9StzNsySYY10wB1J9kedy4lP9J3NOfJXnc+QK8iT7gTg994xnqyvE2ei
AeVGDJEHNI/Yn8ibiSGJZSz9EA8jlijG7wjrTdYfhSX6j6o7m3+FWYnfUkPR
qswm8tvOT7QPPpdnUpgZi92FfoR4NJcVr5HOlaeSu8KiarNeSB6b6/NGWtUZ
GfInscPzX87+X1/P8cPyCXX5MaI=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 290->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KA0EQhQsX4jXEG+gBxCvEE0Qwq4AQF+LOo2uCE3p63l9n0IbOkJnq
qu+9qr59edvsrqrq/ebnZ7P9eDoctp/P18c/r9v9w/3++PHud1d9Pdb5+V+7
1DexZt9BPMvh6qh37Gz/7Bnb9/05xMFqJMxOD8qnNCI97Hy/bK6m/4q550aa
nYfO07qAAcUmfUpYojiSM6nHuBLeUZY1c+7mE+lhPVJ6k5znZeoqDW2M05Xs
amY39Qz503Mxn1zeiYd5POKZYnE6GP/ojCcxLCerM1K7z69yJ3mjmSJ1WW72
nelGK2VxOp0vquZ0j9AMr2FiHqn4Wa2BmVjDonwqkt+dS/Sl96dlSTxkudgZ
Vn9kzhbzJGaG3hFzf9K5dPz2PhBmyQ4YXA9QHnsnCH/vneJxfV1wGg0sN2NA
HiSMrj/ImwWDiVUsjpGxwPkDPbu0PwkLOpPqdvOfMCfxa2qgWVX5nG7k9WmZ
fsxWUDtlYfpSrcpX9C7xYuIZyT3CkmqbvFZnF54RdqQ1nZHWExe7ph9/tQu9
O7F8A+19NiI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 291->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KA0EQhRsXkmuIN9ADiFeIJxhBVwEhWYg7j64RJ/Z03l85YkFnyEz1
q6+qX189vmyfL1prh83nz3Z6vd/vp7eHy+Ofp2l3e7M7frz+Xq2937XT879W
U99ELL6DfKbh6qh3bO/4HBn79+M+xMFqJMyuH6SnekT9sP1jRFqFM0D8iEX1
4/ZVGFBuck6WpcCsziy9V1XeKssanzt/on7YGal+E81TmLqqhz7H9ZWsNi/Q
V8KC2NWcnO7Mw2ZcmZlicX0w/qrHkxymyepUao/6SjvRjTxF6jJt9p31jSJl
cX26uaia8z1CHl7DxGak8he1Cp5Yw6Lm1Ii+25f0l96fniWZIdNie1j9is/O
/CQ8Q++IuT+pLx2/vQ+EWbIDBncGSCe5Ew3VFHdBzYMxLjhND0ybMaAZSJ3w
fEatkfcrTK5imfePPOj8EN/iPTiz6vkwDsSCekr7dv5PmJP8NTWQV5We63sM
5B+aM0dQO2XpPZPmK19WZn0WvXeNzhqWtLc+KjNGLKle4gHrp279xvt/vUaO
H5YPqD4xpA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 292->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FOw1AMRC0WFddA3KAcIOIK7QmCBKtKSGWB2HF0WkSqxJ0Zj4nUL/1G
TfztN/7jh5f33dtdRHzcn3524+fz8Th+7TfnP6/j4Wl7OH98/NsR30Ncnrfa
ob6JtfgO4lmOqo56x87mZ2acv8/nEAer4TBXelA+pRHpYefz6uRSzJkbaa56
WPWUsSsGFOvck3O/LrO6M3euurxdljU+d/qDVse7ihGuoq7SMI+pdFmemDbQ
5bAgdtWnKu/Ew3rc6ZliqXQw/q7HnRiWk9Xp1M75VW4nr+UpUpflZt+ZbrRc
lkpn1RdVc5oj5OE1TKxHKn5Rq+GJNSyqT0HyV+ccfe78zFmcHrJc7Ayr3/HZ
lZ+EZ+iMFPPj+rLiL+eBMEt2wFDdAcrz75kQs6D6wRiv2AqvuveS/RwpN8xj
3k+ulXl/VxGrNF2W6CFigf4Dd9a9H8aBWJAmV3flf4fZiV9Tw9HqeJP1G/mH
xkzLqO2yzGehE8982ek11Dksn27uDourLbO5PUYsbj7HA04PY9A9uOXmLD9I
yzNl
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 293->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9llFKA0EQRBs/JNcQb6AHCF4hnmAF8xUQkg/xz6NrxA2b3qrqakYcWIPZ
nu5XNTWQu5e33f4mIk6b7z+76f3peJw+nm/P/7xOh8eHw/nl/e8T8bmNy+d/
PaHeiXX1HtSzHtUc9R3bmz8z4/L7vA9xsBkOc6UH9VMakR62P69OL8WcuZHm
ysPKU8auGFCtc07O+brM6szce9Xl7bKM5NzxB61OdhUjXMVcpWFZU+myMjE/
QJfDgtiVT1XfmYd53PFMsVQ6GH83404N68nmdGbn/qq309fKFJnLerP3TDda
Lkuls/JFzZzvEcrwCBPzSNVfzWpkYoRF+RSkf7XP0efenyWL4yHrxfaw+Z2c
rfIkMpPPF5234qtyueIzfVc5Z/66+bys5I3q27oT4i5QnUQDqg8w080K8zSW
j+pjnk+elXl/VlEr/RKMigXVqBwoLzOry4L2uLqr/DvMTv3IDEerk03mN8oP
rZmXMdtlWd6FTj3LZcdrpNM9sxEWV1tsY/XbxfEYsTCtjAXVB+NEfQey/9cP
Z/kCLTI1IA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 294->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNllFKA0EQRBs/xGuIN9ADBK8QT7CC+QoI8UP88+iaaMJsp6q6OgviwLi4
29P9qrsGcvv8ut5cRcTbzfef9fT+uNtNH0/X+39epu3D/Xb/8e53R3yu4vT8
D1ut2XcQz3JUddQ7djY/M+P4Pp9DHKyGw1zpQfmURqSHnc+rk0sxZ26kueph
1dMYt8mAeJ05OfO1mMk5px7jcni7LEt87vQHrY53FSPLreoqDfm8M3epHXi2
yo36g3Rd4uMjD+txp2eKpdLB+Lsed2JYTlanUzvnV7mdvJanSF2Wm31nutFy
WSqds9Wc/fEeIQ8vYhrzxjyPNYuGJxwfZHaVG+V04hxt3ftzegqPMf/lVc21
4zPq94EV6cjzRfNWfJUvz/jMviufs/66/pwtkefiOyHuAtVJNKD4KLzqziX7
uWLMnJWnlJbDKmJlvwSjYkEx+Y6ouTvzqVjQGVd35X+H2Ymn/EYNR6vjTdZv
dobFHJZR22UZezHmd7Wq2aF3VS9cXyxhcbXFKs5+uzg9RixMK2NB8cE4Rd3O
PP5y/7B8AT2xNCI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 295->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FqAkEQRId8iNcIuUE8gOQKeoIV4pcgmI+Qvxw9GtTs9lRVVysEB9ZV
p6fnVXf182a/2j611j7mx4/V8Pl2OAxf69npx/uwW7zuTpsv56e172W7vh/h
UWu8j+JZju4O41zGGN+RkbF2HKT+7D+WU+mBd5O6MD3sfFwZM/qOmCM30ox0
On2bnAM9UAyI1+mT01+XWc2NO1dV3iqLy1fJofSwHim9Ts4Yq/aYhnje6bvU
Djyb5Ub1Qbpu8fGFh9W4UjPFkulg/FWPOzEsJ7uncnfMr3I7eS1PkXtZbrbP
dKPlsmQ6s7qoOy9zhDx8F5PgsnpR8ITjg8iucqOcTpyjrTo/jDvLjbyX9fVW
n3V9F56hM5LMj+vLjs+su/I5q6/rz8kSedKZIPwxp+RJ+orq0hKvurwTxvGj
8pj9QbXpGJJYpUkxKhYUE2dE9d3pT8aCzri6M/87zE485TdnItPqeJPVm51h
Mb/LuNtlGdeiEs98Wekn0un64h4WV9u41pUaIxamlbGgeCf22kvg73j2v57I
8cfyA6ErMmU=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 296->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytl0tOA0EMRC0WiGsgbgAHiLhCOMEgkVUkpLBA7Dg6ZAStGVNVLjNpafJr
u/qV7V7k9vl1f7iKiLeb75f99P54Ok0fT9fnLy/T8eH+eN68+3kiPncx3tUT
xf6lHrXG/oIn7yMN5KXKqxhXLIBxqZfzEAs7g9UGshA/SE95RH5Yfl4dLcWc
uZFn5NPp2yoP9EAxIF6nT05/XWbVM/dedXm7LC5fR0P5YT1Sfh3NHKv2mIec
7/RdegczW2mj+iBf/5njXx5W407NFEvlg/F3Z9yJYZrsnM7ZWV9pO7rWTJFz
mTbbZ77Rclkqn7AuRZ9yHJrhizAlXeV7lduYCWcORpwxb0jTiXO8de8P4660
0exVfbV6WrCg+iIu1W/Fx+ZX3QOn7hWzZE85qJ7od6Vbca2+i7ug6sEY/7AV
s+ry5nmOpF3NszNTzMu8iljlSTEqFhSzvENK0+1PxYJyXN9VPxxmJ37LGY5X
ZzZZvVkOi5mXcbbLMj4349lcdmqNfLo928Liesv1dmuMWJhXxoLindjRy13A
/w3d+yL7tyV3ZvkCciU0Xw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 297->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk01KA0EQhRsXkmuIN9ADBK8QTzCCWQWEuBB3Hl0jYZipvL/SDEyGdFe/
/l793L287fY3Y4z3zc/Pbvp4Oh6nz+fb05/X6fD4cDht3p/fMb62Y/6qd5j9
a73qmfdJPNNw96g1drZ+K+NyvZ6reYXrZI1pKj9IT3lEftj5+nS0FHPlRp6R
z6Rurk8UA4pN6pTUN2VWNUvnqsvbZUn5OhrKD6uR8pto1li1xzzU80ndpXfh
K2FRvv7Sx+PMxHLcyZlicT4Yf7fHkximye7p3F31lXaiG/UUuZdps33mGz0p
i/Pp8qLunGcJ9PBVmEpOlO/V2UZPJH1Q2ZU20kziEm/d+WHcThv1nqtrp6a0
303P0Bkx80P9unyGeXfMkr2cQflE60rXca3+i1lQ+WCMF2ymV1PeFWPhVjpJ
fVBuLhhMrGJRjIoFxVTvqu5JfRwLOpP6dvVImJN4yh/OhPOa9CbL92rN9Rhg
SpgVyzIXiMN5VbVDay4XaV/8hyX1tsxHJ8eIhXllLCg+iV3Vs1mP7qvmx579
ZfkGVLgz5w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 298->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0Fqw1AMREUWJdcIvUFygNIruCdwoVkFCs6iZJejty6u+Raa0cjOooYk
5FsavZH0D++f3XlnZtf9z1fXf70OQ397exr/fPSX0/EyvnyePmb3F5t//8OH
PfN7EI80sjrsDOX6X8/Ynvu8hRY6B2dIk/n5q5PpozpRT6K6CrM1LIy51fe8
EQvzQ/PAnBBDFKvMSZmvysxmpt6rKm+VReWraDA/aEbMr6LpY9k75MHnK3On
3okvhYX5WrPHNjGhHld6xlgyH4i/uuNKDNJEdSq1vT7TVnSlnQJ1kTZ6j3xH
j8qS+cz6wmrOdynY4YcwuZ4w34vcwk4oe+DZmXakqcQp3qr3B3Fn2tHuZXNd
u2d+n9KdSebN+ND+Qr6k7yFLwsp6EvWn2rfynSB3wdfN5moBi4GaTBsxRD2g
Ookuna1nSGIZC2NkLFFM22OmiXYoy/EsUY7qm2mrzEr8lhqKV2U3Ub9RDorx
TAozY2nvwvwI8WgvK72OfKoz28KiekNxWY8jFuSV1fDxSuzifOXuy3dpS+4v
yzc/lDZh
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 299->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KREEMhIML8RriDfQA4hXGEzxBVwPCuBB3Hl1nHJu2TFUq82Aa3vy8
TtJfVdLXT6+bl4uIeLv6/tgs7w+73fLxeLn/87xs7263+82b4xPxeR/j+1xP
qD2xxj6JZzXkORNPlTPn4jcyzu8xD70Y8ckZzJuMhfmQ1VMaMz0sH1dZq/A7
Oxt5Mxalp8rrMGSxTp8qlg6z6pl7r7q8XRaXr1ND6WE9Unqdmhir9pgGzHf6
LrULXQ6L0nXKHMeRiXnc8UyxVDoYf3fGnRhWk53TORvrq9pOXWumyLms9tgn
7zNmXC5LpfOwgCXTk+WHmOFVTHPd+FvH6kVjJpw5QHZVO6vpxDnauveHcVe1
s9mr+mrNWRKPfe/OzGEV94fqrfw0fVfMzF93Ph3frDtB+NE7xVP1NcCz4TF4
7c6K8tRhxPe/jFWtfx4leTQuYVGMiiWLmT1WNdkMVTnIkuW4uqt+OMydOT/l
DEerM5vMb5bDYpDJYVYs43czns1lx+tMp9uzNSyuNhZXeZyxMK3qDIx3Ytf0
45zPD8sX5xQ5Hg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 300->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOw0AQG3FAfAPxA3gA4gvlBUGCUyWkckDceDq0lGoztT2eROpKISU7
47G93tuX983bVUR83Pz+2UyfT7vd9PV8vf/nddo+3G/3m3fHJ+L7MU7vSz2h
9sQa91E9w5BzBj5Vz9ib35kj44q8gN/JN4apfEB4SiPSw/rzKrEKv9HszBdx
UXpo3/iYHBBf55yc87U4kz5nHuPl8O1ycfl1MJQedkZKr4OZa9Ue05D7nXOX
2oUuh4vStSTHceTEPO54prhUOhj/bsadGobJ5nRmZ3yF7eBamSJzGfZpn3xH
nPNyuVQ6DytxQXpQf4gMr+I04sYcxzqLRiacHGTuChthOnWOtu79Ob1Fxlj+
8qrOdWnO1mbmH1fdHzqj8tP0nd4b4a+bT8hLaFJeBpop7oLyA3IENXn26DvT
wTjM+k0cJyt51plHoI/WAS6Ko+KCakaPFSbLUNWTuaAeV3d5HgbnTs5dT85y
JbLEtDPdyGv0m9UcljHb5TJ63alnuex4jXS6Z7aGi6uN1VUeIy5Mq5qR653a
WV4XZv8Szx+XH028Nhg=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 301->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FKA0EQbDyI3xB/oA8QvxBfsIKeAkI8iDefrqtxmfRWVVdvwIFJyEx3
dVVN5frpdfdyERFvV98fu+n94XCYPh4v5x/P0/7udj9f3hx3xOd9LN9qR3Hf
2QpLrZN7UM8w5JyBT9Uz9ubvzHE8z33ZC3hOzhim8gHhKY1ID+vPq8Qq/Eaz
M1/ERemhfeM2OSC+zjs572txJn3OPMbL4dvl4vLrYCg97I2UXgcz16o7piH3
O+8utQtdDhela0uO48iJedzxTHGpdDD+3Yw7NQyTzenMzvgK28G1MkXmMuzl
npwjznm5XCqdPytxQXpQf4gMn8VpxI1THOstGplwcpC5K2yE6dQ52rr/H8a7
wkbZq97Vytm8RN63ZGbEhHdqRuWn6bvizPx18wl5CU2V96uZ4r+g/IAcQY3S
wHQwDohLheNkJc9aeQT6aB3gojgqLqhm9FhhMv+rnswF9bi6y/cwOHdy7nqy
ytXfJlqdbKq8L6vKWMJTs10ukFdDq/IVnVVeuG92DhdXG6urPEZcmFY1I9c7
tTmvW7L/H/uXyxcqHzVd
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 302->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk01qQkEQhBsXIdeQ3EAPELyCOcETdCUIZhHceXSj0fBsq6qr4yIDE8mb
/vmqp2a62i03k4j4fP3+sxy+Fvv9cPh4Of+zHrbz2fZ8+HbdEcf3+P1VO4rz
zlb91Lo7B/GsRtVHfVP8D0zku9Id7Dv5xmoqPaie0oj0sPy8ylojLynmzI00
I50d38V4mwyI17mnzhuQzCTP6ce4HN4ui8vXqaH0sDtSep2aOVadMQ0537l3
qV3ocliUrr/4OK5MbMadmSmWSgfj73rciWE1WZ9O71xf1XbqWp4ifVltds50
o+WyVDovK/VGesr8xnxKJsFl3UXDE44PMruqjWo6cY627vth3FVt5L3qXi2f
gfhnPXNZxfuhPap5mnOn70bM1/Vnd25y9qineAtMJ9MQaWZMQxS1GcPdDEzP
OV7JvR54QR6NAyyKUbGgmPGMVU02/yons6AcV3d5HwZzx+fuTBCz0up4U/r9
tiqPASaHWbF07qzK784a6XTv7BkWVxuLq2aMWJhW1SPHO7Edjf+5f1hO7w41
pA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 303->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0tOA0EMRFssENdAuQEcAHGFcIKJRFaRkMICsePokI+iieMqPycLWpqM
Mu0uv7Ldj6uP5fpujPH58PeznL5et9vp++1+9+d92jw/bXabi+Mzxs/LOL3d
M4r9zuO03JrvZ/FKo8rjvqmz8R0ZFWtWi/S7+KY0nZ9Mz3nM/KjzcZVakDly
Z54zn6RvZ7UHM1Xxkj6R/iJmcY7kU1yEt8tC+Toazo/qkfNLNGOs21Me4nnS
d+vd+CIsztc1czyOTKrGnZo5lsqH4u/OOIlRmipPJ3fUd9pEF82UyKu01b7y
nS3KUvncr5A781Oeb9SnZDJcqBeNmSBzENmddqZJ4oi37v1R3JV2NntVX9Gc
JfG3zsx+FfeH5rjgg3WXeqa+dD7PVuMeUJ9R0/Gousz5nMfMG+VVc1zpkFnJ
anPBUMTaehlGx5LFjKRnpPeRlbJkZ6jvsh+AuTPnnbsR9Z1XMptu3k9r1j8Z
M1huymJ7Bu6Lq2v2raoF7dktLFUtyGy7GmcsyqvLEeNJbMfjfz4Hll++9DXl

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 304->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0tqQkEQRRsHwW2IO0gWIG7BrOAFkpEg6ECcuXQ1auhX1v2UDtLQPuzP
rXOrqmdfm9XPpLW2m55/VsN+ud0Oh8+3y5/vYf3xvr5szm+zteOi/X3ZbGK/
MpkWG/1+dh5pqDhsDd2N38iIWLNcpOtgDWkyP5ke85j5QffjkFomc+TOPGc+
nbqNcm/0lOJ16uTU12IG95x4iMvhrbK4fBUN5gfViPl1NONZtoc8xPtO3al3
4sthYb6e6eN2Y0I5ruSMsSgfiL/a484ZpIniVGJHfabt6Fo9BeIibbSPfGfD
ZVE+f0eInfmR9wv5kUyEy6pFoSecPojsTDvTdM453qrvB3Er7az3VF2f7bNX
e+auy94PjKHyaeYdvhuSX7c/R6PwDihX/5+8BZYPyEg8Zt5c3hFjP4WO0ytZ
bh4YxFnmiTEyluzM3bfbB8iTy5LdcX3LehjMlT5nmqomzKvTmw86oU79Whwo
PovtsrCayfoQFqf/Mp9OX7zKonLh9Haa465+URd5ZTHieedsxeN/zivLCSmk
Nt8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 305->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FOw1AMRK0uENeouAEcAHGFcoIg0VUlpLJA7Hr00qqgxJkZjxOJL6VR
+v3Hb2z/7dvHbr+JiM/7n5/d8PVyPA7fr3eXj/fh8PR4uGw+3J6I03P8vf/r
CbUn1ngfxTONKo/6j53N78zIWBkHy+EwV36QnvKI/LDzeZVaJnPmRp6rGlY1
jQUMKNbpk9Nfi5mcc/IxLoe3y7Jmzp36oNWZXcXItFVe5SGfd/ouvQtfDovy
tWSO48bEatypmWKpfDD+7ow7MUyT5enkzvpK29G1ZorkZdpsn/lGy2WpfFZ1
qXJeF5jhVUxj3cRl9aIxE84cZHaljTSdOMdb9/4w7kp7Vkejr9acNVmQj3xm
won2VI6qnmbdFTOrrzufk9W4B4pr8i3uAvPJPKB4tqe0GcOYOUwdZ1ZQbWYM
RaxiUYyKBcVk727vM6vLgs64vqt+OMydOV+Sw/HqzOZMh81KMTuZyWFWLKpn
zn1RdUX/qdnr9GwNS1UL1BOrxmRfeWUsKP6XBfG4ut37Ivu35uyV5Qy8Fzei

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 306->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRJt8SK4h3kAPEHKFeIIVzFdAiB+SP48eo0GyTVV19Q46sFk2
09P9qrvm/uVtt19FxPv662c3fWyPx+n0fHf5eJ0OT4+Hy+bD9Yn43MTv+7+e
UHti3e6jeJajqqP+Y2fzOzMyVsbBajjMlR6UT2lEetj5vMpcJnPmRpqrHlY9
jQUMKNaZkzNfi5mcc+oxLoe3yzLic6c/aHW8qxhZblVXacjnnblL7UKXw6J0
LfFxXJlYjzs9UyyVDsbf9bgTw3KyOp3aOb/K7eS1PEXqstxsn+lGy2WpdFZ9
qWp+L+DhEaZZ3sRlzaLhCZcl12e5UU4nLtdn/VTnUG7EXemEzMVcl/ps1DO3
bHBP1aj6afZdMbP+uv6crcY9UFyzb3EXmE6mAcWzPZWbMXQZIQvxutKCztE4
wKIYFQuKCTCzkflULOiMq7uah8Pc8fmSGo5Wx5vK79Vi9VVtl0XNzLkvqq/o
v6oX7sxGWKpeON5WPUYsTKuqkeOZrk7e7n35q+eH5QwwPzcq
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 307->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk0FqQkEQRBsXIdeQ3CA5gOQK5gQ/EFdCwCyCO4+e+Pl8tKmqrnYGRtGZ
qX5V07P9/N4fNhHx8/z/sZ9+30+n6fzxdP3xNR3fXo/XxZdlRlx2sX6rGcV6
ZyotNdb1G428jjRQ/eqc5M8sgPFWL5+74yD5s/+YpvIDa5NckBbKBNV1mMNk
ztzIM/Lp3Fu3Dype556c+7WYyTmnHuNyeLssLl9HQ/lhd6T8Opp5r1pjHvJ5
596ld+HLYVG+HunjWJhYxp3MFEvlg/F3e9zZwzRZnU7trK+0HV2rp0hdps3W
mW80XJbKZ5VLVXMeoIdHmO50E5dzF52ecFlcbaTp7Mv1WZ7qHNJG3J3sqj5m
Z9w+G+2ZeRTvh9ao8jRzp+9G5Ov2Zzc3+ZZQTfEWmE/mAe1Ha1FoM4bVh8kI
WUivKy/o3MqSMkQsilGxoD1o78j9VCzoDMzHZLH71dQcreF4dXpT9nsxWH1V
22VRd+a8F5Ur+q/Kwr2zEZYqC6e3VcaIhXlVNfL+WKaToeNxZGaO9vmZ5Q/d
aTSk
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 308->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk1FKA2EMhEMfxGsUb6AHEK9QT7CCPhWE+iB969G1P3XZpjOTiRvYljZ/
km/yz27fPncfm4j4uv/92E3fL4fDdHy9O/94n/ZPj/tz8uHyRJyeY/5WTxT5
zqN6qZjzix45j3qg+VWd5I/b78y4/D/XIQ42g+0GsTA9cDbZC9PD6nNUzGEy
Z26kGel07q3rg4rXuSfnfi1mUufMY1wOb5fF5ev0UHrYHSm9Ts98VuWYhlzv
3LvULnQ5LErXf3wcFya2487OFEulg/F3Pe6cYT3ZnM7s3F/1dvpaniJzWW+W
Z7pRuCyVzmov1cwRwMNrmK76Ji7nLjqecFnc3qincy7PZ/tUdag34u7srvIx
q3F9ttYzI4r3x51R8Vfnqp0xPqYvR+c9yF4KNlO8C9X+EKPSOOKPR/RmDHO9
yQhZiNeVFlR3paXwm2JULMx/HR8wTS4LqoH7MVmyLyvmjs9VT+kx4Ummneme
A/iCxc0ZY7bLstxLPl/eT/Cc4z+k0/HFWpZqF463qU9AXmlVM/L5EeYOHY1r
nszRrh8sP3/aNaA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 309->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k0FKA1EQRBsXkmuIN9ADBK8QTzCCWQWEZCHuPLpmiHGmp6q62sGGSUj+
/92v6tfcvbzt9jcRcdp8f+yG96fjcfh4vj3/eB0Ojw+H8+L95Yn43Mb1Wz1R
rHceNU/VdX3Ck9dRD6SlOufwz5iC/690U0axF/VUelA/5gvTw87nqpjDZM7c
SHPlYeWpm4OK17mnzjsgmck5Zx7jcni7LGty7viDqpNdxch6q7lKQz7v3LvU
LnQ5LErXX3IcFybmccczxVLpYPzdjDt7WE82pzM791e9nb5Wpshc1putM92o
XJZKZ+VLNXMskOE1TLO+icu5i04mXBa3N+rp7MvzmZ/qHOqdezk6Z722Qe+X
zZc5a7AsdCCfJj3hmppR+On6Dj1LWhUf05er8x4sdLKZ4l2o/EOMSuN0purN
GMZqMDIWlHWl5WfuYi/xtnpPFCfiY/+rnu79VCzoDPTHZMm5rJg7OVc9ZcZE
Jpl2pntW4g6Yh/mcypHDMvUl7y/vJ/iakz+k08nFWpbKCyfbNCdgXWlVM/L+
sQwPp3nt3Md/PZn5l+ULJrY0ng==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 310->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FOw0AQQ0d8IK6BuEE5AOIK5QRBar8qIZUPxB9Hh1ZNSSa2x0NYaRul
uzvz7HXuX9+2+5uIeL/7+dkOH8/H4/D5cnt62Q2Hx83htPhwmRFfT3F9qhnF
emeqfmpM19F+VgNpqc45/JmJ/a90U0axF9VUelA95gvTw87nUTGHyZy5kebK
w8pTNwcVr3NPnW9AMpNzTj/G5fB2Wdbk3PEHjU52FSOrrfoqDfm8c+9Su9Dl
sChdf8lxXJiYxx3PFEulg/F3M+7sYTVZn07vXF/VdupamSJ9WW22znSj4bJU
Oitfqp7nATK8hklxOXfRyYTL4tZGNZ19jrbu93N9ioxV3o3n0f2y/vI+GywL
HaD+tCZcUz0KP13fkUa2rjLO/ET/O1lhHs16im+h8g8xLjRO56Snqs0YRh0u
44IlnVN3i/ou9qZvg7EoRsXC8tfJAdPksqAz0B+Txc6rWXNtj5xH5nuVTeo3
uQPm4Xim6u2yzN5FvlTm3P1V9jJLp3aHxfKCcSmPybrSqnrk/edheBjpLrvZ
/++ZmX9ZvgEmVDYg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 311->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0sKAjEUKy7Ea4g30AOIV9ATjKArQdCFuPPo/mWmJnl5Dliozkxf85I0
Ha/3y+2glHIc3X6WzWlxODTn1fD+sml2s+nuvjh5zVIu8/L5/9dU/dRor6N6
hvHVw9jn8K85se9KN+UoahGm0oPwlEakh+2vR4hlcq55I82Rh5Gnbg4ivs45
Ze6A5Ez2Of0YL4dvlkufnDv+oJHJruLIsFVfpaHe75y7kwuky+GidP2S4zJ/
TsYv41mkTelg/LMZd2oYJuuT6V3jK2wHN5sn5anKtjoDNFwukc7Il6jnY4AM
9+GkeDlnkcmEy8XFRphO3efd1FfvY9iIt+3di8/7WZ2rnTOR918y08aEa6pH
4KfrO9LI1lXGmZ/oe3QPlEednuIuRP4hjlRju4eZFfic4Mi4sDvBtLz7wtog
n1YOCReWv0wOmCaXC9oD/TG52Hk1Mfv2qPPIfI+ySf0mZ8A8bOOp3i6XzrvI
l8qcWx9lL3NmfbhYXhBeymP2rrSqHnU90/VVZ2r81yz0TK8Fzjcm
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 312->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJyllVFKA0EQRBs/xGuIN9ADBK8QT7CCfgWE+CH+5ega0WXsVFVX7wxswmZ6
ul9115Db57f961VEvN98f+yXj8fjcfl8uj6/vCyHh/vDefPu94k47WL9Vk8U
+51H1VNr3R948j7KgbRU5xz+lQUwjvmUbsooYlFOpQflUxqRHnY+rzKXyZy5
keaqh1VPXR9UvM6cOndAMpNzTj3G5fB2WWZ87vQHrY53FSPLreoqDfm8M3fH
F0iXw6J0bfFx7OLi/2E81+lZpU3pYPxdjzsxLCer06md86vcTt6un1RPlbfV
DNByWSqdsC/FnBwPzzCxvCoexWT2C50NlhNgQblRTicO1Zi9P/m76iHMNcxC
zXWTzwoWpCOfGdngXqNGxV/F5Z6p/rr+RPWUJqqT1RR3QfWDMVKN6R6p3Iyh
y8hY2J1gWv74VaxiUYyKhfmv4wOmyWVBZ1zd1Twc5o7Pt9RwtDrepP0e/LM+
abH6qrbL8u999JF5X1Rf0W+qF52ZzbBYvSBcqsfsXWlVNXI8m0knb/e+0JnM
nv9h+QIsyTig
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 313->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9llFKA0EQRAc/xGuIN9ADBK8QT7CC+QoI8UP88+iaRYfZtqq6OgMObMJm
prtfdddAbp9f94er1trbzffHfnl/PJ2Wj6fr88vLcny4P543736e1j53rX//
19PUnlh9f8gR91EOVD+Lk/zt73dkHH+PcUgvq8F6g1iYHpRPaUR6WHxcaS6T
OXIjzVkPZ3rKGNBZJ6fD4pxjcU49xuXwVllmfO70B62KdxUjy63qKg0x3pm7
4wuky2FRui7x8boEX6VnmTalg/FXPe6cYTlZnUrtmF/ldvJW/aR6qrytZoCW
y5LpzPqS1VzXrln/S1ymTd7A5cyi4gmXxc2Ncjrn+rupL8ax3Ii70rtxFmqu
l/ps1jMjG9wr1Mj4s3N9EW2Mj+mLq3IPVI82NcVdUP1gjFSj8Jczlw1j4oms
3+xOMC2//PCswaIYFQvzX8UHTJPLgmJgf0wW269mztkajlbHm6zfo3/6w84A
JodZsVB2876ovqLfsl64M5thqfSi0mP2rrSqGvE8m0klb/W+0JnMxq8sX40s
OyI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 314->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tqw0AQW/oReo3SGyQHKL1CegIHkq9AIf0o/evR82hjNpORRrIhC06w
d1YjabQvm8/17qm19vV8+lkP3++Hw/DzsTi/bIf9ark/b77+P639vrXx/1FP
Y3tkjfsdRtzPMKo+7Bs6G/8jx/57PJfxQD0UzpWeDI9pzPSg83GVWCLnyDvT
XHk4x1PEIatVMBUuSh06p/RDvBS+Lpc5OVf8yZaTXcYRYbO+TEM8r8xdyUWm
S+HCdE3J8WURfo5nlTamA/F3M67UIEzUx+kd8Rm2guvmiXnKss1mkC2VS6Wz
8qXqeVmmP4r3V9zIS5mFkwmVi4qdYSp147uoL55D2Blvxzs2Y9TfydnczPTc
0j2jR8W/qss4I3/VfGb9mCb7TpC7wPxAHKFGki9lLjcci0xUfqM7gbRc+bNa
xoVxZFxQ/pwcIE1TsqLmVsHus8c4Ozl37sYN/0Krkk3od5efBmqQZtZb5dJ7
HTUr94X5mn1jXqDZK9gOl8oLJdvOO9PKesR6pOuurpvnlOw/4vnjcgQdBzrj

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 315->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0tqAkEQhhsX4jWCNzAHEK+gJ5hAXAkBswjucnR1DENb1P+oJGhDO9hd
j++vqn55+9juZ621z8XlZzt8bY7H4bSbX/+8D4fX1eF6ufzZrX2v2/R91G7s
jqzpHtijGCoPO0O+8RsZ+/PoF2uRnoMzFJPpyeIhFqQH+celmJvJHLkzzZlO
p2/VOVC8TkyHxbFDfk4+xOXwVllcvkoMpgf1iOl1YkZbdoc0RH+n785cZLoc
FqbrN3M8LsJXqZnSxnQg/uqMOzYoJspTyR3js9hO3Oo8sZqy2WY9yJbLonSq
uqic4yrWx6k94nJ6UZkJl8WNncV07Bxt1feDuCu1U3OMfP7aT6Qj+oxLvB83
h+JXdqpmiA/pi6vyDibbbqc5yVtQ9csYocakVyg2YqgyIhb0JpCWyI16g1gY
I2NB81eZA6TJZcl8XN2yHwazO+fVt3HHL7Q6s4nq3c9PnP0sVh+P5XZZ+lpH
e+e9sLpmZ6oWWe//m0XVwpntyn+mleW4W0RXGlfU6Nn7xnIGzZo6pA==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 316->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tqAzEQM/kouUboDdoDlF4hPcEW2q9AIfko+cvR0/SxeMeSRtNADM6S
9VgjabSb14/t+6q1dlh//Wynz+f9fjq+3F3+vE27x4fd5fD+d7d2emrz81Zb
9VNrPif1DCPro94p/gtOjb9Xulk/VYswlR6EpzQiPex+XCmWyTnyRpozD6/x
lHFAtQ5m5RtQdeye04/xcvhWuVyTc8cftCrZVRwZtuqrNMT7ztydXCBdDhel
6z85/l6CX8WzTJvSwfhXM+7UMEzWp9I74itsB7eaJ+WpyraaAVoul0wn9CWZ
03C/6I/j/R9uC++cWVQy4XI5AS4IG2E6dbE/81TdQ9jIk5J3Ysasv52zhAvS
MfjUcYNnhR4DP9N3xZn56+ZzXh0fpWnomeVWfAtUJ8FD9Qv+bdmP6WAcKhyz
PPRnEStqibxRrfRLcFRcUA2qlfMnmlwu6I6rO52HwdnNecWTIQuJViebzO8+
P4sn8bDHU71dLr3XsT7OQN4PZ47XSCeavYNd4ZJ54WS78l9pVT1iPdMFcbtd
zf4t9g+XMxmmOGE=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 317->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FqAkEQRAc/gteQ3CAeQLyCOcEG4pcg6If459GNJsraW1Vd7QYHVtmd
nu5X1T2zr+1qPWmt7ac/P6vusNztuuPn2+Xlu9vMPzaXzfe/p7XTot3/X/Wo
emr191E8yzGoYZxz+CMT+650U0YRi3IqPSgf84XpYefjypibyRy5kebMwzGe
MgYU6+Ss3AEVx8459RiXw1tlGTPnjj9oVWZXMbLcqq7SEM87fXfmAulyWJSu
Z+b4ugRfxbNMm9LB+Ksz7sSwnKxOpXbMr3I7eavzpDxVs616gJbLkunMfMlq
XlfRH8f7W94Wvjm9qMyEy+LmRjmduFifearOodwxl6PzIZfoMav/H/2EOpBP
PTa4p2pkfpq+K2bmrzuf91W8B0ijnDfAkPk3YCR5b/x9HSo3Y6gyMhY060pL
5EaxikUxKhbWn8ocME0uCzrj6k77YTC7c169Gw/8xr3IZpP5PfhmxDi1XZa+
1zE+9kCeD3uO10in27MxLJkXzmxX3pVWVSPGM12S9YnZf8Xzy3IGWr85Yw==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 318->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9llFqw0AMREU+Sq9ReoP2ACFXSE/gQvsVKCQfIX89ehrTGlvMjEYxdMFJ
vKsdvdFqIU/vX/vPTUScHn8+9sN5dzwOl7eH28vHcHh9OdwWn3+fiO9tTN//
9ah8aszXUTzTqPKoOcWfmdi88s3yqVikqfwgPeUR+WH78yi1TObMjTxXNVxT
U8aAYh3Nzh1QcWyfk49xObxdljV97tQHjU7vKkamrfIqD3m/c+5OXyBfDovy
dU8fj0PwdWpWeVM+GH+3x50YpsnydHJnfaXt6Hb7SdVU9bY6AzRclspnVZcq
p1PDLtO0vo3F3ajy5JjMjny6LK420nTicv4wWJCfrJ21HJ+dPmZ73D5b2zPj
KO6Pm6Pir+KqmjE+5i+Pzj2Y9xHTVP6c+iFG6hGcFdNmDF1GxoJ6XXnJ3Oxs
GItiVCzsfDp9wDy5LGiP67s6D4fZ7fN7c8zvCPPq9Catt6gXm3NyuyzT75nP
RT8VXlVd0ZyqxWKt0FnDUtXC6e3Ou/KqcuT4vzOyaxjR/n/kPpmjvX9kuQI3
BTom
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 319->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FOw0AMRUddIK5RcQM4QNUrlBMECVaVKpVFxY6jQwtE6cT/+7lFHSlN
k3js9789y5fd5m3RWnu///7ZDIf1fj98PN8dH16H7dPj9vjx4fdq7XPVxvut
rua+mTX9HsWrHFH9bJ/lb/N7z6hYZxzCf/VO5XR6wtrCF6VH7e9Xxtwgc88d
aY50kr4RTxVDFEtyEhYSp/aReoqL8FZZKF8lh9OjeuT0kpx9rPumNPT7Sd/J
XES6CIvTdckcOy+rnmXanA7FX51xEqNyqjqV2n1+l5vkrc6T89TNtutBtChL
pjPzJatJPKwyndU1/jhv6UxQFpo7ykniiLbq+VHcFe+yOVZ76JxdOzOnlZwf
WmPGB32nnik+pe9sFc/BVIPK6ebK+dez9CvUGPRK6VAM4z2ZicxvdSaUFhVL
WRxjlt+9dzlpfzKWaE/kD2VBMwtZ/6PGtIdKK5lN5bfzy8VktSnL+D+YVXJe
nK/Ru8wL2rNrWDIvyGxXnp1WV6OP/+sR9fC0Lpj9W1w/LF/PGTyi
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 320->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0FOAzEQG/WA+o2KH8ADEF8oL1gkOFVCag+otz4dCuxqd3bsseFApHTV
ZOKxHWf3/LZ/3UTEafv5sx/eH4/H4fx0c/3zMhzu7w7XzdufGXF5iOnLZjT7
zmT92Jj2Z3zyfoVRaenOKfwXnAKvM92B1sEawmR6KjzEBelB5/PoOIfIOfOu
NFc63dy5HKpaBdN5A6wOnVP6IV4KX5eLys/BYHrQHTG9CmauZXtIQz6v3LuS
i0qXwoXp+k2OmZeuZ502pgPxdzOu1CBM1MfpnfEZtoLr5ol5yrLN7qAaKpdO
Z+dL11Px0OXEeCl34WRC5aJiV5hKnaLNfT/Tl2Ss867LMTpT1ppcVjoK/BGX
vR/Yo/NT9F31DPFD+hZD9I1pZPwrDlAn0IBwR/5zHQibcZi+TSY6v6usMy25
dsxxEK5WDgEXdD+rNXb/QJPKpTpT+dPhOrlVuTo9skcL/sK76LKJ/F6tgX5V
f9Zb5TLXn+uzL/R82lPus/JCvbO/cOm8ULLt/GdaWY9c/zUMD3N93v/P+c3l
A2A/OaA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 321->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFVl1OAmEQm/BguIbxBnoA4hXgBEuiTyQm8GB88+j8SNCdbTsdMPoly7L7
zddpOyXhfv22fJ1FxG5++FgO78/b7fCxujs+vAybp8fNcfPhfEV8LuJy/6tL
9VNrtA/qGcakh3HO4T/hRN5XuiFH8o5hKj0Ij/nC9LDzeVWcw+SceSPNSGc3
d10OqNbB7PwGVB075/RjvBy+XS4uvw6G0sNmpPQ6mLlW7TEN+bwzdycXSJfD
Rem6JsfKy65nlTalg/HvZtypYZisT6d3xlfYDm43T8pTlW01A7RcLpXOypeq
p+Nhl5Pi5cyikwmXi4uNMJ263D9+4ffDeLe8W3xf1eyRjtFewqm4IB0TnyJG
/7062YzKT9N3xZn56+YT8hKalEaZN8CB6iQaGO5pgVkxHYzD5Z6/G3lW88m9
spZcG/kOeLVySLiw+UzeqfkTTS4XdAb5U+F2cuty7fTIHqG5Ma1ONpnf0C/h
4U881dvl4uRf1Stf0bvKC3dmt3DpeNHxmD0rrapHrj+thofV839eX1z2v9k7
IA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 322->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FuAkEMi3qo+EbFD+ABqF+gL9hK5YSERA9Vb316CwK6ytqOQ6EjLcvO
JI7tZJ5ed+vNQ0S8z35+1sPH834/fL48Hj7ehu1ysT0czk9PxNcqLu//elQ9
tfI5+kYYkxpGnsNfcRrvV7ohR7LHMJUehKc0Ij0sP69bcc68UT7S2Z27Lgem
pcLs3AEVx/KceoyXw7fLxeXXwVB6WI+UXgczx6ozpiHnO3135gLpcrgoXdfM
sfKy61mlTelg/Lsz7sQwTFanUzvjK2wHtztPylM126oHaLlcKp2VL1VNx8Mu
J8XL6UVnJlwuLjbCdOJy/bjB/WG8O95Vc8xyYGyTC9Ix8Sl+vYJnjRoV/yqu
8ozxY/ry6tyD8RwxTKVP+RdEA8M9LtArpoNxuLzJf9dvdieYlhwb+V1wUVoV
F9afyZ7qP9HkckE5yB+ou+iHw9mdc1UjxD0Y941pdWaT+a38UjFVbZeLM/8q
XvoK9iov7J79gUvHi47H7FtpVTVy/HGZHp5nutOPez6YyzePMTmm
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 323->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1FqAlEQG/pRvEbpDewBpFewJ9iCfgkF/ZD+efRWEbvMJpnMon3wlN03
L5Nksi+fX+vtU0QcFr8/6+H4vt8P3x/P54fNsHtb7s6Hr9cdcVrF7f+/tuqn
Vj5Hzwij6qPeKf6K0/i90h2jXXnEOFd6EB71RXjMPFC+zeWceaP7SGc3d10O
TEuF2fkGVB275/RjvBy+XS4uvw6G0sNmpPQ6mLlWnTEN+b4zdycXSJfDRema
k2PlZdezSpvSwfh3M+7UMEzWp9M74ytsB7ebJ+WpyraaAVoul0on9KWY09zZ
uJxu51cuzB/lrZsJl8sJcEHYCNOpy/2j4gLuIWzkSce7KsfsDp1ngwvSMfEp
/ryCZ40eFf+qrvKM8WP68up8B+McMUylT/nHvgOGe1lgVkwH4wDfGd9KNZ+M
m7XQWsQFaFJaFT6bz+Sdmj/R5HJBd5A/UHcxD4ezm3PVI0abzURpdbLJ/GbY
k+ygGtHb5TLxIDC2ypxbX2WPZePeXCovnGx3npVW1SPXX9ZMD515PHJjLj8k
eDvd
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 324->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFVlFqAlEMDP0ovUbpDeoBFq9gT7CF9ksQ7If0z6Orq1gbZiYTWdoHT3lv
k8nMJIs+v29Wnw8R8fV0/FiNu+V2O36/PZ4OH+N68bo+PXy57Ij9ENfvv9qq
nlr5OTojjKqOulP8Fafbe6U7LtvxiHGu9CA8pRHpYfl5zcU580b5SGd37roc
mJYKs/MOqDiW59RjvBy+XS4uvw6G0sN6pPQ6mDlWPWMacr7Td2cukC6Hi9J1
zxwrL7ueVdqUDsa/O+NODMNkdTq1M77CdnC786Q8VbOteoCWy6XSyTBzbpXf
8cfJm9YQv37fqzo5JnPPNTtc9oALwkaYTlyuHxUXkIewEe+Wd0PI/1koZ45+
Qh3Ip/jBhM9UjeacV3GIM/PXnU9UT2lSGuW8AQ5UJ9HAcKcFesV0MA6UozHP
qj8ZN2thsbZfQmuFr+6vd6r/RJPLBeUgf6Duoh8OZ3fOVY242XAWjPeimk3m
N9MTBGtaRm2Xi6rnvC/SV3BXeYFmY24ulRfObHfOSquqkeOn1fGwOP/nPnM5
AG5GPF0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 325->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1FKA1EQG/ohXqN4Az2AeIV6ghX0qyDUD+lfj66tddnOJpnMCnbhtex7
s5kkk7d+ed+8rSLi4/b7ZzN8Pu12w/755vjyOmwf7rfHw7vzijg8xvj/X0v1
U8/FOahnGFUftaf4j/+/K+8D/BkW2yd7DDP7kvtnPKUx90GezPoS3yzOoXtn
voiL0rPEU8aBaakwO3dA1bHvnH6Ml8O3y8Xl18FQetiMlF4HM9eqM6Yhf+/M
3ckF0uVwUbqW5Fh52fWs0qZ0MP7djDs1DJP16fTO+Arbwe3mSXmqsq1mgB6X
S6UT+nJezuwdD7ucxnPAxZlFJxMul8OEh8JGmE5d7h8VF/Adwkae2N4l/6vZ
Ix0zbiLvSzIzxYRnokflZ7cOcWb+uvlE/SpNOUcMU+lT/rF7wHBPD5gV08E4
UI5GntV8Mm7Wwmptv4TWCl/tj3tFvpEmlwv6BvkDdRfzcDi7Oa96BMnt9I4w
rU42md9Mj6oJo7fL5UJ/qnfui/IV7VVeuDP7C5fKCyfbnXelVfXI9aen4WH1
fs31w+UL9n892w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 326->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FKA0EQbDxIviH+QB+w+IX4ghXMKSAkB/GWp2uCrJvequrqFR2YXWam
p7qquufu5W27u4mI4+brsx3fnw6H8eP59rx4HfePD/vz4f33jDgNMf3/a6p8
alydg3iGUeVRe4r/9B+u72WulW60z/YYZvYl5894SmPOgzxZ5CW+WZxD5858
ERelZ42njAPTUmF23oCKY/ecfIyXw7fLxeXXwVB6WI2UXgczx6ozpiHfd+ru
9AXS5XBRutb0sfKy61mlTelg/Ls97sQwTJankzvjK2wHt9tPylPV26oGaLhc
Kp3Ql6JOa2vjcprOh5+p/GQeZu4LnQ0upxkPhY0wnbicPyou4B7CRp50vKv6
mN2hfWbWk+lY+BQcT/FZ0+dVXOUZ48f05eHUUGmU/QY4UJ1EA8O9DFArpoNx
6HCs+iF7orSwWNsvwbHCV/sK061PxQXdQf5A3UU9HM5un1c52DuYnzGtTm8y
v5keFRNGbpdL1j+Pd96L8hXtVV64NfsNl8oLp7c7a6VV5cjxTBfEnU23Hn85
I68vXD4BO/U8IA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 327->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FqAkEQRJt8SK4RcoN4gJArmBNsIH4JgvkI+fPoKhHZ9FZVV0/AgVV2
pqf7VXXv08d+s32IiK/H889m+n47HKaf99Xl5XParV92l8Pn6xNxfI3b/72e
UGdi5XP0jnJUddQeu5v/M9N8P99j+Zw9lvO2QDzKpzQiPex+XkPMoWtnXsSi
9Ix4yhiYliqnw+LEsXtOPcbl8HZZXL5ODqWH9UjpdXLmWHXGNOT7Tt+duUC6
HBala2SOlZddzyptSgfj7864E8Nysjqd2jm/yu3k7c6T8lTNtuoBWi5LpRP6
UvRptDcu05+6Vx7lJ/Mwsy90NliOMw6VG+V04nL9qFjAPZQbedLxrppjdkfN
mdNPpmPhk8ineEbmvIqrPGN8TF9eTg+VRjlvgEHpZIxUI+gV08EYOozVPGQN
SguMnXlbsShGxcL6g1iq7yhrclnQHeQP1F30w2F257yqkfMhfqbVmU3mN9Pj
xnQ1jMy/ile+or3KC7dn/2HpeNHxmL0rrapGjg/yzUjWRj86T+boxv+ynAA2
2zpl
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 328->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KA0EQhZssJNcI3kAPELxCPMEIugoIcSHucvQY/GGsvL8axUBnmOnq
qu+9qt48PO+eVmOMl/X73256vTscprf7q/PL47S/vdmfN68/1xjH7fh+/tdS
9dSv7qN3lMPVUd8Uv2Kaf1e6x2w5jxjzjz0Qj/JRX4THzAPlW8Q8eDziRyxM
z1JPGQPT4nJ27oCKY+eSeowr4e2ypHydHEoP65HSm+SssWqPaajnk74nc4F0
JSxK15I5Vl52PXPalA7G353xJIblZHU6tWt+lTvJ250n5amabdUD9EtZnE7o
i+nT0t6kTBfaiT/K23QmUpYvX1xulDOJQzV+e3/q03l4kcucYfVtPwGXvVMk
v+JUPEvm3MU5bYyv5laepfcAaVT8iEHpZIxUI+gV08EYOoxuHqoGpQXGzrx1
LIpRsbD+IBZ3j6qmlAWdQf5A3aYfCXM6565GzYf4mdZkNpnfTA+MKZ6p2ilL
Mv9Jf7rx1tdm7qo7mdvEi47H7F1pVTVqfL0vyWwilr9YiKUT/8FyAvp9OSQ=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 329->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FKA0EQHHKQfCP4A31A8AvxBSuYU0CIB8ktT9eILktbVV0VxYXNZma6
q6uqezZPL7v9aozxuv742U1vD8fjdHq8uSyep8P93eFyePv1jnHejvn7X6+q
p556jtYIo6uj9hR/xWm5r3SPxdt5xDh3ehCe0oj0sPz6/BXnyhvlI53p3KUc
mJYOM7kDKo7lOfUYL4dvysXll2AoPaxHSq+DWWPVGdNQ852+O3OBdDlclK5r
5lh5mXrWaVM6GP90xp0YhsnqJLUrvsJ2cNN5Up6q2VY9QI/LpdMJfWn6dG1v
XE4/tBN/lLfuTLhcvn3psBGmE1drMD4sj2EjTxLv5v9G7+tazbLDBemoOUtu
8EzU6PxM4zptjB/Thzxz78Ec29wJdReUTsaRagS9YjoYh4RjNw9Vg9LCYhO/
GMcOX+3Pe818I00uF5SD/Olwk7l1uSY1Kh7iz7Q6s8n8ZnpgTOmlqu1ycebf
6U8a3/maYlfdztw6XiQes7XSqmrUeKYr4ZreF9qT3+Z/cnkHNsY6aQ==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 330->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VUtKBEEUK1yI1xBvoAcYvMJ4ghac1YAwLsSdR9cRadp0kpfXig09TVW9
T/KSYq4fn/eHizHGy9Xnz356vT+dpreHy/PiaTre3R7Phzff7xjvuzF//+sd
7sw8eM7WrEbVx+2pXPwipuU+5uEs2DxorMBc8WH1HEfGR+Xj81eYETfLZzwT
3bo+qPAmNRMsSZzKS/opXAneLpYUX6eG46M0cnyTmhjrzhQHzE90T3zBeCVY
HK8tPnaz7M6s4uZ4KPxdjycxqqbq0+mN9V3tpG7XT26mzttOA/akWCqedC6F
Tlu1STHN57vx4z++6oMxiH3FEzlWng38xnolccseyHvr/cFvNUNWa6lFpT2u
nZcTLIwH5iyx0TPTo5pnN67ipvApfmxm6T2YY4s7ofi5+TmMkiPRSvFQGCTG
wM9OH6yLXFTsqqbRXXGt6rv9Zd/qHiGnFAvLYfOhvAs9Esypz12PYe4Bm1HH
Q242rP7SJ6s9oa/yUYIl8X/iJxefeq+lmeFSxXdm0ZmxWjuurgfGK14drN37
IjX5bf4Xlg9Fqzki
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 331->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FuwkAQW3Go+AbqD8oDon4BXpBK5YSEBAfUG09vQShKJrbHk1aNtCzJ
znhsz+zm47Q7rFprl/XPz66/vp/P/df+5f7y2R+3b8f74etztXbr2rD/12rq
TDzxHL0jjKyO+sZyJ3s3zYvcYp7jB4plnDM9CE9pjFjIE1T3LzlH3igf6XT6
Vp2DjK+D6XBx4lieU4/xcvhWubj8KhhKD+uR0utgxlh1xjTEfKfvzlwgXQ4X
pWvJHCsvq55l2pQOxr86404Mw2R1KrUjvsJ2cKvzpDxVs616gB6XS6YT+pL0
aWlvXE6Tuk8+yk/mYeQ+01ngchvxUNgI04kb1xiv39yfuGceIqzhv9H7+K5m
2eGCdMScMTd4JmpkflbjMm2MH9OHPHPvwRCb3Al1F5ROxpFqBL1iOhgHytGY
Z9WfiBu1sNiKX0xrhq++K0y3P25vK3PrYLuc3TlXNVo3x0P8mVZnNpnfTA+M
SfrraFgy/7MZc30F3zIv7J5F7oX4ihcVj4dZQp4RrapGjGe6JNdCPyoLzUAp
/8HlG9yfO+E=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 332->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOAzEQizggvoH4ATyg4gvlBYsEp0qVygFx69OhAlbt1PbYq0Kk7CrJ
ZMb2OLfP2/Xr1Rjj7ebrs57eH3e76ePp+rB4mTYP95vD4d3PHGO/GvP/v6aq
p0Y9R2uUo6uj9hR+hel4v+M9TI0Y5o4Pyqc4Ij7sfh2Xwlxxo/uIZ+q7FAPj
0uVM3oCKY/ecegyXgzfF4uJLcig+rEeKr5OzxqozxqHed/ru+ALxcrAoXkt8
rLRMNeu4KR4Mf+pxJ4blZHWS2jW/yu3kTf2kNFXeVj1Aw8XS8YS6NH1a2hsX
0xl3oo/S1vWEi8XNjXI6cfP6d+8C74fhTrTbCzysfttPgGupZ46xwTNRo9Mz
jeu4MXyMH9LMfQdzbONb9RYoT9FXxhH1ivFgGOBewePozd4E41JjR/0DXIkP
GRbWn7O9xt+Ik4sF3UH6dHkT37pY3Rq1T8xjjKvjTao34QM1JP1lPnKwnGgg
/NX1J41vdQ1zJ/GdFo636ZpgYVxVjRrPeCVY0/fyV/MbyyfopTok
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 333->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FqAkEQHDxIvhH8gT5g8QvmBRuIJyFgDiE3n24UNWNbVV1txIVRdran
uqq65vX9c7WetNa+Xn5/VuP3crsdf96mh5ePcbOYbw4fZ6fV2m5ol/9nLdVP
PfE7ekcYWR+1p/grTv1+pruZHjHOmR6EpzQiPex8fB7FOfJG55HOau6qHJiW
DLNyB1QdO+f0Y7wcvlUuLr8KhtLDZqT0OpixVn1jGuJ5Z+5OLpAuh4vSdU+O
lZdVzzJtSgfjX824U8MwWZ9K74ivsB3cap6UpyrbagbocblkOqEvyZzunY3L
6UY78Ud562bC5eJiI0yn7vJ+3nvA/ekxWcYy73aCD+tP5zn8LYfLjQ6A33OD
30SPzM9qHeLM/HXzifplmq56JLlVd0HpZByZRjQrpoNxUHtZntW5iBu1UL0F
v1yeTJfineUbaXK5oDPIH5eLlVmTK8s7uwNIG/KokiHqzdAtgA09TObraJDc
Rb6y+VTrM1+r2K1Qb3lBeCmP+zlFXKZV9Yj1TFeFa+WuyNn99/yRyx7kcTxh

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 334->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1FKA1EQG/yQXkO8gR6geIV6ghXsV0FoP8Q/j64VXfZNJ5lkCxa2y+7O
ZJJM3t3L225/ExGnzfffbnp/Oh6nj+fb88PrdHh8OJw/3v9eEZ/bmO//dbF5
7Dd8L+oRRjeHvWP85/t27MtcO91BZiicK1/y/IzHNOY5lScXc4FvEufgszPf
igvTs8ZTxAFp6TCdM8DqUJ8yD/FS+LpcVH4OBtODdsT0Kpi5ln1DGnK/sncl
F5UuhQvTtSbHzEvXs04b04H4uxlXahAmmuPMzvgMW8F188Q8ZdlmO6h+KpdO
J8LMvV2/48/8TtxnJE5KvtRMqFxU7GqWUjc/L65rzw/iLXv3xyVqPmg+3OcC
T+EyaAX4lV43m2rOuzrGhfHL2OUZCIxD9TW5RfqYf4wj0rjco5QV0KP43PmN
zgTSMtSmM3HBteDDtDIuaD9LLu3+gSaVS9VT+dPhOrlVuaK8d5lCOUdaaTaR
NzkrYP6ABbLgaFiTf2U/bn3nq4sdRr3jheMxemZa2Yxcj3Q5XN3zAndybf8P
ly83Kz3b
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 335->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0tKBEEUK1zIXEO8gR5AvMJ4ghZ0NSDMLMSdR9dBaXpeJ3nJ+Gkox6p6
nyQvdfX4sn2+GGMcNp9/ttPr/X4/vT1cHjdP0+72Zne8vP5eY7zfjfn3v5bq
p76TexDPanR91JnCv8JEzjve6JydsZqKD6qnOCI+LL9+v4W54kb5iGfquxQD
49LVTN6AimN5Tj+Gy8GbYnHxJTUUHzYjxdepWWPVHeNQ8525O75AvBwsitc5
PlZappp13BQPhj/1uBPDarI+Se9aX9V26qZ+Upoqb6sZoM/F0vFkNWtul5/o
4+Qhvl2fGoPy6/18bnq2q416OXHzfrF++n4Ybls78L+afd2vYs33kXhG1VN4
zvF5F9dxY/gYv/o5M1z1bHzL+Cn9FEbGEXqK8FA5js6d3uxNMC4nsQtNkZ8R
HsVVYWHzWWJp5084uVhQDtKnq5v41sXK/J5wQxolHlLaDFEbaki8wHzkYHH8
78wnje90TWuPID7RItGY7RVX1aPGM14J1vS9/NX6wvIBqaU+Ig==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 336->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQbPIhXiN4Az1A8ArxBCvoVyAQP8Q/j65BXWY7VdXViYgDs8vs
9KOqunb9uN8+ryLi5frzsZ1e7w+H6e3h6nh4mnZ3t7vj5c33jnjfxPz+qx3q
TqzFPYhnNao+6hvLze+Mcfye87IWPxv1cDBXfFA9qgvhw/Lz+i3MGTfKRzyd
uXV9UOF1ajpYnDiW5/RjuBy8XSwuvk4NxYfNSPF1auZYdcc45Hxn7o4vEC8H
i+J1jo+Vll3NKm6KB8Pf9bgTw2qyPp3eub6q7dTt+klpqrytZoCWi6XiyWrm
3Cq/o4+Th/hWfXIMys/383fTs1Vt1MuJm8/DvvT/Ybg72il9WH86T/P/6HhG
1VN4zvF5FVdxY/gYv7ycGZ70LHzL+Cn9FEbGMfuI1a5yXG9WfsgcFJdF7KAp
8jPCo7gqLGw+I5Zy9sJHDhaUg/Sp6nZ862Lt9kDc0Nw7HlLaIP2lhsQLzEcO
lhM/BL7raOfOM69Lakcj3tKC4FIas7Piqnos1uABV0OG5T/sLywfk3g63w==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 337->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0tqQkEQbFwErxFyg+QA4hXMCV4gWQmCWQR3ObrRiIxt16fNZ2CU96a7
pqq63v3LZvU2i4j3+dfPavpYbrfT7vnu8PA6rZ8e14fDh9OO+FzE+f+/drAz
si7Oi3qEoe5h71Bv/s8cx/e5r+QC7nA4Kz0VHtNY6UH9ef0W58y76q90OnPr
5kDxdTAdLk4d6nPuQ7wcvl0uLr8OBtODZsT0Opi5lp0hDbnfmbuTi0qXw4Xp
uiXHzMuuZ0ob04H4dzPu1CBMdE/n7ozPsB3cbp6YpyzbbAbVcrkonQgz96r+
jj9O33EtThv4xbx1M+FycbErTKfu/Dzsn34/iHfHu3EWavb5mfF2uFQ6cg/D
Y3xuybmqU9oQP6QvL2eGV3eK3Kr5KB3VYp5E8V75GIKjk2fWl3GzlovawdOo
uA583RwiLmg+bg5GflmTy6XqqfxBuAGwFQeHqzPzq7mhjBGtNJvEm+MCekoP
xXwRBuNS5QH5VL1jZ6xe+drFVjlCvigvOx6jZ6aV3ZHrnVrFtfu9/NX+5rIH
g4g7Ig==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 338->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tOw0AMtPhAvQbiBnCAiiuUEwQJvipVKh+IP44O5RGC1/NwEKy0TZO1
xzNj78XdYfdwFhGPm7ef3fR0czxOz7fnp5f7aX99tT8dXn7uiJdtzM//2qwe
Wz/Oi3iEoeqwb4z//Pza+XuBP2Btv7UojxDnypdcP+MxjblO5clQF/hmcQ5e
O/OtuDA9azxFHJAWhdm5AywO5Tn1EC+Hb5eLy6+DwfSgHjG9DmaOZWdIQ853
+u7MRaXL4cJ0rZlj5mXXM6WN6UD8uzPuxCBMVKdTO+MzbAe3O0/MUzbbrAfV
crkonQgz56r8jj9O3vsy/UQeZu65ZoeLi11hOnHz+2L/9v4g3h3v1ByjHMXb
4VLpyDkMj/FZM+cqTmlD/JC+vJweDjXF3Kr+KB3VYp5E8V35uPzfnSGnPxk3
axn05mfBqzOHiAvqjzsHS35Zk8ulyqn8QbgBsBUHh6vT88EPMmNIqzOb8D4s
6jJv59jwartchnziU/WNnbF45WsXW80R8kV52fEYvTOtrEaOd2IV1+59+av9
weUVBdg9IA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 339->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tKA0EQHPyQXEO8gR4geIV4ghX0KyDED/HPo2uiBre3Xr2gA5PJ7nRX
V1X3Xj08754uxhgvm8+f3fR6dzhMb/eXx4fHaX97sz9eXn/vMd6343z+1x7q
TqzZPYhnGK6OesdyZ+fPru8BPvIC+QFjCWfkS61f8ZTGWgd5sqhLfIs4D127
8kVclJ41njIOTIvDTLgkcSwvqcd4JXy7XFJ+HQylh/VI6U0wa6y6YxpqftL3
ZC6QroSL0rVmjpWXXc+cNqWD8e/OeBLDMFmdTu2Kr7AT3O48KU/VbKseoJVy
cToZZs11+R1/kjyk19WpMSi/3qdcTmcwbwgziZvxKrXWfj/1dB4iLDfHLGcW
90tPgtuZGYWn+KyZcxfntDF+TF9dSQ+h9wRT6ZP+CY5M4/m/6Y37drozlPSn
4lYtC71inhEfpVVxYf1ZvDO9R5pSLigH+cNwB8F2HBKuSc+dNtT3zgwpb06r
9EF6SPrL5ijhssgXPqF36k7FO1+72G6OmC/Oy47H7FlpVTVqfBLruHa/l7/a
X1w+ANGDPV8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 340->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FqwlAQfPhRvIZ4Az2A9Ar2BCm0X4KgH9I/j261NjSbmdnZCNJAmiZv
d3Zmdly877efs9bacf79Z9udXg+H7uvt5fry0e3Wq931cHm/WztvWv981q3m
qSueo3eEkc1R3xT//vl7x+8Af4R1vx2PGGfoS5gf8ZTGERbwBM19lDObHfki
LkrPFE8ZB6Ylw6z8BlQd63PmMV4O3yoXl18FQ+lhO1J6HcxYq86Yhtjv7N3J
BdLlcFG6puRYeVn1LNOmdDD+1Yw7NQyTzanMjvgK28Gt5kl5qrKtdoAul0um
k2HG3qy/4o/Th/Rmc2IN6o/nLpfb08gbwnTqBrzM7CA9ERt5UvEuyzHrGdT9
8c7BrWRG4TE+U3Oe1WXaGD+mL17ODqH3BFPpk/sUHJnG/n9jN4yD+pblWfVF
3KgF1iZcKzlkXNh+GBe2e6TJ5YJ6kD8ZbiW3LtfqDKQN7b2SIeVNf4Fa6CHZ
L8uRw2XUL3xC39SZqs98fQQ7q7e9ANymvFfwWEYGGTA9ZFz+w/3D5QLS+Tyk

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 341->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU11Kw2AQ/OiDeI3iDfQAxSvUE0TQp0KhPohvHl2LImEzf5uKGEhL8u3O
zsxOto/H/fNmjPFy/fmzn17vT6fp7eHq/PA0He5uD+fDm+97jPfd+Pn/q1vN
U1c9R88Iw81R7xT/5L/ip36wdwxT6UF4SmPFQp6gub/JufJG/UhnN3ddDkyL
w+x8A6qO9SXzGK+Eb5dLyq+DofSwHSm9CWatVWdMQ+1P9p7kAulKuChda3Ks
vOx65rQpHYx/N+NJDcNkczqzK77CTnC7eVKeqmyrHaAr5eJ0Msza6/o7/iR9
SK+bU2tQfz1PuaTYCDOpQ9iXfj+Md8c7l+O1vBMuSEftUXiKz5qcuzqnjfFj
+uqV7HAx0+TW7cfpQJfyZIRZYXy6GUr2U3GrFlhruHZyyLiw/aQ5GPO7aEq5
oB7kj8Ode2brQq7dGUgb2nsnQ9Sbue+gFnpo9sswFJdFv8gOeqfOVL3z9RJs
Vx97Abitee7godoFRugh4/If7i8uH7oOPyQ=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 342->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FKA0EQHDyI3xB/oA9Y/EJ8wQp6CgjJIXjz6RqUdVPTVV09C+LAZLMz
3dVV1b23z2+716vW2vHm62c3nx4Ph/n96fr88jLvH+7358u7n93ax9SW519t
VU8tvI/eI4ysjjpT/C84TKsN3DLd0Tk7Y5idL1Af8ZTGDivwJKq7lTOrjXwj
LkrPiKeMA9OSYVa+ARXH8px6jJfDt8rF5VfBUHpYj5ReBxNj1R3TgPlO3525
iHQ5XJSukTlWXlY9y7QpHYx/dcadGIbJ6lRqI77CdnCr86Q8VbOtehAtl0um
k2FibpZf8Wc5y3Km3638ZB4id+S6nK9qyH4Z8xbVcuIi3lu/H3xmHjIOisso
b4dLpANzFJ7iMzLnWVymjfFj+nA5PexqJt9E1p9MR7SUJy04z3xc/6/OkNMf
xEUtYWzCtTKHjAvrjzsHbb1Bk8slyon8YbiN/M84OFydnqMXasaYVmc2O+7o
f+LtktO82i6XLl/4FJ2pOxWf+boFO4u3vQi4jbxX8KJYxHA9ZFz+w/7m8gk3
gz+a
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 343->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVlFqAlEMDH6UXkO8QT2A9Ar2BCvUL0GwH8U/j65SWSTOTCZrKX3wXN6+
ZDKTzILzzX69nUXE1+vlZz18vx8Ow/Hj5Xr4HHbLt931cnHbEadVjM+/2qHu
xMr36IwwqjrqHcuFT3Cf8RWe845hKj0IT2nMWKgnqO5vcs68UT7S6cyt64OK
r4PpcHHiWJ5Tj/Fy+Ha5uPw6GEoPm5HS62DmWHXHNOR8Z+6OL5Auh4vSNcXH
qpfdnlXalA7Gv+txJ4Zhsjqd2hlfYTu4XT+pnipvqxmg5XKpdDLMnFvld/oz
vnPmuYqH/waOv1xPOBoyd4WNMJ04hP3s98N4d3pX+Xgqb4cL0pFzFJ7iM8Xn
VVyljfFj+vJyZvhQs/BtNZ9KB1qqJ2F6hfHpesiZT8bNWmBswbXjQ8aFzcf1
wbgMf1ez7fjWnUfJ24x3arDvAM294yHam7uaIeojDk5tl0vlM3c+3fiqr89g
V/FuL1jPu+cOHorNGG4PGZf/sH+4nAHKgT/j
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 344->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VUFKA0EQbDyI35D8QB+w+IX4gg3oKSDEg3jz6RoSltiprqqeGAcmO7vT
U13VXUPuN2/r15uIeL/7+VnPH0+73fz5fLt/eZm3jw/b/ebqOCO+plie/zWD
7ZGR99E7wlB52LfqLHyC/YyPahEnZ2lswVnpQXhMY8ZCNUF5/5Jz5o3OI51O
37o+UHwdTIeLE1edc/JVvBy+XS4uvw4G01P1iOl1MHMs26s05PNO3x1fIF0O
F6ZrxMeslt2aKW1MR8W/63EnpsKs8nRyZ3yG7eB2/cRqyrzNeoCGy+UXjlE3
p0+jvVnWU8D/bciL1IvV1vWEowHlr7ARphOHsC+9PxXvTu2Uj0d5O1yQjnyG
4TE+Iz5XcUpbxa/Sl4fTw7OcwreqP0oHGqwmYXql4tP1kNOfjJu1VLGderk8
K12Mi7pDcbo2zjhecXSrfkjeZryqJdOG+t7xEKvNMqaQ9xDlZ7ldLsv6OFkv
0LfReFnXK3JRtWDcRt47eJVH3Fjlh+59udY8cPkGJs88ZQ==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 345->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVlFqAlEQG/ohvUbpDfQA4hXsCVbQL6GgH+Jfj95KxdYhyWRWERee6+6b
yUsyEXxbfS43LxGxf/35WA6HxW43HD8mp4f1sJ1Nt6fN9/OK+JrH5f6oFWpP
XHkfPSOM6hz1jvW694yv8Jx3DFPpQXhKY8ZCnqBz78k580b9SKczt24OKr4O
psPFqWN9znmMl8O3y8Xl18FQetiMlF4HM9eqPaYh9ztzd3KBdDlclK4xOVZe
dj2rtCkdjH83404Nw2TndM7O+Arbwe3mSXmqsq1mgC6XS6WTYebeqr/lz/xv
OfNkfilv3Uw4GtD5DBthOnUI+9bfD+Pd8a7KscP7/7wd3E6OFZ7iMybnVV2l
jfFj+vLlzBB6TzCVPumf4Mg0Xr6bGWd83GxWecgalBZYS/KM+CitigubD+Ki
fESaXC6oB/nDcINgVxwcrq6XV/MSGWNanWxKz0Et85DxR+c5XDqzQO/G1le+
3oJd1VteRMD/Icpj9qy0Mi6oPhhP4iHj8gzrl8s3hi47Yw==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 346->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FqAlEQRJssxGuE3MAcQHIFPcEIyUoQdCHZ5ejRJMpMU1VdrcGBcXCm
u/6r+v2fN7vVx1NEHOann9VwfNvvh8/17Pznfdi+Lrbnjy9/d8TXMq7PR91q
PXXl7+g/0qjWUe8U/4RhOboTm/J96XEyYsyVH6SnPGYtlAla9z+ZMzfqRz67
c9dlYF4qzc4ZUHWsz1mPcTm8XRaXr6Oh/LA9Un4dzVyrvjEPud/Zd2cukC+H
Rfm6ZY5Vlt3MKm/KB+PvzrhTwzTZOp21s77SdnS786QyVbOt9gBdLkvlk2nm
3qq/k8/PU+TjzqjK1p0JxwNan2kjTacOad97fhi3nV3R0+WOVFOxTLwSfaXH
eCLVuHNe1VXeGF/WVmfAPQdjr0xT+ZP5CUbmEc0U88EY1LtqnlVf1s1eYO0o
W8TlzCHLk7ErFpUj8uSyoB6UD9MNol0xOKxulhNdMWPMqzObMnNQyzIs+YGG
YunsBXp3a32V6z3aVb2VxeUCuSgttkfMK2NB9aE4hY67H4+8f1m+AUUzOmU=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 347->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1FqQkEQG/woXkN6g3oA8Qr2BK+gX4KgH9K/Hr21lYeGSSZj1YX14e5M
NslmZx+71WYSEYfpz89qOC73++Hz/eX0Zz1s52/b0+breUZ8LWL8PmuG2hMD
97P/GUZ1jlpjvfhFTpfr2IdepOtkjWEqPRme0pjpYf047sUZeWf9mU7n3ro5
qPg6mA4Xp471OecxXg7fLheXXwdD6WF3pPQ6mFir9pgG7Hfu3clFpsvhonTd
kmPlZdezSpvSwfh3M+7UMEx2TudsxFfYDm43T8pTlW11B9lwuVQ6GSb2Vv0d
f36/5+ncJ/NLeetmwuXiYmdnOXUZ9n/fD+Nte1f0dHmH+T5Szwi+wlN8bsl5
VVdpY/wQW70B9x2MtUVumT7ln+LINGaZYjoYB7VW5Vn1IS5qSWsLrp0cMi7s
ftwcsOG8hyorju5Lnzq5dbmq8wLOVvlT/jDtTPc4FjChlnmINSpHDhf3bdy7
vvL1kVwcL66G6TH7r7QyLll9VDzJnnsfz5x/XL4BWOs9oA==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 348->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tOQjEUbPwwbsO4A10AcQu4gmsiXyQm+GH8Y+mK4g1MzjwOgk1KaXse
M9O5t8+vy9XVGOPt5utnOb0/bjbTx9P1bvMyrR/u17vLu/0cY7sY8/pfc6g7
MfC+2lc1XB91xnJxRUyH55iHWpTn5IzVVHyqeopjxYfl4zgXZsRd5Vc8k3fr
+sDhTWomWJI4lpf0Y7gSvF0sKb5ODcWHvZHim9TEWHXHOGB+8u6JLypeCRbF
6xQfKy27mjluigfD3/V4EsNqsj6d3lhf1U7qdv2kNFXeVm9QjRSL48lqYq7L
7+jzve6nfc+DONcHYxA7Yj3CYjTdAl5Wu+qVxFW4//r94Oo0ZBgUlgT3r74j
rNvxsaqn8JzicxfnuDF8jB+O5A2Z9qwn4yf1ExgZx/l/6HGGJ/Wm8wNyUFyq
WIc18SHTk/VxWFjfilOKpcqp9HF1O75NsTK/z74PuFU6dTxEtVnAhFimIcYo
HyVYOm9xznin6yWxJFocjVBjtldcGZYqPol1fuh8K5ecP1g+AVD2PqA=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 349->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FKA1EQRBsX4jXEG+gBxCvEE4xgVgEhLsSdR9eghFhUVVfHxA+Tyczv
7v+qu+b66WW1vqiq16uvn9Xy9rDdLu+Pl7uH52Vzd7vZbd78XFUf97W//9dV
bs8s3GfPrEZ3jnuncvGOTIfvMU/VS96pmk4Pq+c0Mj0qH9epmJGb5TOdydym
Puh4k5oJSxKn8pLzFFfCO2VJ+SY1nB41I6c3qYmxbk9pwPxk7okvmK6Exek6
xseul9OeddqcDsU/9XgSo2qqcyZnY31XO6k79ZPrqfO2mwFbKUunU9XE3C5/
0p8kT+Uks5h4QvWe9iLwGzsriWPcf/1+8J7qnPg44S4x946F6cAcV8/xHOPz
Lq7TpviUPlzJDF3vHT9jcDoVo9K4/x96XPFMPZTMB+uiFhrbsCY+VP1U7CrW
zv7AAx2Hm+3Et8gw9W3K6vgLz4Z3jF9pTbxJvwfS/66HGON8lLCk38ap47u+
npMl6cWvFfZYPTutioXFJ7GdH6bfy7mub5ZP7GY+YQ==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 350->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRBs/JNcQb6AHCF4hnmAF8xUQ4of459E1qMHpVFVXj8aBzSbZ
nppX1b1XD0+b7UVEPK8+PjbLy91+v7zeXx5+PC6725vd4eH11xXxto7j/b+u
UM/EGp6DeqZRnaP+Y3uH+/eV/wf6LI+cCaplzCiXfH7Wkyxxupftz2uKOXg9
4kcszM9spoyBeak0HRanju1zzmNcDm+XxeXraCg/rEfKr6OZa9Uz5iHvd/ru
zAXy5bAoXzNzrLLsZlZ5Uz4Yf3fGnRqmyc7pnJ31lbaj250nlamabdUDtFyW
QcfIzenTbG8GXZFPZg6jHmWY2TMr+640K210llOHuH/7/uR7xyfSqXrPuANw
OyzIR96j9BTPzJxXdZU3xsf85eX0UGWv+BGD8skYmcfjd3PGGU93hpz+ZN3s
BdVWrM4csjzZORULOxd5clnQHpQP0w2i7XK7c36SUz67mCvltdPvYf3gyLUs
w1yj5shhcd+Nv66vcj0ni5PFsMyM2W/llbGgeqe2mofu+3Ku65PlHYxjPV8=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 351->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VkFqAkEQbDxIviH5QXyA5AvmBRuIJ0Ewh+DNp6tJlN2erurqQV0Yl93p
qa6qrgUXn7v1ZmZm3y/nn/Xw877fD4eP+eXha9gu37aXzdf/ZXZc2e3+rGVs
j1x+P3qOMLI+7B06O7lfl38f4CM/vCdRLeI82QvqIzym0feJPGn6At8kzsZ7
e74RF6anx1PEAWnJMBUuSh06p/RDvBS+VS4qvwoG04NmxPQqmL6W7SEN/rwy
dyUXkS6FC9PVk2PmZdWzTBvTgfhXM67UIEzUp9Lb4zNsBbeaJ+YpyzabQXSp
XDKdCNOfzc5X/Pm9E38mfVfW/EdQ8qVmAnkfeiHkLeql1EW8oS8jPzK9PTor
Ob7yYbzNcclwKzlmeIxPT86zukwb4of0+UuZIfOe8Y84MJ2II9KoYsPvZTQ3
v6/kmZ1rellem+lTcoj8RH0yLnD+Qr6z2VZyq86D1amYqMc4LxNcljGgtTLv
5nL+N3MhmllvlUtlFvesz3x9JBfFC8St57mCF2bE9NosD9Xv5VHrj8sJM98/
Gg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 352->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1FOw1AMi/hAXANxA3aAiSuMExQJviZNGh9ofzv6NmBoC7bjPG2r1FZt
E8d23Me31eLjLiI+H/aXxfT1sl5Pm9f7w8P7tJw9Lw8fn37PiO08/u63OkN9
E0f+jp4RRjVHvWO9+R7sffzvc/xAtYxzpQfhKY0ZC3mC5l6Sc+aN+pFOZ2/d
HFR8HUyHi1PH+px5jJfDt8vF5dfBUHrYjpReBzPXqm9MQ+539u7kAulyuChd
IzlWXnY9q7QpHYx/N+NODcNkczqzM77CdnC7eVKeqmyrHaDD5VLpZJi5t+rv
+PN9F/6czRV+KW/dTDDvoRdG3tAspw7xpr6c+FfpHdHJ/K92z3jnHSJeozlW
eIrPSM6rukob48f05cPZofJe8UcclE7GkWl0sen/Mg+Ye+VFxUXttqwt9Dk5
ZH4y7qxW7v/oXdLkckE9yB+Xi5VZk6uaccxKJ4tMq4NB/weQ2e3pO6FZzXa5
dHZxyfrK12tycbxg3EaeO3gwI+HXVnno/i/XOn+47ACqtz2g
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 353->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOw1AQG7FAXAP1BnCAqlcoJ0glWFVCKgvUXY8O/agiU9vjSQsiUhLl
vXke2+M8rt6Xb3cR8fHw/VgOn4vNZti+3O8/Xof189N6vzk73RG7eZzff3Wr
furK++gbYVR91JriP+LA1qPWjdbZGsNUehCe0pixkCeo7y05Z97oPNLZzV2X
A9NSYXb+AVXHzjn9GC+Hb5eLy6+DofSwGSm9DmauVXtMQz7vzN3JBdLlcFG6
puRYedn1rNKmdDD+3Yw7NQyT9en0zvgK28Ht5kl5qrKtZoAul0ulk2Hms9X5
jj+Ht/Bn1Ff4pbx1M8G8h14YeUO9nLrsC+Oj6hD2FJ1nrGJOrP9FHclixQXp
yGcUnvJxSs6rukob48f05cuZYfefYPrkPAVHptHFpv/LPEZ5/Lnv6FbzuegV
Rm2hr5NDxoXNp5MDpunarDi6q3k4nDs5z/MJgkszRrQ6GNRvkNkdWEP9VW+X
S2cWt6yvfP1NLo4Xo9mYHrNvpZVxQfXBeBIPGZf/cB+5fAENbj7f
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 354->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U11OwmAQ3PhAuIbxBnoAwxXgBDXRJxITeCC+eXQFSUO2Oz9bgS8ppf12
55uZnT6+fa4/HiJiv/z9WQ+H1W43fG0Wx4f3YfvyvD1uPp2viO/XGO/3uoLt
kZX3q+cKQ53D3qHefA/0PqZ9lR/Zk6oWcVZ6KjzKJaa9qD+va3HOvKv+Sqcz
t24OFF8H0+Hi1KE+5zzEy+Hb5eLy62AwPWhGTK+DmWvZHtKQ+525O7modDlc
mK45OWZedj1T2pgOxL+bcacGYaJzOmdnfIbt4HbzxDxl2WYzqJbLRelEmLlX
9Xf8cfrGRfxi3rqZQN6XXhh5q85y6i7PYN6gPoQ9R+eIJXrQ+Q5vh0ulI/cw
PMZnTs5VndKG+CF9eTkz7H4Taj5KR7WYJwqb9hTfB/NCcWGzVbWQ65ljJ4eI
C5qPm4NLr7Km/2ZlolvgdnLrcmVnqDlU/5FWBwN+D0VmmYe5huXI4dKZxTXr
la+35OJ4cVpGr/PMtCIuVb1Tq/LQ/V5udf1x+QGH9D7h
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 355->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U1tKA0EQbPwQryHeQA+weIV4ghX0KyAkH8G/HF2DErK9VdXV2ezA7jBM
P6qqax7fvzafdxGxf/j9bcbD6243fr/dnw4f4/bleXu6fPr/Io5DnPe1vxjq
fmrle3RGNRCOGHSe5BHzPWM6kvpKF9SDaYOwMD6onsKC+LD8vG6FOeNG+Yin
MzcHH8PAuFQ1HSxOHMtz+jFcDt4uFhdfp4biw2ak+Do1c6y6YxxyvjN3xxeI
l4NF8brGx0rLrmYVN8WD4e963IlhNVmfTu9cX9V26nb9pDRV3lYzQMvFUvFk
NXNuld/Rx8lDfKs+OQbl53umPdTC8Bvq5cSx85L3k3eX57lWkcP6z+Iu6iF8
Szyj6ik81/i8iqu4MXyMX17ODLtvgvGT+gmMjKNbW+ZceinmWFy92ZtgXFCs
whqCjzMf1qfCorTMnJZ6BfHu+NDF3PH5RKeBzEHNjXB1vEn1Bp6deFlwVr1d
LJ1Z3DKe6ZpnsgYWR4vJfESuc1YeYligNkZs5YfOW1nz+8PyAx9VPCI=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 356->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VG1qwlAQXPxRvIb0BvUAwSvYE6RQfwWE+EP859FtSpW62ZmdTYIPniF5
+zEzO8/N13F/WJnZaf3zs2/Pu75vL59vw8t3220/uuHw/W+bXRt7PF+1jZ2R
9XQexKMaqD/Lo/idbnbf/ntQX9Yowg24ZjpE9RAWC2pFmkR9l8TscUf5Ec+l
NEUYEJespoJFiUN5Sj+ES8FbxaLiq9RgfNCMGF+lpo9lZ4iDz1fmrvgi4qVg
Ybym+JhpWdUs48Z4IPxVjysxqCbqU+nt67PaSt2qn5imzNtsBtFSsWQ8UU2f
m+VX9FHyIr5ZHx8T5ftzpH2oheC3qJcSh97n3B//VHmqOaj/KO5+Jt6PimdY
PabjFJ9ncRk3hA/x80uZYfVOIH50ngQj4qjWznIUnTO9kb8Rlyg2w1rxIcKC
5lPxAeI01ysK72weCuaKz5l+j7pkbohrZd6j1djof+/a/PtOOLPeKpbKLJaM
R7raC7AoWjzNh+Qq78xDCAvSJovN/FC5K3R2c/N/sdwACxRAXw==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 357->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA1EQhJssxGsEb6AHCLlCPMEIugoIcRHc5egalfDsqaqujlF8MA7j
65+vuivLh+fN0yIiXq7f/2ym/Xq3m17vr44fj9P27nZ7vLz5eiIOqzi9/+oJ
dSdOvkffqAZjiBXPk/wxf2em8f85z5kJimVaqzmgenIuQA/Lz+dSzJkb5SOd
zt4cPsbAtFQ1HRYnjuU5/RiXw9tlcfk6NZQetiOl16mZY9Ud05Dznb07vkC6
HBal6xwfq1l2Z1ZpUzoYf9fjTgyryfp0euf6qrZTt+snNVPlbbUDdFyWSier
mXOr/M58nDykt+qTY1B+vmezh7Mw/IZ6OXEfx5y3+/vJ747OGPQqFtR/Fkf2
XrEgHTlH1VNzPMfnVVyljfExffk4O+z+Jpg+uU/ByDS6tWXO4KXx3tGt9pN7
ZS0otmLt+JCxsP10fMA0/dQrSHc0fOgyd3x+yh280vEi09rZ9+wAzx4GtgB5
Tm+XpbOLS8ZXc/1NFmcW3/Yjcp1vpZWxoPjM4ngTsfyH55PlDUhNPl8=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 358->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVFtOw0AQG/GBeg3EDegBIq5QTpBK7VelSu1HxR9HhxSIksnY40lKxUrL
Eu08bI+3T9vjZv9gZufV159Ne3k9ndr3t8fuY9ce1i+H7vL5Z5t9NNaf99rG
7sjy99F3VCPrFeVR/DY9PSZUX9UkikVcMx2iegiLEY2RBky3uZg97igfzTGb
m4IPYUBcspoKFiUO5Sn9EC4FbxWLiq9Sg/FBM2J8lZo+lt0hDj5fmbvii4iX
goXxmuNjpmVVs4wb44HwVz2uxKCaqE+lt6/Pait1q35imjJvsxlES8WS8UQ1
fW6WX9HnehJ9VI8ybVVP9P8rnhX8FvVS4q6rGe+l78efmYZDnkMMKAf1H8XM
eB8VH7N6CM9cn2dxGTeED/HzS5lh9U0gfkg/Vg/VrdSmOaLOmd7oTSAuUWyG
NfMh0xP1ybAwLT2npV6JePu3lc1DwVzxeZ/bWPgbOsQZ4gdcK/OerF8sLtZj
jPqz3iqWyixuGZ/p+pdYFC1G8yG5yjfjirBE8R6L4s0Iy3/Y31g+ASLwPhw=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 359->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwkAQW/wQryHeQA8gXkFPUEG/CoJ+iH8e3be04ySTqQ9cqFp3NpNk
ssPlZr7ulVJ2g/PHvNrPttvqsOhfXlZVPRnXl83R/SnlOC3P7189rB9bdt97
9zCiXt45hX+LA/q/6Lojj5DW1h7Qp+CjPp4nL32BbxLnwntbvh4XpqeLp4gD
0hJhZu5ANheKB3Zl+Wa5qPwyGEwPmhHTq2DaWraHNNjzytyVXHi6FC5MV5cc
My+znkXamA7EP5txpQZhoj6Z3hafYSu42TwxT1m22Qy8pXKJdCJMezY6n/Hn
+k38UTPKvFUz8fytZFbIm9dLqbuuaeMBWhEOwvY8UXQ++EQ59vq3ajrcj0yO
GZ5Xn/EzWxdpQ/yQPruUGWbvBNLH/GMckUYVm55BeRJ0s/nYXlaLW0u4Wj5M
K+OC5qPmoOmV1fRuVhTd0TxYncIVnm1kJZNFpFXBgPfByazNMtLMeqtcMrP4
ZH3k6ze5KF605kPOKu9MK+Li1VsuSjY9Lv/w3LicAO7oPF8=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 360->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0FOA0EMi3pAfKPiB/CAii+UFywSPVVCKgfUW58OFWhUUttxti0j7a5m
JnFsJ7t8fV9vFhHxcf/9Wk+fz7vdtH+5O27epu3T4/Z4+fD7RBxWMb7/9YS6
Eyvfoz3CqGqhPMk/zr/BzuM8z/EExTKtlQ8Ir+KS9bD8vK7FecQAvoiL0jPH
U+Sd0lJhOlycOJbn1GO8HL5dLi6/DobSw3qk9DqYOVbdMQ053+m7MxdIl8NF
6Zozx8rLrmeVNqWD8e/OuBPDMFmdTu2Mr7Ad3O48KU/VbKseoOVyqXQyzJxb
5Xf8cfKQ3qpOjkH5+Z55D70w5g3VcuJOa4Q5O0hPxp6jc2AVOaz+pf9HZ2YU
HuMzd86ruEob48f05eX0sPtPMH1VPxlHptHFduYFnVW6VV7GzVpQrOIaQo/T
H1an4qK8zJounRVHd9UPh3Nnzv/4tNJ9gPyJVgeD+T24pNg4OWeaVW2XS6cX
14yvfL0lF8eLsYpcZ6+0Mi4o3omt5qH7v9zq+eHyBQJSQN8=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 361->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VUFqw0AMFDmUfCP0B+0DQr/gvsCB5hQoOIeSm5/emramVjSj0TbOwiZx
VhrNSLN4d3jvjhszO2+/Prr+42UY+svrw/Tw1p+en07T4ePPNhv3Nn/faxs7
I2txHsQjjKxWlEf5u77Z7/b/B/hqT6JYpDXqi6/v8TIuXg/K96uJs+H4iH/E
help6SnigLRkmAoXJQ7lKfUQL4VvlYvKr4LB9KAZMb0Kpo9lZ0iDz1fmrvgi
0qVwYbpafMx6We1Zpo3pQPyrHldiECaqU6nt8Rm2glv1E+sp8zabQbRULplO
hOlzs/xSf/a2eEdmvFC/WG9VT4wiF9VvUS0lznNBfFAewo56IvcuyUH1/3s/
Kj5meIhPq8+zuEwb4of0+aXMsHonkL5snogj0qhi0xx0Luhm8/G1vJYoFnL9
w1P1IeKC5qP6wIT5tHrlSneCW/GtypXVyOYQ/UZaFQx0H/wcFrMB3lNqq1wq
s7hlfNbXNbkovZhXkqs8M62ISxSvxGZ+qN6XtfY3l0//j0Db
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 362->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tOA0EMG/UDcY2KG8ABEFcoJ1gk+KqEVD5Q/3p0KJSqjWzH7oORZle7
kzi2k5m/vC/eZmOMj9vvx2L6fFqtpvXzzfbjdVo+3C+3h3e7Pcbmcezf/7VV
PbXqOfpGGF0tlOfw37//dv0P8F1PUCzT2vng4rM6yBNU95KcK2+Uz/qYzF3K
gWnpMJM7kM6F40FdKd+Ui8svwVB6WI+UXgezxqozpqHmO3135gLpcrgoXafM
sfIy9azTpnQw/umMOzEMk9VJald8he3gpvOkPFWzrXqAlsul08kwa26Xn/jj
5CG9XZ0ag/Lr+c+7wUZnDBvVcuIqF8aH5TFs5IntXZPD6h/FFH8Rv3NmRuEx
PqfOeRfXaWP8mL66nB6md4LpY/4pPIabYHc58NzQrfpTcasWFNtx7eZQ+cnq
dFyUl1XTubPi6O764XBO5vzIp91OZpFpTfqNsAaIHQf/mWZV2+WS9OKS8Z2v
1+TieFG9czxm30or44LindhuHtL7cq39y+ULeMk/4w==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 363->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VVtOAkEQ7PBhvAbxBnoA4hXwBGsiXyQm+GH44+hK1I3b2/XoFZlkYIfp
qamqrg3r59ftbhURb7efH9vh/fFwGI5PN+fFy7B/uN+fN+++Z8RpE+P3tSa7
j428X60rDHVXdc7hP+GAfg9Tt+ER0qp8qPAUl6wHnc/jUpzHmoJvxYXpWeJp
5R3TojA77wCrQ+ec+xAvh2+Xi8uvg8H0oB4xvQ5mrmV7SEM+7/TdyUWly+HC
dC3JMfOy65nSxnQg/t2MOzUIE93TuTvjM2wHt5sn5inLNutBNVwuExzDN6dP
S3szPm9i8h+p+on8Yt66mTiZXGTeRA7yM1wLT9G57C3KmavzB0vleHYm1Spf
luRY1XWz6eZc1SltiB/Sl4fTw+47gfQx/xhHpNHFVmfKfUM360/GzVqqWsW1
k0PEBfWnkwOk6a9ZcXSrfjicOzmf8W/kimnt9LvCinzu9yw4OHe7XDo+ufVu
PysvLoGt6h0vZt4ZHqM104q4VPVOrcpD9335r/nF5QPEhD/d
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 364->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tOA0EMi/hAXANxAzgA4grtCbZS+1UJaftR8cfRYUs7arOx40xbRtqX
JuPYjvd59bnYPJjZ7un3thj2H+M4fC0fp4/1sH173U6bL8fL7Pvd2vO/LmN7
ZPn96DvCyHpF5yh/058eX/UkqkVaMx8ivIyLP4vO+3Urzq0m4BtxYXp6PPX6
My0ZpsJFqUPnlH6Il8K3ykXlV8FgetCMmF4F09eyPaTBn1fmruQi0qVwYbp6
csy8rHqWaWM6EP9qxpUahIn6VHp7fIat4FbzxDxl2WYziJbK5QJH8E2ZU+9s
LnCJP2pGmbdqJpD3oRdC3qJeSp33BfFhdW2RnCk6G1ZyJurnaz1P/96T46yu
mk0151ldpg3xQ/r8UmZY/SeQPuYf44g0qtjwfzlmqZohZT6zXpbXZvoqOURc
0HwqOUCars2Kojubh8K5kvMZfyFXkUeVDDFvIi9PvA4LZE/prXKp+KTWq/OM
vPAz6cHO6hUvmv9n75nH6FudO/KlcRFqszxU/5d7XX9cfgBENz9d
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 365->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U1tqw0AMFPkouUboDdoDhFzBPYELzZeh4HyE/OXoadpibFkzGm0fCxtn
WWk0M9LuXt+748bMTtuPn64/H8axv7w83A9v/fD8NNwvH7+32XVv0/e/trE7
svx9dI4waK0ZHyVn7teCg/vO8Xwe8sSCGsibiMvCF1ff46VcXC7K9+snnFF/
Pd+IC9PT4inigLRkmAoXJQ7lKfUQL4VvlYvKr4LB9KAeMb0Kpo9ld0iDz1f6
rsxFpEvhwnS1zDHzsupZpo3pQPyrM67EIExUp1Lb4zNsBbc6T8xTNtusB9FS
uSxwBN+UPrX2JsJV+ulzlflSZwJ5z/rCsKNaStx0TrxBeQi7VefnSnJQfcUn
hUukA+Gz96PMi+fZEpdpq3iD3oD6DtQ3gfQx/xhHpFHFpjnoXtDN+uNreS1R
LOQqvJPMT1Qn47LCFfrTOisr3QluZW5VrtUaiDPzB2lHuhFWeAazp9RWuUh9
LsbL8xd4Yb+AncUrXkz+z/5nHqNzpe9R7MRFiM3mofpe/mp/cbkBmWQ9oA==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 366->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU10OAWEMbDyIa4gbcABxBU6wEp4kEh7Em6P7l6jOdLor4kvW+rSdzrRj
uNzO1z0z2w8uH/PmMNvtmuOif72sms1kvLkGR4/H7DS11/tXj7EYOT4e3SOM
tFdQR/nb59vQ7/ZZB7kEPdBsIi5vc3H9PR7lEtSien+6cEb79XwjLkxPm5ki
DkhLhqlwUfJQndIP8VL4Vrmo/CoYTA/aEdOrYPpcFkMafL2yd8UXkS6FC9PV
xsdsltWZZdqYDsS/6nElB2GiPpXeHp9hK7hVP7GZMm+zHURH5fKGI8xN2VPb
3US4yj59reIv1RNo9mwvIXbiA/8d3pPZsLzbecSQz1SdT6zMxz4vymWz6OoZ
hsfm2MbnWV6mDfFD+vxRdlj9TyB92T4RR6RRxaY1KC7oZvvxvbyWKDfjWvEh
4oL2U/EB0tTVK4rubB8K54rPsx6IM5sP0o50I6zojryn9Fa5dPFchsXy0Szs
C9hZvjKL10lqlXtl71Gux1D8xLj8w3PncgbR20Ag
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 367->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FKA1EQG/wQryHeQA+weIV6ghX0qyC0H8U/j66lWrrpJJN5VXDhdbv7
ZvKSTPb2+W31ehUR25uvn9W8e9xs5ven6/3Dy7x+uF/vN+++V8THFMf7f1jq
wv3sOcOQZ02HxbBYH96DvY/zvhTzhAerZVorHzK8kgv0sn68fosz8s76M53O
3Bx+jAPTUmE6XJw61uecx3g5fLtcXH4dDKWHzUjpdTCxVu0xDdjvzN3JRabL
4aJ0jeRYedn1rNKmdDD+3Yw7NQyTndM5G/EVtoPbzZPyVGVbzSC7XC4LHMM3
Z06js8lwnXlir5MvNxPMezWXFLvIAf6nz4U3rO/4blrijOpcYAkuWIe1kXDJ
eI1mRuExPqM5r+oqbYwf04eXM8PuN8H0Mf8UHsPtYMsetm/oVvPBs1BLVltx
rXKo/GTnVFyUl6jp0qw4uqt5OJw7OT/j7+ZK+MO0M90ZVvws9JZkzznb5ZJ6
dHou4efMTtUrLy7FruodL9A7x2P2rDLEuKTeGLVVHrrfy1+tA5dPekI+nA==

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 368->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQHPwIXkO8QTyAeAVzgg3EL0HQD/HPo6tRlmzb9eg1gQyMu+N0
V1d1184+d+vNpLV2mF5/1t1xtd93p4+32+Gr2y7et7fL+WO3dl62/vkfNlvx
PjtnGLTW8r4RFspzn5EXxPzBA8UiraoPGZ7sS8hF+XH9FufIO8vPdDpzc/gh
DkiLwnS4OHEoz6mHeDl8q1xcfhUMpgfNiOl1MGMsu0MaYr4zd8cXmS6HC9M1
xsesl9WeKW1MB+Jf9bgTgzBRnUrtiM+wHdyqn1hPmbfZDLLlchngGH1z5jR2
NhmuM8+Y6/jL9QTqPZtLii18EN/hWfQG5T3VAT5zdX4vkdMv4QXWi1c9w/BY
H8f4XMUpbYgf0heXM8PqN4H0qXkijkiji+34JftP6WZ5ETdqyWIZ10b0OPNB
dRSXJ1xjPmO9kumu+FDFuZiUf8FXTKuDgb6HOIdBHPCeU9vlwnwxOIv5ZHcs
nvXiVWwV7/SiX0E76zE6Mw8hLmlvjFjlh+r38lf7zuUClnM94Q==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 369->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVUEKwkAQWzyI3xB/oA8ofkFfUEFPgqAH8ebTVdRqp5NMZr1YqO2ys5kk
k+J0c1jtRqWU0+T+s2rPy+OxvazHj8W23S/m+8fm7HWXcm1K9/yHm11231t7
GGEv51zEUX1aXhCz+fBAtUir64vpb/EkX4AO1PdXzqi35etxYXpqPEUckJYI
U+Gi1KFzSj/ES+Gb5aLyy2AwPWhGTK+CaWvZHtJgzytzV3Lh6VK4MF01OWZe
Zj2LtDEdiH8240oNwkR9Mr0tPsNWcLN5Yp6ybLMZeJfKpYcj+KbMqXY23XtT
uv9YZZ7IL+atmomryIXy+8LwennvcB14is4NvAU5U3W+saIcD858rwVfanIc
1bFs2m+A+Zmti7QhfkifvZQZZr8JpA/5x/AQbgYbfi8kT4puNp9BryLUBlyj
HDI/EXdUC3GF+dRmxdOdyWFUp2JS/kKuvLlnMsS88bzsrUH2lN4qF5YL6xOq
R3usHnlhZ1KDHdUrXnRX4KOyzszdq0W9lWx6XP7hfnK5AVnBOiA=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 370->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG+gBgleIJ/iCrgJCXIg7j65R+Zqmq/r1ZJOBn5/h
91RXVddcP75sny/GGK9XXz/b5e1+v1/eHy4Pm6dld3e7O3y8+X3G+NiM9X0O
j1vxe7bPMMpeybmKI31HXhJz88dD1SqtqS+hf8RDvggdqu+pnFXvyDfj4vTM
eKo4KC0VJuFC6tQ50k/xIny7XCi/DobTo2bk9BLMWOu+KQ3xPJk7yUWmi3Bx
umZy7LzselZpczoU/27GSY3CVH06vSO+wya43Tw5T1223QyyRbkc4QDfyJxm
Z3OEa/yhGXXe0kxQLsQ31Sv7L/eFp+qcws48wd4VZ5z+VcvE/ahyXNW5bMY7
ELGd1qqu0qb4KX1xkRl274TSp/xzeAq3g12d6WaIzCfiRi1preGaZYzyVLoc
F4kL5jOblUx3J4dVHcW0/Bu5cloJhroPKgPfS2SP9KZcOj7Repw/4cWp2FU9
8WJd/2ZReaz2nblntRGDeqi4nMPzw+UTQe49og==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 371->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVVFKA1EQG/yQXkO8gR6geIV6ghX0q1CoH+KfR9dWW3xjksnsKvhgu33s
vEwyybZXD7vN00VEPK8+PjbTy91+P73eXx42j9P29mZ7eHj9dUW8reN8/w+X
Wvk52iOMshc4V3F075mX5AJ6sNkgLsNcUv+MZ82F6GB9l3JmvTNfxEXpmTNT
xoFpqTAdLk4dO+f0Y7wcvl0uLr8OhtLDPFJ6Hcxcq54xDfm847uTC6TL4aJ0
zcmxmmV3ZpU2pYPx72bcqWGYrE+nd8ZX2A5uN09qpirbygO0XC4DjjE3x6e5
3iBcx8981smXmwk2e+ULxD5doBf6TvfFbI6L1A2L5MzVecKocpzrBgzAM39f
mhmFh+qZ5u9rbl2ljfFj+vJyPOy+E0yfmp/iyDS62NWZboYcfzJu1oJqK66d
HDIuzJ9ODpimpVlxdFd+OJw7OXfycFzEN6a14zfDgvt1/PiNzDUqRw4Xy+dm
vesnmkX8AnZV78ximH8E/w8z9h3fUe2Zi1Fb5aH7vvzV9cnlHa6ePSA=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 372->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3oI+UbpD9oHmH7BfYELzclQcA4ltzw9MS0uGaSRxm4hC5vN
sjMaaUZ+fP/sDw+tteP++tMPX6/TNJzedvPlYxhfnsf58elnt3bu2nLew85W
fEd3hKFqoTzF0T0jfsoF1GC9QVyYHoTn9IXpYHX/knPkjfLZHNXcHH6MA9Oi
MB0uThzLc+oxXg7fKheXXwUj08NmlOl1MGNs9sY0xHxn7o4vkC6HS6ZrjY+z
XlZ7prRlOhj/qsedGIbJ6lRqR/wM28Gt+inraebtbAZouVyUToYZc1V+pT9O
HtKr6sQYlB/fWe8pJsMWPoj/6d2dl+HxeJZ0tlutcq6Ij9GXrZ7J8FA80xx7
tyZOaWP8mL64nBlWvwmmL+tfxpFpdLFVTtVDznwibtSCYhXXig8ZFzafig+Y
pq1ecXSreTicKz53/IA4Z/1h2pluhsXuiINT2+VizbkY786T9WIrtop3erGs
7vdUPWb3ytxR7A0PEav8UP1e/mt/c7kARnI+5Q==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 373->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3Io+UboD9oHmHzBfYELzclQcA4htzy9NS3BnUgajdNDDBuz
2VmNpJF375/9YdNaO26/f/rhtJ+m4fz2NG8+hvH1ZZwPn39Xa5euXd+PsNQT
z9EeYdBeHb+XcYRvcB7xJRfQg3mDuDAfEJ7jC9PB+v4n58gb3Uc6nbk5/BgH
piXDdLg4deye04/xcvhWubj8KhhKD5uR0utgxlp1xjTE+87cnVwgXQ4XpWtN
jpWXVc8ybUoH41/NuFPDMFmfSu+Ir7Ad3GqelKcq22oG6HG5ZDoZZryb3a/4
49xDerM+sQbdj+fM+z+YhbyhXk7ddZ/Na7mAnohd0gmwZI6XPRAf8L+DW8mM
wlM+rsl5VpdpY/yYvvg4M6x+E0yf8k9xZBpdbPq9qDwZutV8bno1ozbRV8kh
48Lm4+Zg6VXUdG9WHN3ZPFSdi1npwTgrf5h2ppthsT3i4PR2uVhzLtbb+SNe
3Iud1Tte3HhneMz2lbmj2ojhesi4PML64fIFsmg/ng==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 374->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHFyI1xBvoAcIXiGe4Am6CghxIe48ugZleLT166eLDExehumu
ruquuX582T9fjDFer75+9svb/fG4vD9cng5Py+Hu9nC6vPnZY3zsxvyew1ar
3qMzwnC1UJ7jCL/gvuJTzJ2PZVpdHxBe0hemg9X9T86VN8pnc3RzS/gxDkyL
w0y4JHEsL6nHeCV8u1xSfh0MpYfNSOlNMGusumMaan4y98QXSFfCRena4mPV
y27PnDalg/HvejyJYZisTqd2xVfYCW7XT6qnyttqBmilXJxOhllzXX6nP0ke
0uvq1BiUX+/n/xDTYaNaSdw8rzbksvoiPahfTHPSO+njdQ3EZ+P76HhG4aF4
prn2bkuc08b4MX11JTPsvgmmT/VPcWQaU2yZw+4D3Wo+tVbVAmMN144PGRc2
n9QHI5jPVq8kut08VFyKKfkjXDE3pjXxJnsPcw6A21hxRPVV7ZSL8kXtE4tn
dyre9fUv2C4+6cVcwhfpWWllXH6thp8cl3PY31w+ATm8QBo=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 375->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3Io+UboD9oHmHzBfYEL7ckQcA4htzw9dVsCnkgajdtCDY7Z
WKuVNPLu9dC/b1prx+3HTz+c9tM0nF8e5sXbMD4/jfPLx++7tUvXbs//cKsr
vkdrxCHPImdnGt1n1EU5u3stKhukheWA+JxcmA927m9qjrrRfuTTmZujj2lg
XjJOR4uDY/uc85guR29Vi6uvwqH8sBkpvw5nxKp3zEPc78zd6QXy5WhRvtb0
WGVZzSzzpnww/dWOOxjGyc6pnB35FbfDW+2TylR1W80AXa6WBY+RmzOntbNB
vM48416nX24nPp8dzobNRXGjsxxc1MK8LnDAT+RGmVSyy3os9YD/Hd5KZxQf
xLM8G8ZXcJk3po/5i5czw+o3wfyx/BQf461wyz2FbmZ9iB6UF4hNtGY9VHky
7QxLeY35rO2K4zubh8K5nFI/4hVzY16dbrLvIc5isQY9WmDE2a6WSk4u3u6f
yPUn3BneyeJ2iV64azl3ogXhHWzWB/c7+ev7S8sV048/2w==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 376->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0GKAkEQa/YgfmPxB/oA2S/oC0bQkyDMHpa97dPXQfEQK6lUq2DDKE1X
pZNU+nN32hw+Wmvf8/PPZvj5GsfhdzubNvvhuFoep8PF9Wvtb91u/+/wqYXn
0T7CkHeRuzOO7j/yyjBVLdOa+eDioy9MB7v3mZyRd9Qf6XTm5vBjHJiWDNPh
0psLxwNcVb5VLi6/CobSw2ak9DqYWKvOmAbsd+bu5CLS5XBRunpyrLysepZp
UzoY/2rGnRqGye6p3I34CtvBreZJeaqyrWYQLZdLppNhYm/WX/HH6Yv0Zvdg
TdSP58x7NReFHd3l1LG9o09x6tUZ4WSzj3i3jvdRyYzCi+qZZvSupy7Txvgx
fbicGVbfBNOn/FMcmUYXO+upZsiZD+KilrA24VrJIePC5uPmoBnz6c2Kozub
h6pzMSX/CFfMjWl1ssneA84i8xBrVI4cLhWf3Ho7f8SLR7GzeseLO+8Mj9le
zp1wieqd2iwP1ffyqu/C5R/PokHj
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 377->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRD9ZSK4RvIEeIHiFeIIRdBUQ4kLc5egxQYK0XdWvZ7Lww2T4
THd1VXVl8/K+e1uNMT7W3z+76fPpcJi+nu/Ol9dp//iwP3+8/3nGOG7H9f0f
Hnfi9+yeYdhZYnbFkb4jrwrT1SqtlQ8UX83JPMnm3pJz5J31ZzrJ3gg/xUFp
qTAJl7m5IB7E0+Xb5UL5dTCcHrUjp5dgxlr3TWmI/WTvJBeZLsLF6ZqTY+dl
17NKm9Oh+HczTmoUpprTmR3xHTbB7ebJeeqy7XaQHcql2p/6Rnq7u8lwyT5j
L8kXzcTlXWAT39wsUqfuRJ/jlPV0vKty7Pj89lZ5sTQzDi+rV5qjd3PqKm2K
n9IXD9lh9z+h9Dn/HEelkWJXPd0Mkf1E3Kglq624dnKouKj9dHKgNC3NCtFd
7YNw7uSc5CHj7PxR2pVuhTUKb9MeM5tyQXtu1tN9Ki+WYlf1xIvrKXrJ3e5d
cPlzkoyQbGZcbvGMpf0XLieEk0Dl
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 378->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FKA0EQbHIQvxH8gT5A/EJ8wQp6CgjxILnl6RrUZdOpqq6eiDiwSSbT
U11VXbt+et28rCLi7frzYzO9P+x20/7x6rh5nrZ3t9vj4c33E3G4j/n7r55Q
Z2Llc7RHGLLXgo9zZ+mX8515VZiqlmmtfHDxWR/kCer7m5wzb3Qf6XTm5vBj
HJiWCtPhMpoLx4O8uny7XFx+HQylh81I6XUwc606YxryfWfuTi6QLoeL0jWS
Y+Vl17NKm9LB+Hcz7tQwTNan0zvjK2wHt5unk9+NbKsZoOVy+eERhA/DzHpY
T8dDyMnUge46+XIzwbxXc1HYqJdTx/aOPsVpVCfCqWbPeCsvLs2MwlM+juS8
qqu0MX5MX17ODLvvBNNXzZNxZBpdbCcv6L9Kt7qXcbMWVKu4RvGeVH6yPhWX
M1xjPqNZQbo7OazqXEzJH+GquRGtTjbZ+zDPAXm74Ij6q94uF5WL7BOrZ2eq
vvL1Euyq3vFiXsVdZ6+0Mi5nq5Gnist/eL64fAAv/0Bf
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 379->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlkFKQ0EQRBsX4jXEG+gBgleIJ4igq4AQF+LOo2tiEn7GrurX3yAOfMMw
PdVVXTXg9ePL8vkiIl6vvv4sV2/3m83q/eFyu3lare9u19vDm/0X8bGI4+9f
fbH/0jOzxvNsn2FIHod14ATuTOdFfkdeJaapVVqrOWR4aC5Ch+p7Ts4j7+x+
ppP4RvgpDkpLhUm4kDp1j/RTvAjfLhfKr4Ph9CiPnF6COda6M6VhvE98J7nI
dBEuTtecHLtZdmdWaXM6FP9uxkmNwlR9Or1HfIdNcLt5cjN12XYeZItyqfxT
Z+Ru15sMl/g53iX5oplQs3e+OOysF6lTe6LPcZqrM8OpvFe83Sx+mxmH5+Y4
J+f0LbnMkAy5N0DfAX0TSl/lp+KoNFJs+V4WcfL//fSc6Hb3fvQKUFvo6+RQ
cVH+0BwE8GduVojuyg9XRzE7PXbLZUxoJXlW7+HoQzHbrL/rTbm4XEz3ZHZd
P7NZnAO7qiez2K2JN2TGau+0Ki5Z/egLyWbG5T9831w+AT3MPqI=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 380->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FKA0EQbDyI3xB/oA8IfiG+YAVzCgjxIN58ugazYaetqq7OgrgwuztM
d3VVd83t8+t2dxURbzffr+30/ng4TB9P18fNy7R/uN8fD+9OK+JzE+fvX604
LXgmnnyO9giD8pifmZORs+zXwGEz4izxcx7ryfAFsUwr7Euqn/EqLkoHq7uW
M5tv5ou4KD1Kc5cD01JhOlycOJbn1GO8HL5dLi6/DobSw2ak9DqYOVadMQ05
35m74wuky+GidF3iY9XLbs8qbUoH49/1uBPDMFmdTu2Mr7Ad3K6fhv+Gt9UM
0ONymXkE4cMwsx5W0+kh5GTqQLmOv1xPnP9NzAob1XLihr3hHcfj+Vv1kGGz
HFbfvh8FF6Qj5yg8xudSn1dxlTbGb8Au7oB7D9w7wfTNdwL5kOExXIgNYlXO
kks+d3SrvF+1oo6t9HV8yLiw+XR8wDSt9Yqju5qHw7njc8cPzENKa2feCCtA
7Mwl88kxykcOF2vOzXh3nqqva7CreKcXy/6rXGevtDIuKD5zcbyJuPyH9cPl
Cw3nQhQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 381->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FqQkEMDH6UXkO8QXsA8Qr2BE9ov4SC/Sj+9eit1ZW3eZnJxCelC6uu
m0xmktnl7n37tjCzj8efj+3wuTkchuPLw+nwOuyfn/any9Vlm32t7fr9l9vQ
/2T5++gcYUAObV34KDnjfnUc1j3OGN/nsX4YiUVasz5EeBkXpgPVvSdnzzvK
j3Qqc1P4IQ5IS4apcFHiUJ5SD/FS+Fa5qPwqGEwPmhHTq2D6WHaHNPh8Ze6K
LyJdChem6xYfs15We5ZpYzoQ/6rHlRiEiepUant8hq3gVv3U/S54m80gWiqX
xsMAH4Tp9aCaSg9DTqKOKFfxl+qJ6+8CJsOOailxk3PmnbYTvYi/2juW08WQ
mbJezPUMw0N8bvV5FpdpQ/w67OQNqO9AfRNIH3sXCA/hRthRLMuxERd/r+hm
eZNalsdCrkHPmFbGBc2n4gOkaa5XJrpFLqpfVcxKjTYf6DGgVfEz6jfyQPNJ
xEGprXKR5lyMV+fJ+joHO4tXevG73AyyHqNzZe5RrMdQe4i4/Id95vIN7wNB
1Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 382->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FqQkEQG/pRvIb0BvYA0ivYE7xC+yUI+iH98+itVh8yJpnME6EP1nXZ
2UySzc4/Nquvp4jYzX5/VsP+bbsdvt+fj4vPYf26WB83X84j4rCMcf4PQ315
H60RRtlreR7GmWu/nDnzoph5BrVMa+UDwqu4BMBmHijfpnLOvNF5pNO5N4cf
48C0VJgOF6eOnXP6MV4O3y4Xl18HQ+lhd6T0Opi5Vu0xDfm8c+9OLpAuh4vS
NSXHysuuZ5U2pYPx72bcqWGYrE+nd8ZX2A5uN0/KU5VtdQfoc7mc5ssA5xhm
1qO0VB5CTqYOdNbJl5uJ8X8DU2GjXk4dW9PsGBnPc+UhwqpyrPhMfR+dzCg8
xmdqzqu6Shvjx/Tlz7nD7ptg+tS7UByZRvXfyUtcccn7jm517qZX1LUV104O
GRd2P50cME33ZgXp7uTQ5dzJ+Q1/I1fIo06GlDdj3WUIb1F/1dvlAj0iPrF6
tqfqK1/vwa7qHS9OX+Gpu1ZaGRdU79RWeei+l0eNPy4/6uE/Xw==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 383->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA0EQRJt8SK4h3kAPEHKFeIIVzFdAiB+SP48egyZseruqqzYKDmx2
N9tT86qn5v7lbbNdRMT78utnM3ys9/vh8Hx3enkddk+Pu9PHh58r4nMVl/t/
uNjI36v3SkNZC2mheeo9c7majLdaq+pDpeeyoPl5/BYz60fFwvwwzy4D8tJp
KixKHZqnrIe4FF6XReVzNJgftEfMr6KZa9m37hw5+67kovKlsDBfc3LMeun2
rPPGfCB+N+NKDdJE6zhrZ32mrei6ebp6NrLN9qAaKsuZIwAP0sx+0JpKD0sm
0Uc1V8mXmonLs6HJtKu1lDr0rvhjfhG/o81YGE97PhqWykeew/RYH+fkvKvr
vCE+5C8PZQ/dM4H8sXPBGJFH9qzkJUYs+bvim82brBV9befPySFiQfvj5AB5
ujUriu9uPxRmJ+dXfSqyi5hZf5B35HsyziypFvUw17AcKSyT/ox4xv91+1Nq
kfqur7dod/VKLxDbnHdHr8xI6LVdHtzz8lfXN8sRzr4/Yw==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 384->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FOw1AMRC0WqNdA3AAOUHGFcoIg0VUlpLJA7Dg6FJEqcWbG47QLvpS2
v99//MZ27l7edvubiHjf/Hzsho+n43H4fL49bV6Hw+PD4XR4//dEfG3j/P0f
HrXyOdojDScX02L33O/M1dVUvCgXqgPS67Kw+3ldi1nVA7EoP8pzl4F5qTQd
FieO3XPyMS6Ht8vi8nU0lB/WI+XX0cyx6qx6jzp9d+YC+XJYlK81c6xq2a1Z
5U35YPzdGXdimCbL08md9ZW2o9udp9nvxmyrHqDlspz/IzxMM4rzNb1B/S/7
mVicXnRmIvt1NJU2yuXEsb3jT/ll/B1txaJ4xroG6XvFgnws9IUe40Gec+1Y
bVRc5Y3xLbTB+fQuY1zzTjB/0965ekwXaoNYdWfKks8d3+reIlfUsZW/ag5V
PVmeikXVMnu6dFYc31U/HObOnM/qBGaXMav6MO/M92KNLCmW1TDHqDlyWKw+
N+PdfuZ1Le0q3qnFbJk1ZnvllbGg+JEF8Sgdtx/dJy65+8vyDbNSPp4=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 385->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVUFqw0AMFD2EfqP0B80DTL+QvMCF5mQoJIfQW5/ehBTjajWj0bqFLGyc
9WpHM9Isfnr72B0ezOz0ePnZjefX43H83G+ui/dx2r5M183nn2n2Ndj8vIfJ
ht+P1hGGkgthoXP+acNtNu+tPadiZnyjXFEdIrwqF3Tej7/izOoRcWF6mOYq
B6Qlw1S4KHHonJIP8VL4Vrmo/CoYTA/qEdOrYPpYtpfdo0rfFV9EuhQuTFeP
j1ktqzXLtDEdiH/V40oMwkR5Krk9PsNWcKt+YjVl3mY9iIbKZX432PyNVXzq
9TAtWQ0hJ0HHkneWx8d47j4n+p9hMuwolxKH1oo+pneNzug8633E2zruR8Uz
DA/x6fV5FpdpQ/yQPj+UHlbvBNI3966Ah3BD7CCWnVly8fuKbnauyWV5LOQK
PKbyRLoULg2u0J9erzS6E9yKb1WuLAfsA/MY0Kr4Gd0H3wfPxfPxMcxHChep
z8V42X+krmuws3ilFr+GWGO0ZloRlyheic38UL0v/zVvXL4BnBA/Hg==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 386->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqAkEQbHIQvxH8QfIA8QvmBRuIJ0HQg+SWpydL3GXsdFVXzxJwYVyX
qamu6q55fj/tD09mdln//OyH6+58Hj7fVuPHx3B8fTmOm5vbMvva2vx+hMUe
vx99RxxKLcSFzkXvaN/r6uVkXrM+MI2qlswj6luvZtaPSAvzwzxXNSAvGaei
RcGhc0o9pEvRW9Wi6qtwMD9oRsyvwumxbC+7R5W5K7mIfClamK+eHLNeVnuW
eWM+kP5qxhUM4kR1KrU9P+NWeKt5uvtfyDabQfSoWiYdBvQgTkv2e2YTzV+Z
Z6tFmUUlE95vyplwR7UU3PxNZoX8Mb/RmUrv2BlU3+eI9WJpZhhfhEeefe96
cJk3pA/5848yw+qdQP7aLKp8iDfkDrDsTKvF7yu+2bk/tSzHZlorOURa0HzU
HFi7nKelWYl8pzks5FXlRPqj7LazCecGvCp5Rvdh1uKwkxavx2NYjhQt0pyL
eDl/pK9LuDO80guki/UYfTOvrIbHK9hMa/W+/Nf61fINPf5DVQ==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 387->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOA0EMizigfgPxA3jAii+UFywSnCpVKgfEjadDKVrRrO0400tHmrbb
yTi247172W/fbiLiffPzsZ0/ng6H+fP59vjwOu8eH3bHw/u/HfE1xfJ9DVut
1fm0PkcYTi/0rO6hb3SeeY1iMn6Ke9aG+rlcKo3Mt1HOyg/ERelRmrscmJYK
0+Hi1LF7Tj/Gy+Hb5eLy62AoPWxGSq+DmWvVWfUedebu5ALpcrgoXSM5Vl52
Pau0KR2MfzfjTg3DZH06vTO+wnZwu3nqeqAyqJbLZflvOu3KN2dOo7NBuM48
I3FyvHUzsfw2MSts1MupO3sWfJA+xQnd6Xin7rD+ZzWFF5dmRuGheqY5ezdS
V2lj/Ji+vJwZdt8Jpm+ZXQOP4UJsUKvu/OeSzx3d6t6qV9S1FddODhkXNh83
B2HMZzQrSHeZw0ZeXUzGH2WXcVb+MO1MN8IKUPu7QKZzjcqRw8Wac7Pezp/w
9RLsqt7xgvFSHrNnpVX1yPXLMj1kXK5hn7h8A2vWQds=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 388->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqAkEQbHIQvxHyA/MAyRf0BSvEkxDQQ/Dm01WMssxWVVcPERyYXYbu
qa7qrnnf/Ky2bxFxmF8+q+H3a78fjuvZ9fA97D4Xu2vw429HnJbx+L/CVmsS
X07jCMOphc7qHvqjeMurF5PxU9xbbaieyyXTyPrWy1n1A3FRepTmKgemJcN0
uDh57J5Tj/Fy+Fa5uPwqGEoPm5HS62C2uSqWvaPK3B1fIF0OF6Wrx8eql9We
ZdqUDsa/6nEnh2GyOpXaLb7CdnCrfqr2QHlQLZdLNj8Wc+5WZ4NwnXkG6Y/q
resJ1nuKmWCjWk4eO1Pv3DfRO4516Qx8X80e8W55OrgVzyg8xqfX5+5bYtoY
P6avXc4Mq2+C6RvPzsVjuBAb5Ko7Yy5t3NGt7k1qRZ6bcc18qPrJ6mRcJrjG
fHq9gnSnPiz41cVk/JF3GWfVH6ad6UZYAXIfS2hWtV0u1pyL+bb/QC/+AzvL
d3rBeKkes7PSqmq0+U5uxrX6Xp61b1zOiW8/Xw==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 389->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1EOQUEMbHyIa4gbcABxBU7wJHxJJHyIP0dH8EJ1ptOHxCbrZW07nZl2
h8vtfN0zs/3g8jNvDrPdrjku+tfDqtlMxpvr5ei+zU5Ta7//sNny99E5wlBq
ISyUF32je8+rKybTmvnAOKpcMo3It66cmR8RF6aHaa5yQFoyTIWLEofylHqI
l8K3ykXlV8FgelCPmF4F08eyu+wdVfquzEWkS+HCdHWZY+Zl1bNMG9OB+Fdn
XIlBmKhOpbbHZ9gKbnWeqh6wGWRL5ZL1D90pudXeRLhKPw34w7xVZwJ5zzAZ
dlRLiWvPj/8K+pjeT3RG+az3/py9j4xLpMPnMDzEp+ucq28JaUP8kD6/lB5W
3wTS185iAQ/hhthBLMt55uLvFd0s762W5bGZvsocIi6oP+ocoPWNWVF0Z/1Q
eFfm/MWnYHYRZ+YP0o50R1gWxLaLaGa1VS5Sn91We8fwM18/wc7iFS8QL+Yx
OjOtrIaPV2IzrtX38qt943IGtY9A4Q==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 390->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k1FKA0EQRJt8iNcI3kAPELxCPMEK+hUIxA/xz6NrMDssvVXV1UYHNslk
eqpfdfdun4/7101EvN1+f+yn98fTafp4ujlvXqbDw/3hfHh3eSI+dzG+3Sca
sd1HrdX5hWV5jjScXGiv7sFvcJ65upqKF+VCdUB6XRZ2P6+/Ylb1QCzKj/Lc
ZWBeKk2HxYlj95x8jMvh7bK4fB0N5Yf1SPl1NHOsOqveo07fnblAvhwW5es3
c6xq2a1Z5U35YPzdGXdimCbL08md9ZW2o9udp24N1Ayq5bJU/WNnYc6x65cx
lf1MLE4vOjPBak81C22Uy4kb+/m/hj84L2TObJ+B76ve5/3wQ/peseQ4qC/0
GA/yvFyqNiqu8sb4mL+8nB523wnmb9k7V4/pQm0Qq+4sWVbnhm/Vn1WuqGMp
K5kx5lWxsP64czCzIE/XzsrKd6E787jz6moy/qoP6Dfz6miw92GwpNixhGeV
22Wx+mz0B2kp/aqu12hX8U4tGJeqMdsrrypHjndiK9bu+/Jfzw/LFz3iQBg=

                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 391->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1FKQ0EQG/wQryHeQA8gXqGeoIL9Kgj1Q/zz6FqxxY5JJulzYVuWnc0k
mbzrp5fV5qKqXq++flbrt4fdbv3+eLk/PK+3d7fb/eXNz676uK/jv7srqE23
Wv3+wOX3GWE4vdBZvYP/4L7zSjEVX9QL+YDwUi7sfV//xVn5gbgoPUpzyoFp
mTAdLk4de+f0Y7wcvikXl1+CofSwGSm9DmavVXfTd5TM3ckF0uVwUbrOybHy
MvVs0qZ0MP5pxp0ahsn6JL07vsJ2cNM8pR6oDKrlcpnmx+7KzLGrl3Ea59m4
OLNIMsG8p5gDNurl1LGzo0/pPVsnwJlmz3grL5ZmRuHBeqK5e8e8UXWTNsaP
6evLmWH6TTB9yKsJj+FCbFCr3hT49hwcZz5/etVcO3Gdcqj8ZH0mLsrLrmlp
VpDuJIcu5yTnJz6B/DLOyh+mnelGWAVqj0toVr1dLtac23Znp/AnX5dgT/WO
FyfL9JidlVbGBdUfuCA+CsedR7pZFqy331w+AcWsPp4=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 392->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAlEQbLIIXiPkBuYA4hXMCUYwK0HQhbjL0RMliNNUVVfPuMiDUZ+v
X3V9et62h83XS0ScFr8fm+G8Ph6Hy+frdbMb9h/L/fXw/e+J+F7F/fs/PGrl
89t+Nd4jDKcX2qt76BudZ15TMRk/xT1rQ/1cLpVG5ttUzsoPxEXpUZq7HJiW
CtPh4tSxe04/xsvh2+Xi8utgKD0sI6XXwcy16qx6jzq5O3OBdDlclK4pc6y8
7HpWaVM6GH9HSxR6Ki8rzzq6M77CdnC78zT63ZhtlQFaLpcqP3bm3O1mg3DL
PNN8OVl0ZoJ5rzAVNurl1LG9o0/pnaMT3VfZM97Ki7kzo/BgPdGcvWPeqLpK
G+PH9OXlZNh9J5g+5BXyEC03e6YD1cVD38yR8iy4qGyr2kpfNYcqH9an4qK8
zJrmzoqju8rD4dyZ85FPYC4YZ+UP0850I6wAtWyf/1Nz5HCxcm7Wu3kiL56B
XdU7XjBeymO2V1pVj1x/X6aHjMuznphz98blB0ZgQN8=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 393->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qQkEQhBsXIdcIuUFyAPEK5gQvkKyEgC7EXY5ulCDPtqq6eswiD56P
cXpqvuqfp/ev9eciInaPPz/rab/abqfD28Np8TFtXl82p83n3zfiexmX7394
1ZP3z+vl9RppOHehtTqHvmg/c41qMj7Fnr2h+1yWyiPL2yizygdiUX6U5y4D
81JpOixOHDvn3Me4HN4ui8vX0VB+WI2UX0czx6q9ao46dXf6AvlyWJSvkT5W
uZS1GvCmfDD+ykvM38IvY6hy5uoiZqXt6Hb7qZsD1YPqcVnK+pE952y3NkjX
qWc+6+TW7Yl5H7uaShvd5cRd1rNZcv0pv4y/o61YFE81HxUL8pHPKD3GM9rn
7iwxb4yP+cuPU8PuTDB/aiaCeGC6UBvEqjMxu7ej49Tn5q6oYyt/nT5kLKw+
nT5gnu7tFcd3VQ+HudPnV3kC/cuYVX6Yd+YbaQWIZev8n+ojh8WqczPerSfK
xV9oV/FOLhiXyjFbK6/qjhzvxFas3XmR9bvn7JnlCIlLQKA=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 394->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0Fqw1AMREUXIdcovUF6gNArpCdwoV0FAskidNejtynFuIpmNGNnEYPj
fL7+6I2k//h22H08RMRp/fOzG84vx+Pw+bq6LN6H/fNmf9l8+nsjvrYxfu/h
ZU/er9aVhpILaaFz1bfaz1xzNZnXrg6MUWXpPKK6zWVm9ahYmB/m2WVAXjpN
hUWJQ+eUfIhL4XVZVD5Hg/lBPWJ+Fc0cy/a6e+T0XZmLypfCwnzNmWNWS7dm
nTfmA/ErXnKccg8qTZTH8Y1YWL5bzpNbAzaD7FFZuv6hPeWs2xtnViq/XZ4c
U53P++N/Q5NpV7mUOLRW/DG/iN/RZiyMp7sfHUvlI59heqyOc+ZcvUvIG+JD
/vKj9NC9E8gfuxMBPCDdUruIZWdikjczMh2lP1e5oo/t/DlziFhQf5w5QJ6W
zoriu+uHwuzM+b86Gb1i9VE1UL2nLNPY8SGeWW6VRerz5HV6x/S7ui7R7uKV
WiAuVmO0Zl5ZjhyvxHas7n2h/Vty9pflG595QGM=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 395->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqwzAQFP0ouUbpDdIDmF4hPYELyZeh4HyU/OXoeVCMI+/MzkT+qEBx
hHZnZ2ZXb98/u8NLKeW4uf7s+t/PcexPX6+3w74fPrbD7fL9b5dy7sr0/Q+b
rcV9t7yPMJRa0Znlhd/gvublYjK+Ua3IhwjP5YLy67UWZ+ZHxIXpYZpdDkhL
hqlwUeJQnlIP8VL4ulxUfg4G04N6xPQqmHUsu8vekdN3ZS4iXQoXpuuZOWZe
up5l2pgOxF/RUscp7yDCRHUc3YgLq7fmPLkesBlkS+WS9Q/dKblub5xZeVjA
H+atOhPIe4bJsKNaShw6K/qY3hadUT7rPeLNvGidGYbHfHxmztW3hLQhfkhf
vZQeum8C6bv/N/EQbogdxLKcMuNTc2Q4Sn8WtUoem+lz5hBxQf1x5gBpap0V
RXfWD4WzM+cPPhm9Yv6oGMjvOZd57LSIZlZb5SL1udpq7xh+5msLdhaveIF4
MY/RmWllNep4JTbj6r4X2r+W3DuXC+3DPqQ=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 396->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKAkEMGzyI3xB/oA8Qv7C+YAU9CcJ6EG8+XQVdtNuk6Y4HB1YZ2qZJ
2pnvTs1hUko5zx4/TXvZdF173U6fl317XC2Pz+Di9ZVyW5f+/x8+dgbx9TDu
YSi9vDur8/69uOU1FhPxY9ytNq+fyiXSiHwby5n54XFhepjmLAekJcJUuCh5
qE7ph3gpfLNcVH4ZDKYHzYjpVTBtLotF7ygzd2UvPF0KF6ZrzB4zL7OeRdqY
DsRf0WLzlHfgYaI+Gd2IC+v3y33KesB2kB2VSzQ/FFNqs7PJ7IqnN+pjc7x6
G0feM0yG7fVS8vp74I2nj+mt0enVs9kj3syL2p1heMzHMXuuviWkDfFD+uxR
Zph9E0jfexczeAjXxXZyWU0RMFW/0ZtAWrzcDBfGkXFB88nsAdJUuyuK7mge
CufMnn/5lJgV80fFQH5/cvnM7Q/RzHqrXKQ5m0+dHcOPfK3BjvIVLxAv5jG6
M62sh81XciOu2fcSza+u9g4Gsj8m
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 397->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvYA4QvEI8wQi6CgTiQrLL0ZOohLHz6tezcWAydPp1
vap61Y9vu83HXWvt8+H8s5m+Xvb76fB6f1m8T9vV8/ay+fT7tnZct+v3P7zs
6ferdYXh9EJY6Fz1rfZ7XqOYTKvygXF0uSiNyLdRzsyPigvTwzSnHJAWhelw
cerQOacf4uXwTbm4/BIMpgfNiOl1MPtatqfuUTJ3JxeVLocL0zWSY+Zl6pnS
xnQg/mnGnRqEifokvXt8hu3gpnlKPWAZZI/LRc0P7Tln09lUuHKe65+38od5
62YCeQ8xBXbVy6m7roU3lT6md1hngaNmj3gzL5ZmhuExH0dy7t4lpA3xQ/r6
x5lheieQvnnWb/CABoRbYhe17EzVc35flG42n5teTdcqfUkOERc0nyQHSNPS
rDi61TwczknO//gUzIr542Igv+dc5rVo3f/HcuRwSWbRwtkxfOXrEmxV73iB
eDGP0ZppZT36eqdWcU3vC53fkrPfXE4ynkPf
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 398->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U0FuwkAQW/VQ9RsVPygPqPoFeEGQ4IRUiR6q3vr0FgTRZhh77KSNtCTL
znhsz+zz7n1zeGitfTz9/myGz7fTafjaPp43++G4fjmeD1fX1dr3axvf6mpG
rLvYc3d+5dKfZxhKrWzP8rJ3dh55zcVE/Bj3qC2rp3KpNCLf5nJmfmRcmB6m
2eWAtFSYChclDuUp9RAvha/LReXnYDA9qEdMr4IZY9lZdY+cvitzkelSuDBd
c+aYeel6VmljOhB/d8aVGISJ6ji1Iz7DVnDdeXI9YDPIHpVL1T90puS6vclw
lX7GXMVbdSbGbwOTYWe1lLhx3y1VX+oZmLP+W8VGOaj+JOa2gBdLZ4bhIT5z
51y9S0gb4of0TR6Cs+ROIH3sTkQu8WGeIK1VTlZTwVH6c1er1bEOF8aRcUH9
ceYAaVo6K4ruqh8KZ2fOJz4ZvWL+qBjI755LH4v28T82RwoXpxd/GV/5+p9c
FC8QL+Yx2jOtrEaMV2Irru59of1bknvh8gNPBkGe
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 399->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU9sJAkEQW/wQ2xA70ALEFrSCE/RLEPRD/LN0H6h4yyST3Cl4oOe6M9kk
kx2v98vtoJRyHN2+ls1pcTg059Xwvtg0u9l0d9+cPD+lXObl/f6HD3vq/Wgd
YShnISzUF72j/ZpXV0ymNfOBcVS5ZBqRb105Mz8iLkwP0+xyQFoyTIWLUof6
lPMQL4Wvy0Xl52AwPWhGTK+CWdeyveweOXNXchHpUrgwXV1yzLx0Pcu0MR2I
v6KlJHoyLzPPHN01PsNWcN08tX4b2WYziB6VSzY/tKf0urOJcJV51r1KvtRM
IO8ZJsOOzlLq3uvEm0gf09tHZ9TPZo94My/6ZobhMR+75Fy9S0gb4of01Y8y
Q/dOIH2vLDp4CDfEDmpZTxEwVb/RnUBaolqHC+PIuKD5ODlAmvpmRdGdzUPh
7OS85ZMxK+aPioH8/uTyWYvW9X8sRwoXZxbfrM98/SUXxQvEi3mM1kwrO6Ou
V2ozru59ofPr0/vgcgUfjkFl
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 400->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U0tqAkEQLVxIriG5gR4geAVzggnElSCYRXDn0Y1Bhpm23qdmdGA+PV39
+n2qV1/H3X4RET9vf49d97s9nbrz5/I2+O4Om/XhNvl+vyMuH9G/3TsKtdWb
Xe18Ns4wnL0QFlqXvbP5ltdUTKZV+cA4ulyURuTbVM7Mj4wL08M0VzkgLQrT
4eLUoXXOfoiXw7fKxeVXwWB6UEZMr4PZ1rI5dY4quTt9kelyuDBdU/qYeVn1
TGljOhB/R0sIPcpL5VlFd9z5ONgObrWfRt+F3mYZZJfLReWH5tpM0Z6Oh4yT
zDPG/5wsEAbDU1yUL2wvp64fC29YXYY9WWeCQ3MlvJkXc3uG4SE+qZ/B6506
pQ3xQ/raq3IO3DOB9A17/QEPaEC4KXZSy9Zke/bfhm6Wz8NeoWuVvkofIi4o
n0ofIE1ze8XRrfJwOFf6fORTISvmj4uB/B5yGdaicfuP9ZHDpZLFM+uVr6/k
4niBeDGP0ZhpZXu09U6t4lo9LzS/OWv/uVwBTDpBXw==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 401->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytVUFOA0EMi3pAfKPiB/CAii+UFywSPVVCKgfUW58ORVBNs7Fjsx1puzsa
J7HjjLp+fd/uVhHxcf/9s50+nw+H6fhyd968Tfunx/358OH3iTht4vJWnzCw
7sNWPv/jMu6rHEqtas/iyndxnnm5ORnfqlbVhyqfywXF53UrzqwfFRemh2l2
OSAtXU6Fi4JDcUo9xEvh63JR+Tk5mB7kEdOr5MxYdtbdI8d3ZS4qXQoXpus/
c8x66fas08Z0IP7ujCsYlBPVcWoHiGH1bjlPV9/GbDMPqqVy6fwr+zJw72oq
PWScFD9HLooXSNtMZ9LczizpC6ul4HKNbna6GQ8wZ+O3mhvFoPozHPC945Jx
VX6WD/EpvQ2OV3CdNsQP6ctL8dC9E0gfuxMBNKC8Ze4Cy2KqmkoexZ9Zreix
DhfGkXFB/jhzgDQtnRVFd+eHwtmZ86s+GV6x/qg5UL9HLiP2sohmVlvlonoR
m5D+Ax0/WV+X5O7wSi8QL9ZjtGdaWY2MV7AdV/e+UP+WxP5w+QLKREFZ
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 402->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqA0EMMz2EfqP0B80DSr+QvmADySlQSA+ltz69DWzCxpFkebeHDEyW
ydiyJHueth+b/UNEfD7+/WyGr7fjcfh+X50Ou+GwfjmcLp/HHfHzGpfvPWy1
8j06IwynFsNiefAL7jOvLqbii2ohHxBelwvLz+u/OCs/EBelR2nucmBaKkyH
ixPH8px6jJfDt8vF5dfBUHpYj5ReBzPHqrvqHXX67swF0uVwUbrmzLHysutZ
pU3pYPy7M+7EMExWp1M74ytsB7c7T10P1Ayq5XKp+lf5UtV09TJOc+bY8dad
CQf7ki88VbWcuKsa43b1Kb1zdLKeVT3K5+p9VFyQjpyj8Bgf2NvQ8U5cpY3x
Y/ry6rwD900wfedZhHhEA8OF2CBW5aCa0/dS6Vb9uakVdSzlAjQprYoL609n
DpimpbOS/XG5uPPqYrIaqBeMs/LHxWB+T7lMY9k5/6fmyOHi9iLG3emdwq98
XYJdxTteMF7KY3ZWWlWNHO/EVly776Xq37LcXzHlQx4=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 403->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk00KwlAMhIML8RriDfQA4hX0BBV0JQi6EHce3R9UJM1MJraChVqeLy/5
ZpI3Xu+X24GZHUe3n2VzWhwOzXk1vC82zW423d03J8/X7DK39/cfXvb4/Wgd
5VBqoVzonPr1XNWcjDeqFfkQ5auyoPP+6YuZ+RGxMD1Mc5UBaclyKixKHDqn
1ENcCm+VReWr5GB6UI+YXiWnj2V72T2q9F2Zi0iXwsJ0fTPHzMuqZ5k2pgPx
K1os0ZN5mXlW0Y1YWL0+56nqAZtB9qgsWf/8nlV7L+pFTGo/I3+Yt6E2a+8r
ub03LHdUS4mLuFV9TO83OlHPst4jbuZF15lh+ZiPrd4aj1fiMm2ID+nzT+Ue
qHcC6XvNeyUfyhvmDmLZGUP7yXwq/WnVsjy2wsK0MhbUn8ocIE1dZ8X7o7Ko
86rmRDWiXiBm5o+aA/n9yfIZi9b+PzZHCkulF33GZ77+kkXxAnExj9GaaWU1
fLwSm7FW7wvtX5ezD5Yra2FBog==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 404->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuwkAQG/WA+EbVH8ADUL9AX5BKcEJCooeqtz69pUIodcYeT3IhUhq2
6/XY49nn9/P++BQRH+vfP/vh8/VyGb7eVtfFYThtN6fr5svtjfjexf37CK96
cD9bZxxOLcbFzuE34Dvmw3MuZ6V3omHsBeojX1cLO4/PEs0sE9SbaVF+lOeu
Bual4nS0ODh2zqnHdDl6u1pcfR0O5YdlpPw6nIhVe9U96uTuzEXmy9GifM2Z
Y9XLbs8qb8oH09+dcQfDOFmdTm3kV9wOb3eeuj1QM6geV0uV36Rvzexdv0yT
m2fWH9VbdyYcbuyN4s5qObhMt+svnRcyZ45PllmVfaY7SN8cLYhL+QUf05Nm
Gzm+g6u8MX3MHz6de+DeCeZvDh/jzbhVnQo32Td0qnywFnrJsCmnyJ15VVpY
Pp05YJ6Wzgr2x9XizqvLyWoo3ew3OzNnNv/hEixb4//UHDla3Cxi9LrZKf6q
r0u4K7zTC6ZL9ZitlVdVA/EOttLavS8yvyVn/7T8ABjKPuM=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 405->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQbLIQrxG8gR4geIV4ghF0FQjEhbjz6BoIIdPT9el5LhyYz5vX
XV1V3W/7ety/byLi4/73sZ8+n0+n6evl7rx4mw5Pj4fz5sPljvjexfX9H252
5f1qXWE4tRAWysvvQP9jmediKr5VrcqHCq/LBeXn6684Mz8qLkwP09zlgLQo
TIeLE4fynHqIl8O3y8Xl18FgelCPmF4HM8eyPXWOOn135qLS5XBhutbMMfOy
65nSxnQg/o6WEHqUl8qzju648HGwHdzuPM2+G7PNelBdLhfVv7yXvVM1HQ8Z
J9nPmP9zegG1ETzFRc0vq+XEXdfCm0of0zui8/YsOb1HvJkXozPD8Mp4oDl7
h7xhcUob4rfALvZvcxHHNWcC6VuDh3ArbFZHxS32DZ6sP7lW1lLFlpik70gr
44L605kDpGl0VrI/Lhd3Xl1MVIPxRt8oZ81szuKKWLTO/9gcOVzcXlQcFRbD
V76OYKt4xwvEi3mM1kwrq5HjnVjFtXteVP/Gcn8A+nI95Q==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 406->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tuQkEMi7qoeo2qN4ADIK5AT/Aq0RUSEl2g7np0oKWohNixH2/Rkd5n
NIljO5nnt+3q/SEiPp6Or9WwX+52w+fr42mzHjbz2eZ0+HJ+Ir4Wcfn+h4et
fF7tKwylFsJCeeo383IxGd+qVuVDhedyQfl5TcWZ+VFxYXqYZpcD0tJhKlyU
OJSn1EO8FL4uF5Wfg8H0oB4xvQpmjmVn3T1y+q7MRaVL4cJ0jZlj5qXrWaeN
6UD83RlXYhAmquPUDpDD6k05T1f/xmyzHlRL5dL1r/Olq6l4yDi1/Uy8lF4g
DIbXcfntZ54v5FP3D/eNN5U+pneMzgtWk4Pqy/ej4VLpyDkMj/l409vg8Upc
pw3xu8Euzv/mdpqcO4H0UTygAeFW2KxOF3d13syn0p9cK2upYh0uTCvjgvrj
zAHSdO+sZH9ULuq8qpioBuON/lHOmNnMZ2wfC5zD5kjh4vTie535qPHO7I3h
4sQjn5iXjsdo7/S9is0YqoeIy1TPPXg/uQesekCi
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 407->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3oo+UbJD9IHhH7BfYED6clQcA+ltz69NTEmHkYaqfahCxuz
8axG0shPl/fu7aG19nH4/en6z5dx7L9eH6fDtR+eT8P08jjv1r7PbXn+h81W
fJ+dMwylF8JC99Rn5OViMr5Zr8yHDM/lgu7HtRdn5kfGhelhml0OSEuFqXBR
6tA9pR/ipfB1uaj8HAymB82I6VUwYy17V31HztyVXGS6FC5M119yzLx0Pau0
MR2Iv5txpQZhoj5O74jPsBVcN0+uByyDbKlcqvlVvlQ9Vb2IkzrPzB/mrZoJ
BXu5P2+GnfVS6lY9iDeZvjQvIGeKzgWruIP6r2ruNKEsbMkMw0N80tm2vN6p
q7Qhfgg7Luc7UL8JpI/iAQ0IN8Nmfao6B0eZT8SKWrJahwvjyLig+Tg5QJq2
ZkXRXc1D4ezkvMox4sz8UTGQ3ygD6Bz/YzlSuDizWJZR72TP5mLWI5+Yl47H
6OzMPauNGKqHiMteewve7e4P4i0/Jg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 408->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FOAlEQRDssDNcg3kAPQLwCnmBMdEVCggvjjqMjYmbRdFVXzWfhTz7k
z/SvftXds3k77D5WEfG5/vnZTV8vx+P0/fpwObxP++en/eXl49+OOG1j/v8P
m638vjpXGkoupIXu5f/YXvfN87i9p2p2vFWu+ZzyZz2XBd3Pa4QZ9STzVizM
D/PsMiAvnabCosShe0o+xKXwuiwqn6PB/KAeMb+KZo5l77rvyOm7MheVL4WF
+Voyx6yWbs06b8wH4ndnXIlBmiiPk/t3FXdYvnvOk1sDNoNsqSxd/7q6dDlV
v4hJ7WdVH1bbir3yiWpPNYl2lUuJq7hVf8zvqE92R+GO9LziG5kZpod4Ks+5
dqg2LK7zhviQdl5KD91vAvlbood0K22Wp4tzdJT+ZK3spYp1WBgjY0H9ceYA
eRqdFcV31w+F2Znzbo4RM6uPqoHqjWYAnfMzNkcKi9OLeRnxzuy5LEvjlVog
LlZjdHb6XsVmDbWGiOVee0TvevcM4vs+KA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 409->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKwkAMXDyI3xB/oA8Qv1BfUEFPBaEexJtP16qIhMxksu3Bhdqum0xm
Jtnl4dycZqWUy+L507TXXd+3t/182BzbbrPuhsPV5ynlvi3f9z88bNlzb+9h
KLUQFspz38655ZXFZHy9Wp4PHl6WC8q3ayrOzA+PC9PDNGc5IC0RpsJFiUN5
Sj3ES+Gb5aLyy2AwPahHTK+CaWPZWXSPMn1X5sLTpXBhumrmmHmZ9SzSxnQg
/tkZV2IQJqqTqf1aTg6rN+U8ZT1gM8iWyiXqX+RLVFPVizgp/UT+MG89DIYX
cYnml9VS4r77wBtPH9M7Rmf54aP0HvFmXoydGYbHfIz6WRMXaUP8ELZdmXug
3gmkrwYP4XrYrE4UZ88VnizP1rJavFgXk/Rd5Yl0KVyYl1bT2Fmx/qhc1HlV
MVENxht9o5ya2bRn6t7+x+ZI4ZLpBfKAxWdmL8ulNl7xAvFiHqN9pu9erMVQ
PURcpnrG4L1zH/WrQOc=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 410->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOw0AMtDggvoH4ATyg4gvlBUGCUyWk9lBx4+kQFVXBmRmPkxyItE22
a49nxt7714/9+01EnO5+fvbD+fl4HD5fbsfN23B4ejyMhw+/K+JrF9f3f1jq
yedojzCcWgyL5eV37C5r9n/M81zMii+qhXxAeF0uLD8/W3FWfiAuSo/S3OXA
tFSYDhcnjuU59Rgvh2+Xi8uvg6H0sB4pvQ5mjlVn1T3q9N2ZC6TL4aJ0LZlj
5WXXs0qb0sH4d2fciWGYrE6ndpAcVW/Lefrz3Zht1QP0uFyq/lW+VDUdDxWn
sp/jQ/xR3iLuSCfzHvZrugg2quXEId6uPqV3ic4rVpHj8J765d6PzsyguIqP
7K3QWt0HxUXxm2GjOxAcZ82dYPqW4DFchK3qVHGzc4On6k+ulbWgWIg5WdUc
Kj9ZnYqL8jJrWjsr2R+XizuvLiaroXizb5azZDbzmbvP/6k5crh0esE8UPGd
2etyWRrveMF4KY/ZvtN3FJsxXA8Zl63WGrxL7jdD9j/f
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 411->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOA0EMi3pAfKPiB/AAxBfKCxaJniohlQPi1qeXVrBqs7Fjb/fASNvd
6SSOnXjWbx+b7SoiPu9/fjbD18t+P3y/3p0278Pu6XF3Onz4fSIOzzG+/8PD
Vj6v9hWGUgthobz8DvR/TPNUzI5vVavqQ4XnckH5eS3FmfWj4sL0MM0uB6Sl
w1S4KHEoT6mHeCl8XS4qPweD6UEzYnoVzBzLzrp75Mxd8UWlS+HCdM3xMeul
27NOG9OB+LseV2IQJqrj1A6Qw+ot6aerb8PbbAbVUrl08+v60tVUesg4tfNM
vJRZIAyG13H5myfqC6ulxFW8VX1M7xydI1aTo/CO9P/V9wKeqeJcb6JeoTiE
y7gwfgg7L+ceqHcC6ZuDh3ArbFani5ucCzzZfHKtrKWKLTEvHseHiAvzqeoD
pOlWr+T+nJfhQ5Wz4/POxxPOoEeOh1hvxrgidrK/iFNqq1ycWaAesHjHey6X
ufFKLxAv1mO0Z1pZjRyvxHZc3ftC53dL7pnLEcO0QKA=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 412->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0sKwlAMDC7Ea4g30AOIV9ATVNCVIOhC3Hl0P2jBNDOZtC588KyvTSYz
k7zp9rjej8zsPHn8rJvL6nRqrpvx87BrDov54flx9t5mt6W1z3/YbPnv0TnC
UGohLJTnn4beWzdPxcz4RrUiHyK8KheU79evODM/Ii5MD9Nc5YC0ZJgKFyUO
5Sn1EC+Fb5WLyq+CwfSgHjG9CqaPZd+ye1TpuzIXkS6FC9PVZ46Zl1XPMm1M
B+JfnXElBmGiOpXaHp9hK7jVefr6X5ht1oNoqVyy/mW+ZDUVDxkntZ+RP8xb
dSYU7DafeMpqKXERb1Uf09tHZ4vlNGe9j3ibex/xGzIzDI/52OltwslziOIy
bYgfwvarcg/UO4H09cFDuBE2q5PFVXCU/ngsryWKDTHfO7snmZ+oTsaFeek1
DZ0V74/KRZ1XFRPVeC1xrpg/SHs2m19xxNv2/Nmm1Va5VHqBPGDxldmrcukb
r3iBeDGP0ZlpZTV8vBKbca3eF9q/IbkvLndG+UEi
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 413->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOQlEQm7gwXMNwAz2A4Qp4gk+CKxITWBB3Hl0xQGCYdtqHC1/ygcef
12k7fU+rj+X7Q0TsZj8fy2m/2G6nz7fHw2Y9bV6eN4eX8+MT8fUa5+//8LCV
31f7CkPphbDQufwd6P+4PadidnyrXpUPFZ7LBZ3P6684Mz8qLkwP0+xyQFo6
TIWLUofOKf0QL4Wvy0Xl52AwPWhGTK+CmWvZu+4eOXNXclHpUrgwXSM5Zl66
nnXamA7E3824UoMwUR+nd8Zn2Aqum6er30a22QyqpXI58QjAp/Ol66l4WHIS
dfwu4A/zVs0E8r6c1+UDsKteSl3FW9XH9I7oRDPrZl/xjgKrw3Uyw/Cqejhb
QWt3HzptiB/CzkuZoXsnkL4RPIRbYbM+XZ2Do8wnY2UtVS28A8I96fxEfTou
zMus6d6sZH9ULmpeVUzU47yMLCKtI9m8qQPeXu3drAlcnFkgD1i9kz2Xy2i9
4gXixTxGe6aV9cj1Sm3H1b0v3fzuO/sN2u8/4w==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 414->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqAzEQMz2EfKP0B+0DQr+QvmALzWmhsDmE3vr0NqGYMBlpJG8PMWwW
Z8caSSM/vn/uDw+tteP292c/nV6XZfp625w3H9P88jyfPz79Pa1971p/38PD
Vvye7TMMpRfCQufUd+TlYjK+Wa/MhwzP5YLOx/VfnJkfGRemh2l2OSAtFabC
RalD55R+iJfC1+Wi8nMwmB40I6ZXwYy17Ft1j5y5K7nIdClcmK6RHDMvXc8q
bUwH4u9mXKlBmKiP0zviM2wF180T85Rlm80gWyqXy5tkvPKl6ql4mHISdURe
yiycTCjY1z4iX1gvpS7jrepjekd0dqyguZo94s28WJsZhsd8vJltwSlyUHQy
f50MxX6VJudOIH0jeAg3w2Z9qjoHR5lPxIpaslo3Y6wGcWE5VXOANK3NSvRH
5aLmVcVEPfoysoi0jmTzun9/Wo7T92bWFC7MH8d39T/mhZOLNfWKF4gX8xjt
mVbWI9YrtRVX977Q+a05e+HyA9hOQSQ=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 415->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOw0AQW3FA/QbiB/CAii+UFwQJTpUqlQPixtOhESow2B474cBKabTN
rMf2eK8eDrunizHG8+bjZze93B2P0+v95WnzOO1vb/anj9efzxhv23F+/4dH
rfod7RGG04thsXPuu/JKMRVf1Av5gPBSLux8XX/FWfmBuCg9SnPKgWnpMB0u
Th075/RjvBy+KReXX4Kh9LAZKb0OZq1V37p7lMzdyQXS5XBRupbkWHmZetZp
UzoY/zTjTg3DZH2S3hVfYTu4aZ6UpyrbagZouVzmt8h450vX0/EQcjJ1VF7O
LJJMONiojmGjXk4d4u3qU3rX6ETn1ewZb+XF93wuyYziyfggzfPafj2yztSp
/E0yVPt1mpI7wfR1eAPgMVyErfp0dQmOM5+KVbWg2jRjqoZxYfNJcsA0rc1K
9cfl4ubVxWQ9zivIItO6JJu/6oi3P/Zh1hwuyp/Ed/e/zgs3F2vqHS8YL+Ux
2yutqketd2o7rul9kfNbc3bm8g7JsEBl
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 416->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuwkAQW/WA+AbqD8oDUL8AL0ilckJCggPqjaeXVBFqh7HH3vTASiEJ
mfXYHu/q47jdv7TWzsvbz3a4vJ9Ow9duMb58Dof122H8+DpdrV037X5/hout
+D17zzCUXggL7VPvkZeLyfhmvTIfMjyXC9of139xZn5kXJgeptnlgLRUmAoX
pQ7tU/ohXgpfl4vKz8FgetCMmF4FM9ayb9U5cuau5CLTpXBhunpyzLx0Pau0
MR2Iv5txpQZhoj5O74jPsBVcN09/nqdLyTabQbZULr95ZPsqX6qeiocpJ1HH
zwL+sHypmUDep/MCM6l6KXUZb1Uf09ujE82smj3izbyYmxmGx3x8mO24phmX
daJO5q+ShbiUGbpnAunrwUO4GTbrU9U5OMp8IlbUktW6GWM1iAuaj5MDpGlu
VqI/Khc1ryom6nFfRhaR1p5sxjrkLdPMeqtcmD+O7+p/lRdqLubUK14gXsxj
9M60sh6xXqmtuLrnRTlL/Xu/AdanP2c=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 417->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqAzEQMz2UfKP0B+0DQr+QvmALzSlQSA4ltzw9CZTF0Y40Gu+lBu+u
12ONpBm/fP3s9k+ttdPm9thNvx/H43T+fL4vvqfD+9vhvvn6N1u7bNv8/g9T
DdyP1hGGk4thsXP4bttuAh6eczEzvgsOvRbIj3hVLuw8jjWcWU2Qb8RF6VGa
qxyYlgzT4eLEsXNOPsbL4Vvl4vKrYCg9rEZKr4OJsWovu0eVujt9EelyuChd
I32svKx6lmlTOhj/ao87MQyT5ankRnyF7eBW+2mRw+xtVYNouFzmf6THM1+y
nI6HlJOh44GXWYtKTzDvw3r1XnbrLFf0zdaZNyouwh7RyWqW1Z7xVl6oOxLp
QHzFk/EJa9txYXyy+5B5xvgxbBxODat3gukbwWO4EbbKk8Ut9g2eqj6YC7VE
sdUeUzGMi+pTtw+YprW9gv64XNx+dTFZjnkUepFpHelNjGPeKs0qt8vlYd1P
2Mt8d/9lXiCfEews3vKC8FIes7XSqnJgvBObca3el6x+685eAV0PPmE=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 418->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EQLVyI1xBvoAcYvEI8wQhmFRDiQtx5dA3KkKl+79WriQsbOqGn
q9+vq2+fX3f7q4h4u/n+2c3vj8fj/PF0fVq8zIeH+8Np8+53RnxOsfz/h6lG
3kdrhOFwMSx2Lv/H9DOH7zGeczErvYgL5YDwulrY+Tz+SrPKA2lRfpTnrgbm
pcJ0tDh17JzDx3Q5ertaXH0dDOWH3ZHy62DmWrVXvaPOvTt9gXw5WpSvLX2s
suxmVnlTPpj+bo87NQyT8XS4M77CdnC7/dTNQPWgGq6W5Rvp8SqXitP1CzUZ
Pla6zLvo9ATLXmJOZzPSd8Cl8hzWRTbI3+D3TN+lPtUZxr+qQTnFGhfdK6xD
+KCu0oM8Ky1IA8pEaVH6GHYezh123wTztwWP4SJsxVPVDfuGTnU/mSt7QbWq
x6p3UuXJeCotijt7urRXcj6uFrdfXUzGsYxGLzKvW3oz17FslWfF7WqB2ao9
gKOwOr2n7qqDXdU7WTBdKmO2Vl4VR653aiut3ffivKXtZ78A3j9AHg==
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 419->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVkFqw0AQG3Io/UbID9oHhH4hfYED7SlQSA8ltzy9TUmMq4w0GvvSBWe9
2VmNNKMFr/cfu/dVRHw+/vzshq+X43E4vT5cFm/D4fnpcNncXJ+I8zbG+T88
auB+ts4wnFwMi53DOWCe4uE5F7Pie8dhqgXyI16XCzuPYwln1hPkm3FRepTm
LgempcJ0uDhx7JyTj/Fy+Ha5uPw6GEoP65HS62BirNqr7lGn744vMl0OF6Vr
jo9VLbs1q7QpHYx/1+NODMNkeTq5EV9hO7hdP3VroDyohstl/I94vKpLldPV
m3IydPzhZfai4wlW+xJzG+n3SpYre6frojYZF8ptqc7iDMuv+ojvrK9pnMBX
98fxi+KScchwFRfFj2HjcHrYvRNM3xw8hpthqzxV3N2+wVP1B3Ohliy26zEV
w7gon7o+YJqWegXr43Jx/epishzjMHyj6sO0V97EOFbbcX17wsvtcklrq/Ym
dXGwOt5LY2ZgV/FOLRgvVWO2VlpVDox3Yiuu3fsi+7fk7C+Xb4m5P90=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 420->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tuwkAMHXVR9RoVN4ADVL0CPUGQYIWERBdVdxwdqKIoMX4fJyw6UkiG
8Ty/92y/707bw0tr7fvt9rPtfj7P5+736/W+2XfHzfp4P1z1T2uXjza8/8PD
VjzP9hmGkwthoXvuO/KqYjK+Wa7MhwyvygXdj+tZnJkfGRemh2muckBaFKbD
xYlD95x8iJfDt8rF5VfBYHpQjZheBzPGsjM1R5W6O32R6XK4MF1z+ph5WfVM
aWM6EH9HSxN6lJfKs4ru1vNxsB3caj9Nvgu9zWqQLZfL8B/oceWLyul4CDkZ
Oia8zFogjEwn8l5ijvrsMvrOcjE/H/bCm4wL5PYEnewOyj+JEV4s7RmGx3yM
mh2tah6UNsQPYcfl1LA6E0jfHDyEm2GzPCru4XzU647faCaQliwWzoAxJ8pP
lEdxYV5GTUt7JfrjcnH71cVEOYZV6EWkdU5vxjjk7eRutdcMLqm37Kw/d2qX
/ae8cPtiSbzjBeLFPEZ7ppXliPFOrOJanRdavyV3/7hcAQnMQF0=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 421->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuwkAQW/VQ8Q3UH5QHoH6BviBI5YSEBAfUG09vKShShrHHznLoSiEk
O+uxPc5ye9jsXlprp8Xvz2Y4fxyPw/fn6/Xha9iv3vfXzbf71dpl3cb7f7jY
ivvZc4ah9EJY6Jx6j7xcTMY365X5kOG5XND5uJ7FmfmRcWF6mGaXA9JSYSpc
lDp0TumHeCl8XS4qPweD6UEzYnoVzFjL9qrvyJm7kotMl8KF6ZqTY+al61ml
jelA/N2MKzUIE/Vxev+t5Azr98w8Tf4b2WYzyJbKZXwHMl75UvVUPIScBB0T
XuIsEEamE3lfYq6nnsbMVf/hc+FNxqXk1qGTnUH95e+j4BLrMnyGx3yMmkff
7ndaJ+pk/kpZaI/vKt/cbwLpm4OHcDNs1qeqc3CU+USsqCWrdTPGahAXNB8n
B0hTb1aiPyoXNa8qJuoxLiOLSOucbMY65C3LibJfcWH+OL6r7yov1Fz01Cte
IF7MYzYjpJX1iPVKrZOX3qsH73b2B61dQGM=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 422->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuwkAMtDhUfAP1B/QBiC/QF6RSe4qEBAfEjae3VNWKeD3jccKhK4Ww
We94xh5vPo6Hr5WZndc/P4fhsj+dhuv7y33zOYxv2/F++Pr3mN121t7/4WHL
n0f7CEPJhbDQvfAdnHteVUzGN8oV1SHCq3JB9/16FmdWj4gL08M0VzkgLRmm
wkWJQ/eUfIiXwrfKReVXwWB6UI+YXgXTx7KzbI4qfVd8EelSuDBdc3zMalmt
WaaN6UD8qx5XYhAmylPJ7fEZtoJb9dPkf8HbrAfRUrm0b8DjWV2ynEoNISdB
h+el9KLiCQW7w3zobcNmPiD17PZJbSZcnMfaesBZpDO4z3qfeUzFrXiG4bE6
es2tbmbh3HoOik5WX8kL1n9T50CdCaQvw7MAD+FG2CxPFteduznI6o1mAmmJ
YtkMZHOS9QflybiwWnpNS73i66NyUf2qYqIcbRW8iLTO8aaPQ7X1vvEx1GsC
l8me+KvjLvQu+pbVwvOZg53FS7UAvFiN0Z5pZTl8vBKbca3OC+3fkru/XL4B
7ntAHA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 423->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVUFqw0AQG3oI/UbpD9IHmH7BeYELzclQcA+ltz69DQSXnR1pNHYOMTj2
emc1klZLnt4+xvODmX0+/v2M09frskzfp8Nl8D7NL8f5Mvl8vc1+Bluf93Cz
y89H4whD6YWw0LrwGcx7XlVMxjfqFfkQ4VW5oPX+uhVn5kfEhelhmqsckJYM
U+Gi1KF1Sj/ES+Fb5aLyq2AwPWiPmF4F09eyuewcVfZdyUWkS+HCdG3JMfOy
6lmmjelA/KsZV2oQJupT6e3xGbaCW81T817INtuD6FK5rN9AxjNfsp6Kh5CT
oMPzUvaikgkFG2Ha8H/THATvcJx403BxGet42X6dbI3niXgzL/ZmhuExH73m
pkdSp+pk/kpZsP6beg7UM4H0bcFDuBE265PVhR4lPNn+dFiW18IzIJyTzE/U
J+PCvPSa9mbF+6NyUfOqYqIe61XIItK6JZu+DnnbjAfr/k9o1gQuzJ+K7+q3
zItmfiN2Vq94gXgxj9GYaWU9fL1Sm3Gtnpds//at/QXzYz+g
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 424->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwkAQW/wQryHeQA8gXkFPUEG/CkL9EP88ugpS7HSSyWz9cKGP7c5m
kmy6PF7251kp5bp43fbNbdd1zf0wf09OTbtZt+/F1ecq5bEt/fMfLjbsujf3
MJReCAvtU5+WVxaT8fV6eT54eFkuaL8dv+LM/PC4MD1Mc5YD0hJhKlyUOrRP
6Yd4KXyzXFR+GQymB50R06tg2lq2Fv1HmXNXcuHpUrgwXTU5Zl5mPYu0MR2I
fzbjSg3CRH0yvS0+w1Zws3kavCeyzc7AGyqX/hvIeORL1FPxEHISdFheyllk
MqFgh5hRDpx3OA+8GXBBnn3hTNH5MDj0XAlv5sXUzDA85uNI53ePoE7VyfyV
slDG39T/QM0v0leDh3A9bNYnqnM9Cniy8xlhlbgWZQzxQFoZF5ZTNQdI09Ss
WH9ULmpeVUzUox+JLCKtNdm0dcjbwTybNYEL8yfju/ot8mKwXokd1SteIF7M
YzRnWlkPW6/URlyz/0t0ftP2PgHlcEAi
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 425->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwkAQW/wQryHeQA8gXqGeoIJ+CUL9EP88ug+k2HGSyWz9cKGP7c5m
kmw6352aw6SUcp49bk172XRde91On5N9e1wtj8/Fxfsq5bYu/fMfLjbsujf3
MJReCAvtU5+WVxaT8fV6eT54eFkuaL8dv+LM/PC4MD1Mc5YD0hJhKlyUOrRP
6Yd4KXyzXFR+GQymB50R06tg2lq2Fv1HmXNXcuHpUrgwXTU5Zl5mPYu0MR2I
fzbjSg3CRH0yvS0+w1Zws3kavCeyzc7AGyqX/hvIeORL1FPxEHISdFheyllk
MqFgh5hr8O70RZzQXsoFeeZwqdIZ7BnoILyZL2Mzw/CYj1Yz6+GtQ51EG+KH
sO3I/AdqfpG+GjyE62GzPlGd61HAk53PF1aJa7MZYzWIC8upmgOkaWxWrD8q
FzWvKibq0Y9EFpHWmmzaOuTtYP7xVLKmcBnMPy+z5p5rcHbet8gLy6cGO6qX
vAC8mMdozrSyHrZeqY24Zv8Xen5j9r643AGA3D9f
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 426->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuwkAMtDigfgP1B/QBiC/QFwSJnpAq0UPFjadTKhRtHM94nL2w0hI2
a49n7Mnm+H34WpnZz9vfz2H43V8uw/Vz/TichvPH9vy4fH9us9vOxucrbLb8
fXSOMJRaCAvl+aftmu3wfJ6KmfGdcWi1uPoer8oF5fvVwxnNxPONuDA9THOV
A9KSYSpclDiUp9RDvBS+VS4qvwoG04NmxPQqmD6W3WXfUWXuii8iXQoXpmuJ
j1kvqz3LtDEdiH/V40oMwkR1KrU9PsNWcKt+mvwveJvNIFoql/Ed8HjWl6ym
0kPISdDheSmzqHhCwVYx/1fmCZDPeDIuYc8CLkt0ZjkTzoQ360WvZxge66PX
xmpE94pO1t/MC76nbW6mqeJfpG8JHsKNsFmdLC66t4Qnm88My/LYqsdYDOLC
fKr6AGnq9Yrvj8pF9auKiWqMS/Fiu0Hfq970cai3k3PzVLymcJn1B+hEc6VY
wbusF6oveuKVXiBerMfozLSyGj5eic24Vr+XbH59uXe2zj8g
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 427->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVUtuwlAQG3VR9RoVNygHiHoFOEEqwQqpEl1U3fXoBYT4TGyPp+miTwoh
vHke2+OI57f31fYhIj6eDh+r8fN1vx+/1o/Hh824W77sjpuL8xXxPcTl/h8u
tfI+ekYYTi+Gxc7le7DfY3rOxaz4ol7IB4TX5cLO5/VXnJUfiIvSozR3OTAt
FabDxalj55x+jJfDt8vF5dfBUHrYjJReBzPXqr3qPerM3ckF0uVwUbp+k2Pl
ZdezSpvSwfh3M+7UMEzWp9M74ytsB7ebp7vvjWyrGaDlcrn8RjJe+VL1dDyk
nAwdmdekjnjrZkJhdzBjuF4yE+y84Km4QM9uZj5HZ3XmjrPgrbyYmxmFp3zM
2lQPtO/oVP5WWcie3p6tNHXyy/S5nqHlzp71qerQfpz9cvxm+WZaUK3KGOLB
tCouKqduDpimuVnJ/rhc3Ly6mGU2nSwa70U3m7mOeQt5m1lzuCh/ZFaGmPyf
deeJvHBzMdHSqHe8YLyUx+XcAKbqkeud2opr932R85tz9sTlB8RqPKI=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 428->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FOw1AMRL9YIK6BuAEcoOIK5QRBglUlpLJA7Dg6VILq1/WMn5sNkdI0
iT2eGU9un9+2r1djjPebn5/t8vG43y+fT9eHm5dl93C/O7y8+z3H+NqM4/U/
nO6I77P7DIPMUliqL17HZjoDXuyjmBXfMw6zljA/4nW5qP54rOGsdhL5Zlyc
Hqe5y0FpqTAJF1Kn+sg8xYvw7XKh/DoYTo/akdNLMGOte1d9R529k1xkuggX
p+uSHDsvu55V2pwOxb+bcVKjMNWczuyI77AJbjdPJ/8b2XY7yA7K5fhMZLzy
pZpJPJScgI7Ii+wCZ8J4fwnmmDBljehXvRWX1LNp51UPwXZcTrQL3s6LtZlx
eM7HqM3NyN4Tnc5fm4Xkfu6tNHXyq/RRz7KD7l7NqeqUR9RvlW+lJavtZszV
KC4upzQHStParER/KBeaV4pZZpNkEXwX3WzGOuVtyhtmjXA582fSW/n+Vyux
kmeVF5ELxY57JLkle+x4XO4twXQzYj2prbh2v5dqf+t6vwFlgz2g
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 429->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuAkEMi3pAfKPiB+UBFV+gL1ikckKqBAfUW5/eUiG0hNixWQ6MNCww
Gcd2vK+br/X2JSIO87+P9XBc7ffD98fs9ONz2C3fdqfDxXlH/LzH5fkMm618
Xv2uMJReCAvdU5+Zl4vJ+Fa9Kh8qPJcLup/XozgzPyouTA/T7HJAWjpMhYtS
h+4p/RAvha/LReXnYDA9aEZMr4KZa9lZ9x45c1dyUelSuDBd9+SYeel61mlj
OhB/N+NKDcJEfZzeGZ9hK7hunq6+G9lmM6iWyuXyH8h450vXU/EQchJ0ZF7K
LJxMKNgqZhT8Oz+vluAp4zzGyT0cnTHa7E7WjngzL6ZmhuExH280kx7VuaKT
za7LQp7D+G6nyckv0qd6Vi119qhPV8c8U/xG7wTSUtW6GWM1iAvLqZoDpGlq
VrI/Khc1rypmm00xV0zrPdnMdchbxFvJmsKl9JadjTHPm2E52bs5N7DzHJXc
KnN0PFbm1tVXtRlD9RBxedSOKXf/ufwCo2U+4Q==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 430->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRD9ZSK4RvIEeQLxCPMEIugoIyUKyy9E1KENsuqpfZ7Lww2Rm
8vtXV1XXbF4/tu+rMcZh/f2znT6f9/vp+HJ3fnmbdo8Pu/Pm/e81xulpzPf/
cLkV97P3DIP0UljqHL1HXl1MxzfrlfmQ4XW5qPNx3Yqz8yPj4vQ4zV0OSkuF
SbiQOnWO9FO8CN8uF8qvg+H0qBk5vQQz1rq96jvqzJ3kItNFuDhd1+TYedn1
rNLmdCj+3YyTGoWp+nR6R3yHTXC7efrz3Mi2m0G2KJf5P5HxypeqJ/FQcgI6
Ii8yi04mCDbFHAn/yk+lU/FxnOclPG/pvNDjuFxqV7ydF0sz4/Ccj1Gz65Ht
E53OX5KFuDrfAc2v0kc9yxadvepT1SmPqN/qm1BastpuxlyN4uJySnOgNC3N
SvSHcqF5pZhlNmGunNZrshnrlLeKN8ka4eL8qXzP+HXmmXlBc7GknniheDmP
ydyq+qw2YlAPFZdbXUvwfs5+AbpHQKY=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 431->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRD8uxGuIN9ADiFeIJxhBVwEhLiS7HD0ZkQE7XdWvM1n4YTIz
+f2rq6pr7t8+Nx83Y4yvu9PPZvp+2e2m/evt/PI+bZ8et/Pmw+81xuF5LPf/
cLkV97P3DIP0UljqHL1HXl1MxzfrlfmQ4XW5qPNxXYuz8yPj4vQ4zV0OSkuF
SbiQOnWO9FO8CN8uF8qvg+H0qBk5vQQz1rq96jvqzJ3kItNFuDhdl+TYedn1
rNLmdCj+3YyTGoWp+nR6R3yHTXC7efrz3Mi2m0G2KJflP5HxypeqJ/FQcgI6
Ii8yi04mCDbFHAn/yk+lU/FxnJclPKc63Xk5V8PbebE2Mw7P+Xim2fTI9olO
NzuShbg63wHNr9JHPRth9kqje6Z5cfsZVnXOzbaq7WbM1SguLqc0B0rT2qxE
fygXmleKabM5L5grp/WSbMY65a3iTbJGuDh/Kt8zfp15Zl7QXKypJ14oXs5j
MreqPquNGNRDxeVa11hz9ofLEZVLQGU=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 432->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwkAQG/wQryHeQA8gXkFPUEG/BEE/xD+PrgVfHSeZTPXDhdquO5tJ
stnxer/cDszsOLr9LJvT4nBozqthO9k0u9l01y5O7o/ZZW7P9z88bPj1aB5h
KL0QFtqnvj2vKibjG/WKfIjwqlzQfj9+xZn5EXFhepjmKgekJcNUuCh1aJ/S
D/FS+Fa5qPwqGEwPOiOmV8H0tWwtu0eVc1dyEelSuDBdfXLMvKx6lmljOhD/
asaVGoSJ+lR6e3yGreBW89T5LmSbnUE0VC7Z+WW+ZD0VDxkn9Twjf5i3aiYU
bBXTAv6Zn0gn4sM4s559dbI9mY4Kr76ZYXjMR6+50yOpU3Uyf5UsPLhY4Qyr
+UX6VM/e+SHcCJv1yeqYZ4rf6E5EI7s/TIdag7iwnKo5QJq+zYr3R+Wi5lXF
pNlsh5grprVPNn0d8vY5TzLKODMuH/6wNbPXfRayFv2XeaHm4kNLoV7xAvFi
HqM508p6+HqlNuNavS/Z+X239wrpBkFh
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 433->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FOA0EMBK0cEN+I+AE8IOIL4QWLRE6RkMIB5ZanQwAh1mu3y5McGGmy
mR273W73rp9ft7uVmb3dfv5sp/fHw2E6Pt2cDy/T/uF+f768+9lmp439Pv/D
VsvfR+cIg9TKsLI8/7TN9168t2Uexaz4RrUiHSK8Lpcs369rcVZ6RFxUP6rn
LoeslwqTcCFxWR6pl/EifLtcKL8Ohuonm5Hql2D6WHVXfUeduRNfRH0RLqqv
ER8rLbuaVb2pPjL+XY+TmAwzq9Op7fEVNsHt+mn2v+FtNYNoUS7V/CpdqppE
Q8WJzjPSR2lLPUGwKaYF/Cs9q3PFBflwtM8ih/ImvEY9o/CUjr7nWY0ijvap
9MVeKHxLts/NdBzRLFp09lmdKi66j7CqPNJP9f2oPmhMxkX5lPog6+lSr3h9
KBfqV4pZehP6SvU64k0fl2mb8SZeI1xm57/b3S24A69F7yotPB+K7edIfEvm
2NGYzK2Kj2I9BtUw43KtbZfkfnH5AAnIPeU=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 434->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG+gBgleIJ/iCrgJCXIg7j64RlaTTVf36z8aByedn
uquraupfP75sny/GGK9XXz/b5e1+v1/eHy4PL0/L7u52dzi8+dljfGzG3/M/
bLfiefaeYZBZCkv1xefYHO2AF/soZsX3jMOxljA/4nW5qP64ZjirO4l8My5O
j9Pc5aC0VJiEC6lTfWSe4kX4drlQfh0Mp0fdkdNLMGOtO6u+o869k1xkuggX
p2tNjp2XXc8qbU6H4t/NOKlRmGpOZ3bEd9gEt5unrgcug25RLtX9Vb5UM6le
xYneZ+aP85ZmgmBTzAEyofrVe8WF5HBGp+uhvAmvtZlxeM7HqPlkRlFHdTp/
URZ+d5hXaerkV+mjnmWL3r2aU9Vl5xlW1Uf0VN+P00FrFBeXU5oDpWk2K9Ef
yoXmlWKW2YS5clrXZDPWKW8Vb5I1wuXMH3eWLIuV/Fd5QXMxU0+8ULycx+Te
qnrnM6mtuHa/F3t/M73fXD4BSMY/Jg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 435->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKxFAQRD+zEK8xeAM9wOAVxhNE0NXAwLgQdx5dByRkmq7q18nGD0n4
/O7qqvqV/ev5+L4bY3zc/76O0+fz5TJ9vdxdN2/T6enxdD18+HvG+D6M+fsf
HrfiebbPMMgshaX66Dfy6mI6vtkst8/mUS6qP64tnB3vrD/2kGxRfoqD0lJh
Ei6kTvWReYoX4dvlQvl1MJwedUdOL8GMte6s+o86905ykekiXJyuNTl2XnY9
q7Q5HYp/N+OkRmGqOZ3ZEd9hE9xunroeuAy6RblU91f5Us2kehUnep+ZP85b
mgmCTTEHyITqX2KMgOW4kBxu0el6nI4ur7WZcXiKT6b5ZkZRR3U6f7tZWPZW
mjr5VfqoZ9mid6/mVHXOM+K3+ieUlqy2mzFXo7i4nNIcKE1bsxL9oVxoXilm
mU2YK6d1TTZjnfJ23hcZdZwdl5v98glnM8biPM7q3mfmReSzBruqR14IXs5j
tXda3YxYT2orrt3/pbq/bb0/A5Y/og==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 436->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuAjEQi3pA/UbVH8ADUL9AX7CV4ISERA8VN54OqO1qmR177HAhUliF
TDy247x9HTa7l9ba9+v1ZzP8fByPw+lzcVtsh/1qub9tvv/N1s7rNn6fYbIR
97N1hqH0QljonPqNvFxMxjfrNa7/J8BzuaDzcTzCGd1J5JtxYXqYZpcD0lJh
KlyUOnRO6Yd4KXxdLio/B4PpQXfE9CqYsZbtVe/IuXclF5kuhQvT1ZNj5qXr
WaWN6UD83YwrNQgT9XF6R3yGreC6eXI9YBlkQ+VS3V/lS9VT1Ys4qfeZ+cO8
VTOhYDuYVSbQ+bv1+ncqXNSevTrZGabD5dWbGYaH+GSaZzpInaqT+etmYXoW
ZaMnv0gfxIq1k/8QbobN+lR1zDPFb/QmslG9H6ZDrUFcWE5RxlBv5lNPVqI/
Khc1ryom6jEOMVdMa082Yx3ydlwDX1mOFC4zfya9Ut9BDap3spdxUbCb0Jd5
y7x0PEZrppX1iPVKbcXVfS/V/T129gIqSD8g
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 437->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlkFqQkEQRJssgteQ3CAe4JMrmBP8QFwJgi6CO4+eCCL8trv69bjJwFeH
311TVV0Drr8O292LmZ1Wfx/b+efjeJzPn6/Xzfe837zvry/fbo/ZZbL79394
1PLvo32EQc7KsLI++u15dTEV3+isxV7gdblk/X6lnIteNRPPN+Ki9CjNXQ5R
LcEkXEhd1kfOy3gRvl0ulF8HQ+nJZqT0Ekxfq95lGnw/mTvJRaSLcFG6RnKs
vOx6VmlTOjL+RIsVeiovK886uu3Gh2AT3G6eFr8b2VYziBblUs2v8qU6k3io
OJXzdLzILDIMhVdxoZhlJpL+bF9xoWeO6lQ9lDfhNZoZhad89JofdIg6qlP5
i7Mw2eK/6GV65PbMncj0Uc+i1bkHNFejuSPzUXqq+6N00JqMi8ppdX+ieVOu
JCveH8qF5pViltmEuVJaR7Lp6zJv73v3kKwRLsqf1HfHo8Ki2evkwnvTqgde
ZLyUx9leaVVn+HpSW3Ht3pdqfs/1/gLp8T7h
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 438->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRIcsxGsEb6AHCF4hnuALugoE4kLceXQNqHw7XdWvx40DPz+f
6amuqq7ZPh73z5sxxsv1589+eb0/nZa3h6vzx9NyuLs9nDdvvp4x3nfj5/0f
HrfifvadYZBeCkudS9/JfuTVxXR8s15rLlFb1o9yUefjkpyLs24mkW/Gxelx
mrscslqCSbiQOnWO9FO8CN8uF8qvg+H0qBk5vQQz1ro9pSGeJ3Mnuch0ES5O
10yOnZddzyptTofi3804qVGYqk+nd8R32AS3m6df/xvZdjPIFuVSza/ypepJ
PHSc6Dwzf5y3NBMEu4NZZkKcV98VF9pzVqc7Q3kTXrOZcXjOx6j5Qoepozqd
vzgLWW6LO9DJr9KHPFs/BjfDdn2qOucZ8VvdiWxV98fpoDWKi8upypjq7Xya
yUr0h3KheaWYMpvfC+bKaZ3JZqxT3l7wLjKgMBD39RP2omcj2evOM/Mi8pnB
ruqRF4KX89jOTWh1PWI9qa24du9LNb+/nf0AZGhAIA==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 439->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KQ0EQhAcXkmuIN9ADBK8QT/AEXQWEuBB3Hl0D8fHSdlV//eLCgUky
mf6pqq65eXrdvVyNMd423x+76f3hcJg+Hq+Ph+dpf3+3P17envYYn9sxf/+H
7Va8z85ZDdJL1VJ56XdyH3F1azq8Wa8llsgt60exqPy4JOYi180k4s2wOD6O
cxdDFktqEiwkTuWRfgoXwdvFQvF1ajg+akaOL6kZY92d4hDzydyJLzJeBIvj
tcbHTsuuZhU3x0Ph73qcxKiaqk+nd6zvapO6XT91NXAedItiqeZX6VL1pHwV
JjrPTB+nLfXE/PuPalaeUPnzuYmF9iQaZjxdjuPRxbXWM66ewpNx/sXDxFGe
Tl/khROO2M/5o+tfxY9qlq3OO6C+Wus7Mh/Hp3o/jgeNUVicT6v3k82bYiVe
ifpQLNSvtGbpTeJF8C663oxxStuz8wIL8RrBcnZe7nAXNfvZbnbZf5UW1BeX
xCMtBC6nsTo7rq5HjCexFdbue6nmd1nuF0f0QF8=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 440->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqQkEQHFyI1xBvkBxAcgU9wRPiSgiYRcjOo6ugD1/b9elx48Co4+up
rqqut9z9bPaz1trv4vKxGf6+jsfhfzu/Hr6Hw+fH4fpwddutndZt/H6HzVZ8
np0zDKcXwkL3su/seeTVi8m0plpCf8TR5aI0It/GJe6ymUS+GRemh2mucshq
HUyHi1OH7jn9EC+Hb5WLy6+CwfSgGTG9DmasZc+QhnjfmbuTi0yXw4Xp6skx
87LqmdLGdCD+jpYm9CgvlWcV3e3Gx8F2cKt5mvwuZJvNIFsuFzU/5Yvq6XjI
OMl5Bl7OLBAGw1NcXEyZCXB/PD9sh4vbs1enyjHSUeXVmxmGh/hkmp90kDpX
J/PXygLQjebRk1+kz/LscRPcDJv1UXXMM8dv9E5kS70/TIdbg7iwnKKMod7M
p56sRH9cLm5eXUyYzfsyc8W09mQz1iFvJ2eSUcaZcZmcSb6iZ/fNZpf9p7xw
c/FKveUF4MU8RmemlfWI9U6t4lp9X9T8Xrt7BonXQN0=
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 441->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuAjEQG/WA+EbVH9AHrPoFeMEiwQmpEhwqbjwdECWH2bHHk+VApGy0
ysSxPc7n9ne9/zCz0/L2WY9/P8fjeN4s7j+78fC9Otw3v/6n2WWwtr7DZMPv
R/8RhnIXwkLnojXa97x6MZnWUIu7H3FUuWQakW9tJGdZTzzfiAvTwzRXOUS1
CqbCRalD55T7EC+Fb5WLyq+CwfSgHjG9CqavZXtIgz+v9F3JRaRL4cJ09eSY
eVn1LNPGdCD+ihZL9GReZp5VdCMu7L5X5ol5yrLNehANlUvWv8yX7E7FQ8Yp
7afjpfQCYTC8jIuKqWRC+he5VHNY1ZnlGOmY8z4qmWF4iE+keaKD1Kk6mb9Z
Fmxwq2GcOW8C6ZtgRLXP6UblHai56s2d0p8IK6utZozVIC4sp2oOkKa5WfH+
qFzUvKqY6I42xFwxrT3Z9HXIW8RbyZrCpdKLNgZr7zqrr2Rvst+JndUrXiBe
zGOlb1l9VOsxVA8Rl1fNOXiPs1cw+j9j
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 442->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylU0FqAkEQbDyI35D8wDxA8gXzgg2YkyDoQXLL0xMhCWunq7pqdmEdl5mu
rqqu2b6dD++riLhuvn8O0+3lcpk+Xtf3j+N0et6d7ptPP2/E5z7+VvUN46z7
sifvV98VhtILYaG6ci32My8Xk/Gtes25ZG1VP5ULqs8P5NzUsplkvhUXpodp
djlUZxVMhYtyDtUp/RAvha/LReXnYDA9aEZMr4KZz7I9pCHXK3NXclHpUrgw
XSM5Zl66nnXamA7EX9ESjZ7Oy84zR3fGZ9gKrpunh/9GttkMqkfl8ssjQMY7
X7qeioclJ1FH5qXMwsmEgu1gtpkA9Y4vXV6Q5yM6WQ3T4fIazQzD67zM2EzH
iE7mb5eF2Kc1MM6SO4H0qZ5Vj3MP1FyN5k6ZD9Pj3Dkly8p8UJ+OC+vNfBrJ
SvZH5aLmVcVssynmimkdyea8/3xFmagwWW+Vyz9/2B7BQ+ed7Dm5WHJe8QLx
Yh4rc+vOlxkJ/WzH1b0v3fyW1X4B2Q4+ZQ==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 443->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylU0FqAzEQG3oo+UbpD5oHhH4hecEGklMgkB5Kb316s9CEzTDSSI7Bu2s8
liWN9m1/3h5fIuJrdX1sp+/Py2X62b3Oi8N0Wn+c5s33/xnxu4n7W51h1LqT
jbxfrSsM5S6Ehc5V72o/8xrFZFoVLYijyqXTiHxTz7KeZL4VHtPDNLscqloF
U+Gi1KFzyn2Il8LX5aLyczCYHtQjplfBzLVsD2nI55W+K7modClcmK6RHDMv
Xc86bUwH4q9oiUZP52XnmaM74zNsBdfN08O3kW3Wg2qoXG48AmS886W7U/Gw
5CTqyLyUXjiZULAdzDYT4LzjS5cX5PmIzmV+FI2uF89mhuF1XmZspmNEJ/O3
y0IA3agXo/8E0qd6Fpk30Mi+1byM5E7pT4XV1boZYzWIC8tp9/9U/Va5KlnJ
/qhc1LyqmDSb8xBzxbSOZHN5//Jd4hS8lawpXJxe3HmCu9x+5jHCxalHPjEv
HY/Rmmlld+R6pbbj6v4vXf+eO/sHTY4+og==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 444->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqAkEQbDxIviH+QB8Q8gXzghXiSQiYQ8gtT0+WaIhNV3XVxIMD4+4y
PdVV1eVq/7o7LCLi7eH7Zze9P51O08fzcv54mY7bzXE+XJ93xOdj/D7vYbOV
z6vvCkPphbDQvfJZnGdeLibjW/Vi31U/lQu6nxfi3N1lM8l8Kzymh2l2OVS1
CqbCRalD95R+iJfC1+Wi8nMwmB40I6ZXwcy17AxpyPeVuSu5qHQpXJiukRwz
L13POm1MB+LvZlypQZioj9M74zNsBdfN09W7kW02g2qpXLr5db50PRUPGSd1
npU/zFs1Ewq2g9lmAtx3fOnygjwf0dnlGOlweY1mhuF1XmZspmNEJ/O3y0IA
3UHmMZJfpE/1LDJvoJG9q3kZyZ0ynwqrq3UzxmoQF5bT7v9TzVvlqmQl+6Ny
UfOqYtJszkvMFdM6ks2ruj8bZaLCZL1VLs4sLn5VXqB6J3sjXJx65BPz0vFY
mVtXX9VmDNVDxOVW+z94P3e/AKwiQGM=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 445->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FqAlEQe/Sj9BrFG+gBSq+gJ1hBvxYE+1H616NXRQWHSSYZf7qw7sqb
ySSZ7Pv2sN6/jDG+3k4/6+n783icfjav5z+7aV4t5/Ph4nqP8fsx7s//cLMr
nmf/MwxlFsJCfdkzO4+8uphMq6IFcVS5VBqRb2ov20nkm+ExPUyzyyGrVTAV
Lkod6lPmIV4KX5eLys/BYHrQjpheBTPWsjOkIfYre1dykelSuDBdnRwzL13P
Km1MB+LvZlypQZhojjM74jNsBdfN08O7kW22g+xSuVT7q3ypZioeMk7qPjN/
mLdqJhRsB7PMBOh3fKnygjzv6GQ9TIfLq5sZhld5GbGZjo5O5m+VhXGryfwr
vgEnv0if6tmIvIFG9q7mpZM7ZT8ZVlXrZozVIC4sp9X3k+1b5apkJfqjclHz
qmLSbJJdxXOmtZPNrC6bx3iz2SoXZxfZVdU72XO5dOsVLxAv5rGyt6qe+azU
Vlzd74Xu75neC5c/iJtA5w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 446->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk1FKg0EMhBcfpNco3kAPULxCPcEv6FOh0D6Ibz26/iJiYzL5Zl3Y/l02
mcwks9vn4/71Zoxx3nz+7Je3x9NpeX+6XQ8vy+Hh/rBe3n3vMS678fOlexix
7lYr3mfnDIPUqrCqvPSb3EdeLqbim9VS56we5VLlx1Vx7nLVTCLfDE/pUZpd
DlkswSRcSFyVR+pVvAhflwvl52AoPdWMlF6CGWPVXaUh5pO5E19kuggXpWvG
x6qXbs86bUpHxd/1OImpMKs6Tu2Ir7AJruunq/+Gt9UMskW5dPPr+tLVJD1U
nOg8s/6o3lJPEGwHs/VEkf/nDLnQmrM6VY7S4fKa9YzCq/hkmjsdMzpVf4kX
yv41b8Dxb6WP9mzlMhzuoE4XR3pG3oeabRfrekzFVFyUT7v3k82bciVeif2h
XKhfKab0pphVvFdaZ7x5FffrjVSeyDBVbcrFmUW2unjHey6X2XjSi4qX6jGZ
Wxev+kxiO67ue5Hz+0/uF5cPepFBJA==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 447->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG+gBgldITvAFXQWEuBB3Ht1EQzBNV/XriQsHJp9h
eqqrqiu3T6/rl6sxxtvN/me9vD/udsvH5vpweF62D/fbw+XdcY/xuRqn73/Y
bsX77JxhkF4KS73Lvtl95DWL6bQSLYoj5VJpVL7Rt24mkW+G5/Q4zV0OWS3B
JFxInXpH+ilehG+XC+XXwXB61IycXoIZa92d0hDfk7mTXGS6CBenaybHzsuu
Z5U2p0Px72ac1ChM1afTO+I7bILbzZPz1GXbzSBblEs1v8qXqifx0HGi83R+
Kg8jhsOruFBMkglyply6OezqrHKsdHR4jQsy43gqPpnm73Xkovp0dTp/SRYq
/+j+Xe96THsWVud/QHM1mzsynwyrqu1mzNUoLspzxcX1dj7NZCX6Q7nQvFJM
m00zq3jvtM5kM6vL+jnerjfl0pnFaa3Ot6vvZK/L5ezcqCdeKF7OYzK3qj6r
jRjUQ8Xlr/YleD9vvwDKbkAm
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 448->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0tqA0EMRJssgq8RcoPkACZXcE4wgXhlCNiL4J2P7g/GEKEqPc1sMjAe
N60uVZWqX75+NtunMcZhdfnZTL8f+/10/Hy+Lr6n3fvb7rr5en/HOK3H4/sf
XvfE/WydYZBeCkudy77ZfuQ1F9NpJVoUR8ql0qh8o2fdTCLfDM/pcZq7HLJa
gkm4kDp1jvRTvAjfLhfKr4Ph9KgZOb0EM9a6PaUhnidzJ7nIdBEuTtecHDsv
u55V2pwOxb+bcVKjMFWfTu+I77AJbjdPzlOXbTeD7KFcqvlVvlQ9iYeOE52n
81N5GDEcXsWFYpJMoDXk0s1hV2dXY9eLpZlxeIpPpvn2rO+v6NPV6fwlWUhx
4T2g+VX6kGcBr+Qu/tO82NwVusmdUFqy2m7GXI3iouajuLjeUdPSrER/KBea
V4ops2l4Z/vDnJmTzazuT79k/eABs0a4dGaR8i7qO9nrcplbT7xQvJzHdm5C
q+sR60ltxbV7X+z8lpy9cTkDW3tBYw==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 449->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FKA0EURBsXkmuIN9ADBK8QTzCCWQWEuBB3Hl0TQgid+tWvOg70NEP/
rl9Vv+bh7WOzvWutfa7+Xpvl62W/X75f7w8f78vu+Wl3OHw8rdZ+1u2809WC
2nS55+r8xOXyXGGQXurb3VO7Ou95zWJW/Cru6lv1o1xGGivf6F03k56vwnN6
nOaUg6olmIQLqavukX4VL8I35UL5JRhOTzUjp5dg9rXurNLQ3ydzJ7lQuggX
p2smx87L1LORNqej4p9mnNRUmFWfpHeP77AJbpon56nLtpuBeiiX436xRr6l
syceSk5QR8+LzCLJBMFOMEkmyDflkuYw1ZlqTL24NTMOr+KjNJ930yfV6fwl
WZC48D+g+a30Uc/Uk/wHZPYEU2GN7hE9yT9HskzmU/UZcXG9nU8zWen9oVxo
XimmzWaQq2ayNpPNq7rC2yqDJGuESzILybvgQuapvEi4zNYTLypezmMyt1G9
qu0xqIcVl/9a7Za7Ry6/w/BBog==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 450->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk1FKA0EQRAc/xGuIN9ADiFeIJ1jBfAWE+CH+eXSNhIU0XTWvNgubZTI9
1VXVNfdvH7v9zRjj8+7vZ7d8vRyPy/fr7WnxvhyeHg+nzYfzO8bP81i/9B1B
bfq6p+536w6D9FJY6lz37fYrr62YTivRojhSLjONyjd61s2k8u3wnB6nOeXQ
1RJMwoXUqXOkn+JF+KZcKL8Ew+lRM3J6CWatdXtKQz1P5k5y0ekiXJyuLTl2
XqaezbQ5HYp/mnFSozBVn6R3xXfYBDfNk/PUZdvNoHsolwsc4Fs6e+Kh40Tn
6fxUHlYMhzfjQjFJJsiacklzmOpMNaZe/H+vyIzSmWRzrT1zUX1Snc5flIUO
F94Dml+lb6tnSiPNFKlznhG/1Z3ontn9cTpojeKiPFdcXG/n05asVH8oF5pX
ijnLJs3VaP4jGXLe1LqLfs165QGzRrgks1C8XX2SvZTL1nriheLlPLZzE1pd
j1pPamdc0/sym991Z38B6fFAYw==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 451->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA0EURBsX4jXEG+gBgleIJxhBVwEhLsSdR9dokKHzq/pVx4UDnUnT
v+tX1a+5fnzZPl+01l6vvn62y9v9fr+8P1weNk/L7u52dzi8Oa7WPjbt9/0f
lntOzjfHtTqvMEivau/uVe/qvOc1i6n4Ke7VvupHuYw0Kt/oXTeTnm+F5/Q4
zSmHqpZgEi6kTt0j/RQvwjflQvklGE6PmpHTSzD7WnemNPT3ydxJLipdhIvT
NZNj52Xq2Uib06H4pxknNQpT9Ul69/gOm+CmeXKeumy7GVQP5fL9Xq2Rb+ns
iYclJ6ij50VmkWSCYCeYJBNkT7mkOUx1phpTL87NjMNTfCrN1TOqI5yVvyQL
JS78Dmh+lT7s2YrTkLv4T/MykzsynwprVJtmzNUoLspzxcX1dj7NZKX3h3Kh
eaWYo2zSXDmtM9ms6qp+KoMka4RLMgvF29Un2Uu5zNYTLxQv5zGZ26i+qu0x
qIeKy1+tc/B+7n4CXl9A5Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 452->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG+gBgleIJ/iCrgJCsgjuPLomhE+cdNW8+mbhwORn
mO7q6uqa+9eP9ftNa2139/OznvbP2+30+XJ7OLxNm6fHzeHy4bRb+1q1+fsf
tlsX96vTPruvMEit6uzyqm913/Naiqn4Ke7VuapHuYx6VLrRXDeTnm+F5/px
PaccqliCSbiQOJVH6ilehG/KhfJLMFw/akauX4LZx7o71UOfT+ZOfFH1Rbi4
vpb42GmZajbqzfWh+KceJzEKU9VJavf4Dpvgpn5ymjpvuxlUi3L5hQN0S2dP
NHSc6DydnkrDHsPhjbhQTOIJcqZcEh+2s037nP9D30daXMEzVVzqzVmbbpVx
QZ9OX+KFEhe+A+pf1R/STKzkHZDZE8wKa5RH+lGxqcdcjOKiNFdcXG2n0xKv
9PocV+BDyjnx+ZwralWc6btIvVnqU9RTHiReI1ySWSjeLj7xXsplaTzRQvFy
GpO5jeKr2B6Daqi4XGu3v+QeuXwDoQU/pA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 453->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3oo+UbpD9IHmHzBeYELzSlQcA6htz69dSimmYw00jaHGhx7
vbMaSaM8vb6Ph4fW2mnz/TNO5908Tx/7x2XxNh1ftsdl8/nnbu1zaOvzP9zs
utkfbvczDKVXtmbnsme2H3n1YiJ+iHu2zvqpXCqNyDf1LJtJ5JvhMT1Ms8sh
q1UwFS5KHTqn9EO8FL4uF5Wfg8H0oBkxvQpmrGV7SEM8r8xdyUWmS+HCdPXk
mHnpelZpYzoQfzfjSg3CRH2c3hGfYSu4bp6u3o1ssxlkl8pl/QYyXvlS9VQ8
hJwEHZGXMgsnEwq2g1lmApx3fKnygjzv0elqtLy4Q2aQTiebkT/q4+pk/ipZ
SHEL39z8In2SZ79vhTt4V/PSkztlPhlWVetmjNUgLmg+iAvrzXzqyUr0R+Wi
5lXFTM+CXoxzS74pGWLexLqrfsl65SFmTeHizALxZvVO9lwuvfWKF4gX85jO
DWhlPWK9Ultxdf8vdH5/OXvh8gW8EkIg
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 454->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1FKA1EQe/RDvIZ4Az2A9Ar1BCvoV0GoH9I/j14rS9ExySRPF7bb5c1k
kkz25ul197IZY7xdf/7slvft4bAcH6/OL8/L/v5ufz68Xe8xPh7G5eneI6hN
b3X9Ol+5fD9HGM4s9K764BOcV14ppuKLZql3NM/lwvrrxTh3vWonlS/CU3qU
5pQDqnUwHS5OHetz5jFeDt+Ui8svwVB62I6UXgez1qozpqH2O3t3coF0OVyU
rpkcKy9TzzptSgfjn2bcqWGYbE4yu+IrbAc3zdOP/0G21Q7Q5XLp9tf50s10
PFSc3H0if5S3biYc7ASzzQTpT3zp8sI8n9F5+W/mPvHiPzLDdCbZrPzZnFSn
8tfJAsRd784/N79Mn+WZ6RvCVnO6Oscz5/twM4Bq04ypGsaF7YdxUbOVTzNZ
qf64XNy8upg0m6BXcVZaZ7KJ6tC8NAMMw+HenTHeqj7JXspltt7xgvFSHqu9
Ma1qRq13ajuu6fci9/eX3i8uJ+vRQeM=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 455->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1FuwlAMi/iYdg3EDcYB0K7ATlCk8YWExD4m/jg6MME00tixy55UStXE
sR13vtmvt7OI+Hq9/KyH7/fDYTh+vFwfPofd8m13fbm4XRGnVfzenSvMehmX
nPz+ziOShqqvm1U9sz50j/wc4z4Hk/EdzSZaMp7LBfXngzh3vWwnmW+Fx/Qw
zS6HqlbBVLgodahPmYd4KXxdLio/B4PpQTtiehXMXMveIQ25X9m7kotKl8KF
6ZqSY+al61mnjelA/N2MKzUIE81xZmd8hq3gunl6+G9km+2gOiqXbn+dL91M
xUPGSd1n5Q/zVs2Egu1gtpkA/Y4vXV6g538uVSfzhulQeP1HZhhPZVbFH81x
dTJ/lSwgHZ0mJ79I31TPGHf0382L4pnyfagZqGrdjLEaxAV57uQAaXo2K9mf
n2PkUOXs5PzBp9WYT8VZ/S7cbJb+FPPcDCAMhXv3DvFm9U72XC5T6xUvEC/m
Mdsb0spm5HqltuPqfi/d/p7rPQNN5kCk
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 456->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1FKQ0EQW/ohXkO8gR6g9Ar1BE/Qr4JQP6R/Hr22WJUxySSrC9uy7Gwm
yeTdPL5sn1djjNfrj5/t8rbZ75fDw9Xp8LTs7u92p8vbzz3G+3p8/Sd7hPU2
rlj1/sLj5xlhOL3QWb2D/+C+8koxFV/Ui/lS8VIu7H1dkLPAR3oQb6S5vnGy
5XrKOKBaB9Ph4tSxd04/xsvhm3Jx+SUYSg+bkdLrYNZadcc01PfO3J1cIF0O
F6VrJsfKy9SzTpvSwfinGXdqGCbrk/Su+ArbwU3zpDxV2VYzQMvl0s2v86Xr
6XioOLnzVH4yDyuGwuu4uJhOJpyzyyXJYYp9Xuvv7WhMvPiPzKC6NJuVP+uT
6lT+OllgOtAsZr8Jps/y7LIb3xC26tPVOZ4534ebAVSbZkzVMC5sPoyL6q18
mslK9ee8ghy6nJOc/5plkCuldSab0B/QL80Aw3C4d3eMt6pPspdyma13vGC8
lMdqbkyr6lHrndqOa/q9dPP729sjY+BBIg==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 457->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOw0AQW3FAfAPxA3hAxRfKC4IEp0pI7aHixtMhFSBlanvshgMrpelq
Zz22x7l9ftu+Xo0xDjdfP9vp+LjfT+9P1/PmZdo93O/mw7vvZ4yPzfh9/4dH
rXp+2m+We4Th9EJ7dQ++wXnllWIqvqiX2qN+Lhd2vy7GuburZlL5IjylR2lO
OaBaB9Ph4tSxe04/xsvhm3Jx+SUYSg+bkdLrYNZadcY01PvO3J1cIF0OF6Xr
khwrL1PPOm1KB+OfZtypYZisT9K74itsBzfN0+J/kG01A7RcLj88Bsl450vX
0/EQcjJ1VF7OLJJMONgJZpsJcj/xpcvLGs87rK5f4sVfZAbVpdms/FmfVKfy
18kC09FpSvLL9Fmemb4hbNWnq3M8c74PNwOoNs2YqmFc2HySHDBNa7NS/XG5
uHl1MWk25xXkSmm9JJuoDvU7491kgGE43LuzM96CizNP5EXCZbEP6h0vGC/l
sZwb0ap61HqntuOafi9yfmvunrh8AqnDQWM=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 458->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8weIV4ghHMKiAkC3Hn0TVBg/NSVa8qurBhPk2/
T1W96punl/XmaoyxX32+1vPrw243vz1eHzbP8/b+bns4vP16xnifxun7Hx61
6vlxPy33qIbTC+1VHvyC84orranwol5qj/q5WFh+XQxzl6tmUvGieoqP4pxi
QLFOTQeLE8fynH4Ml4M3xeLiS2ooPmxGiq9Ts8aqM8ah5jtzd3yBeDlYFK9L
fKy0TDXruCkeDH/qcSeG1WR9kt61vqrt1E39tPgPvK1mgJaL5RsHy+t06Xo6
GkJMJo+Ky5lF4gmndlKz9QTJT3Tp/NL5IOGZcky0+AvPoLjUmxU/65PyVPo6
XmA8RqNd4l/Gz9Ls52NgZ/+pXxzNnPvhegDFph5TMQwLmw/DonornS7xStXn
uAIfupgTn59yJ4wFYXbvRepNqA/odzbfxgOshoO9OzvDLbA480RaJFgW+yDe
0YLhUhrLuRGuqkeNd2I7rOl96eb3u9wPkJFBoA==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 459->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3Io+UboD9oHmHzBfYELzclQcA4htzw9SUkDHkYaye6hBsdZ
dkYjabW7z+/+sGmtHbe3n3447adpOH+83Bdfw/j+Nt43Xx9va5euPb//4WVP
3P9Zd/N1hqHMytasL/0m+5GXi8n4ZrPYOpunckH98UGcq152JpFvhsf0MM0u
h6xWwVS4KHWoT5mHeCl8XS4qPweD6UFnxPQqmLGW7SENsV85dyUXmS6FC9O1
JMfMS9ezShvTgfi7GVdqECaa48yO+AxbwXXzNPtvZJudQfaoXH55oL7Kl2qm
4mHKSdQReSln4WRCwXYwy0yAfseXKi9rPK+wqnmOF3+RmazOzSa6a8+ax+vq
ZP4qWUA6GtHj5hf5sNQzxh39d/OieKbcDzUDWa2bMVaDuCDPnRwgTWuzMvMn
3BEFW+Xs5Jz5V+WKaV2Szawum+dmAGEo3Ks9xJvVO9lzuSytV7xAvJjH7NyQ
VjYj1iu1FVf3vlTnt673CuRuQiI=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 460->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQG3Io+UbpD9oHhHwhfYELyclQSA8ltz49tSmFDCONtOmhBsdZ
dlYjabSPb++H0yYiPrbfP4fpc38+T5fXh2VxnOaX53nZfPp5I7528fv9Dy97
8v663t2uKwylV7Vm58pvsZ95uZiMb9WLrat+Khd0Pj+Ic3eWzSTzrfCYHqbZ
5VDVKpgKF6UOnVP6IV4KX5eLys/BYHrQjJheBTPXsj2kIZ9X5q7kotKlcGG6
RnLMvHQ967QxHYi/m3GlBmGiPk7vjM+wFVw3T8xTlm02g+pRuXTz63zpeioe
Mk7qPJmfyMOMwfA6LiqmkgllrXJxchgDOl2Njhd/kZmqzs0mumtdncIZ+atk
AemIxjsnv0jfqGeMO/rv5kXxTLkfagaqWjdjrAZxQZ4jLqw382kkK5U/DrbK
2cl5xyVzVrWOZLOqq/q5GUAYCvduD/Fm9U72XC6j9YoXiBfzmM0NaWU9cr1S
23F17wud3z1nVy5XexhCJg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 461->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3Io/UboD5oHmH7BeYELzclQcA4ltzy9dSgFT0YaadtDDY6z
7KxG0mj3r+/jaddaOz9+/YzTx8uyTJfjw7p4m+bD87xuPn2/rV2H9vP9Dy97
4v5tPWzXGYbSK1uzc+k32Y+8XEzGN+vF1lk/lQs6Hx/EuTrLZhL5ZnhMD9Ps
cshqFUyFi1KHzin9EC+Fr8tF5edgMD1oRkyvghlr2R7SEM8rc1dykelSuDBd
PTlmXrqeVdqYDsTfzbhSgzBRH6d3xGfYCq6bJ+YpyzabQfaoXKr5Vb5UPRUP
GSd1nsxP5GHEYHgVFxXzrq7wU8VTOCOcyMXRqWhUMxa5/EVmsjo3m+iuVXUK
Z+SvkgVHR++dQPp6PWPc0X8lL725U+bD9Dh3TsmyMh/UZ/MFGUO9mU89Wcn8
cbBVzr1Zz85GzqrWnmxmdVk/NwMIQ+Fe7SHerN7Jnsult17xAvFiHrO5Ia2s
R6xXaiuu7n2p5ve7s5+qfEAo
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 462->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0sKAjEUKy7Ea4g30AOIV9ATjKCrAUEX4s6j+0FFHy9pUl04MNbS17wk
LzNe75bbQSnlMLr+LLvjYr/vTqvhbbPp+tm0vx1OHm8p53l5rf/wsiee3/fz
z32GofTK9uxeuibnkZeLyfhmvdg+66dyQffjgzjX7rKZRL4ZHtPDNLscsloF
U+Gi1KF7Sj/ES+HrclH5ORhMD5oR06tgxlp2hjTE+8rclVxkuhQuTFdLjpmX
rmc1bUwH4u9mXKlBmKiP0zviM2wF180T85Rlm80ge1Qu9/Xtrfnmzl7xMOUk
6oi8lFk4mVCwHUwlE8pe5SL3bNTpanS8+EVmsjo3m5E/7GPqZP4qWUA6CtHj
5hf50OoZ447+u3lRPFO+DzUDWa2bMVaDuCDPnxmo9VVy3ZqVzB8HW+Xs5LzG
JXJWtbZkM6vL+rkZQBgK99oZ4s3qney5XFrrFS8QL+YxmxvSynrEeqW2xtX9
Xmrz++7uBTWYQaQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 463->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EOAUEQnDiIb4gf8ADxBV6wEk4SCQdx83RskGhdNVXDwSZrTaanuqq6
ZrzeL7eDUspxdPtZdqfF4dCdV8P7YtPtZtPdfXPyeEu5zMvr+w8ve+J+v56/
rzMMpVe2Zueyb7YfebViIn7Ql2Sd9VO51DQi39SzbCaRb4bH9DDNLoesVsFU
uCh16JzSD/FS+LpcVH4OBtODZsT0Kpixlu0hDfG8MnclF5kuhQvT1ZJj5qXr
WU0b04H4uxlXahAm6uP0jvgMW8F188Q8ZdlmM8gelcsbjuCbO3vFQ8ZJnSfz
E3kYMRhejYuKqWRCWatc3BxmGWA6XY2OF7/IDNLpZDPyR31cncxfJQuOjtY7
gfS1esa4o/9uXhTPlPuhZiCrdTPGahAX5Hn/feKK94j51JKV6E9JONfmoXBu
zXp29oOzqLUlm1ld1s/NAMJQuNf2EG9W72TP5dJar3iBeDGP2dyQVtYj1iu1
Na7ufaHz++Zsz+UK7IxCpA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 464->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FKREEQQxsX4jXEG+gBxCuMJ/iCrgaEcSHuPLqOOCJNJfXS+uHPn6ar
U0kqffnwvHs6G2O8XHz+7LbXu8Nhe7s/Py4et/3N9f64efX9jvF+O36+yTvC
eoxrnnn/xOP3usIgvaq1O1d9q/2Z1yqm4id9KdZVP8ql06h8o2fdTGa+FZ7T
4zSnHKpagkm4kDp1jvRTvAjflAvll2A4PWpGTi/BnGvdntIwnydzJ7modBEu
TtdKjp2XqWedNqdD8U8zTmoUpuqT9J7xHTbBTfPkPHXZdjOoHsqlm1/nS9eT
eOg40Xk6P5WHM4bD67hQTJIJsqZc0hymOlONiRf/kRmlM8mmumtdHeGs/CVZ
SHSs3gmlb9Uzx139T/NCPCP3g2agqk0z5moUF+X51/eEC++R82klK5U/CTbl
vJr16uzMmWpdyWZVV/VLM6AwCPduT/F29Un2Ui6r9cQLxct57OamtLoecz2p
7bim96Wb39/OfgDNN0Hn
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 465->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FOAzEUQyMWiGsgbkAPUHGFcoJBglWlSmWB2HF0aIEKwrfzHFgw0nRm
mv8d29+5vNttHs5aa48Xbz+b5elmv1+eb88PH/fLdnW9PSxefdytvazb6fkf
bnf1632PwiB7KWzVVz2r9Z7XLKbTTrQojpTLSKPyjfa6mfR8Kzynx2lOOVS1
BJNwIXWqj+yneBG+KRfKL8FwetSMnF6C2de6NaWh7ydzJ7modBEuTtdMjp2X
qWcjbU6H4p9mnNQoTLVPsneP77AJbpon56nLtptBdVEup//W7/fIt3T2xEPJ
CejoeZFZJJkg2AkmyQT5plySHLYvWaA6U42JF3+RmaouzWbPX+2T6nT+kiwk
OmbPhNI365njrt7TvBDPyPmgGahq04y5GsVFeX58fuLCc+R8mslK5U+CTTnP
Zr3q7TlTrTPZrOqq/X7wHmRAYRDuo7Vv14ALnXelnXKZrSdeKF7OYzs3odXt
0deT2hHX9LzY+f2m98jlFT6hQeM=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 466->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytV0FOw0AQG3FAfAPxA3gA4gvlBUGip0pI5YB669PbIoiSYeyxt0TaJtHO
eG2Pc+j928dmexMRn3fnn8309bLfT4fX28vL+7R7etxdNh9+VsTxOea7u2Kg
p8UkV95f8ogFn6qvOwtho77qXu2veDZcGCbUDrhX79V5KpdOI/JN7WUzyXwr
PKaHaXY5VLUKpsJFqUN9ynmIl8LX5aLyczCYHjQjplfBzLVsD2nI/crclVxU
uhQuTNdIjpmXrmedNqYD8XczrtQgTHSOc3bGZ9gKrpsn5inLNptBdalcVjiC
b+7sFQ8ZJ3WezE/kYcZgeB0XFVPJhPKucnFy+Dv/KgdI5/ws5t7y4h8yU9W5
2cz8c18sl6GT+atkwdEx+k0gH0Y9Y9zRs5qXkdwp82F6UK2bMVaDuCDP50xG
tP8jkaZrs1L542CrnEezXvVmzqrWkWxWddV5f3g3GUAYCvdub3U1XNR5V9pV
LqP1iheIF/OYzg1oZWfkeqW24+p+L3R+1/R+czkBA8ZA3w==
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 467->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0GqwlAMfLj4eA3xBnoA8Qr+E1TQVUHQhbjz6OpHC42ZySS6+AVty0sm
M5PpbHvY7CettdP0/rfpzuvjsbv8/jxedl2/XPSPw/nz19p11Yb7f/ixy57b
PoShzGLYXp93984tryom4oe4e+/IL4VLpBH5pvaynXj7jWYwXYqniINXq2Aq
XJQ61KfMQ7wUvlkuKr8MBtODdsT0Kpi2lp0hDbZf2buSC0+XwoXpquSYeZn1
LNLGdCD+2YwrNQgTzcnMtvgMW8HN5mn0nMg224F3qVxePBrIeORLNFPx0OUk
6rC8lF1kMqFgZzDDTID+jC9RXpDnFe+GZzH3KS++kBmmM/LSw0Y6KjqZv0oW
Mjqq3wTSV/WMcUfPal4quVP2w/Sg2mzGWA3igjx/fTt/l7B7T9OnWfH8yWCr
nKtZ93ot55FWkrVKNr260TznfeAhZk3hktnFG2/CRd23p13lUq1XvEC8mMd0
b0Arm2HrldqIa/Z7ifb3We8NmN9FXQ==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 468->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KQ0EQhAcX4jXEG+gBxCvEEzwhrgJCXIg7j66JMUinq/rrIYIDk8lj
+qequub66WX1fDHGeL36+lktbw/b7fL+eLn7WC+bu9vN7vLmsMf4uB/H8z9s
t+J9zFM1SC9XO8vLzuw+4pqtqfAp7Nm30otgqTgq3Wium0k236qH40U0VRiy
WFKTYCFxKo/0U7gI3i4Wiq9Tw/FRM3J8Sc0Y6+4Uh5hP5k58kfEiWByvGR87
LbuaVdwcD4W/63ESo2qqPp3esb6rTep2/eQ0dd52M8gWxbI/gdeULlVPomGK
CfKIuMgsImfVk9bOtKl4HNcvLC6/o0vlF+fDAbRztap+NK77plSu4tnxZsSv
+nR5On2JFzo8CMeqxzk0c9jV/65fiGbkfVAPZLFdj7kYhUVpvj9/6sJ35HSa
8UqmT6c2xTzr9Sw3YqZcZ7yZxWX9TnAfNvEawdKZxQlug4XOO+NOsczGEy0U
LqexnZvg6nrEeBJbYe2+l7/a31g+AVdERF8=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 469->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlEFKQ0EQRAcX4jXEG+gBxCvEE3xBVwEhLsSdR9eEGMykqub1mIUfJj9h
uqurqkuvn15XLxettber74/V8v6w2Swfj5fbH8/L+u52vb282Z/WPu/b4f0f
Tnr6+77PYZBZCVv1qbe673nNYjp+jrv67fwiXEYanW+0N+1E7Xc0I+kinjoO
qpZgEi6kzvWReY4X4VvlQvlVMJIet6Okl2D2tenOaej7yd5JLpQuwiXpmslx
8rLq2Uhb0uH4VzNOahymm1OZ3eMnbIJbzVPyNGU77UA9lMvuDbLmfBnNJB5K
TlBHz2u4i2ImCLbyZqSj/T7BT4pHODsc4pvTGTUGHYTXOTKTdJJZin/fp3ZJ
dCZ/SRYqOqp7VTPO4Vni7r5X80I8I38fNAOqtpqxVOO4OM8PmWzt6P9dmp18
msmK8qeCTTnPZl319pyp1plsqjo174T3IAMOg3Af3Z3w3p9UX8lelctsPfHi
6IEex70ZrY6Lqv/hovgkHLqP6ml/6d1x+QLFi0Oc
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 470->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqQkEQRIcsxGsEb2AOELyCOcEXzEoI6EKyy9ETiQiOXdWvBwU/jN/P
9FRXVde8br7Wny+ttcP872c9HVf7/fT9MTt9bKfd23J32lycV2s/7+3yfobl
nn6/P6cwSC+HHZ2L3tF+z2sUU/FT3KNv5RfhkmlUvtGzbibRfLMeThfxVHGI
agkm4ULq1DnST/EifKtcKL8KhtOjZuT0Esy+1u0pDf15MneSi0gX4eJ0jeTY
eVn1LNPmdCj+1YyTGoWp+lR69/gOm+BW8+Q8ddl2M4geyiWbX+ZL1pN46DjR
eTo/lYc9hsPLuFDMS10wP3e+4kuWF5pDojPLsdJBeN0jM44n6RXxl32KOp2/
JAsVHaN3Qvkw6pnjrv5X80I8I/eDZiCqrWbM1SguyvMrrvAeOZ9GshL5k/HJ
emd9K1mPzvacqdaRbEZ1Ub8b3kkGFAbhnu3d8D4vV1/JXpXLaD3x4uqBHtu5
Ca2KS1RParM8VO/Lo9Y/l1+JRUOi
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 471->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k0FOAzEUQyMWiGsgbgAHqLhCOcEgwaoSUlkgdhwdChXQzLfzHMRI6XSU
//1tx7m8f9o+nrXWni8+frbLy+1+v7zenR8+HpbdzfXusHl1XK29bdr3O11t
omeIaZ5+f9UnMMgsh131Ve9q//feiIvDVPwU9+q7mke5jDQq32ivO5Oeb4Xn
9DjNKYeqlmASLqRO9ZF5ihfhm3Kh/BIMp0edkdNLMPtat6c09P3k3EkuKl2E
i9M1k2PnZerZSJvTofinGSc1ClPNSWb3+A6b4KZ5cp66bLszqB7K5fMNsqZ8
Gc0kHpacoI6eFzmLJBMEO8F0Z+f6V9+Qy19yiHRufhbJvfOC5iXJjNNJZlX8
1ZxUp/OXZCHRMXsnlL5Zzxx39T/NC/GM3A+agao2zZirUVyU5ydc4T1yPs1k
pfInwaacZ7Ne9facqdaZbFZ11bwV70EGFAbhPtpb8T4uV59kL+UyW0+8OHmg
x/bchFbFpaontaM8pPflv9YXl3dOf0Jh
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 472->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA0EQRAc/xGuIN9ADiFeIJ4igXwEhfoh/Hl2jIjipqn49KLiw2SzT
0/2qpvb87nHzcDLGeDp7/9lsn2/2++3L7enh5X67u7rcHRYvvu4xXq/H9/M/
3Oma1+d9rgeZlXqrfeqp1meu1Z6Oz7Grd+cXYak0Ot/o3nQm6nyrGUkX8dQx
qFrSk7CQOrePzHNchLfLQvk6PZIed0ZJL+k516Y1p2HeT86d5ELpIixJ10qO
k5ddzyptSYfj72ac1Liebk5n9tw/9SZ9u3lKnqZspzNQF2X5eIKsOV+qmcRD
yQR1zFwr5+Jm0t7Km0qHutL+ji9VXmgOic4qx04H4fqNzCROMkvxyzkhl9Qz
x6cYko4R9HTz63xY9Syxu//dvBDPyPdBM6BquxlLNY7Feb7yHSWfVrKi/On0
psydnFcsMzPVupJNVafmHXEXGXA9CHu1dsT9daf6Tva6LKv1xIsfF/Q4npvR
6lhUPamt8tD9Xv7q/mR5A2ZhRaA=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 473->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k01qAkEUhJssxGsEbxAPILmCOcEIcSUIugjZ5eiJRER7qupVNTjQjkO/
n69eV7/ujtv9S2vtvPz72U5f76fT9P2xuHx8Tof12+Gyubqu1n427fZOVxvI
KWuKp9+/52h3PCiv6sVqszz0RvsPnAWLqkm1E3b0jfq5LJVGNjc3V51Jz4vq
KT1Kc8qAYp2aDosTx/KcfozL4U1ZXL6khtLDzkjpdWr2sWqPaejznXN3fIF0
OSxK14iP1SzTmVXalA7Gn3rciWE1WZ+kd19f1Xbqpn5SM1XeVmcAH5OlOr9q
Lir3tr/hPBWTe55qng95oSec2mg2lQ70qPxkLpVfXB86OisfMx0OV3KnWK7i
dHohftYn1anm63gh0ZGea6VvdGaKnf1P/eLMzLkfrgdQbOoxFcNY2MxH7pGa
04hX0HyS2i7zqNdRbs/sah3xJopD/WbchQdYDYe92ptxX5eKT7yXsozGO7Ng
XGrG8tyIVtWjj3diK9b0vjxr/bP8AhqBQ6A=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 474->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U1FqAkEUG/woXkN6g/YA4hXsCbZQv4SCfoh/Ht1KZWnHJC8Z2oFxV+ZN
XpKXXb1/bneL1tpx+fWznU6bw2E6vz3d/nxM+9eX/e3w+b5bu6zb/Ex3G7hT
YorVn//k0QSG04ths3voic5/8Sy4KEyqnXBH/1E/l0ulkfnm3lUz6fkiPKVH
aU45oFoH0+Hi1LF7Tj/Gy+GbcnH5JRhKD5uR0utg9rXqjGno7ztzd3KBdDlc
lK6RHCsvU88qbUoH459m3KlhmKxP0rvHV9gObpon5anKtpoBWi6Xan6VL1XP
eQX+ON4zXiNzYT1dbORNpQMtdT/xpcqLm0NH5/xu5l554ehLM6N0Or0Qf9hH
5NLhovghDkoHmkU6V9TjLzxT3Nl7mhfHM+f7cDOAatOMqRrGhXk+8h0pn0ay
gvxJsF3OSc4rLj1nV+tINlEd6vfAu8gAw3C4V2cPvO9b1SfZS7mM1jteMF7K
Yzk3olX16Oud2opr+r381/7mcgU6CkQg
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 475->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVkFqQkEUG7ooXqP0Bu0BpFewJ/iFuhIKuijuPLraStH5SV4y3Tgw6mfe
y0sy+eDTx9dq/dBa2y1OH6vp+227nfbvj+eHz2nz+rI5Hz5fdmuHZfv7voet
Vn9+0ycwnFkKG/Whb3R+fVZxUZiMH+OOntE8l0ulkfnm9qo76fkiPKVHaU45
oFoH0+Hi1LE+Zx7j5fBNubj8Egylh92R0utg9rXqjGno+517d3KBdDlclK6R
HCsvU88qbUoH459m3KlhmGxOMrvHV9gObpon5anKtroDtFwu1f1VvlQzf9ay
3fyHSDi596n8/E8mHGzkTaUDLdWf+FLlxc2ho7PKMdPh8EreKdareDqzEH82
J9Wp/HWykOhI77XSN+qZ4s5+p3lxPHPeDzcDqDbNmKphXJjnI++R8mkkK8if
dtkOtst5NOuot+fsah3JJqpD82a8iwwwDId7dTbjfXWfrD7JXspltN7xgnEb
eU7wUO0Mw/SQcbmH/cvlCJXWRKA=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 476->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKQ0EUG/wQtyHuQBcg3UJdwRX0qyDUj9K/Lr0PS7mdJjnJiODA9N4y
52SSnNzH96/l511r7fvh8LOcNov1etq+3R//fEyrl+fV8fDpvFvbvbbL8z9s
tfrzqz6B4dylsFEfeqLz+VnFRWEyfow7+o/uc7lUGplvbq+aSc8X4Sk9SnPK
AdU6mA4Xp471OfcxXg7flIvLL8FQetiMlF4Hs69VZ0xD3+/M3ckF0uVwUbpG
cqy8TD2rtCkdjH+acaeGYbJ7krt7fIXt4KZ5Up6qbKsZoOVyucIxfEtnr7Ad
Tu48lZ+/yYSDjbypdKCl+hNfqry4OXR0nt6D3CsvHH1pZpRO5y7Ev+9r8x3o
VP46WWA62DxG8st8GPVMcWfvaV4cz5zvw80Aqk0zpmoYF+b5yHekfBrJCvLn
tExsl3OSc+VflSuldSSbqA7dd8O7yADDcLhXZze8z1vVJ9lLuYzWO15c1kxj
5bGcG9HKuKB6p7bKQ/q9/NX+4bIH+8JEXQ==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 477->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FqAkEQRAc/xGtIbqAHCLmCOcEG4tdCQD+Cfx49kQTBsaq6akBwYN2V
6e55XV2z/vja7RettePq92c3fb8dDtPpfXn58znN28182Xz5f1o7v7br+xke
tfr9Po/VcM5StVEeeqP9nmu0JuNj7Og/08thqXpkurm5aiZovtUZqi9HU8aA
Yp2aDosTx/Kc8xiXw5uyuHxJDdUPm5Hq16nZx6o91kOf78zd8QXqy2FRfY34
WGmZalb1pvpg/KnHnRhWk52TnN3XV7Wduqmfbr4Db6sZwGWyVPOrdFG51/1Q
H0d7xlXOIvSEUxtpU/WBlspPdKn8wjR3fKxm5vheaeH0l3pGcTpnIf4+r4V3
iWnG+KradzxFT4l/mQ6jmil29p36xdHMuR+uB1Bs6jEVw1iY5iP3SOk04hWk
T1LbZU58XrH0zG6vI95Ecei8O+7CA6yGw17tQc4iPvFeyjIa72hxs0yN5dxI
r4wFxTuxlR/S+/Ko54/lBwObRGE=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 478->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKBEEQQxs/xGuIN9ADiFdYTzCCfi0I64f459F1cRGnSVKvBgUbemeH
rk4lqczlw/Pu6WyM8XLx+bNbXu8Oh+Xt/vz48rjsb673x8Or0x7j/XZ8P//D
Tms+X907bYVBeiVsdU891fnPs4pLwnT8HHf1rvpRLpVG5xu9m2Yy81V4SU/S
3OWgagkm4ULq3D3Sz/EifLtcKL8ORtLjZpT0Esy5Np05DfN9MneSC6WLcEm6
tuQ4edn1rNKWdDj+3YyTGofp+nR6z/gJm+B287T638h2moFckEs1v8qXdLc7
G8WJzlP5Q+fielJs5U2lQ610v+NLlRfnOfFLYpksJx2E129kJukkvRR/16er
M/lLsuB0qFl051rpw54J72gmXZ+qjnhGvg+aAVXbzViqcVyc5yuu8DtKPm3J
ivKHcKF5JVyrbHZylbRuyaaqU/26GXAYhHt1JnkW9Z3sdblsrSderBb0OM3N
aXVcVD2prfLQ/V7+an9x+QBsaUVd
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 479->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FqAlEQG/woXkO8QXsA6RW2J1jBfi0U9KP459HbrVbwNclkXqV0YV2X
N5NJMtnV9m14XUTEYfn5M4zvz/v9eHx5mF924/T0OM2H68sdcdrE9fkfbnW1
520fw3BmKWzUh57ovOXVi8n4Me7onfnlcMk0Mt/cXrUTtN9shtLleMo4oFoH
0+Hi1LE+Zx7j5fCtcnH5VTCUHrYjpdfBbGvVGdPQ9jt7d3KBdDlclK6eHCsv
q55l2pQOxr+acaeGYbI5ldktvsJ2cKt5Up6qbKsdoMvlku0v8yWb6XioOLn7
VH7+JhMONvIm04Eu1V/xJcuLm0NHZ5ZjpsPhdY/MKJ7OLMS/7Yvv86JO5a+T
hYqO6l7RjHt4priz/9W8OJ4534ebAVRbzZiqYVyY5zdcze9I+dSTFeRPBdvl
3Jt11NtydrX2ZBPVoXnVDDAMh3t2xniq+kr2qlx66x0vvq5N/Ph+lMdqb0wr
44LqQ+xc4bj7+Mv7zOUDZFRGIA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 480->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k01qAkEUhJssgtcIuUFygCFXMCeYQFwJAV0Edx5dJUGctqpeVZM0tDr2
+/nqdc3Tx9d689Ba26/OH+v5+223mw/vj5eHz3n7+rK9HD7/7taOU7t+p7sN
5JQ1xerPbznahGOUNqc2y0Pf6HzBWbComlQ7YUfPqJ/LUmlkc3Nz1Z30vKie
0qM0pwwo1qnpsDhxLM/px7gc3pTF5UtqKD3sjpRep2Yfq86Yhj7fuXfHF0iX
w6J0jfhYzTKdWaVN6WD8qcedGFaT9Ul69/VVbadu6ic1U+VtdQdwmSyLOsbc
0rtXLA6Te59qnou80BNObTSbSgdaKj+ZS+UX14eOzsrHTIfD9ReeUZxOL8TP
+qQ61XwdLyQ60nut9I3OTLGz36lfnJk574frARSbekzFMBY28wWr+R6pOY14
Bc2nTZqn6l31TbyOcntmV+uIN1Ec6pd6gNVw2KuzO+7bTeIT76Usd/+Z8c4s
rkt4xH1WWhkLindiK9b0ffmv/cNyAqVoQx4=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 481->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U1FOAlEQe/GDeA3DDeQAxivgCZZEvkhM8MP459GVCIR9tJ32KZssy+bN
dNpO92Hztt7etdbe739+1tPH834/fb4sDi+v0271uDscLo93a19P7fwcudtg
H8UTV3/e9534oL5qlsJGfeiJzi/PKi4Kk/Fj3NE7mudyqTQy39xetZOeL8JT
epTmlAOqdTAdLk4d63PmMV4O35SLyy/BUHrYjpReB7OvVWdMQ9/v7N3JBdLl
cFG6RnKsvEw9q7QpHYx/mnGnhmGyOcnsHl9hO7hpnpSnKttqB+hyucxwDN/S
3TNcl5O7T+XnrC/MhIONvKl0oEv1X72bXP6SQ0fnyVOVnSonjNd/ZEbpdGYh
/mxOqlP562Qh0ZHutdI36pnizv6neXE8c74PNwOoNs2YqmFcmOczruZ3pHwa
yQryp+JTza7mJllHvT1nV+tINlEdmpdmgGE43KuzK94XO2X1SfZSLqP1jheM
l/JY7Y1pVTP6eqe24pp+L7e6f7l8A6jHQyA=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 482->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk0FOQzEQQyMWiGsgbgAHQFyhnOAjwaoSUlmg7nr0tqgg/XTsPIdI6W+b
Gcf2+N+/fW4+blprX3enj83y/bLbLfvX2/OP92X79Lg9Hz5cdmuH5/b3nNlt
sk/imdWf930Kg9zlsKu+6lmd97xmMRU/xb36rfwiXEYalW+0182kmu/oDqeL
eKo4VLUEk3AhdaqP3Kd4Eb4pF8ovwXB61IycXoLZ17ozpaHvJ3Mnuah0ES5O
10yOnZepZyNtTofin2ac1ChMdU9yd4/vsAlumifnqcu2m0G1KJcVDvAtnT3x
0HGi83R+rvrCTBDsypuRjmq5/sSXUV5oDolOonGUk0Rfmhmnk9xV8Vf3pDqd
vyQLSkczetL8Kn2znjnu6nuaF+IZeT9oBqraNGOuRnFRns+8R86nmaxU/iTY
lHOS8xGXnjPVOpPNqq66L82AwiDcR2dXvC/b1SfZS7lc/QfriRerBT12c1Na
FZeq/pdLxcfh0Hmku/2n94fLEX98QuE=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 483->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylU1FKA1EQe/ghXqN4Az2AeIV6ghX0qyC0H8W/Hl1btLTPJJOMC9vt8mYy
SSa7ev1Yv9+MMXZ33z/rZf+83S6fL7fHl7dl8/iwOR7e/9xjHJ7G+Zneo9FT
YoprPr/kcfUO+qpZDJv1oSc6n3l1Mal2wh29o3kul0oj883tVTuZ+SI8pUdp
TjmgWgfT4eLUsT5nHuPl8E25uPwSDKWH7UjpdTDnWnXGNMz9zt6dXCBdDhel
q5Nj5WXqWaVN6WD804w7NQyTzUlmz/gK28FN86Q8VdlWO0CXy+X0vLgr39Ld
Ox5CTqaOmVe5izATDjbyptKBLtWf+FLlxc2ho/P838y98sLNS5IZpdOZhfiz
OalO5a+ThURHutdKX9czxZ39T/PieOZ8H24GUG2aMVXDuDDPO9+R8qmTldmf
8XtmYrucu1lHvX84m1o72UR1aF6aAYbhcK/OIM+iPsleyqVb73hxdZkeq70x
rYwLqndqqzyk34vc3396T1y+APLzRJ4=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 484->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1k11qAkEQhAcfxGtIbqAHkFzBnGCF+CQI5iHkLUdP/EGSoaq6atCFdV2m
p/urmtrl7rjdz1prH4vfn+30+Xo6TV9v8/PL+3RYrw7nxZfb3dr3pt2f6d0G
9pQ9xdWv/+W4XKSHM4v1ZvvQE63/4yxYVE+qnbCjdzTPZak0Mt/cvepMel7U
T+lRmlMGVOv0dFicOrbPmce4HN6UxeVLeig97IyUXqdnX6vWmIZ+v3PuTi6Q
LodF6RrJsfIy9azSpnQw/jTjTg3ryeYks/v+qrfTN82T8lRlW50BulyWy9PI
GvOlmul4CJlMHT1XeRZhJpzeyJtKB7rU/sSXKi9uDh2dVY6ZDofrEZlRnM4s
xA/niFy6njE+xKB0NKEnzS/zYdQzxc7+p3lxPHO+DzcDqDbNmKphLMzzke9I
+TSSFeRPlUuHtzpTay9h6ZldrSPZRHVoXpoB1sNhr9YgZ1GfZC9lGa13vGBc
ymN1bkyrmtHXO7UVa/q9POu+svwAHphFHg==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 485->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXwWtIbpAcQLxCPMEEzCogxIW48+iaH1wU9V591bjIwGQy
dHXV916/edq/7w4PY4yPx9+f3fL5cjotX6+r88vbctxujufF9e0e4/t5/D3v
4XZXXI/7VA8yy/XO9mXPbD1yzfZUfIo9e1d+EZZKo/KN7nVnkp1vNcPpIp4q
hqyW9CQspE7tI/MUF+HtslC+Tg+nR52R00t6xlq3pjTE/eTcSS4yXYTF6ZrJ
sfOy61mlzelQ/N2MkxrVU83pzI79XW/St5sn56nLtjuD7KIslyfImvKlmkk8
TJmgjshVnkUzE6R35k2lI7vc/o4vVV5oDonOKsdKB+H6j8w4TjIr44/7hqgj
zMpfkgWlYxg93fwqH2Y9c+zqfzcvxDPyfdAMZLXdjLkaxaI8n/mOnE8zWcn8
qXJJeKszpVnP9kZmqnUmm1ldNq+bAdWDsFdritPVd7LXZZmtJ14oLuexOzel
1c2I9Zer4aFiuYf7yvIDFptGIA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 486->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNkztugjEQhK0UKNeIcgM4QJQrkBP8kaBCQoIiSpej80hCseyMvzUUWDLG
8j5mZud/+dwu10+ttf3z8Wc5fb3vdtP3x+x0WU2bxXxzenz92639vLXL+Qjb
rfge81QN0svVzvKyM3uPuEZrKnwKe3ZXehEsPY5KN5rrZpLNt9fD8SKaKgxZ
LKlJsJA4lUf6KVwEbxULxVep4fioGTm+pGaMdW+KQ8wncye+yHgRLI7XiI+d
llXNetwcD4W/6nESo2qqPpXesb6rTepW/eQ0dd52M8gWxXI+gdeULr2eRMMU
E+QRcY3MRfWktTNtejyy5fKv7hDLLT4kPP/9Q33vtKB+qXjG8SS9Mvwxr4k4
glnpS7xQ4VGda9bjHpo57Op/1S9EM/J9UA9ksVWPuRiFRWk+8h05nUa8ovSh
tSnmUa9nuREz5TrizSwu61f1gKpBsPfeFE4XX/FeFctoPNFC4XIau7kprq5H
jD+vgoYKyyPsXywH3wtHXw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 487->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKREEQa1zIXEO8gR5g8ArjCZ7grAaEcSHuPLoOykNrklTSKNjwvl2f
JJW+enja7S/GGM+bj9tuebk7HpfX+8vTx+NyuL05nDavv64x3rZjff6HS626
X/NYDaeXqo3y0BPtV1yzNRk+hh19M70cLB1Hppubq2aC5tv1ULwcTRkGFOvU
dLA4cSzP6cdwOXhTLC6+pIbiw2ak+Do1a6zaYxxqvjN3xxeIl4NF8ZrxsdIy
1azjpngw/KnHnRhWk/VJetf6qrZTN/XTj/fA22oGaLlY1n/E450uXc91Bfo4
2jNcM3NhPd3aSJuOB1oqP9Gl8wvT3NFLzczxvdLC4Zd6RuF0eiH8NW+Wp9LX
8ULCI50r6vEbmins7D31i6OZcz5cD6DY1GMqhmFhms+cI6XTjFeQPiPwoYt5
1usD4KmYXa4z3kRxqF/qAVbDwd7tneH+piGLT7yXYjn7Z8Y7WjBcSmM1N8ZV
9ajxTmyHNT0vf3V9YnkHkjFFXw==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 488->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FKQ1EQG1yI1xBvoAcQr1BP8AW7Kgh1Ie48uhZt8T+TTPLqg2/7fTOZ
JJNeP71sthdV9Xr19WezvD3s98v74+Xh5XnZ3d3uDpc3P0/Vx32dPtOnJnpa
THHG+988Vu+gr5vFsFkf+kT3I69ZTKqdcEfvaJ7LpdPIfHN71U5GvghP6VGa
Uw6o1sF0uDh1rM+Zx3g5fFMuLr8EQ+lhO1J6HcyxVt0xDWO/s3cnF0iXw0Xp
msmx8jL1rNOmdDD+acadGobJ5iSzR3yF7eCmeVp9D7KtdoCOy+XIowifzpdu
5ukE/jjeM14ze2EzXWzkTacDHdWf+NLlhXne+tXszMm98sLRx7iwXsXTmYX4
j31F6pycs905WUh0OBq7Gf/hmeLOvqd5cTxzfh9uBlBtmjFVw7gwz6PfEdF0
blaQPxXk0OU8m3XUO3J2tc5kE9WheWkGGIbDvbtjPFV9kr2Uy5//mfWOF6tj
eqz2xrQyLqj+yAXxUTjuPtLnHLzv3k8CXkVb
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 489->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJylk1FOAzEMRCM+ENdA3AAOUHGFcoJFol+VkMoH4o+jQxEqrOsZP6eR0m02
9njGnr19ft3ursYYbzffP9vl/fFwWD6ero+Hl2X/cL8/Xt797jE+N+P07O4x
kVNimhXv//NYnZO8qpbCVnnZM7uPvGYxpXbBPTtn9SiXSqPqG811M4l8Mzyn
x2nucshiCSbhQuJUHqmneBG+XS6UXwfD6VEzcnoJZox1d0pDzCdzJ77IdBEu
TteMj10vuz2rtDkdin/X4yRGYao6ndoR32ET3K6fuj1wHnSLcjm9Ex6v+lLV
pHpTTkBH5DUzF1WTYme9qXRky+WfnSEX4kOnbZXvsKDvXS+oX2JNl+t0kloZ
/5gXuVCdbnbEC0qH8saMf1UfZnvmuKv/Xb+QnpHvg3ogi+16zMUoLqrn7e8o
0XSpV7L+VL4kfKuZotzN36a+clpnvJnFZfW6HlAYhHt1p3i6+I73ulzO3sF4
0ovVgj12c1NaFZcs3vFxOHQe3T0uyf3h8gX+qELd
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 490->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytVFFKA0EUe/ghXkO8gR5g8Qr1BCvoV0GoH+KfR9eKlHaa5CVTB7bb7byX
l2SyvX1+27xeVdX7zc/HZv143O3Wz6fr/cPLun243+437/6uqq+lDvf0qome
FlOscf+Yx8kz6OtmMWzWh+5of+Q1i0m1E+7oGc1zuXQamW9urzqTkS/CU3qU
5pQDqnUwHS5OHetz5jFeDt+Ui8svwVB62BkpvQ7mWKv2mIax3zl3JxdIl8NF
6ZrJsfIy9azTpnQw/mnGnRqGyeYks0d8he3gpnlKPVAZlMvk0p1f54vqPewv
nE/HyT1P5A/sCzPhYCNvOh1oqf7Ely4vzPMZ78bfu3nKC/f9OM5Vlxml05mF
+I99szrV2TlZSHQ4GrsZ/+GZ4s6+p3lxPHPeDzcDqDbNmKphXJjn8XsENF2a
FeaPi+1ynsl6LQX/s0bOrtaZbKI6NC/NAMNwuHd7lKeoT7KXcjn7zax3vDhZ
psfq3JhWxgXVKz4Kxz2P9KpLen+5fAODAENd
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 491->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU01qgkEUG7qQXkN6Az2A9Ap6gk+oK0Gwi+LOo1dpqzAkecnUhQPjD/Mm
L8nLzLeH9e6ltfb5evlYT1/vx+N02syufz6m/XKxvx6+/e7Wzqt2+0736L0K
k63+nHFB96peCpvpZv71eI5fFSbjx7ij/+7sEJdKI/PNvatmguZb9XDzmnJA
tQ7m6Nth3jk+q3eV8k25uPwSDKWHzUjpdTD7WnXGNPT3nbk7uUC6HC5K10iO
lZepZ5U2pYPxTzPu1DBM1ifp3eMrbAc3zVPqgcogXKv7drhU86t8UXfPf1wM
vYyTO0/kjzsX1tPFRt5UOtBS9xNfqrwwzx2/IFaQe+WF+z6YTnRX6XR6If79
vVGdSpOThURHOlfU4xGeKe7sd5oXxzPnfbgZQLVpxlQN48I8T98R0vTfrDB/
XGyX82jWW5grpXUkm6gO9UszwDAc7tUZ46nqk+ylXOhsi3rHC8ZLeazmxrSq
Hn39bZkeMi7PsH+4fAM6xEce
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 492->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U0tqAkEUbFwEryHeIB5AcgVzghHiShDMIrjz6CrRLDqvfm0y0A5jv65X
Va96sT1sdrPW2uf8+rOZvt6Ox+n0/nL7+Jj2q9f9bXN5X62d1+3nna7RcwoT
Pf0+4lKdU70YNtKN/OvxHL8UJuKHuFff7uwqLkoj8s09y2ZSzVf1cPOacqhq
HczRu4O8c3xm9yrlm3Jx+SUYTA+aEdPrYPa1bA9p6M87c3dyUelyuDBdIzlm
XqaeKW1MB+KfZtypQZioT9K7x2fYDm6ap9QDlkH2uFzU/JQvqqerF3Fy51n5
484F9XSxK2+Ujuph5xNfVF6Q545fz8xVeeHiIp3VWabT1cDmxXQmXBi/CjvV
kc616vEXnilPnD6qzvHMuR9uBqra0XuSZB15nt6jStOzWUH+uNgu59GstzBX
TOtINqu6ql+aAYThcFd7iCerT7KXcvn132OJescLxIt5zOaGtLIefb1Tq7im
9+W/1jeXC5OrRuE=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 493->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA0EURJssxGsEb6AHGLxCPMEIZhUQ4kKyy9E1YRCnqfr//Y4LG3p6
hu6uX1W/Zvv6vttvWmsf99+P3fz5fDzOp5e7y8fbfHh6PFw2H5bZ2nlqP+t/
mNHo9/t7DoPUirDVPbWq/Z7XKKbj57irb+cX4ZJpdL7Ru1FPVH+zGpEu4qnj
oM4STMKFnHP3SD3Hi/CtcqH8KhiRHtejSC/B7M9Ge05Df5/0neRC6SJcIl0j
OY68rHqWaYt0OP7VjJMzDtPVqdRu0zIBNsGt5mn1Xsh21AM1KJesf5kvWU3i
YcQp7WfHa6QvribFVt5kOtSI7ld8yfLiPCd+3dLXzAuK63Q2oHkkm1G/VnvT
r3WZlEvET3GIdBD/aH6dD6OeRdzdezUvxDPyf9AMqLOj/wnOuqhT7VOW61uy
4vyh2JRzJeeRf1muIq0j2VTnVL1qBhwG4Z7tOZ7XdaCfyosKF4kHuBAvVgN6
HPXNaXVc1Hmlz+FmGfqLqXzGd69cvgCC+kVb
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 494->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0GKAkEQazwsfkP8we4DBr/gvmCE3ZMg6EG8+XRXEZEmSSUzlx0Ye6Sr
0kkqvdodtr+L1tpp+fezHc+b43G8fH/c//yM+6/P/X1z/Xxbuw7ttf6HVz39
/nuPwnDOYtisD61oX/FMMCvtlRbG0eVSaWS+ub1qJj1fhKf0KM0pB1TrYDpc
nDrW55zHeDl8Uy4uvwRD6WEzUnodzL5W7TENfb8zdycXSJfDRemakmPlZepZ
pU3pYPzTjDs1DJOdk5zd4ytsBzfNU+qByqB8TC7V/CpfVO9rf+B8Kk7uPJE/
sC/MhIONvKl0oEf1J75UeWGeOzlO7obSMed+MJ2oV+l0Nah5Qf5Dg5lXXBQ/
xEHpcPxz8+t4nHimuLPvNC+OZ879cDOAaqfekyTrzPP0HiFNc7PC/HGxXc5J
zpV/Va6U1inZRHXovDQDDMPhXu0xno91wjyRFwmXJBfKW+Vl4rGaG9Oqzujr
ndqKa3pf5Pzm9D643AAHKEVf
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 495->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy1U0Fqw0AQG3Io/UbID5oHhH7BfYED7ckQcA+ltz69NXWCuxlpJJsaNo7Z
WY2k0e7Pl+5tFxHvjz8/Xf/xPI7958vD9PHaD8enYdo8zCvi6xS3t7PCrJdx
ydPuL7kEwVB6IWx0Lntn+394FlwYJtQOuGffWT+VS6UR+aaeZTNp+WZ4TA/T
7HLIahVMhYtSh84p/RAvha/LReXnYDA9aEZMr4LZ1rI9pKE9r8xdyUWmS+HC
dK3JMfPS9azSxnQg/oqWKPRUXlaeObpj5qNgK7hunlwPWAbhs/C84lLNr/KF
nb3OHnFROJXzbHiVsyAYDK/iomKy2bHzji9VXpDnSo6du8F0bLkfSGd2lulU
NbB5QZ1J7hkXxi/jwHS0fdfMNethe7ZcAnf0382L4plyP9QMZLVr74mTdTQf
tW+V6y1ZQf6o2CpnJ+d3/hi5YlrXZDOry/q5GUAYCvdqD/Fk9U72XC5OLpi3
zEvHYzY3pJX1aOuV2oqre1/+a/1y+QZPsUVZ
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 496->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqQkEQRIcsgtcIuYEeQLyCOcEPxJUg6EKyy9ETRQSHquqq+S4y8P1+
Zrr7VXXP2+dhu3tprZ0Wfz/b6bw5Hqfvj9fLx9e0Xy33l83329Paz7rd3//h
Uavfv8fcHpbDqcVyszj0RvsPnAWLykm1E3b0jeq5LJVG5psbq3rS86J8So/S
nDKgs05Oh8U5x+KceozL4U1ZXL4kh9LDeqT0Ojn7s2qPaejjnb47c4F0OSxK
18gcKy9TzyptSgfjd7S0Qk/lZeVZopuxqHrPnKfUAzWDbCUsVf8qX6q6TbA4
TGU/O66RvrCabm7kTaUDLRWf+FLNC/Pc8Su5G0rHnPvBdKJYpdPVoPqldCYs
ig/lTnWkfUU1hj0z2dn/dF4cz5z74c4AOjt6T5JZZ56n9whpmjsrzB83t8s8
Ousotmd2tY7MJjqH6qUzwHI47NUe47y+B/qJvEhYYD6DxfHiYZkew+9CK2NB
552z1Tyk90X2b07sleUXbJpIWQ==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 497->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FqAkEUG/wQr1F6g3oA8Qp6gi20X4JgP4p/Pbra2sUOSV6yUnBhdlnm
vbwkk3l63W/eZ621j8X5tRk+14fDcNzOLz9vw275srtsPl9Xa1+rNn4fYamn
3x97rothOLMYNutDX7T/h2fBRWFS7YQ7+kfzXC6VRuab26vOpOeL8JQepTnl
gGodTIeLU8f6nHmMl8M35eLySzCUHnZGSq+D2deqPaah73fO3ckF0uVwUbqm
5Fh5mXpWaVM6GP80404Nw2Rzktk9vsJ2cL/rgjylHqgMwqfg03Opzq/yRfYa
3lSc3PNE/rhz2UwXG3lT6UCP6k98qfLCPHf8Su6G0nHP/WA6Ua/S6WpQ5zXu
/ea93XwDLoof4qB0tOAOVPl1PE48qzxx5lR1jmfO/XAzgGqn3pMk68zz9B4h
TfdmhfnjYruck5wr/6pcKa1Tsonq0Lw0AwzD4V7tMZ6qPsleygXiGfWOF4yX
8lidG9OqZvT1Tm3FNb0v/7V+uJwA7cBG2w==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 498->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqQkEQHLIIXiPkBskBJFcwJ3iBuBICugjuPLofROJQVV01z0UGxuHZ
v6rq7pevn9X6qbW2W5x+VtPvx3Y77T+fzx/f0+b9bXM2vl5va4dlu73/4arT
228x18tyOLVYbhaHXmS/w1lgUTkpd4IdfaN6LpaKI9PNjVU96fGifIqP4pxi
QL5OTgeL48finHoMl4M3xeLiS3IoPqxHiq+Ts/dVNsahj3f67swF4uVgUbxG
5lhpmWpWcVM8GH6HSyv4VFpWmiW8LwfEqHqPnKdUAzWD9ARYqv5VusjYP71P
9HF0YrhG+sJqurmRNhUPdFR8oks1L0xzR69kNxSPOfvBeKJYxdPloPp1Z1t2
b4BF4UMYUh5pX1GNR2hWaeLUqfwczZz9cGcA+Y7uSTLrTPN0jxCnubPC9HFz
u5hHZr2RWj1ml+vIbCI/VC+dAZbDwV7ZGE7ln8xeioX9V/k7WjBcSmPVN8ZV
1ej9Hd8Ka7ovsn9zYi9YjpeqRd0=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 499->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqAzEQMzmUfiP0B+0DQr+QvmAL7SlQSA6htzw9TQihaySN5O2hBq9Z
PKORNOP1+9f2c9VaOzz+fLbT8XW/n77fHi4/H9Pu5Xl3uXy67dZOm3Y//8NW
q7+/59w2w3BqMWyWh050P+NZcFGYVDvhjv5RPZdLpZH55uaqnvR8EZ7SozSn
HFCsg+lwceJYnlOP8XL4plxcfgmG0sN6pPQ6mH2sumMa+nyn785cIF0OF6Vr
ZI6Vl6lnlTalg/FPZ9yJYZisTlK7x1fYDm46T6kHagbVcrlU/at8kbmD/jg+
MV4jfWE1XWzkTaUDLZWf+FLNC/Pc8St5G0rHkvfBdKJcpdPVoPo1u9t0Z8BF
8UMcUh1pX1GNv/Cs8sSpU8U5njnvw50BFDv6TpJZZ56n7whpWjorzB8X2+U8
Ousot+fsah2ZTRSH6qUzwDAc7tUd46nik9lLucz+f+8i3vGC8VIeq9lnWlUN
hHVdpoeoVvpeZP+W5F65nAEXWUWe
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 500->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU01OAlEYe2FhvIbxBnoAwhXwBGOiKxITWBB2Hh0hhDiPtl/7ZOEkw8zw
/bX9+p7ev9afi9ba7vHnZz3tV9vtdHh7OH18TJvXl80p+Hy5W/tetuvzP9zq
6uPXmsvNejizWG9Wh54oPsNZYFE9KXeCHX2jeS6WiiPTza1VO+nxon6Kj+Kc
YkC5Tk8Hi5PH6px5DJeDN8Xi4kt6KD5sR4qv07PPVTHGoa939u74AvFysChe
Iz5WWqaaVdwUD4Y/9biTw3qyOcnsRmrUvHv6afYeeFvtAF0ulmp/lS6ydlAf
R3uGa2QvbKbbG2lT8UCXqk90qfzCNHf0Ss6G4uHgSrCwWsXT5aD2NYstu2eA
ReFDGFIe6V7RjHtoVmnizKnyHM2c8+F6AOWOnpPE60zz3pPObKXTiFd6fc5n
IvChi3nE6wzHDWaT64g3UR6al3qA9XCwVzGGU+Un3kuxsP+qfEcLhktpPKsD
mJh+avbveN+70hDNSs+L3N9fas9YjnXqRRw=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 501->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAlEQbFyI15DcIB5AvII5wQTiShB0Idnl6IlBh8yzq7rqmYUDz3Ho
X1V1veX7YbubRcRp8fOzHc6b43H4fJtfPj6G/ep1fwm+XE/E1zrG9zMc9rTx
seZ6UA9lFuqN6rJ3Fp/gLLCwnpA7wJ59Z/NULBVHpJtay3bS4s36MT6Ms4sh
y1V6KliUPFSnzEO4FLwuFhWf04PxQTtifJWebS6LIQ5tvbJ3xRcZLwUL49Xj
Y6alq1nFjfFA+BUuUfCptKw06+Gt9Fb6un6a/De8zXaQPSqWan+VLspMVx9F
e4SrZy6aqfbOtKl4ZA+rd3Sp/II0V/Ry7gbjoeBysKBaxlPlwPY1ia2bt4GF
4cswuDzcvWYz/kOzShNlTpWnaKbcD9UDWW7vPXG8jjR371HG6VGvZPqE4UMV
c6/XMywtZpVrjzfHB/TOvhUPoB4K9iqGcLJ8x3suFrjbIl/RAuFiGt98dTst
JqQfm/03ruTexYx9uCceqf3F8g09PkdZ
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 502->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqw0AQW/JReo2QG7QHCL2CewIHmq9Awf0o+cvRW9PE4EHSaDYtdMFe
lp2HpNFuD+/DcdNa+3j8/g3j58s0jefXh/nwNp6en07z5e76tXbZt2X/D59a
8X7JCRxQXtaL1WZ5aEf3EVdvTcqdYEdn1M/FknFkurm5aiYRL6qn+CjOVQwo
1qnpYHHiWJ7Tj+Fy8FaxuPgqNRQfNiPF16kZY9Ud4xDznbk7vkC8HCyKV4+P
lZZVzTJuigfDn3FpBp9My0yzCu9YX9V26iKezrxcDZQH6RJ4IpZ0fokuKjfT
xcHkzhPp4/ZlPd3aSJuMB1oqv6JL5hemuaNX5W0oHve8D8YT5SqeLgc1r9Xd
PuwFLAofwlDlUZ0r6vEbmmWaOH2yOEcz5324HkCxve+k4nWmefUdIU73egXp
0wo+dDH3eh1hiZhdrj3eXBapjc6OB1gNB3t2x3Cq+Ir3qljobJN4R4vVMjW+
+SrqrrgyLCjeic38UH0vf/X9YPkC9w1E3Q==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 503->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAlEQbLIIXiPkBuYA4hXMCSZgVoKgC3GXoydKCEzbVV31dJEH44z0
r6q63svHfvP5FBHHxc/PZjqtD4fp/P58+bOddm/L3SX4+vtEfK3i7/0fHnZy
PNegHsos1BvVVe8qnnGN9mTcFS4Io4ql44h0U2vZTjLeqh/jwzi7GKpcpaeC
RclDdco8hEvB62JR8Tk9GB+0I8ZX6ZlzWQxxyPXK3hVfVLwULIzXiI+Zlq5m
HTfGA+FXuETDp9Oy08zhfT1FDZv3SD/Nvg1vsx3cnKZ37o90VXRhtaP6KNoj
XCNz0Uy1d6VNx6M6rN7RpfML0lzRy7kbjIeCy8GCahlPlQPb1yy2Sm8DC8NX
YXB5uHutZjxCs04TZU6Xp2im3A/VA1Xu6D1xvI40d+9Rxeler1T6hOFDFfOo
1yssGbPKdcSbVV41z/UA6qFg72IIJ8t3vOdigbtt8hUtZkfUmHofcEVYqnwl
9yZm7MN94p7aK5ZvEo1Eng==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 504->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tqAkEQHPwIuUbwBuYAwSvoCVbQLyFgPoJ/OboPQtChqrpqNgu6LNNd
XVVd87b73BwWrbWv1+vfZvpen07Tefty+9hPx/fV8Xa4/P219vPR/t7Jr4X1
Nq54+vNHLk/foK+axbBZH3qj857XKCbVTrijbzTP5VJpZL65vWonPV+Ep/Qo
zSkHVOtgOlycOtbnzGO8HL4pF5dfgqH0sB0pvQ5mX6vOmIa+39m7kwuky+Gi
dI3kWHmZelZpUzoY/zTjTg3DZHOS2T2+wnZw0zylHqgMqsflUu2v8sWZmfrj
+MR4jcxlM11s5E2lAz2qP/Glygvz3PEruRtKx5z7wXSiXqXT1aD29XQ2g4vi
hzikOtK9ohn/4VnliTOnqnM8c+6HmwFUO3pPkqwzz9N7hDTNzQrypwU5dDmP
Zh1x6Tm7WkeyierQvDQDDMPhXp0xnqo+yV7Khe62qHe8YLyUxzL7RKuagbCq
2oprel/k/ub03rlcAEVTRt8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 505->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KQ0EQhAcXkmsEb6AHEK8QT/CEuAoIcSHucnQNimCnqrpqEsEHL48w
/fNVdc/66WXzfDXGeF19/myWt4f9fnl/vD7+2S67u9vd8fDm+x3jcD9+vv/h
VU89rzmshtOL1WZ56IvOK9dsTaXd0cIYXZZOI/PNzVUzqbyontKjNKcMKNap
6bA4cSzP6ce4HN6UxeVLaig9bEZKr1OzxqozpqHmO3N39gLpcliUrpk9Vl6m
nnXalA7G72ipcc49QDUZU6Kb5ah+7b4Y+4H6jmC31QxOHnP+lQlp6HxRue6r
mNx5In/cvqynWxt50+lAj8pPfOn2hXnu+JXcDaXD4UpYWK7S6WpQ8/p1dgaL
4kMMqY50rqjHJTzrPHH6dHGOZ879cHcAxc7ek2TXmefpPUKazt0V5M8I9tBl
nt11xFKZXa0zu4niUL90B1gNh707Y5wqPtm9lIXOtol3vGBcymO5+0Sr6oFq
dbEda3pf/ur9YvkArJREog==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 506->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKAkEMG/wQryHeQA8gXkFPsIJ+CYJ+iH8eXcUHOCRpOiviwLqsbdMk
7YzX++V2UEo5jm4/y+60OBy682p4/9h0u9l0dw9Onk8pl3l5v//hUaeO1zUM
w+nFsFkdeqN4zasVU2l3tDCOLpdII/PNrVUzqfkiPKVHac5yQLkOpsPFyWN1
Tj/Gy+Gb5eLyy2AoPWxGSq+DWeeqGNNQ1ztzd/YC6XK4KF0te6y8zHoWaVM6
GH9HSwn0RF5GnmV01/gK28F96VN5qq+722oG6LhcovlFvjg9Q/8EJ3eeyB+3
L+vpYiNvIh3oqPqML9G+MM8dvzJ3Q+nocz+YTlSrdLoa1LxQrIWL4oc4ZHVk
54p6fMOzyBOnT5TneObcD3cHUG7rPcnsOvM8e4+Qpr67wvxxsV3OfXY9s1dK
a8tuojzUL7sDDMPhHsUYT5Wf2b0sF/ZflO948XFMj9XuM62MC8p/cUF8FI47
j18+Dy5XdfdF4Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 507->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqA0EMMz2EfKP0B+kDln4hfcEGmtNCITmU3vr0Nmk3gUGS5dkGMjBZ
JuOxJVl+3L1v9w8RcVz//GzHj5fDYfx8XZ0Ob+P0vJlOl09/O+JriMv3HrZa
7f35PO/gOZxa6KzeoS+6b3H15mT4qC7gjOq5WDKOTDf3repJixflU3wU5yoG
FOvkdLA4ceydU4/hcvBWsbj4KjkUH9YjxdfJ2caqO8ahfe/03fEF4uVgUbx6
fKy0lL3q4KZ4MPwOF5SvomWmmZsXYVa5nbyz1ipO1XW9rXqAlosl61+mi1Mz
1U9gcvuJ9HHrsppubqRNxgMt9b6iS+YXprmjV2U2FI8l88F4oreKp8tB9Qvd
9WBR+BCGKo9qX1GN/9As08Spk8U5mjnz4XoAxfbOScXrTPPqHCFOS72C9ImC
D13MPV6P4bpdXymuPd5Ecahe1QMsh4M9u2M4VXzFe1Us7L8s3tGC4VIaS+8T
rqoGynVepoaoVnVebrV/sXwDn1NCYw==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 508->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytVVtKA0EQbPIhXkO8gR4g5ArxBCvoV0CIH8G/HD0maFg7VdXVsw5Mls30
o6q6hn14/di+ryLi8/77ZzsdNvv99PVyd355m3bPT7vz4ePPjjiu4/rs7GjG
23XFyue/OCJxQHlVL/Su8tDzmLDkWhUWVpPhzfFSp8D9XCwsPy+GucpVM7nR
GNRTfBTnLgYU69R0sDhxLM/px3A5eLtYXHydGooPm5Hi69TMseqMccj5ztwd
XyBeDhbFa8THSsuuZhU3xYPhd7hc1zrKb5uqeYOp0EnpHcA7rF/pl9muNHex
Ms0Zp7yc+WdMKK/SxelZ6icwufNE+rh9WU+3NtKm4oGWyu/oUvmFae7o1bkb
iseS+8F4olzF0+Wg5oXORrAofAhDl0d3rqjHf2hWaeL0qeIczZz74XoAxY7e
k47Xmebde4Q4LfUK08et7WIe8XqQXhmzy3XEmygO9et6gNVwsFdnDKeK73iv
i4X9V8U7WvxZpsaX99nOmJh+svfs3IlFXnfn0d2xJPeC5QQmMEMc
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 509->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0tOw0AUG7FAXANxg3KAqlcoJwhSu6pUqSwqdhwdGpUqGWw/O2WkaZS+
n+3nPL8ft/uH1trH08/PdjhvTqfh8+3x8rIbDq+rwyX4cr2tfa3b7Zncdr1p
XdlXnD4+xTEe0sOZhd5VHXqi+DRWYVE9GT6qC3hH81wsFUemm1urdtLjRf0U
H8U5xYBynZ4OFieP1TnzGC4Hb4rFxZf0UHzYjhRfp2efq2KMQ1/v7N3xBeLl
YFG8lvhYaZlqVnFTPBh+h0uKj/VkPRLet/7AO2ye6xlH81QDNUMdF0u1v0oX
Z6ajHcPk7rPageUJ0a/C4vZUu1P1iS6VX5jmiccrHIlPEn6KJ6pVPF0Oal8o
tgSLwocwpDzSvaIZ/6FZpYkzp8pzNHO+D9cDKHfpd5J4nWmefkeI071eYfq4
vV3Msdd/L6jtMbtcl3hzPKI3enc8wHo42KsYw6nyE++lWNh/Vb6jxeyYGs/q
ACamn5w9iTu5f2LBPtLb7qkdsXwD4HxDXw==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 510->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tOAzEQi/hAXANxAzgA4grlBItEvyohlQ/Uvx69D8GKDbbHzhIpXaWZ
cWzPzP3bx2Z701r7vDv/bKavl/1+OrzeXg7v0+7pcXe5fPjerR2f2/xN9kiO
i8tWfz/ndHxQXvUWw1bamX89nuNZhUm1E+7o7NYPcak0Mt/cXFWTni/CU3qU
5pQDinUwR+eHeef4rOYq5ZtycfklGEoPq5HS62D2seqOaejznbo7fYF0OVyU
rpE+Vl6mnlXalA7G39GS8mOYfzgVPim/K2wXd479xcepl+uB6kG1nPr3nFBe
5YvzZumd4OTWE/njvsvedLGRN5UOtFR+4kvVL8xzx69kNpSONfPBdKJcpdPV
oOqF7ka4KH6IQ6ojrSt64z88qzxx3qniHM+c+XB7AMWOzknS68zzdI6QprW9
svBnoA9dznGvC28WnLsYpXWkN69LYKOz0wMMw+Fe3TGeKj7pvZQL+6+Kd7xY
LNNj2PsN4BlcUPwPF8SH4gT1SHdbk3vlcgIj8UMg
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 511->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk10OAUEQhCcexDXEDTiAuAInWAlPm0h4EG+OjgRhVFVXz9oEWdM/X1X3
TLeH9X5USjlN7l/r7rw6HrvLZvx42XX9Yt4/DmfPTynXZXn/Zj4lGW/XFU99
/sny9Q7yol6sNstDv+i85mqtSbUTdvSO+rkskUbmm5urZlLzonpKj9KcZUCx
Tk2HxYljeU4/xuXwZllcvkwNpYfNSOl1atax6oxpqPOduTt7gXQ5LEpXyx4r
L7OeRdqUDsbvaMnysZo/TIFPyu+otlv3xVE+eJx5uR6oHVSPM/+aCeVFvjg9
Q/8EkztP5I/bl/V0ayNvIh3oUfkZX6J9YZ47fmXuhtIx5H4wnShX6XQ1qHmh
sxYWxYcYsjqyc0U9/uFZ5InTJ4pzPHPuh7sDKLb1nmR2nXmevUdI09BdYf64
tV3mll1nuTWzq7VlN1Ec6pfdAVbDYY/OGKeKz+xeloX9F8U7Xnw9psdq95lW
xoLiFY+q486j5S4Ny70BJd5BZQ==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 512->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tqQkEUG/yQbkO6g3YB4hZ0BVdov4SC/Sj+uXS1LWKnSU4yemG8jOeV
5OQuth/r91lr7fPp/LOevlb7/XTYzC+Xt2n3+rK7BJ9/T2vHZbu+k9PCfLuv
ePr4LZY/d1BXzWK9WR16o3iPa7Qn5U6wozua52KpODLd3Fq1kx4v6qf4KM4p
BpTr9HSwOHmszpnHcDl4UywuvqSH4sN2pPg6PftcFWMc+npn744vEC8Hi+I1
4mOlZapZxU3xYPgdLi42hgH6Y3lzAt59f4XRxez4g811va12gB4XS7WfShdn
pqMdw+Tus9rBqCfc/bo91e5UfaJL5RemeeLxCkfik4Sf4olqFU+Xg9oXio1g
UfgQhpRHulc04xGaVZo4c6o8RzPn+3A9gHJHv5PE60zz9DtCnO71CtPH7e1i
HvE6q+0xu1xHvIny0LzUA6yHg72KMZwqP/FeioX9V+U7WjBcSuPvO9BdcVUz
+nwn918s2Ed67un3U3sCWSVDYw==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 513->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1FKA0EUe/ghXkO8gR5AvEI9wQr2qyDUD/HPo2uLFndM8pKpC9tlOu9l
krzM9dPLZntRVa9XXz+b5e1hv1/eHy8Pi+dld3e7O2zefL9VH/d1+iZvhfU2
rnjG/d9cVmvQ153FsFkf+qL9kdcsJtVOuKM1Os/l0mlkvrm9aiYjX4Sn9CjN
KQdU62A6XJw61uecx3g5fFMuLr8EQ+lhM1J6HcyxVu0xDWO/M3cnF0iXw0Xp
msmx8jL1rNOmdJy+DYc2T4b3DBNxKuFTx6GAHnSemxnHc4ZZAGusQ2v2uFy6
+XW+OGc63jFOzjydGTgYCq/j4mKq2an+xJcuL8zzJOMdjyQniT6lE/Uqna4G
NS+0N8NF8UMcUh3pXNEZ/+FZ54lzTlfneObcDzcDqHb2niRZZ56n9whpOjcr
K38mcuhyjrP+84LeFecBX2mdyebxEdho7WSAYTjcuz3GU9Un2Uu5sP+6escL
xkt5DLNff/93uKB6p7bjmt4XOb9zeo9cPgG0hULf
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 514->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytVktKA0EUbFyI1xBvoAcIXiGeYARdBYRkEdx5dA3IYF5e/ToGJkPn/arq
VUPuXz+27zdjjMPdz9d2OT7v98vny+3p8Lbsnh53p+DD7zPG12as7+QZYb7d
l3xq/C+Ws3NTp2ah3qiue3fximu2J+QOsHfnbp6LRXFEurm1bCcVb9eP8WGc
UwxdrtPTweLkoTpnHsLl4E2xuPiSHowP2hHj6/SsuSyGONR6Z++OLzpeDhbG
a8bHTMtUM8WN8VjfAoP0k6E96nmBSeik9B4qbvR1/VF5uRqwGezjYlH7U7o4
Mx3tEKZonyGG2oP1U1jcnmx3rD7RRfkFaZ54XOFIfJLwYzy7WsbT5cD21cVm
sDB8HYaUR7rXbsZ/aKY0ceaoPEcz5364HuhyZ+9J4nWkeXqPOk7XegXp4/Z2
Mc94HdVWzC7XGW92ed281AOoh4NdxRBOlp94L8WCflP5jhYIF9N4PW/G2X9T
xpXNqPlOrsKa3he1v+tqvwF7wERh
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 515->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbFxIriG5QTyA5ArmBCPoShDMImSXoyeGMGjz6tdmYUM7tP0+
VfWqV7vT9rBorb0//fxsp4/X83n6fFteDvvpuH45Xi6f/3ZrX5s2fx9hs9Xf
zzkdhypP9UK1UV71re57XKM1IXeAvTpX/VwsiiPSzc1lM+nxVvUYH8Y5xVDF
OjUdLE4cynP6IVwO3hSLiy+pwfigGTG+Ts0+lt0hDn2+M3fHFxUvBwvjNeJj
pmWqmeLGeCD8DpebZWiPaiJMCe8552qrfq5nHM1drEhzqGu3XCxqfkoXp6ej
HcLkzlPNwPIEqaewuDXZ7Fh+oovyC9I88bjCkfgk4cd4VrmMp8uBzau6G8HC
8FUYUh7pXKse/6GZ0sTpo+IczZz34Xqgih19J4nXkebpO6o43esVpI9b28Uc
e51o02N2uY5483eR2tXZ8QCq4WBXdwgni0+8l2JB/6l4RwuEi2nMvI+4sh5V
LRWrsKbvRc3vvtxvvR9EIg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 516->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk01Kw1AUhR8OxG2IO9AFiFuoK4hgRwWhDsSZS9eClBjO76uBNKTv/nzn
3pPbl7fd/mqM8X7z87NbPp6Ox+Xz+fr08rocHu4Pp8O733uMr8dxfrb3mMix
NcW1PV9zjBUPynO9WG2Wh57o/A+nYVE1qXbCjt5Rv5TFaWRzS3PVTra8qJ7S
ozS3DCg2qZmwJHEsL+nHuBLeliXla2ooPWxHSm9ScxurzpiGbX6y98QXSFfC
onTN+FjNsp2Z06Z0nJ+GwfopmD2rSZkK3WsdQ5yndVN/tKyoJnpnV8ri9ufm
kvRMZseY0n26HUSeEPUcS1pT7U7lN3NxfmEzbzzuOBqfNPqUTpSrdKYa1L7Q
2QyL4kMMrY52r6jHf8zMzSTp4+KSmSXfR+oBFDv7nTReZzNvvyOk6VKvsPmk
tVPmGa+z3C1zqnXGmygO9Ws9wGok7O6Mcar4xnstC/vPxSezYFxqxsr7TKvq
gWq5WMfafi9uf5flfgOdJELj
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 517->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIIuUbIDfQAwSuYE4wQV4JgFsFdjp5IRCZtVb2q1kUGeobm
/arq1Txv9uvtQ2vt4+nntZ4+V4fDdHx7PF3ep91ysTsFX86nta/Xdvn+h6Oe
Pn5VR3o4s1RvVIe+KD6PVVhUT4aPYUd3NM/FUnFkurm1aic9XtRP8VGcUwwo
1+npYHHyWJ0zj+Fy8KZYXHxJD8WH7UjxdXr2uSrGOPT1zt4dXyBeDhbFa8TH
SstUs4qb4nH5FhhKPxnas54IUxM6Kb3bjEs1z/WMo7mLFfVEd/a4WKr9Vbo4
Mx3tGCZ3n9UOLE+IfhUWt6fanapPdKn8wjRPPF7hSHyS8FM8Ua3i6XJQ+0Kx
ESwKH8KQ8kj3imbcQ7NKE2dOledo5vwfrgdQ7uh/knidaZ7+R4jTrV5h+ri9
XcyjXke1PWaX64g3UR6al3qA9XCwVzGGU+Un3kuxpLtlOiktE43/YACYmH5q
9jzu5F7Fgn2k55Z+v7XfzX1FIA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 518->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqw0AUG7IovUboDdoDhF4hPYED7coQSBcluxw9cSmhDJKeNO6iBmdw
3k/S02wPx/3HprX2+Xj72U9fr6fTdH57WD7ep/nleV6CTz9va5ddu5//4VVP
H+/rWA9nluqN6tCJ4j2u0Z4MH8OOvpleDpaKI9PNrVU7QfutZihejqYMA8p1
ejpYnDxW58xjuBy8KRYXX9JD8WE7Unydnn2uijEOfb2zd8cXiJeDRfEa8bHS
MtWs4qZ4MPwOFxcbw8D6fD9CJ4Wh6q30T++Umut6W+0APS6Waj+VLs5MRzuG
yd1ntYNRT7j7dXuq3an6RJfKL0zzxOMVjsQnCT/FE9Uqni4HtS8UG8Gi8CEM
KY90r2jGX2hWaeLMqfIczZz74XoA5Y7ek8TrTPP0HiFOa72C9GmBD13MI15v
v07XV4rriDdRHpqXeoD1cLBXMYZT5SfeS7Gw/6p8RwuGS2mMMPT6V/Uot+/h
aojq0/tS7W9d7RUMNENl
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 519->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRBsX4jXEG+gBxCvEE3xBVwEhLsSdR9eIhmSsqq6a78IPk8/P
9HS/6q65fHjePJ1V1cvF589meb3b7Za3+/P9x+Oyvbne7jevvlfV+20d3v9h
qWfcP5w5WiiHU4vlZufQG+2fcDYsKifVTtjRN6rnsnQaWd/cs2omIy/Kp/Qo
zSkDinVyOixOHDvn1GNcDm/K4vIlOZQeNiOl18k5xqo9pmE878zd8QXS5bAo
XTM+Vr1Me9ZpUzpYjKPFZWMMLE/9rED3r/yC0WV2/IH6lnibfbPHZenm0/XF
qen0jjG58+xmkHgC5etY3JxqdtKnQV86v7CeJx7vOBKfJPqUTnRW6XQ1qHmh
vRkWxYcYUh3pXFGNv+hZ1xOnThfn9My5H64HUOzsPUm8znqe3iOkaa1XUH8q
8KHLPOP1IrVGZlfrjDdRHKqXeoDlcNi7Pcap4hPvpSzsvy7e6QXjkj0GDMdv
1j9V+yS/Eas0jPtrV605+8XyAWQvQeM=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 520->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FKxVAQG1yI1xBvoAcQr/A9QQVdfRC+C3Hn0fWjSPtIMsmrhbaUeZNJ
Mun10+vh5aKq3q6+H4fl/eF0Wj4eL88fz8vx7vZ4Lt783lWf9/X3Tu+a6Gkx
xTXW1zxqxQf1dbMYNutDb1Tf8Gy4KEyqnXBH32iey6XTyHxze9VORr4IT+lR
mlMO6KyD6XBxzrE+Zx7j5fBNubj8Egylh+1I6XUwx7OqxjSM/c7enVwgXQ4X
pWsmx8rL1LNOm9KxqQkObZ4M7xmm5GTqHnWofTi4bj5SrggTfbPL5dLtr/PF
mel4xzi5++x2YGeC4HVcXEy1O9Wf+NLlhXmeZLzjkeQk0ad0ol6l09Wg9oVq
M1wUP8Qh1ZHuFc34D886T5w53TnHM+f/cDOAzs7+J0nWmefpf4Q07c0K8qeC
HLqcZ7OOekfOrtaZbKJzaF6aAYbhcO9qjKc6n2Qv5ZLulvmkvIw8BhzWb+af
mr3BN84qDWN9770H76f3Cwf4QaQ=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 521->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk11KA0EQhAcfJNcQb6AHCF4hnmAF8xQQkgfJW46eHzRmh6rqqokLk2Uz
3T1fddc8fXyt1g+ttd3i9LOavt+222n//nj++Jw2ry+b8+bzz2rtsGzXd7ra
QE5ZUzz9/i3H5SE1nLNYbZaH3mh/xlmwqJpUO2FH3+g8l6XSyPrm5qqZ9Lyo
ntKjNKcMKNap6bA4cSzPOY9xObwpi8uX1FB62IyUXqdmH6v2mIY+35m74wuk
y2FRukZ8rHqZ9qzSpnRc37+LMFR+cnrPcihToHuWUzC6zI4/UlZUE32zx2Wp
5lP1xTnT6R1jcudZzcD2BKlXsbg11exUftKXyi+s54nHK47EJ4k+pRPlKp2u
BjUvtDfCovgQQ6ojnSs64z96VvXEOaeKc3rm3A/XAyh29J4kXmc9T+8R0nSv
V1h/3Nou84jX2/Jvub5SWke8ieLQeakHWA2HvdpjnCo+8V7Kwv6r4p1eMC7Z
Y8Bw+2b9U2fP6huxSkO/f+/q70+Ue2E5AgL6QiI=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 522->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0sKwkAQRAcX4jXEG+gBxCvoCSLoKiDoQtx5dD+I6FBVXT1xYSCGOP15
XV2Zbg/r/aiUcprcf9bdeXU8dpfN+PGy6/rFvH8czl53KddleT//4VZXfV7n
sRpOL1Ub5aEnOq+5WmsyPsaO3pleDks0I9PNzVU7QfuNeqi5HE0ZA4p1ajos
ThzLc/oxLoc3y+LyZWqoediO1LxOzTpWnbEZ6nxn744v0FwOi5qrxcfPS/Bl
NItmU3N8shTBEPnJ0Z7lICblOcWANGD9XM84mrusjJEx15fLEu0n0sXp6WjH
mNx9RjtwPcHqRSxuTbU7lZ/RJfIL0zzj8Ygj45PMfGpOlKvmdGdQ+0JnLSyK
DzFk58juFfX4hWaRJk6fKM7RzPk+XA+g2NbvJON1pnn2O0IzDfUK08et7TIP
8XrGV2rWFm+iONQv6wFWw2GPzhinis94L8vC/oviHS0Yl9QYMHw+mX6q91d9
I1bNUJ8PvcuQ3CfLDT1kRGM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 523->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FKA0EQRJt8iNcI3kAPELxCPMEK+hUIxA/xz6NrREIcqqqrZl3YbJaZ
7nlVXbt9Pu5fN1X1dvv9s1/eH0+n5ePp5vzyshwe7g/nxbvfu+pzV5dnetdE
TdtTXOP6yIL2KG1ub1SHnmj9eq1jUT0ZH2NH7+g8l6XTyHxza9VMRl7UT+lR
mlMGtNfp6bA4+1idcx7jcnhTFpcv6aH0sBkpvU7Pca9aYxrGemfuTi6QLodF
6YpzbMw78azTpnTUwMMYujw53rOayyVYnEyjearz3Mw4nrusjJExj5fL0s2n
88U50/GOMbnz7GbgZoL161jcnmp2qj7xpcsL8zzJeMeR5CTRp3SiWqXT1aDm
hdZmWBQfYkh1pHNFZ/yHZ50nzjndPscz5/twM4D2zn4nSdaZ5+l3hDStzQrz
x+3tMq/JepIrpXUmm+ximUD/1dkuC/OHrTEu1cvNXjKzGXbmk/Iy8hgwXD+Z
f+rsP/2NvUrDuL72rjW1PyxfX55DIg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 524->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FKA2EMhEMfxGuIN9ADlF6hnmAFfSoI9UH65tFrRWX9nUy+7Lrwd/mb
ZDIzyd48vuyfNxHxev3xs5/edsfjdHq4ulyepsP93eESvP06Ee/b+Hl3Tyyo
KTHNM8ZVncIgvRy2qlNvFZ/HKi4OM+OXcVd31Y9yqTRmvtFaN5ORr8Jzepzm
LgeVSzAJF5KX1ZF+GS/Ct8uF8utgOD3ZjJxegjnmulimYawncyd7oXQRLk5X
e4/BvDueVdqcjkj6Ei2UW8Yhw1FcyE5/66k4Us5kP7pcFaa6Zw/lUs2n8oX0
JN5lnOg8qxmgnTB4FReK6Wbn6ju+VPuSed7Z8YpHZ086+pxOVet0Ug1uXiq2
hIvjpzh0dXTnqnr8h2eVJ6RPlUc8I98H3QGVu/Q76ex65nn3O1Ka1u5K5g/F
ppzX7Hpnr5zWJbsZ29kR2OpOdiDDQNwHTsT3jAuZ5/j8iRsc91+Vj7xIeFmP
hX/zd+af6/0LH+Q6DWN87Yk1tZ9czsyCQl8=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 525->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAlEQbFwEryG5QXKAkCuYE4yQrAYC4yK48+jqIGKeVdXV87LIwHN4
9q+qumaz+95+rSJivz7/bIef92kaDh9Pl8vnML6+jJfg8/VEHN/i9v4PRz1t
/KGO1DuzVG9Uh94ofh/LsKieDB/Dju5onosl48h0c2vVTlq8qJ/iozhXMaBc
p6eDxcljdc48hsvBW8Xi4qv0UHzYjhRfp2ebq2KMQ1vv7N3xBeLlYFG8yj6+
HoWvolnGTfGIBg/DkPnJ0Z7VPGAKzinD0Oqq5rmecTR3saKe6M4eF0u2n0wX
Z6ajHcPk7jPbgeUJ0S/D4vZUu1P1FV0yvzDNKx7PcFR8UuGneKJaxdPloPaF
YkuwKHwIQ5VHda9oxl9olmnizMnyHM2c78P1AMpd+p1UvM40r35HiFOvV5g+
bm8Xc4/XK75SXJd4c35Eb3R3PMB6ONjn/1SM4FT5Fe9Vdqb+y/IdLRguqTHA
cP9m+qnZv/obuYpDG+890VM7YzkBvEdFHg==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 526->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIIXiPkBvEA4hXMCSYQV4KgC8kuR1cTDdJW1auaCSQDPU33
+1XVe/30tl2tH1pr+9nptxoOy91u+Hh9PB/eh838ZXM2Pl9Wa5+L9rP/h6W+
3n4Xt7gsEFfVUrlRHNqRvYH7MTkZPoYdnVE9F4vkKHRzY1VPerwon+KjOKcY
kK+T08Hi+LE4px7D5eBNsbj4khyKD+uR4uvk7H2VjXHo452+O3OBeDlYFK94
jo1+J5pV3BSPRuo6XFxsDMNdnk6bhPc1/spJYbTymvORYkU50Zl9LpaqP5Uu
Tk2n5wyT00+mj1uX1XRzI20qHuhT8Yku1bwwzR29orcheEx5H4wnilU8XQ6q
X8g2BovChzCkPNK+ohq/oVmliVOn8nM0c96HOwPId+w7SWadaZ6+I8Rp6qww
fdzcLuYps57MleI6ZjaRH6qXzgDL4WD/ulM2glP5J7OX9EzdVf6OFgyX0hhh
uN2Zfqr2rd3xVRx6+1+ubyxHANZEXw==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 527->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA0EQRAc/xGuIN9ADBK8QT7CCfgWE+CH+eXQNaoibqurXGxEHdpfZ
7qmuqu65vH9aP56NMZ4vPl7r6eV2u51e7853m4dpc3O92QWvvp4x3lZj//0P
T1rzuDqnMEithK3Oqa+KD/F/Cabj57irvapHuUSNwTd6NvVkzlfhJT1Jc5eD
yiWYhAvJc+dIPceL8O1yofw6GEmP61HSSzDnuSnmNMzPk76TuVC6CJekqz3H
oN8dzyptFjPUJVooN8fhCMfk0pmm8Qp3rI65VJ5TrgpT7d2iXCpvKl9ITdJz
x6nTzy6HOUbCq7hQzNS7dL7jSzUvznPiF70bnTnp6Es61dmkk2pI/VKxJVwS
P8Whq6PbV1XjNzyrPCF1qjziGbkfdAZU7tJ70pl153n3HilNp86K84diU86n
zHpnrpLWJbO5XwZb7ckMOAzCvYo5nim/M3tdLu5flU+8+LGgx4rD4df5F2sf
xL+5KD4VDunHXz6fXN4BRj9E3w==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 528->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0Fqw0AQW3Io+UbpD9oHhHwhfYELzSlQSA8ltz49TQnGXSSNtK7BcczO
aCSN/Pj2cThuWmuf25+fw/S1P5+ny+vD7eV9Or08n26HT/e7te9dm58jdxvs
o3ji6s9RH8JwZils1Iee6Hx5VnFRmIwf447e0TyXS6WR+eb2qp30fBGe0qM0
pxxQrYPpcHHqWJ8zj/Fy+KZcXH4JhtLDdqT0Oph9rTpjGvp+Z+9OLpAuh4vS
FefY2HfiWaUt0cE4VHlyvGc980Vq3Uy75y5nJx8pV4SJ3tnlcqm8qXxxZjre
MU7JPlMOPYbCq7i4mGp3qj/xpcoL8zzJeMUjyUmiT+lEvUqnq0HtC52NcFH8
EIdUR7pXNOM/PKs8ceZUdY5nzvfhZgDVjn4nSdaZ5+l3hDStzQrzx8V2Oa/J
epIrpXUkm6gOzUszwDAc7tUZ46nqk+ylXOb/IRfHiz+X6zHgsHwy/+TsJf6d
C+JT4Tj7SO+2pveXyxXL7USg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 529->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FKQ1EQG7oQr1G8gR5AvEI9wRfsqiDUhbjr0WtLkfpIMsmrH34fvzOT
STLz1m8fm+2qqj7vf342y9fLfr98v96dPt6X3dPj7hR8uLxVh+f6PWfemqyj
eOIZ46gOYTi9FDaqQyeKX8c6LgqT8WPc0Tfq53LpNDLf3Fo1k5EvwlN6lOaU
A8p1MB0uTh6rc/oxXg7flIvLL8FQetiMlF4Hc8xVMaZhrHfm7uwF0uVwUbri
PTbm3XnG+iovHR2MQ7dPjves5vxcfEG57k678Q63AO9un1yubHaM8/i4XDpv
Ol+cns7MGadknimHEUPhdVxcTDU7VZ/40u0L89zxy70byZ4k+pROVKt0uhrU
vFBshovihzikOtK5oh7/4VnnidOny3M8c+6HuwMod/aeJLvOPE/vEdJ0664w
f1xsl/Mtu57sldI6s5soD/VLd4BhONy7GOOp8pPdS7mw/7p8x4uRVzkeAw7X
J/NP9f6DL+o7HGceM2/N1p25HAElLkOi
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 530->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1FqQkEQW/woXkN6g/YA4hXsCV6hfgkF/RD/PLq1tBbWJJPsq/DUx85k
kkx29f653S1aa8fl19d2Om0Oh+n89nR7+Zj2ry/72+Hzz9PaZd3uvyPPnF6G
xz79OepDGM4shc00M/96PMerCpPxY9zRu7s3xKXSyHxze9VOer4IT+lRmlMO
qNbBHL03zDvHZ3WvUr4pF5dfgqH0sB0pvQ5mX6vOmIa+39m7kwuky+HS1n9P
hVdpdPZdecbmKi8ZHprraHG1Mg4POKTWzbR77nJ28pFyZbtjnPuPy6XypvLF
mel4xzgl+0w59BgKr+LiYqrdqf7ElyovzPMk4xWPJCeJPqUT9Sqdrga1L3Q2
wkXxQxxSHele0Yz/8KzyxJlT1TmeOffDzQCqHb0nSdaZ5+k9QprmZoX542K7
nOdkPcmV0jqSTVSH5qUZYBgO9+qM8VT1SfZSLvf/IRfHC8ZLevz7DrgwrWpG
X6/6KxxnHyNPG+375nIFm2REYQ==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 531->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA1EMRR/9kG6juANdgLiFuoIR9KsgtB/Svy5diyJtuLk5eYoD02Ga
l+Tcm8zm+W37uhpjHNafP9vl/XG/X45PN+eXl2V3f7c7B2+/7zFOD+PnOXOP
yby0nrliXOWpGqSXq63y1FPFL2MVi6uZ8WXs6l31oyyVxsw3mutmEnlVPafH
ae4yqLOkJmEh57I80i/jIrxdFsrXqeH0ZDNyeknNeNbFMg0xn8yd7IXSRVio
J0QjmXflGWXJdER/4xmihWqtvIz/KRay0zROmcl+dFmz2WXM8aIslTeVL6Qn
8S5j6syzyxBruHoVC63pZufyO75U+5J53tnxiqOzJx19TqfKdTqpBjcvFZth
cXyKoaujO1fV4y88qzwhfapzxDPyfdAdUGdnv5POrmeed78jpem3u5L5Q2tT
5tldH829clpndvPqnOnX3YGsBmGvYsqDjIXMU3nRYXG7T/aWzLHl8eUtmDL/
XO+r+ia/qkPm8Z/3F8sHZwREog==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 532->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FKA0EURBsXkmuIN9ADiFeIJxhBVwEhWYg7j64RDeZTVb+qJwOdYdLd
1a/q/755ftu+Xo0xDpvvn+3y/rjfLx9P18ePl2V3f7c7Tt7+jjE+H8bpPTPW
7GV67KnzaB/ScM5S2swzy6/qOVl1moyPsaNvt26IpfPIcnP3qppUXqSn/CjP
KQNa62jO3huWnZOzulcpb8ri8iUayg+rkfLraNa1ao55qPudujt9gXw5LG4m
jken3l1mLgvzUfOtaxwvrtcuy/ofYnF62p13mZ3+SFlZ7RhzfVyWLpsuF+dM
JzvGlNQzZagaSq9jcTVV7dT+JJeuX1jmSY93HEmfJP6UT7RX+XQ9qHqhuRkW
xYcYUh9pXdEZl8isy8Q5p1vnZObcD7cH0NrZe5L0Oss8vUfI09peYfm42i7z
ml5P+kp5nenNs3XivLQHmIbD3s2hDBiLU0+URcJyyi5kcbJgXDJjwPD/zfJT
Z5/p/z3Fc8daWS45xuy+H5YvDGNEIg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 533->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FKA0EQRRsX4jWCN9ADBK8QTzCCrgKBuBB3ObpGZJhpf/161WPDZJh0
V9X7v6p3L6fD201r7f3u++cwfTydz9Pn8+3143U6Pj4cr5v3v09rl32b3yNP
G4wL85nV76s4lYPUcrlVnHqr/eVexuJyRnwRu/pW9ShLpjHyjca6nvS8Kp/T
4zRXGdRZkpOwkHNRHKkXcRHeKgvlq+RweqIeOb0kZ3/W7UUa/sSDvpO5ULoI
C/WEaCT9zjyjLJGO+b+gLtFCtWZezmvB42auwuDq2bxwPqqsUe8i5n5Rlsyb
zBdSk/Q8Yqr0s8rQ53D5Mhaa0/XOxVd8yeYl8pz4VbobRseW+xHpVLFOJ9Xg
+qX2Rlgcn2Ko6qj2VdX4D88yT0id7BzxjNwPOgPq7Og9qcx65Hn1HilNW2cl
8ofmpsxbZr0yV07ryGyuzpl61RmIchD2bG+1EhbST+VFhWX2buEhYSFeRFzO
Y+XH8q1yuhr9+dUCHqr46n0hTxuJ+WH5An6lQeE=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 534->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0FKA0EQHHIQvxH8gT4g+IX4ghX0FAjEg3jz6RqRZRiqqqtmE9hMNt1d
XVXds389H993rbWP+9+v4/L5fLksXy9315e35fT0eLoGH/6f1r4PbT1nnjZZ
R/HEZ4yjOoTh9FLYqA6dKN7HKi4Kk/Fj3NE76udyqTQy39xaNZORL8JTepTm
lAPKdTAdLk4eq3P6MV4O35SLyy/BUHrYjJReB3PMVTGmYT27x5m9o9/1jPlT
4VUanXlXnrlcmI4+F/V1tLhaKy/Ru9q5hIPTD9aZ+5FyZbNjnMePy6XypvLF
6enMnHFK5plyGDEUXsXFxVSzU/WJL9W+MM8dv6K7IXRsuR9MJ6pVOl0Nal4o
NsNF8UMcUh3pXFGPW3hWeeL0qfIcz5z74e4Ayp29J8muM8/Te4Q0bd0V5o+L
7XLesuvJXimtM7uJ8lC/dAcYhsO9ijGeKj/ZvZTL+jvk4njBeCmPEYf+ZP6p
3n3c/Y9pGOO3etpMzR+XH+diRCI=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 535->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk1FKBEEMRBs/xGuIN9ADiFdYTzCCfi0I64f459F1VYY1pCovPYINPcNM
0pWqSvry4Xn3dDbGeLn4fOyW17vDYXm7Pz9+PC77m+v9MXj1s8d4vx3re2Zv
Oavw1Irx7FyGQWo5bKVZ+RfxiFcVpuKnuGfftG8Zl0qj8o2edT2JfDM8p8dp
7nLIcgnm7L1R3hGf3b3q8u1yofw6GE6P6pHTSzBjrospDfE86TuZi0wX4UI9
IRpJvyvPKBelI/obc4gWqrXycl0il840jVe4I+FdzRPlqnqnOMdFuVTeVL6Q
mqTnilOnn10OEcPhVVwopuudO9/xpZoX5Tnxi96Nzpx09Dmd2Vmnk2pw/cpi
M1wcv4xDV0e3r1mNv/Cs8oTUqfKIZ+R+0BnIcmfvSWfWlefde5Rp2joryh+K
TTlvmfXOXDmtM7P5a5l63RlQGIT71z8XC5wdF9LPuDo9W+uebsiFeKF4OY8z
P07fGaarEfPpP6Uhxv9zf3P5ADctQiQ=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 536->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0FKg0EMhQcX0muIN9ADlF6hnuAX7KogtIvizqNrVSqEvJcvU8GBaWmT
yXzvJXP3/Lrd3YwxjqvPj+1y2hwOy9vT7fnHy7J/fNifg/c/e4z39bh8z+xr
zqp6asV4di6rQe5ytZVm5V+sR7yqaio+xZ79pn3LWCqNyjd61vUk8mb1nB6n
ucuQ5ZKas+9GeUd8du+qy9tloXydGk6P6pHTS2rGXBdTGuJ50ncyF5kuwkI9
IRpJvyvPKIvSEf2NOUQL1Vp5eVkil840jVNmMh9dVtU7xRwXZam8qXwhdxLv
FFOnn12GWMPVq1hoTdc7d77jSzUvyvPOjFccnTnp6HM6s7NOJ9Xg+pXFZlgc
X8bQ1dHta3bHX3hWeULuqfKIZ+R90BnIcmffSWfWU8+bM6E0XTsrX2v9u7tz
SJnbsw77EOs7rTOzGf1R93VnQNUg7FUs80CxkH7G1WVRDCS/8kJxOY8di9Lq
7oj59D+lIcb/c3+zfAD3aEVf
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 537->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFlVtKg0EMhYc+iNso7kAXUNxCXcEv6FNBqA/iW5de66XQkHPyZRQc+Hub
TPKdkwxdP75sn1djjNfrj5ft8na/3y/vD1enL0/L7u52d9q8+X7GOGzG+X3m
+c1ZlU+tuJ+dy3KQWi630qz8i/mIV1VOxafYs++0bxlLpVH5Rs+6nkTeLJ/T
4zR3GbJYknP23ijviM/uXnV5uyyUr5PD6VE9cnpJzhjr9pSGeJ70ncxFpouw
UE+IRtLvyjPKonR8LlOXaKFaKy9/WIaIpTNN96u8I+Gu5omyqt4p5rgoS+VN
5QupSXqumDr97DLEHC5fxUJzut658x1fqnlRnhO/6N3ozElHn9OZnXU6qQbX
r2xvhsXxZQxdHd2+ZjX+wrPKE1KniiOekftBZyCLnb0nnVmnWkht59PMrJzX
Zlz8Z9PclLk967APMb/TOjObaqn+ZZ9dbcrS6YXidPGd2euyKAYSX3mhtDqP
HYvSqliyePqb4o37//l8sRwBJ1BC4w==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 538->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU0sOAUEU7FiIa4gbcABxBU4wElYSCQuxc3SEYDqv6lU1iU7azOju9+rX
4/V+uR2UUo6j28+yOy0Oh+68Gt4/Nt1uNt3dFyfPWcplXl7PlvnNWVQPjXo9
OhfVUHqx2ogz0q+up2iV1UT4EPboW/UtwpJxRLqpZ5knNd6oHuPDOLsYor1K
zdZ7g7RTdGb3ysXrYlHxOTUYH+QR46vUrPeyNcShd/45Fe8V/qpmSJ+sXsZR
8TvTTMWCePT0DfoqXFSumZbRN8ucg0Hp5/qU6eZkm3kZDRVLpk2mi9JT0Q5h
cvx0MdQ1WL0Mi1qTecfOO7pkeUGaOxnPcDg5cfgxntFZxlPlwPyK1lqwMHwR
BpeH62vU4xeaZZoofbJ9imbK/XAyoNRU7omT9W/7qpxasvIa8/fTyaGKuTXz
bq4Y15ZsooH8i95ZbxWL4wXCyfY72YP7hBw6WBQtQq4fM/MpeiL9WO/PdfU/
xKFe/+d8YLkCkItF3w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 539->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk1FqAkEQRId8hFwj5AZ6APEK5gQrxC8hYD6Cfzl6YhSzDl3VrwchA+Ps
2tPVVdW9z9v3ze6htfbx9POzmT7Xh8N0fH08vbxN++Vifwq+XHZrX6t2PUd2
G8yTeGb18SgvwiC1HHaUF51RfB7LuDhMxU9xj96jepRLplH5RnNdT3q+EZ7T
4zRXOUR3CSbhQu6pPFJP8SJ8q1wovwqG06N65PQSzP6uiykNN/mXTXpP9FPP
lD8ZXqaR9DvzjHJROn6XqUu0UK2ZlxEfN3MVDq6exCzMR5Wr6p3i3C/KJfMm
84XUJD1XnCr9rHLoMRxexoViut65/Iov2bwoz4lf9NuozElFn9MZ5TqdVIPr
VxQb4eL4RRyqOqp9jWrcw7PME1Inu0c8I98HnYEGMcl3Upl1qoXUdj6NzMp1
rf7OyhxSzqMzX50rp3VkNtVS/YueXW3KpdILxdPdr8yevEfmsMCFeBFqne2s
T9Gp/HO153H6n9LQx/9zn7l8Awn6Q54=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 540->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FKA0EQRAc/xGuIN9ADiFeIJ1jBfAWE+CH+eXSNSIhjVfXrNQObzTLT
3a+qe66fXjbbizHG69XXz2Z5e9jvl/fHy8PH87K7u90dNm9+njE+7sfxveYZ
K+NsvrDmfRWncpBaKbeKU2+1f7pXsaScjs+xq29Vj7JUGp1vNDb1ZOZV+ZKe
pLnLoM6SnISFnHNxpJ7jIrxdFsrXyZH0uB4lvSTnfDbtOQ1zPOk7mQuli7BQ
T4hG0u/KM8ridHyvUJdooVorL9V3mrkOA6n3J6YxH11W1zvHPC/KUnlT+UJq
kp47pk4/uwxzjpSvYqE5U+9SfMeXal6c58Qvejc6c9LRl3Sq2KSTakj9Untr
WBKfYujq6PZV1TiHZ5UnpE51jnhG7kdnBkhOck86s/7fulTTmlk5LjPrVW7K
vHbmu3OVtK6ZTbdc/9T/VJuySB9Onsp3x0L66bQrns4cVizEC8flPHF+zP6r
86n2rOvXKjxU8ee8L7TPPuYTl2hEIA==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 541->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tKQ0EUG/ohbkPcgS6gdAt1BVfQr4JQP6R/Lr0WH9hDkpNMO3B7e5k5
OUlO5u75bfu6GmO83379bJePzX6/HJ5uTh8vy+7xYXfavP95xvhcj7/3zDMm
6yieWHUf1SEMp5fCRnXojfb/73VcFCbjx7ijb9TP5dJpZL65tWomlS/CU3qU
5pQDOutgOlycc6zO6cd4OXxTLi6/BEPpYTNSeh3MelbtMQ213pm7kwuky+Hi
euJodObdeeZyYTqqv/WMo8XV2nmJvlXmEg5Ov3ROnW9JttUs0XK5dN50vjg9
He8Yp2SeKYeKofA6Li6mmp2qT3zp8sI8TzLe8UhykuhTOlGt0ulqUPNCezNc
FD/EIdWRzhX2uIJnnSfoP8zLmvNxPHPuR5IBB9O5J0nWL+3raprKyu8iWe+w
Xc6zme/mUPGVVhdD3QnWL80Aw3C4d3uMpzqfZI+eC3PYcXG8YLwql86P6j86
r3pXXWer8RDVX/O+XPJ8czkCwZZF3w==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 542->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU1tKA0EQHPwIXkO8QXIA8QrxBBtIvgJC/BD/PLrGhLCMXa/ZDMwuQ/dU
V1X3PO3et4eH1trH4+9nO32+nk7T19vqfNhPx836eA4+X3dr3y/t9h/ZS+4i
PLT6eHWvwnBqMWykGfnX4zleKUzED3Gvzm7fKi5KI/LNvct60vOt8Jgepjnl
UOU6mKPvBnnn+MzeVco35eLySzCYHtQjptfB7HNZDGm4/Wfb6b2j3/UM+aPw
lEan38ozlwvSMc+t6jpaXK3Ky+rMZi7h4NRL+6R8c2db9bJaLhfljfLFqel4
hzgl/Uw59BgMT3FxMVnv2P3EFzUvyPNkxhWPZE4SfUxndZfpdDWwflWxES6M
X8Uh1ZH2tapxD8+UJ06dv0W0O5457yOZAQfTeSfJrC+t62oamZUEE2lwOI/O
vOpDj8+0uhjsTaB66QwgDIe7iiGeLD+ZPZjnzGHAxfEC8eq5KD96/6t8Vnse
/7eEh9X9e76XJfvC5Qc6p0Xf
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 543->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FKQ1EMRC9+SLch7kAXULqFuoIn2K+CUD+Kfy5dqyIlJpMzt73w3uOR
ZDIzyb17ft3ubsYYb6uv13Y5bg6H5f3p9vTzsuwfH/an4P3vM8bHevx9Z54x
WVfiiRPjWV2GQXop7Kwu+2bx81jHRWFW/Cru2X/Wj3LpNFa+0Vo1k8g3w1N6
lGaXQ5ZLMAkXklfVkX4VL8LX5UL5ORhKTzUjpZdgxlwVqzTEejJ3sheZLsKF
ekI0knl3nlEulY7ob8whWqjWzsvsX+2cw4H0c+fU+ebstppldiiXzpvOF9KT
eFdxcubpcogYCq/jQjHV7FS940u3L5Xnzo53PJw9cfQpnVmt0kk1qHllsRku
il/GwdXhzjXrcQ3POk9In+8jtBPPyP1wdoBgknvi7PqlfammmV1xMCsNhPPs
zndziPhKK8VQd6Lq5+5AhUG4d7GKp8p3dq/MI3tocCFeVLwil86P6H+Wr3qf
x/+dxsOs/pr35ZLnh8snNFhG3w==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 544->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk01KA1EQhB8uxGuIN9ADiFeIJxjBrAJCXIg7j65RkfCs6v5qkgfjGF7/
fFXdc/30stlejDFer77+bJa3h/1+eX+8PPx4XnZ3t7vD5c3vM8bH/fh7r3nG
yjxbrzjzvcpTNUivqrbKU291f3zXsVQ1HZ9jV79VP8rSaXS+0dxqJjOvqlfp
qTSnDCqW1CQsJM7lkX6Oi/CmLJQvqVHpcTOq9JKac2x15zTM+WTuZC+ULsJC
PSEaybw7zyiL0/F9ir5EC9XaeXnMomLpTtN7ykz2I2V1s3PM86EsnTedL6Qn
8c4xJfNMGeYaVb2OhdasZlflJ750++I8T3a840j2JNFX6VS5lU6qoZqXulvD
UvEphlRHOlfV4xyedZ6QPl0c8Yx8H8kOkJrkO0l2/dS+VNOaXUlqOg2Eee3O
p3tVaV2zm+64+an/q96UJZmF5Gzik92zcWQPAxbiheOaWZTn7i39Mywq/t9p
PFT55/xeTnl+WD4BeqZG3Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 545->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FqAjEYhIMPpdcQb1APUHoFPcEW9Eko2IfSN4+uYhFJZ+afyboQ1yXJ
5Jv5/yw/vzb7RWvt+/Xys5l+Po7H6Xf7cv3YTYf12+E6ufobrZ3e2/09Mubs
ZXrs6efRPqThnKW0mWeWX6/nZFVpMj7Gjr7duiGWyiPLzd2ratLzIj3lR3lO
GdBaR3P03rDsnJzVvUp5UxaXL9FQfliNlF9Hs1+r5piH+/thOLV3/LuZoXya
oVd5dOpdZcbOlVkSPXSu48X1yhgYO2Jxetqdd5md/khZWe0Yc/+4LFU2VS7O
mU52jCmpZ8rQayi9isXVVLVT+5Ncqn5hmSc9XnEkfZL4Uz7RXuXT9aDqheZG
WBQfYkh9pHVFZzwjsyoT55xqnZOZcz+SHnA0nXuS9Prcc11PI72SaDIPDvNo
z6d9pbyO9CZ7WP3Qf3W2y5LUAnIW65Peo+vCPqxYnCwYV8+CMmdvmB9hQev/
PUWGaP8z78uccWM5A10sRSA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 546->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0tKg0EQhBsX4jWCN9ADBK8QT/ALugoE4kLc5egalGDGruqvJxmYPJjp
6nr0rF52m7ebiHi/+/7YLB9P+/3y+Xx7/PO6bB8ftsfD+98dcVjH6XtmX1Kr
8NQaz7O6DIP0cthKs/JvxCNeVZiKn+Ke/ae5ZVwqjco3WusyGflmeE6P09zl
kN0lmLPvRnlHfHbvqsu3y4Xy62A4PSojp5dgjnfdmdJwVg8yp3OR6SJcqCdE
I8m78oxyUTrO/E36Ei1Ua+XlaYm7dKbpeYUbCe9qnihXlZ3iPC7KpfKm8oX0
JJkrTp08uxxGDIdXcaGYLjtX3/GlmhflOfGLvo3OnHT0OZ1ZrdNJNbi8srMZ
Lo5fxqGro5tr1uManlWekD7VPeIZeR90BgJiknfSmXWqhfR2Ps3MSgdTaSCc
Z2e+O1dO68xsqqXyy3673pRL6sOfXfkeBkvhKy/kPTKHDS7EC8LL5TRyUVoV
l+z+v1V4mNVf871csn+4fAF1lkWc
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 547->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk01KQ0EQhIcsxGsEb6AHCF4hnuAJugoIcSHucvSYGASbruqvJxmYhMdM
V9dPz/r1Y/u+GmN83v/8bJev5/1++X65O328Lbunx93p8OGyxzhsxt//zL6m
VuGpFc+zugyD9HLYSrPyL+IRrypMxU9xz75pbhmXSqPyjda6TCLfDM/pcZq7
HLK7BHP23SjviM/uXXX5drlQfh0Mp0dl5PQSzHjXnSkNsZ7kTuYi00W4UE+I
RpJ35RnlonScl+lLtFCtlZcZHzdzHQ6un8RszEeXq8pOcY6Lcqm8qXwhPUnm
ilMnzy6HiOHwKi4U02Xn6ju+VPOiPCd+0bfRmZOOPqczq3U6qQaXV3Y2w8Xx
yzh0dXRzzXrcwrPKE9LnvDaXDTEzrKqOzsCAmOSddGadaiG9nU8zs9LBVBoI
59mZr3KI+E4rxXBvQvXrzoDCINyrM8XT3e/MXjcrxaviQrygvCo/ov/Zfdc7
6vq3Cg+z+lu+l2v2L5cjhNlE4Q==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 548->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytU0kKAjEQDB7Eb4g/0AeIX9AXjKAnQdCDePPpKorMhK7qqoyBuJB0dS2d
+f68PU5KKdfZ62Pb3TaXS3ffTd9/Dt1ptTy9DxffXcpjXX7fLXtMLcJDqz6P
6iIMpRfDRpqRfzWe4lWGifgh7tF/NbeIS6YR+abWskxqvhEe08M0uxyiuwpm
67tB3ik+s3fl8nW5qPwcDKYHZcT0Kpj1XXaGNAzqv1vJXtGvehb5UwS8TKOS
d+YZ6su87Gvoa4n6KlpUrchLxD3iosy0eq5yVubD5YqyQ5zrpXLJvMl8UXoq
3iFOTp4uhxqD4WVcVEyWHat3fMnmBXnuzHjGw5kTRx/TGdUynaoGlld01sKF
8Ys4uDrcXKMe//As80Tpk91TPFPehzMDCqbyTpxZH9tX1dQyKw4m0qBwbp15
d66Y1pbZRAvlF/1mvVUuThaIJ7vvzJ6bFeKVcVG8UHllftT+R/dZ71rXYCUe
RvX/fC9j9ofLEx5TRiA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 549->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FKA0EQRAc/xGuIN9ADiFeIJ1jBfAWE+CH+eXQNBtG1qvr1JAOTzTLT
3a+qe6+fXjbbizHG69XXz2Z5e9jvl/fHy8PL87K7u90dDm+Oe4yP+/HznNlj
Ms7mC2t9ruJUDlIr5VZx6qnOf59VLCmn43Ps6l3VoyyVRucbjU09WfOqfElP
0txlUHdJTsJC7rk4Us9xEd4uC+Xr5Eh6XI+SXpJzfTedOQ1/4kHP6VwoXYSF
ekI0kn5XnlEWp0PVSgzVPBHvXYx6TzPXYSD1un1K/aIekF6qRVkqbypfSE3i
nWPq9LPLsM6R8lUsNGfqXYrv+FLNi/O8M+MVR2dOOvqSThWbdFINqV/qbIYl
8SmGro5uX1WNc3hWeULqVPeIZ+T76MwAyUm+k86sn1qXapqZlU5Op4Ewz858
d66S1pnZdMv1T/1PtSmL9eK4K99HyJXyKy8SC5pDyEK8IFypT2sWp9WxqPv/
VuGhij/n93LK/mb5BNEZRt0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 550->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytl0FOAlEQRDssDNcg3kAPQLgCnmBMdEVCggvDjqMrOpLQdFVXffnJOBn/
dP1X1T0LVq/77fsiIj6W33+20+fmcJiOLw/nh7dp9/y0O28+zlfEaR2X+8gV
g3VQj6y8f1M381R13VlMu6qr7jcsSatjYZqID7FXz9V5Kguqzwsxd7WsJ5m3
0mN+mGeXoXpX0VRYlPdQnXIe4lJ4XRaVz9FgflCPmF9FM7/L9pCHy/2vXui7
MheVL4VFzUTxqPS7y0xlQT6i+D9j6OZJyR7VVM9s5hwG5Ty3T6xfagZKL6ul
snTZdLkoZyrZISanny5D1mB6HYuqyXrH6p1cunlBmTsz3nE4c+L4Yz6rWuZT
9cD6Ve2NsDC+isH14fa1OuMemXWZKOf8rHWUvwPcuVP6w/ycZg5FU/lOnFlX
vShns5xGZsXRRB4U5tGZ7/qQ9ZlXVYN9E+g8dwaQhsJ+tZfmGmWAWJR+Iu/u
rGSNjkXJQuWCeRT5oPzY2dnX1WoyrOrv+b385/pl+QIhcERd
                    "], {{0, 
                    35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 551->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FKA1EQRD8uxGuIN9ADiFeIJxhBVwEhLsSdR9doEPOtqn49ZmAShj9d
/aq65/LhefN0NsZ4ufj82Syvd7vd8nZ/vn94XLY319v94dXhHuP9dvz8r7nH
yjqrF675/E/dgUfVVb2StqpT/+r891nFkjQdn2NXz6ofZak8utxobZrJzKv0
kp/kucug3iWahIW85+pIP8dFeLsslK+jkfy4GSW/RHN+N505D3M9mTvZC+WL
sNBMiEcy7yozyuJ8qF6Jodonkr2rUc9p5zoMpF93TmleNAMyS3VRliqbKhfS
k2TnmDrz7DLMGkmvYqGaaXapvpNLtS8u886OVxydPen4Sz5VbfJJPaR5qbM1
LIlPMXR9dOeqepwisyoT0ufrCt5JZuT7oDswoCb5Tjq7Tr2Q3imnNbvS0XQe
CPPana/mMOsnr1QjfROuX3cHnAZhPzqDuTsWMk/nvbsrs0bFQrKgXDYPkY/L
L/WefR1dRYaq/pTfy3/ub5YPwOZGng==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 552->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA1EMRYMf4jbEHegCiluoKxhBvwpC/RD/XLoWi2iae3MyiPjgdTq8
l+Tcm8zl/dP28Swini8+frbLy+1+v7zenR9eHpbdzfXucHh13BFvm/h6/oft
Vj4/iRM5SC2Xu4qrntX597OOxeVUfIq9eq/qUZZOo/KNxrqeZN4qn9PjNE8Z
qrskJ2Eh91Qcqae4CO+UhfJNcjg9qkdOL8mZ77ozpSHHk76Tuah0ERbqCdFI
+t15RllKHZvjDl2XaKFaOy8j6alYyEzTc8pM5mPKqnqnmPOiLJ03nS+kJvFO
MU36OWXIOVy+joXmdL1z8RNfunlRnk9mvOOYzMlEn9NZxTqdVIPrV3W2hsXx
VQxTHdO+VjV+w7POE1Knu0c8I98HnYGAOcl3Mpl1qoXUdj6tmZVJTqWBMK+d
+elcOa1rZlMt1b/qv6tNWUof0kw7DxQL6afSXvFM5rBjIV4QLtenyO9Cq2Kp
7p+sxsMf90A//nJ/srwDqKtG2w==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 553->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlUFqAkEQRRsXIdeQ3CAeQLyCnmCEuBICZhHceXQ1Sojtr1+vJi5sGIeh
u6re/1WN0/XncjNprX29nn6Ww/ditxv2q5fzx8ewnb1vz5tv16e1w7z9vp/h
cavfV3EqB6nlcqs49Vb7f/cyFpcz4ovY1beqR1kyjZFvNNb1pOdV+Zwep7nK
oM6SnISFnIviSL2Ii/BWWShfJYfTE/XI6SU5+7NuL9JwEw96TudC6SIs1BOi
kfQ784yySB1BLceQzRPxPopR327mKgykXrVPrl/UA9JLtShL5k3mC6lJvIuY
Kv2sMvQ5XL6MheZ0vXPxFV+yeYk8r8x4xlGZk4o+p1PFOp1Ug+uX2hvD4vgU
Q1VHta+qxiM8yzwhdX7WvN39P42ZO9Ifp+dw5SA5yT2pzDrVQmo7n8bMSiVn
pIEwj535rA99fqeV5nB3IqpXnYEoB2HP9iJOd74ye9VeRVwZC/GCcmV+9P6r
8652r+tmJR6q+Efel/88F5Yjg3JG3w==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 554->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG+gBxCvEE0TQVUCIC3Hn0TUqIY5V1a9/snBg8pn0
dHVVdc/lw/Pq6WyM8XLx+bNav95tt+u3+/Pd4XG9ubne7IJXP3uM99ux//6H
ndYcV3kKg9RK2CpPfVX8MFZxSZiOn+Ouzqoe5VJpdL7R3NSTma/CS3qS5i4H
dZdgEi7knssj9RwvwrfLhfLrYCQ9rkdJL8Gc76aY0zDnk76TuVC6CBfqCdFI
+l15RrlIHaZW4lDNE/He5ahzmrkOB1Kv26fUL+oB6aValEvlTeULqUm8c5w6
/exymDESXsWFYqbepfyOL9W8OM87M17x6MxJR1/SqXKTTqoh9UvFlnBJ/BSH
ro5uX1WNU3hWeULqfK2gnXhG3kdnBggmeSedWT+2LtW0ZFY6mE4D4bx05qs+
zPhJK8VIb8LV686AwyDc9/+bmOPpsBy+86Lbq184DS7EC8rL+iH8cf6l2ofx
P6vwUOWf8r0cs7+5fAAhp0ee
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 555->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytlVFKA0EQRBs/xGuIN9ADBK8QT7CCfgWE+CH+5egaDcFMuqpfj1nYhM3M
VL+q7iW3z2/r16uIeL/5/lgvH4/b7fL5dL1/eFk2D/eb/eLd4Y7YreL4PXPH
5DmpZ65xfeQIoUFqOe3sXPadrf9dq1icpuJT7NlzVo+yVB5VbvSs68nIm+k5
P85zlyHbSzQJC9mnzpF6iovwdlkoX0fD+VE9cn6J5rjXrSkPZ+dB38lcZL4I
C82EeCT9rjKjLKkPUcsxVPNEsldnsmc3cx0GUq/bJ9cvmgHpZXZRliqbKhdS
k2SnmDr97DKMGk6vYqGarnfufCeXal5U5p0Zrzg6c9Lx53xmZ51P6sH1K1ub
YXF8GUPXR7evWY1LZFZlQur8XKs4+3+amTvSH+dnd+AgmuQ96cw69UJqu5xm
ZqWjqTwQ5tmZr/ow6juvVMO9E6pedwaUBmE//i7WFKfSUvoqi26vFFfFQrKg
XFUeY/7Zfld79HVyFRlm5y/5vvzn/mX5Aq4BRZ4=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 556->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FqwzAQREU+Sq8ReoP2ACFXcE/gQvsVKLgfIX85euK2uGS7MzsjR6AE
I2n0Zna1ffscPjatta/H688wHvfTNJ5eH+aP9/Hw8nyYF59+Z2vnXVv+e+aa
s0gPjbiencs0lLuYNvKM8ot6SlaVJuJD7Nm3WreMpfKIclPPsppE3kyP+WGe
XYZsr6LZ+25QdkrO7F25vC6LyudoMD+oRsyvohn3sjXk4d95oe5KX2S+FBY1
E7jXrHeVmcqS+tj9TXSv0uPVupLlwtLwXrWn1XWVWekPlxXVDjHHobJU2VS5
KHcq2SEmp54uQ9RgehWLqslqx847uVT9gjJ3erzicPrE8cd8ZmeZT9UDq1e2
1sPC+DIG14db1+yOe2RWZaLc8z2IdyUz5X04PaBoKu/E6fW196qeenrF0UQe
FObenq/qEPWZV1WDvQl0n9sDSENhr9YQJ9vv9J5bK8RVsShZqFxVHjH/bD+7
O/q6GUWG2fl7vpc184flAk9zRh4=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 557->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FKA0EURBsX4jXEG+gBxCvEE4ygq4AQF+LOo2s0ZNGpqv/+JAOdYdLd
1a/q/759ed+8XY0xPm5+fzbL59Nut3w9X+8/Xpftw/12P3l3GGN8P47je804
Z6/Tc888r/YpDXJW0naeXX6zHsmq0nR8jl1907oplsqjy43uTTWZeZVe8pM8
dxnUWqK59t647EjO6V51ebsslK+jkfy4GiW/RHNem+ach5P9oO6kL5QvwkIz
IR5JvavMKIvzMcT/iaHqJ5K97DXBrlhIT9N5ykz6o8vqaueY54eyVNlUuZAz
SXaOqVPPLsOskfQqFqqZapf2d3Kp+sVl3unxiqPTJx1/yafam3xSD6leam4N
S+JTDF0f3bqqMy6RWZUJOefvCd5JZuR+dHqAaJJ70un1c8+lntb0SkfTeSDM
a3u+qsOsn7xSjXQn3HndHnAahP34/2GQ3EfQcvouC7uO9iFkIVkQrlQn9Zb5
GRa1/uQpMlT7L3lfzhn/LD80fkWe
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 558->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FKQ0EQRJssxGsEb6AHCF4hnuALugoIyUKyy9E1KCKTquqqifhh8vOZ
mZpX1T3r57ft66qqDrefP9vl/XG/X45PN+ePl2X3cL87T959j6rTpn7eM+Oa
vUyPPeM82oc0nLOUNvPM8hv1nKw6TcbH2NG3WzfE0nlkubl7VU1GXqSn/CjP
KQNa62jO3huWnZOzulcpb8ri8iUayg+rkfLraI5r1RzzcLHfqLvTF8iXw+Jm
4nh06t1l5rIwH7UZ3qUZun5ysoe9BtgRi9PT7rzL7PRHyspqx5jHx2Xpsuly
cc50smNMST1ThlFD6XUsrqaqndqf5NL1C8s86fGOI+mTxJ/yifYqn64HVS80
N8Oi+BBD6iOtKzrjLzLrMnHO6dY5mTn3I+kBR9O5J0mvX3uu62mmVxJN5sFh
nu35tK+U15neZA+rH/qvznZZYA6/Rpd7CS2mz7Kg68I+7FicLBwuVSf0hvkR
FrTeeZSHzst/ji+WD9JfQ+E=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 559->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FKBDEURIML8RriDfQA4hXGE7SgqwFhXIg7j66D4iL+qv8qIzb09HQn
qbyq/3P58Lx7OhtjvFx8/uy217vDYXu7Pz++PG77m+v9cfDq+x7j/Xb8PFfu
U9YqPXXN49W6SoPs5bSVZ5XfrEey6jQVn2Kv3mndKpbOo8qNrnU1mXkrPefH
eU4ZqrlEc/XcqOxIzu5cpbwpC+VLNJwfVSPnl2jOc92Y8vBrPag76YvKF2Gh
mRCPpN5dZpTF+Zi/O4aun0j2JUPBXrGQnqbjlJn0R8qqaqeY54uydNl0uZA9
SXaKKalnyjBrOL2OhWq62rn1SS5dv6jMkx7vOJI+Sfw5n9Va55N6cPWqxlZY
HF/FkPpI61rt8ReZdZmQfbp5JDNyPpIeIJrknCS9fuq+1NNKrySaygNhXu35
tK+c15XeVJeqX/Xf7U1ZbBZB7vSby0LOC/uwYyFZEC5Xp+pZaSqWaj65nIfO
y3/eXywf6lZFog==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 560->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9lUFKA1EQRJssxGsEb6AHCF4hnmAEXQWEuJDscvQYDRK+1dWvP+LAZJj5
86tfVfeQ9fPb9nUVEe+3nz/b5eNxv18OTzfnm5dl93C/Oy/eXc6I4yZ+rjNn
TO5L9cwxrqt9SoPUctpqn7qq9eu1isVpZnwZu7pX9ShL5THLje51PRl5lZ7z
4zx3GdS7RJOwkPeyfaRexkV4uyyUr6Ph/GQ9cn6J5viuW8s8qP2k98Q/zSzL
p9JzvAH7XWVGWTIfIZ47hmqeSPZy1gS7YiEzTdcpM5mPLmvWu4x5PChLlU2V
C6lJssuYOv3sMowaTq9ioZqud25/J5dqXrLMOzNecXTmpOPP+VR7nU/qwfVL
rc2wOD7F0PXR7auq8ReZVZmQOl/HJuR/QnfuSH+cn+OFg2iS76Qz69QLqe1y
mpmVjmbmgTDPznzVh1HfeaUa7pvI6v3q+9W8udqUxWbRyJ0+c1l0e5VxVSwk
C8qlMs+uSjNjUe+Tw3movPzn+c1yArIzRCA=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 561->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRAc/xGuIN9ADiFeIJ4hgvgJC/BD/PLoGNchQVf16FBc2y2am
a15V914+PG12Z2OM54uPn8325e5w2L7enx9fHrf7m+v9cfHq6x7j7Xacniv3
WKyzeuGa11Wd0iBnJW1Vp55q/edaxZI0HZ9jV+/qPMpSeXS50drUk5lX6SU/
yXOXQe0lmoSF7HN15DzHRXi7LJSvo5H8uB4lv0Rz3pvWnAdVT3pP/NPMXD6V
XuIdsN9VZpQl+Zj/TwzVPJHsJYNgVyxkpuk6ZSbz0WV1vXPM80VZqmyqXMiZ
JDvH1Olnl2HWSHoVC9VMvUv1nVyqeXGZd2a84ujMScdf8qlqk0/qIfVLra2w
JD7F0PXR7as64y8yqzIh51T7SGbk++jMANEk30ln1n97LvW0MisdTeeBMK/O
fHeukteV2XSX699J83sN9JywxCwaudP/UhbdXjmuioVkQblU5u6pNB2L2k+u
5KHy8p/3J8s74blEog==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 562->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FKA1EQRBsXkmuIN9ADBK8QTzCCWQWEuBB3Hl2jIsNPdfXrrzgwDvFP
V7+q7rl6eNrtLyLiefPxZ7e83B2Py+v95enH43K4vTmcDq+/74i3bfw8Z+6Y
rEv1zDWeqzqlQXo5bVWnnup8fVaxOM2ML2NXv1U/ylJ5zHKjtW4mI6/Sc36c
5y6DepdoEhbyXlZH+mVchLfLQvk6Gs5PNiPnl2iO77qzzMNZPZg72Qvli7DQ
TCqPYfqu66rMKIvzMf7fMVT7RLKXDIJdsZCdpueUmexHlzWbXcY8XpSlyqbK
hfQk2WVMnXl2GUYNp1exUE03O1ffyaXalyzzzo5XHJ096fhzPlWt80k9uHmp
sxkWx6cYuj66c1U9/iKzKhPS5/My3klm5Pvo7ADRJN9JZ9d/25d6mtmVjmbm
gTDP7nw1h1HfeaUa7pvI+p3NfX2b3pTFZgFyD6Pl9FUW3VllXBULyYJyqcyz
p8wvYVHvk8t5qLz85/3F8g47iUTf
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 563->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FKA1EQRD8uxGuIN9ADBK8QTzCCrgJCXIg7j65BkeGnqvr1IA5MJkn/
7n5V3XP9+LJ/vhhjvF59feyXt/vjcXl/uDz9eFoOd7eHU/Dm5x7jYzd+n1vu
sTHP1gvXHFd5qgbplWqrPPVU8XWsYkk1HZ9jV79VP8pSaXS+0dw0k5lX1Ut6
kuYugzpLahIWcs7lkX6Oi/B2WShfp0bS42aU9JKa89kUcxrO8sHcyV4oXYSF
elJpHKHvOq/yjLIkHfP/iaHaJ+K9ZBDsioXsNI1TZrIfXVY3O8c8X5Sl8qby
hfQk3jmmzjy7DHONVK9ioTXT7FJ+x5dqX5znnR2vODp70tGXdKrcpJNqSPNS
sS0siU8xdHV05yp7/IFnlSfqu9yXnechnpH3g+7AgDXJe9LZdaqF9E4+bdqV
Rk2ngTBv3flqDnP9pJXWSO+E63c299W+pd6UJXoBfHcsZJ5Oe3dX5hoVC/GC
cinP3VP6Z1jUeXIlDZWW/7y/WT4B9xFD3w==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 564->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKQ0EMRYMf4jbEHdQFlG6hruAJ+lUQ6kfxz6VrUeQx3tycjMWB6Ws7
k+Tcm7zbx5f981VEvN58fuyX0+54XN4ers8/npbD/eZwPrz73hHv2/h5zuyY
jEvzmTWeqziVg9RyuVWceqrz9VnF4nJmfBm7+q3qUZZKY+YbjXU9GXlVPqfH
ae4yqLskJ2Eh97I4Ui/jIrxdFsrXyeH0ZD1yeknO8a47yzT8igd9J3OhdBEW
6kmlMUzddVzlGWXJdMR2tUVdpKU4J16O9dVdOtP0nDKT+eiyZr3LmMdFWSpv
Kl9ITeJdxtTpZ5dhzOHyVSw0p+udi+/4Us1L5nlnxiuOzpx09DmdKtbppBpc
v9TZDIvjUwxdHd2+qhqX8KzyhNSp7hHPyPvRmQGSk7wnnVn/a12qaWZWOjkz
DYR5dua7c+W0zsxmtrL+qe+uNmWRPqw29Z3+57xI7zXnsGIhXhAu1yf1VDkz
FnWfLKeh0vKf+4vlAy3SRF8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 565->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9lUFKA0EURD8uxGuIN9ADDF4hnmAEXQWEZBHc5egaDS46VfWrWrFhMkx6
uvpV/d/M7fPb5vWqqvY3nz+b9fC4263vT9enh5d1+3C/PU3ena+q41I/95nr
N2uZHhvjPFqHNJy9lDbzzPIb9ZysOk3Gx9jRs1s3xNJ5ZLm5a1VNRl6kp/wo
zykDetfRnD03LDsnZ3WuUt6UxeVLNJQfViPl19Ec31VzzANa79Te8e9mxvLp
9BxelaWTmcvCfNQy3EszdP3kZA97DbAjFqen3XmX2emPlJXVjjGPw2Xpsuly
cfZ0smNMST1ThlFD6XUsrqaqnVqf5NL1C8s86fGOI+mTxJ/yidYqn64HVS80
N8Oi+BBD6iOtK9rjLzLrMnH2+RpLwW9C2ndOfZSf45nD0XTOSdLrrhdnb5XT
TK8kmsyDwzzb810dRn3l1dVQZ4Ltl/YA03DYL7SC3N3/VBZprRhXx+Jk4XKh
zNkdaTIW9L4zlIfOy39e3ywfDDBEIg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 566->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRAc/xGuIN9ADiFeIJ1jBfAWE+CH+eXQNhiCb6upXozgwWTYz
3f2qu/b66WWzvRhjvF59/WyWt4f9fnl/vDy8PC+7u9vd4fDmuMf4uB+n58we
k3FlPrPW5ypO5SC1XG4Vp57q/OdZx+JyVnwVu3pX9ShLp7HqG411M1nzqnxO
j9OcMqi7JCdhIfeqOFKv4iK8KQvlS3I4PdWMnF6Sc33XnVUazuLB3IkvlC7C
QntCNJJ5dz2jLJWOIf53DJ2fSO+l1wS7YiGepueUmfgjZa1mVzGvF2XpetP1
hdQkvauYknmmDOscLl/HQnO62bn4pC+dX6qeJx7vOBKfJPqcThXrdFINbl7q
bIbF8SmGVEc6V1XjL3rW9YTU6e6RnpHvI/EAyUm+k8Trv61LNc14JclZaSDM
s55PfeW0znizWtX8TjmPm8ycsCSzkJzN/cR7KUvFRe+TOVINZ3MST9m/gkXd
J8tp6LT85/5m+QRGp0Th
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 567->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KA1EQhJssxGsEb6AHCLlCPMEIugoIcRHceXQNBhmeVdVVD/HBy2To
v6+6e7ZPr4eXTVW93X79HJbz/nRa3h9vLi/Py/Hh/ngx3l1v1ceufp4ztybj
aD5xRjuKQzmcWio3ikNPZF/bOhaVk/ExdvSO6rksnUbWNzdWzWTkRfmUHqU5
ZUC+Tk6HxfFjcU49xuXwpiwuX5JD6WEzUnqdnKOvsjENv+KNuTt7gXQ5LG5P
Oo0l6q7jup65LExH7VYX1LW0NHanl2N95OvutGt3mZ39SFnZ7BjzeFyWrjdd
X5yaTu8YUzLPlGHMofJ1LG5ONTsVn/Sl2xfW82THO45kTxJ9SieKVTpdDWpe
yDbDovgQQ6ojnSuq8Rc963ri1On8nJ4534e7A8h39jtJdt3V4tRWfZrZlSQn
0+Awz+58uldK68xussPmh/6r2i5LMgvWA+Wf7B70ud5kDzsWpxcdVzcn9EQ5
GQvyd47S0Gn5z/vN8gknw0Ph
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 568->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9lVFKA0EQRJt8SK4RvIEeYPEK8QQr6FcgED/EP4+uQQkyVlVXDcGBzWaZ
7p5X1b3s7um4f9lU1ev262e/vj2cTuv748354Xk93N8dzpu3P1fVx1KX+8xV
k3m0nljjPspDNZyzVG2Uh+5o//dex6JqMj7Gjp7ReS5Lp5H55uaqnoy8qJ7S
ozSnDCjWqemwOHEszzmPcTm8KYvLl9RQeliPlF6n5hir9pgGlO/03tHvesb8
6eo5vMpLxzOXhemopS7fIXSuo8XV2nmJnt2+zzC6zM58pKysd4x5XC5L503n
i3Om4x1jSvqZMow1VL2Oxa2peqfyE1+6eWGeJzPecSRzkuhTOlGu0ulqUP1C
ezMsig8xpDrSvqIzruFZ54lzThfneOa8H5aepf58I2dmTMUwFuh5OBNoXWNW
kpqsHw7z7Mync6W0zswmW2wm0H91tsuS9IJ5oOKT2aNx4Rx2LI4XDpfqE7qj
mowFxTtLaei0/Of1zfIJ+r5EYQ==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 569->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFlUFqAkEURBsXwWtIbmAOMOQK5gQT0JUQ0IVk59GNJJjQVtWvaoQ0TIah
+1e/qv8lq/ePzW7RWjsuv/5s5tPr4TB/vj1dP7bz/mW9v24+/zytnad2e488
bbCO6onV76M6pOHcpbRRHXqj/b97FYvSZHyMHX2j+1yWyiPLza1VPel5kZ7y
ozynDOiso+mwOOdYnXMf43J4UxaXL9FQfliPlF9Hsz+r9pgHVO/03vHvZsby
qfQcXpWlk5nLAn1Mvw+71/Hieq2yRN9u30cYXWZnPlJW1jvG3C+XpcqmysW5
08mOMSX9TBl6DaVXsbiaqneqPsmlmheWeTLjFUcyJ4k/5RPVKp+uB9UvtDfC
ovgQQ+oj7Su64xGZVZk491TnnMyc34flZ2p3/yNHZkydYSww83Am0HrErCSa
rB8O8+jMp3OlvI7MJltsJm6awaw5LEkvWAbqfDJ78Ezn2ZnDisXJgnEhjl6b
vZEmY0HnnaU89Pv/+XyzXADOFELf
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 570->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRAc/JNcQb6AHEK8QT7CCfgWE5EP88+gaDUHWqurXgzgwuywz
3f2quvfq8WX7fDHGOGw+H9vl9X6/X94eLo8fT8vu9mZ3PLw+7THe78b5PbPH
ZJzNF9b6XMWpHKRWyq3i1Fud/zyrWFJOx+fY1beqR1kqjc43Gpt6suZV+ZKe
pLnLoO6SnISF3HNxpJ7jIrxdFsrXyZH0uB4lvSTn+m46cxpUPOk90U89c/5U
+Qhv8pJ4RlmcDlUrMVTzRLx3Meqb9n2GkTKT+eiyut455vWiLJU3lS+kJvHO
MXX62WVY50j5KhaaM/UuxXd8qebFed6Z8YqjMycdfUmnik06qYbUL3U2w5L4
FENXR7evqsZfeFZ5QupU94hn5P+gM/C1QE7yn3RmnWohtZNPM7PSyek0EObZ
me/OVdI6M5tuuf6dc5426Tlh6fRCchb3O7PXZXFc9D7pI9Xwq0/iLf0zLOo+
WUlDpeU/9zfLB0fBQ6Q=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 571->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k0FqQkEQRAcXwWuIN0gOIF7BnOALcSUEdCHuPHoiESVDV/XrMWRg/H5m
puZVdf/F9nOzm7XWjvPvn810Wh8O0/n95fryMe3fXvfXxeVttnZZtftzZD5z
Vump0a9H5yINcpfTVp5Vfr0eySrTVHyKPXqndYtYMo8qN3rW1aTnjfScH+e5
yhDtJZqj343KjuTsvqsqb5WF8lU0nB9VI+eXaPZ73ZryEJ0ntSf+aWYqn0yP
8LosSWaUJfSxekx1L/FCvdIs1V7a03SdMpP+qLKq2inmflCWLJssF3InyU4x
VepZZeg1nF7GQjVd7dz5Si5Zv6jMKz2ecVT6pOLP+YzOOp/Ug6tXtDbC4vgi
hqqPal2jO/4isywTck+2j2RGvg/aA+02n+kxt0exUC/kbpfTSK9UNJUHwjza
89W+cl5HelMNVb9f/2HNCUulFioDt7/Se3JfsQ8zFpIF4XJ1ip6RpmKJ9pPh
PGRe/nP+sHwB2OdGXw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 572->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0FKBDEURIML8RriDfQA4hXGE7SgqwFhXIg7j66NOkisqv9+K9iQ6WmS
VF7V/zm/e9w9nIwxns7ef3bL883hsLzcnq4f98v+6nK/Tl58jjFer8fxvWX8
Zq/Tc888r/YpDXJW0naeXX6zHsmq0nR8jl1907oplsqjy43uTTWZeZVe8pM8
dxnUWqK59d647EjO6V51ebsslK+jkfy4GiW/RHNem+achx/7Qd1JXyhfhIVm
QjySeleZURbnY83zOMS5xAv1WmX5nUWtpT1N5yvdIbirfqKsrnaOeX4oS5VN
lQs5k9TcMXXq2WWYNZJexUI1U+3S/k4uVb+4zEle9G50+qTjL/lUe5NP6iHV
S81tYUl8iqHro1tXdcZfZFZlQs6p1pHMyP2gPTCgJrknnV6nXsjZKactvdLR
dB4I89ae7/ZV8rqlN93j6qf+p7MpS6cWkrNY3+k9ueZrXaMPKxaSheNSHLO2
e8v8DItaT57kYZ7/z/HB8gZN5kKg
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 573->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9lVFKQ0EMRUM/xG2IO9AFlG6hruAJ+lUQ6of0z6XXahUdbm5ORnFg+vqY
THLuTUqv7p+2j6uIeL58+9guL5v9fjncXZxeHpbd7c3udHh93hGv6/h6zuyY
vJfmM2s8V/dUDlLL5Vb31FOdfz+rWFzOjC9jV++qHmWpNGa+0buuJyOvyuf0
OM1dBhVLchIWEpfdI/UyLsLbZaF8nRxOT9Yjp5fkHGPdWaZB3Se9J/qpZ5k/
VT7C67wknlGWTMf7MnWJFqq18jLW8eM/UbGQmabnlJnMR5c1613GPC7KUnlT
+UJqEu8ypk4/uwxjDpevYqE5Xe/c/Y4v1bxknndmvOLozElHn9Op7jqdVIPr
lzqbYXF8iqGro9tXVeMvPKs8IXWqOOIZ+X3QGYjz/s2MuZiMhWohtZ1PM7PS
yZlpIMyzM9+dK6d1ZjazlfVPfXe1KUunF5KziO/Mnoz5jGvMYcVCvKi4qj6p
p/QvYVHxZDkNlZb/3B8sR0ihQ+E=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 574->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KA0EQhRsXwWtIbqAHkFwhnmAEXQWEuJDsPLqGhCBlvVdftZKGyWTo
6lfvp/ru+W37ejPGeL/9/tkuH5v9fjk8rY4fL8vu4X533FyfnzE+H8flPfP8
5azCUyvuZ+cyDNLLYSvNyr+IR7yqMBU/xT37prllXCqNyjd61mUS+WZ4To/T
3OWQ1RLM2XujvCM+u3vV5dvlQvl1MJwelZHTSzBjrdtTGn6dB7mTuch0ES7U
E6KR5F15RrkoHT89zfoSLVRr5WXMNuNCZpruU85kPrpcVXaKc1yUS+VN5Qvp
SbxTnDp5djlEDIdXcaGYLjt3vuNLNS/K886MVzw6c9LR53RmZ51OqsHlle3N
cHH8Mg5dHd1csx7/4VnlCelT1RHPyP2gM6DOzdyTzqxTLaS382lmVjqYSgPh
PDvz3blyWmdmUy2VX/bf9aZcOlmkPIv6zuylNQA7YtB6kiPVoLKJ/mf1rnfU
VS2nodJyzefE5QtB8ERj
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 575->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0tqAkEUbFxIriG5gTlAyBX0BBPQlRAwi5CdR1dJGKStqlc1Iza0g/R7
1fV5vfr82uwXrbXvl8vPZvj5OB6H3+3y+mc3HN7Wh+vh6/9u7fTexu+UPaeX
4bHVn6M+hOHcpbCZZuZfj+d4VWEyfow7+u/mhrhUGplvbq/KpOeL8JQepTnl
gGodzKnvhnnn+KzeVco35eLySzCUHpaR0utg9rXqjGlA/U72jn7XM+ZPhaf4
NjPvyjOXC9OB7lIcqnlyvK+8ZLXuTLvnLmdnPlKuLDvGuV8ul8qbyhfnTsc7
xinJM+XQYyi8iouLqbJT/Ykv1bwwz5MZr3gkc5LoUzpRr9LpalB5obMpXBQ/
xCHVkeaK7niEZ5Unzj3jMn1mWFWfOwMjlxkzpmoYF1oTviOkae6sJJgsD4fz
1JmvcujxlVYXQ70Jdt9d7rdb3O1ySbKAPIv6ZPZgjYHdY7j1To6uhrucwBf6
R7igemcpDZWWZ+4/LmffDkEk
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 576->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01qAkEQhRsXkmtIbmAOILmCOcEEzEoImEVw59ETSeJPp96rrxqxYRyH
7nr1varqxev7+m3WWvt4+P5ZT5/Pu920f5kfPzbT9mm5PW4+/j6tHVbt9B55
2mCc1DOr34/iIg2Sy2lHcdE72r/cy1icpuJT7NF3lI+yZB5V3Wis60nPG+k5
P85zlSE6SzQJCzmn4kg+xUV4qyyUr6Lh/KgeOb9Esz/r9pSHf/Gg72QuIl+E
hdaEeCT9zmpGWZSP0xJ5iRfqFddydeZxM1dhiPYz3T8OMh9VVtU7xdwvypLV
JqsLyUl6rpgq/awy9BpOL2Ohmq53Lr5Sl2xeVM1JvejdqMxJxZ/zGcU6n9SD
61e0N8Li+CKGqo9qX6Mct6hZVhOSJztHakbuB50BFTdyTyqzTr2Q3K5OI7NS
0VQeCPPozFfnynkdmU21VP+u/sOeE5ZKL1QN3PnK7FVZFBc9T/pIPfQ60TvS
VCzRebKch8zLPZ8fli+AyELj
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 577->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k19qwjEQhIMPpdco3sAeQLyCPcGv0D4JBftQfOvRrVZFw87st6k0EP+Q
ZPLN7Obp9WP9PmutfT7+fKynr9V2O+1eHg5/3qbN82JzWJyfZmvfy3b5Hpl/
Oav01OjXo3ORBrnLaSvPKr9ej2SVaSo+xR79p3WLWDKPKjd61tWk5430nB/n
ucoQ7SWao+9GZUdydu+qyltloXwVDedH1cj5JZr9XremPETnSe2Jf5qZyifT
I7wuS5IZZVE+orscQ9ZPJPs0y+VpBiykp+l6pnvmIP1RZVW1U8z9oCxZNlku
5E5Sc8VUqWeVoddwehkL1XS1c+cruWT9ojInedG3UemTij/nMzrrfFIPrl7R
2giL44sYqj6qdY3uuEdmWSbknmwfyYy8D9oDxwE0yTup9Dr1Qu52OY30SkVT
eSDMoz1f7SvndaQ31VD1u/kNa05YKrUIOZP9ld4L91xN24cFFpJFxpXVKfoO
8xMs0X4ynIfMy3/OX5Y9QkRCYQ==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 578->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk1FKA0EQRAc/xGuIN9ADiFeIJ1jBfAWE+CH+eXSNiiRDVfXrVXBgM7vp
6eqq6p7Lh6fN9myM8Xzx8bNZXu72++X1/vzw8bjsbq53h+DV9zPG2+342dc8
Y2WexQtrjqs8hUFqJWyVp3YVP45VXBKm4+e4q29Vj3KpNDrfaG7qycxX4SU9
SXOXgzpLMAkXcs7lkXqOF+Hb5UL5dTCSHtejpJdgzmdTzGk4yW/0nuinnil/
BsCrNJJ+V565uslLh1m9Oy1Uq+OQtKeZ63BQcYQL56PL1fXOcZ4X5VJ5U/lC
apKeO06dfnY5zBgJr+JCMVPvUn7Hl2penOfEr9bdCDp+cz+cTpWbdFINqV8q
toZL4qc4dHV0+6pq/IVnlSekTnWOeEbuB52BzwUwyT3pzDrVQmonn9bMSgfT
aSCc1858d66S1jWz6Zbr38k77Dnh0umF5Fmc78xePFfN4dF/FRfiheOleMzY
bpf+GS7qPFlJwxz/z+eLyzu6TEKi
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 579->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA1EMRYMf4jbEHegCxC3UFYygXwWhfkj/uvS22Mr0kXtzMhUHXoch
LzfnJun92+fq4yYivu4OP6vp+2Wzmbavt8eP92n99Lg+Bh9OJ2L3HL/vJScW
5kk984zxLC/TILWcdpaXvbP4PFaxOE3Fp9iz76weZak8qr7RXDeTkTfTc36c
5y5DdpdoEhZyT+WReoqL8HZZKF9Hw/lRM3J+ieZ418WUh4v80yGzJ/5pz1R/
Kr3KI5l31TPKonxktRxDtU+k97SXGQvZaRqnumQ/uqxqdor5vPvRZKl6U/XF
5dLjmDrz7DKMGk6vYqGa6exMP6keYVY6Tq/y2Zlr1Quqq3xmuc4n9eDmlcWW
sDi+jKHrozvXrMZf9KzqCakT8wM1M60qj+7AmeWaHXN3FIu809gJ5enaXelo
qnkQ5qU7X81h1HdeqYb7T6h63R1QGoS9iqWcxf3O7pG5yD00fVF7S+ZIPajZ
jP3P7rva8zh5nIfKy3+eH5Y9O3JDng==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 580->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFlEFKA0EQRZssJNcI3kAPMHiFeIIRdBUQkoVkl6Nrooah/fXrVSs40BlC
df16v6qSzdPr9mXVWjusPz6289vDfj8fH2/OX57n3f3d7hy8/TqtnaZ2fY+c
NpgX6pmnj6s8pUFqOW2Vp94qvoxlLE4z4ovY1XdVj7JkHqO+0Vw3k55X6Tk/
znOVQd0lmoSF3IvySL2Ii/BWWShfRcP5iWbk/BLN/q6LRR5+5IO5k71QvggL
7QnxSOad9YyyRD5ULceQ7RPpPe2lYiE7TeOZbgv2kMyL9oDM8vJMi1NgyXqT
9UXGkxlXmCrzzPqaaTi9jIVqytmZflI9whzpOL3MZ2WuWS+obuRT5Tqf1IOb
l4qNsDg+xVD1UZ2rqvEXPct6Qupcnqld/+uIptLK8ugOfLP8ZsfcnYiFeiG1
XZ9GdqWiGXkgzKM7n82h13deqYb7TUT1qjsQaRD2LCY5k/uV3bP3FrWyPcxY
SC8cV8/Ra0dv2b+ARd0nj/OgvPzX+WR5B4hrQaA=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 581->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0FKA1EQRBsXkmuIN9ADiFeIJxhBVwEhWYg7j67REMJPV/XrH8GByTD8
6epX1Z2b57f161VE7FbfP+vl/XG7XT6ervcvL8vm/m6zP7w93BGfD3F8ztwx
WSf1zDWeZ3WZBunltLO67Jmdn55VLE5T8Sn27D3rR1kqjyo3WutmMvJmes6P
89xlyL4lmoSFfKfqSD/FRXi7LJSvo+H8qBk5v0Rz/NadKQ9n9WDuZC8yX4SF
ZkI8knlXmVEW5SPr5RiqfSLZ0ywzFrLT9Jzqkv3osqrZKeafC+i7/LK6Khdb
W8z6kpkqLtJPaTi9ioVqytmJPKkeYVY6Tq/y2ZlrlQXVVT6zWueTenDzys5m
WBxfxtD10Z1r1uMvMqsyIX2OF8xZaVV1dAficF+yY+4bxUK9kN4up5ld6Wgq
D4R5duerOYz6zivVcP8J1a+7A0qDsJ9pgdwVC5mn8q5YQmiPGhULycJxjRwu
j9Onys/1Hn1Vl/OQefmv+5flC8CiQKQ=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 582->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFk0FKBFEMRIML8RriDfQAg1cYT9CCrgaEcSHuPLoODs34TVVevgN++N00
SSpVlfT148v2+SIiXq++Htvl7X6/X94fLg8fT8vu7nZ3CN4cb8THJtb3zI3J
OolnzhjP6jIM0sthZ3XZO4ufxiouDlPxU9yz76wf5VJpVL7RWjeTkW+G5/Q4
zV0OWS7BJFxInqoj/RQvwrfLhfLrYDg9akZOL8Ecc11MafhVD+ZO9iLTRbhQ
T4hGMu/KM8pF6ch6OQ7VPhHvqZcZF7LTNH4OXOdbZ7fdLNcD8J1/WV3lC9FP
Zq44dXzvchgxHF7FhWLK2Qk/KR7hrHAcXqWzM9fKC4qrdGa1TifV4OaVxWa4
OH4Zh66O7lyzHufwrPKE9FkP9FlhVXV0B+J4/7JjLkdxoVpIb+fTzK50MJUG
wnl256s5jPhOK8Vw/4Tq190BhUG4VzHF0+V3dq/Mg3tYcSFeOF6xiR//u/Pj
9K38c71HXdVxGjIt/3W/uXwCjANAJg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 583->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzFU1tKA0EQbPyQXEO8gR5AvEI8wQr6FRDih/jn0TUaljCpV4+CA5Nl093V
VdW9V48v2+eLqnrdfP1sl7f7/X55f7g8vDwtu9ub3SF4fbxVH3e1PmduTdZR
PHHGOKpDGEkvhY3q0BPFT2OOi8Jk/Bh39I76pVycRuZbWqtmMvJFeEqP0tzl
gHITzIRLksfqkn6MV8K3yyXl18FQetiMlN4Ec8xVMabhrD6Ye7IXSFfCJfUk
0ZjM23mWcmE6UC/Fwe1T4n3qZQlNXQ4o7nAr1MZ86+y2muX3GfikXJw3zhcY
NzPucOrM0/nqMBSe45JiwtkJP1O8hDPDUXhOZ2euzosUl+lEtUpnqkHNC8Vm
uCh+iENXR3euqMdfeOY8SfqsJ/SZYbm6dAfqeH+zYyqHcUm1JL2VTzO70sFk
GhLOszvv5jDiK60phvomWL/uDjCMhDuKFeG+/iewFD7ywuaRfiqm9jaZI+NV
BGv0bfQf5avep/HkKA1My3/cHy6flvpAIA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 584->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9U0tqwzAQHbIouUbIDdoDlF7BPYED6SpQcBYluxy9dWNCUOZ9RikVyMaM
9OZ9xpvd5/Cxiojj+ucxjF9v0zSe3p/mj/14eHk+zMXtsiPOr3F99+xH7iI8
tNp6di/DcHoxbKQZ+dfiOV4pTMQPcc++3dwyLkoj8s29yzJp+WZ4TA/TXOWQ
nXUwe/8b5J3jM/uvqnyrXFx+FQymB2XE9DqY7VlWQxru7hu5O3OR6XK4uJ44
Gp28lWcuF6Qj68U4qHlyvHe9DKKpyiGrK9y43ewc8K0y2yzL33XDo8JFeaN8
Sesi4wqnSp7KV4XB8BQXFzPNjvjp4jmcEQ7DUzoruSovXFykM7vLdLoaWF5Z
rYcL45dxqOqo5pr1+AvPlCdOn+syfUZY6p47A7HsR2aMnUFcXC1Ob+ZTz6xU
MJEGh3PvzKscWnym1cVg/wTqV50BhOFwVzXEk52vzJ48Z86h4uJ44fBiOWVv
5B/r3epSi2lQWv5zX7h8A4aLQOM=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 585->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01qQkEQhAcXIdcQbxAPEHIFc4IXiCtB0EVw59FVYt5i7Kr+ehIyMMpj
pqvrp2f5sd9sF6214/P1ZzN9vR0O0+n96fbxOe3WL7vb4eq+Wzu/tvl/ZP+m
VuGp1Z9HdREG6eWwlWblX49HvMowFT/FPfqmuUVcMo3KN1rrMun5RnhOj9Nc
5RDdJZij70Z5R3x276rKt8qF8qtgOD0qI6eXYPZ33ZnS8FAPcidzEekiXKgn
RCPJO/OMclE6ol6OQzZPxHvqZcSFzDQ9R7g/29xTvlVm22U5L4Dv/IvqMl9c
Ld2OUyXPKocew+FlXCimzE74SfEIZ4Xj8DKdlVwzLyiu0hnVOp1Ug8srOhvh
4vhFHKo6qrlGPf7Cs8wT0mde0GeFldXRGWgQk7yTyqxTLaS382lkViqYSgPh
PDrzWQ49vtNKMdybUP2qM6AwCPfsLOSZ3K/MXnrPzWGBC/GC8Mpy6rMK/RNc
ovtkOQ2Zlv/c31wuj09DYQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 586->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KA0EQhQsXkmuIN9ADBK8QTzCCWQWEuBB3Hl0DOsTOq1dfNWJDzzB0
16v3U3Pz9LLbX0XE6+brsVveHo7H5f3x+vTxvBzu7w6nw9vvHfGxjfU9s2Oy
LsUzazxXdQqD9HLYqk691fn5WcXFYWb8Mu7qW/WjXCqNmW+01mUy8lV4To/T
3OWg7hJMwoXcy+pIv4wX4dvlQvl1MJyeLCOnl2COd91ZpuGiHuRO5kLpIlyo
J0QjybvyjHLJdKhejkM1T8R76qXiQmaaniPcn23uZb51ZttluS6A7/xTdZUv
rpZux6mTZ5fDiOHwKi4UM80u8ZPiEc4ZjsOrdHZyrbyguJlOVet0Ug0uL3U2
w8XxUxy6Orq5qh5/4VnlCemzLuhzhlXV0RkIiEn+k86sUy2kt/NpZlY6mJkG
wnl25qscRnynlWK4fyLrd5H7+Ta9KRfrBfA9DJbDV16QXNwcur7uvsuxi7X6
PX4nWjMu6j5ZEgfm8R/7N5dP1VlBoA==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 587->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA0EQRRsXkmuIN9ADDF4hnmAEswoIyULceXQNJANW6v96NYjY0JkM
3fXr/aqau5e37e5mjHHcfP9s5/enw2H+eL49vbzO+8eH/enw/rzH+JzG8vwP
2614fhU3nXcSV+Vy2llc9rxiCVoVi9NUfIo9e8/yURYVH5dirmJdTyJvpuf8
OM9dhuwu0SQs5J6KI/kUF+HtslC+jobzo3rk/BLNeNedKQ9ZPOk98U9rpupT
6RFeV0tSM8qifGS5HEM1T6T2tJYZC5lpeo50L9vcU3XrzLbr5bKAvqtfFlfV
xcXS7Zg6/ewyRA2nV7FQTdk7UU+qR5iVjtOrfHb6WtWC6iqfWazzST24fmVn
a1gcX8bQ9dHta5bjN2pW1YTkWRass9Kq4ugMDKhJvpPOrFMvJLer05pZ6Wgq
D4R57cxXfYj6zivVcN+EytedAaVB2KuzyBn/d/upvLu+yDmcxvIdViykFo7L
aSkW5VWxZPfTVczm5Q7px1/snyxfmN1A4Q==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 588->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqAlEQRD8uJNeQ3CAeQHIFPcEEdCUIZhGyy9ETQYfkT1f168GAH9px
6N/VVV09q7fT9rBorb0//fxsh4/X83n43C0vL/vhuH45XpLP12jta9PG5yOE
O31+UicwSC+HHdVFzyj/O5dxcZiKn+IevUf9KJdMo5obrXWe9HwjPKfHaa5y
iO4STMKF3FN1pJ/iRfhWuVB+FQynR3nk9BLM/q7LKQ2TeuA72YtIF+FCZ0I0
Er+zmVEuSkfUy3HI9onMns4y4kJ2muYR7i3MPTW3ym47L8cD8N38orpsLq6W
huNU8bPKocdweBkXiim9E/OkeISzwnF4mc6Kr9ksKK7SGdU6nVSD8yvKzeHi
+EUcqjqqvkY97jGzbCakz3jgnBVWVkd3oEFM8p1Udp1qIb3dnObsSgVTaSCc
5+585kOP77RSDPdNqH7VHVAYhHuW63n2/6t+Ku3OF7uHCXeKl+2Yw7rxGKNN
8QiX6L48AKfyff1n/PXoG+JuQSI=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 589->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA0EQRRsX4jXEG+gBxCvEE4xgVgEhLsSdR9eoBGn///VqzMKGzmTo
rl/vV9VcPjxttmdjjOeLj5/N8nK33y+v9+eHl8dld3O9Oxxefe8x3m7H8fkf
dlrzuYpTGiRX0lZx6qnOf55VLEnT8Tl29a7yUZbKo6sbjU09mXmVXvKTPHcZ
1F2iSVjIPRdH8jkuwttloXwdjeTH9Sj5JZrz3XTmPPyKB30nc6F8ERZaE+KR
9LuqGWVxPlSuxFDNE6k9raViITNNz5EunI8uq+udY/5cQD/VT8VVdUmxdCem
Tj+7DLNG0qtYqKbtnakn1SPMTifpVT47fa1qQXWdTxWbfFIPqV/qbA1L4lMM
XR/dvqocp6hZVROS57hgnZ1WFUdnYEBN8p10Zp16IblTndbMSkfTeSDMa2e+
6sOsn7xSjfRNuHzdGXAahL06mznn/91+Ou+pL2kOK3aqV83YKGrunkrTsaj7
ZFX9OuX38pf9xfIO3gVDJA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 590->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0FKQ0EQRAcX4jXEG+gBgleIJ/iCrgJCXIg7j65BCTipqn79k4HJzzDT
1VXV3bfPb9vXqzHG+83Pz3b5eNzvl8+n68PhZdk93O8Ol3d/e4yvzTh+1+yx
Ms7ihTXfyziBQXIlbBWnvv9wN6dYFZeE6fg57uqs8lEuLn5ejnMVm2oy81V4
SU/S3OWg3hJMwoW8c3Ekn+NF+Ha5UH4djKTH1SjpJZjz23TnNKh4Unuin3rm
/KnwCN/kJfGMcnE6VK7Eoeon4j31UnEhPU3vKS7pjy5XVzvHmeIn/1Rc5UuK
pTtx6tSzy6HyjmIrbyodaqX4ji9VvzjPiV/d2XA6zpkPp1PFJp1UQ6qXulvD
JfFTHLo6unVVOS7hWeUJyXNc0GeHVcXRHhgQk8xJp9epFpI7+bSmVzqYTgPh
vLbnqzrM+EkrxUgz4fJ1e8BhEO7V3cxz/t+tp9Nu3xV9WHFPs+G8pBpUbcZ8
FpiOi3pPVlWvS87LOfuXyze/vEEm
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 591->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlkFqAlEQRD8uQq4h3sAcQLyCOcEIZiUEzCK48+hGlCH5dlW/Hl1kYNSh
f1e/6u4B59vPzcestfb1+vOxGb7Xh8NwfH+5POyG/dtyfwkubndrp1Ubv//D
7a4+HuVFGqSW047you8o/juWsThNxafYo+eoHmXJPKq+0Vw3k5430nN+nOcq
Q3SWaBIWck7lkXqKi/BWWShfRcP5UTNyfolmf9bFlIe7fDB3sheRL8JCe0I8
knlnPaMsykdUyzFk+0R6T3sZsZCdpnGsC/ajyqpmp5hHjiJL1pusLzY3mfUj
M1VcpJ7ScHoZC9WUsxP9pHqEWek4vcxnZa5ZL6iu8hnlOp/Ug5tXFJvC4vgi
hqqP6lyjGs/oWdYTUme8YJ+VVpZHd6BBTfKeVHadeiG1XZ+m7EpFU3kgzFN3
PptDr++8Ug33Tqh61R1QGoQ9i/Wc/e/qPJV3eS7Zw4zdvRuql9TDn+dVu/sv
prwqlug8ubJ5PfN9eeS+spwB6fxBYw==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 592->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN9ADiFeIJxhBVwEhWYg7j65REWnfe/XVmIUNncnQ
Xa/eT83F/dP28WyMcdi8/2yX59v9fnm5Oz++PCy766vd8fDya4/xejO+n/9h
pzWfqzqFQXolbFWnnur851nFJWE6fo67elf9KJdKo/ON1qZMZr4KL+lJmrsc
1F2CSbiQe66O9HO8CN8uF8qvg5H0uIySXoI5301nTsOvepA7mQuli3ChnhCN
JO/KM8rF6VC9Eodqnoj31EvFhcw0Pae4ZD66XF12jvPHAvjJP1VX+ZJq6U6c
Onl2OcwYCa/iQjFtdsZPikc4O5yEV+ns5Fp5QXGdTlWbdFINKS91toZL4qc4
dHV0c1U9TuFZ5QnpU90jnpHvg87AgJjkO+nMOtVCeief1sxKB9NpIJzXznx3
rpLWNbPplstP/U+9KZfoReH7/L+bp9OecklzmPqm+8lLqkFlM+Z3gem4qPtk
VXmd8nv5y/7k8gbd80Ll
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 593->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk01OAkEQhTssDNcg3EAPYLwCnmBMdEViAgvDjqMDoob01Hv1VUsnzQzp
rlfvp2b19rn5WLTW9svzz2b6etntpsPrw+XP+7R9etxeDtc/u7Xjc/t7juw2
WCfxzOrPZ3UCg/Ry2FFd9IzOb88yLg5T8VPco/9RP8ol06h8o7Uuk55vhOf0
OM1VDtFdgkm4kHuqjvRTvAjfKhfKr4Lh9KiMnF6C2d91Z0pDVE+yJ/qpZ8qf
DI/wdV4SzygXpSPq5Thk80S8p15GXMhM03OMC+ajylVlpzjf8qhwybzJfHG1
dDtOlTyrHHoMh5dxoZgyO+EnxSOcFY7Dy3RWcs28oLhKZ1TrdFINLq/obISL
4xdxqOqo5hr1uIdnmSekT3aPeEa+DzoD3wtgku+kMutUC+ntfBqZlQqm0kA4
j858da6c1pHZVEvlF7273pSL9SLxvX+v5qm0u1zsHJq+zlvnJdUwy+Z3tzke
4RLdJyvL657fy3/2lcsJf1FA5Q==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 594->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk11KA0EQhAcfxGuIN9ADBK8QT7CCPgWE+CC+eXSNhihrVfXXmx2Y7IaZ
rq6f3uvHl+3zxRjj9errZzu93e/30/vD5eHP07S7u90dDm+Oe4yPzTg9l+yx
sM7ihTU/V3UKg/RK2KpOPdX537OKS8J0/Bx39V/1o1wqjc43WpsymfNVeElP
0tzloO4STMKF3HN1pJ/jRfh2uVB+HYykx2WU9BLM+d105jT8qwe5k7lQuggX
6gnRSPKuPKNcnA7VK3Go5ol4T71UXMhM0/MKdxw3mY8uV5ed4/y9COfgn6qr
fEm1dCdOnTy7HOYYCa/iQjFtdsZPikc4O5yEV+ns5Fp5QXGdTlWbdFINKS91
toRL4qc4dHV0c1U91vCs8oT0qe4Rz8j3gfRsfp/nzFi647hIz5szodYas9LB
dHkQzktnvjtXSeuS2XTLzYR6T70pl+hF4fv8vZun055ySXOY+qb7ycsu1skP
kZXCdFzUfbKqvNb8Xs7ZP1w+AZfYQGU=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 595->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk11KA0EQhAcfxGuIN9ADiFeIJ4hgngJCfBDfPLpGRWS2qvrrVdCByW6Y
6er66T2/e9jsTsYYj2dvP5vt083hsH2+PT3+ud/ury73x8OLzz3Gy/X4ev6H
ndZ8ruoUBumVsFWdeqrz72cVl4Tp+Dnu6r/qR7lUGp1vtDZlMvNVeElP0tzl
oO4STMKF3HN1pJ/jRfh2uVB+HYykx2WU9BLM+W46cxoW9SB3MhdKF+FCPSEa
Sd6VZ5SL06F6JQ7VPBHvqZeKC5lpeo5w4Xx0ubrsHOf3BfCTf6qu8iXV0p04
dfLscpgxEl7FhWLa7IyfFI9wdjgJr9LZybXyguI6nao26aQaUl7qbA2XxE9x
6Oro5qp6/IZnlSekT3WPeEa+DzoD6u7a76Qz69Lz5kw4TT+dlQ6m845wXjvz
3blKWtfMpltuJtR76k25dLKYec7v3Tyd9pSL9MP4U80tyVFiJc/nPZZ4hIu6
v1iFh2PCV1r+an9weQVO0UMg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 596->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k11qw0AMhEUfSq4ReoP0AKFXcE/gQvJkKDgPoW85emtIf1jPjEabUMPG
DruSvhlpt2/vw/EhIk6br59hPL/M8/jx+rj8OYzT825aNp+uK+Kyj593z4rO
OJpPPO3+Ku7Kg+KyWio3ikNvtP93L2NRORkfY0f/UT2XJdPIfHNjVU9aXpRP
6VGaqwzorJPTYXHOsTinHuNyeKssLl8lh9LDeqT0Ojnbs2qPaUDxTu8d/a5n
zJ8sn8OrvHQ8c1mYDlRLMWTz5HjveolYnJl29928znxUWVnvGLObX/mH4jJf
VKy7FFOln1WGzDs3N/Im04EeFV/xJZsX5rnjV/VuMB233A+mE8Uqna4G1S+0
18Oi+BBDVUe1r6jGPTzLPHHqZOccz5z74c4AOtt7Tyqz7mpxaiufemalkpNp
cJh7Z746V0prz2yyh/UPfavaLkulFy1n+13tJ9Ou+qJ8z9ir+RiXyhWiVygn
Y0HnV0/iYbQLaPnP9c3x68snHb1C4Q==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 597->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KQ0EQhAcX4jXEG+gBxCvEE0Qwq4AQF+LOo2tQQpxUVX/9COLA5L0w
09X10+/66WW1uRhjvF59/azWbw+73fr98XL/53m9vbvd7g9vfvYYH/fj8PwP
O635/KTOYJBeCVvVqac6Pz6ruCRMx89xV/9VP8ql0uh8o7Upk5mvwkt6kuYu
B3WXYBIu5J6rI/0cL8K3y4Xy62AkPS6jpJdgznfTmdNwUg9yJ3OhdBEu1BOi
keRdeUa5OB2qV+JQzRPxnnqpuJCZpufnwE2+dWY7ZXlYAD/5p+oqX4h+krnj
1PG9y2HGSHgVF4ppszN+UjzC2eEkvEpnJ9fKC4rrdKrapJNqSHmpsyVcEj/F
oaujm6vqcQ7PKk9In+oe8Yx8H3QG1N2l30ln1qkW0jv5tGRWOphOA+G8dOa7
c5W0LplNt1x+6j31plw6Wcw85/dunk57yiX5XnHv4jleCWuErBSm46Luk/UL
52iTPP5yf3P5BIhCRCI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 598->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA0EURBsX4jXEG+gBxCvEE4xgVgEhLsSdR9eoSGiq6r8/ycKGzkzo
7upX9f9cP71sthdjjNerr5/N8vaw3y/vj5eHP8/L7u52d1i8+Z1jfNyPv+d/
mGnM6+qc0iB3JW11Tj3V+vFaxZI0HZ9jV//VfZSl8uhyo2dTTWZepZf8JM9d
BrWXaBIWss+dI/c5LsLbZaF8HY3kx9Uo+SWa89605jyo86T2xD/NzOVT6RHe
lCXJjLI4H+quxFD1E8meZqlYSE/TdawL+qPL6mrnmI85BuztmUlxVbmks3Qm
pk49uwyzRtKrWKimrZ3Jk+oRZqeT9CqfnbpWWVBd51OdTT6ph1QvtbaGJfEp
hq6Pbl3VHefIrMqE3FPtI5mR74P2wPcAmuQ76fS6zLzZE87Tqb3S0XT1IMxr
e77bV8nrmt50w/WEek93U5ZOLWbO+b1bT+c91cXmDthbeoEraQ3D4rw6FrWf
jKofzvm9nDJ/WD4By1lDog==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 599->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk0tKg0EQhAcX4jXEG+gBxCvEE0Qwq4AQF+LOo2tUXEyqqr8eMzD/g+mu
rqruuX562ewuxhivV1+Pzfbt4XDYvj9eHn+et/u72/3x8OZ3j/FxP/7eK3ss
5lm8sObzkzyDQWolbJWn3jOXGavikjAdP8dd/at6lIvLn5fjXOWmnsx8FV7S
kzR3OahYgkm4kDiXR+o5XoRvlwvl18FIelyPkl6COcemM6fhJB/0ncyF0kW4
UE+IRtLvyjPKxelQtRKHap6I99RLxYXMND0/B27yrTPbqZcd/OSfyqt8IfpJ
zx2nju9dDpV3FFt5U+lQK+V3fKnmxXlO/Fq5G3TGKK7TqXKTTqoh9UudrXBJ
/BSHro5uX1WNc3hWeULqVHHEM3I/6Ayo2NV70pl1qoXUTj6tzEoH02kgnFdn
vjtXSevKbLrl+qe+U23KpdOLmef83e2n0576knyvuHfxHK+E9b1ErNPquKh4
sqp5OOd9+c/+4fIJiEFDpA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 600->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k01KQ0EQhAcX4jXEG+gBxCvEE0Qwq4AQF+LOo2swBByrqr8exIHJe2Gm
q+un3/XTy2Z3McZ4vfr62WzfHg6H7fvj5fHP83Z/d7s/Ht6c9hgf9+P87O5x
2iu1FjOs+Xzmcd6irurlsF2deqrzHzwLLgnTajfc1X/Vj3KpNDrfaG3KZOar
8JKepLnLQd0lmIQLuefqSD/Hi/DtcqH8OhhJj8so6SWY89105jT8qge5k7lQ
uggX6gnRSPKuPKNcnA7VK3Go5ol4T71UXMhM0/MWLpwniumyc5wpfvJP1VW+
pFq6E6dOnl0OlXcUW3lT6VAr1Xd8qebFeU78Wvk26IxRXKdT1SadVEPKS52t
cEn8FIeujm6uqsdfeFZ5QvpU94hn5PugM6Durn4nnVmnWkjv5NPKrHQwnQbC
eXXmu3OVtK7MplsuP/WeelMunSxmnvN7N0+nPeWSfK+4d/EcrwE9n7NSmI6L
ui/XiU/CoXn85/7m8glLeEOg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 601->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9VltKA0EQbPwQryHeQA8QvEI8wQrmKyDED/HPo2swKDupqq4agguT3WWm
q+vRC7l9ft3urqrq7eb7Z7u8Px4Oy8fT9fHlZdk/3O+Pm3enVfW5qd97uuq0
ZmopprjG/RWP+uOC6rpeDJvVoTvaX/FsuChMqp1wR++on8ul08h8c2tVJiNf
hKf0KM0pB3TWwXS4OOdYndOP8XL4plxcfgmG0sMyUnodzPGs2mMazuqN3J25
QLocLq4njkYn784zlwvTgXopDt08Od67XiIuzky7+5fAVb4ls62yTPCVf6iu
88XR72TOOCW+pxw671xs5E2nA12qPvGlmxfmuePXzLfhzpiLy3SiWqXT1aDy
QnszXBQ/xCHVkeaKelzCs84Tp093zvHM+T4sPZta/edQmM53ksy6q8XprXya
mZUEk2lwOM/OfDpXSuvMbLKL5YeeVW+XS5LFyHN8TvNk2lUuyveOe4rHeJXp
+ZgVwmRc0HnnOsMJ8vjP9cPlC6MmQyI=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 602->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJytk1FKxEAQRAc/xGuIN9ADiFdYTxBBvxaE9UP88+i6KBJiVfXr2Q1ks2Fm
ql9Vd66fXncvF2OMt6vvn93y/nA4LB+Pl8eX52V/d7s/Lt783mN83o+/58w9
Js9ZvXBt1/+dMxqkVtJW59RTra/XKpak6fgcu3pX9ShL5dHlRs+mnmx5lV7y
kzx3GdReoklYyD53jtRzXIS3y0L5OhrJj+tR8ks0t3vTmvOgzpPeE/80M5dP
pUd4U5YkM8rifKhaiaGaJ5I9zVKxkJmm65XuWDPAeaKsrneOeax4OixVNlUu
cr3ocYep088q10oj6VUsVFP2LuRJ9Qiz00l6lc9OX6ssqK7zqc4mn9RD6pda
m2FJfIqh66PbV1XjHJlVmZA61T6SGfk+OjNANMl30pn1U+tSTzOz0tF0Hgjz
7Mx35yp5nZlNd7n+qf+pNmXp9GLLuf3f7afznvqScq/Yu3qOK2mp9+TVsaj9
5Krm4Zzfyyn3D8sXAmhEYQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 603->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRD8uxGuIN9ADiFeIJ4hgVgEhLsSdR9egDPJTVf16dJGByWTo
39Wvunuun142u4sxxuvV189m+/ZwOGzfHy+PL8/b/d3t/hi8+bnH+Lgfy/Mc
7nTN8ZM8o0FqJW2Vp54q/jtWsSRNx+fY1buqR1kqj65vNDfNZOZVeslP8txl
UGeJJmEh51weqee4CG+XhfJ1NJIfN6Pkl2jOZ1PMeTjJB3Mne6F8ERbaE+KR
zLvqGWVxPlStxFDtE+k97aViITtN41gX7EeX1c3OMS8cTZaqN1VfYm4x67/M
1HGRek4j6VUsVNPOzvST6hFmp5P0Kp+duVa9oLrOp8pNPqmHNC8VW8OS+BRD
10d3rqrGf/Ss6gmps1ywz06ryqM7MKAm+U46u069kNqpT2t2paPpPBDmtTtf
zWHWT16pRvomXL3uDjgNwl7FZs75f3eeznuaS+p7xd7Vc1wD9nyeldJ0LOq8
vIrdVCzncH+zfAJ2+UQg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 604->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqAkEQRRsX4jXEG8QDSK5gTjABXQmCWYTscvREYlx06v961UpwYJyR
7vr9fv2a5etxu5+11t4W3z/b6f35dJo+XubnP7vpsH46nBdXl7u1z027Ph/h
dle/3tcpDXKW047qome03nONaio+xR79V/0iLJlH1Tda6zKJ8s3OcL5ITxVD
tJdoEhayT9WR8xQX4a2yUL6KhvOjMnJ+iWa/160pD3/qQe5kLiJfhIX2hHgk
eWc9oyzKR3SWY8jmifSe9jJiITNN17EumI8qq8pOMf9ykFlV/Yvqsr64Wno7
pkqeVYZew+llLFRTZif6SfUIs9JxepnPSq5ZL6iu8hnVOp/Ug8srWhthcXwR
Q9VHNdfojHv0LOsJOSfbR3pGvo/KDBBN8p1UZv3Wc6mnkVmpaCoPhHl05qtz
5byOzKa6VH7RuzubslSy6Dn792qeyrvLxfU9Y6/qKS6n1UxWkaZiifbLy+kU
8vjP+4flC6gzRt8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 605->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJy9k1FKA0EQRAc/xGuIN9ADBK8QT7CCfgWE+CH+eXSNiiRjVfXrRRyYZJeZ
rn7V3Xt5/7R9PBtjPF98/GyXl9v9fnm9Oz+8PCy7m+vd4fDqe4/xthk//909
VsSUmmHN58cc44hHxVW5nLaLU//q/ISzYEma1rthV+8qH2WpPLq60djUk5lX
6SU/yXOXQd0lmoSF3HNxJJ/jIrxdFsrX0Uh+XI+SX6I5301nzsOveNB3MhfK
F2GhNSEeSb+rmlEW50PlSgzVPJHa01oqFjLT9JzqkvnosrreOebPBfRT/VRc
VZcUS3di6vSzyzBrJL2KhWra3pl6Uj3C7HSSXuWz09eqFlTX+VSxySf1kPql
ztawJD7F0PXR7avM8Qc1q2qinrvzQmpGvg86AwNqku+kM+vUC8md6rRqVhqa
zgNhXjvz3blKXtfMpluuf+o55aYsnV7MnPNzt5/Oe+pLqnvF3tVzXElLvSev
jkXdt6vQof34z/3F8g7L8UPh
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 606->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqAkEQRRsXwWtIbhAPIF7BnGACcSUIuhB3Ht1IxEWn/q9XrYs0jOPQ
XVXv/6pefO0321lr7Tj/+dlMp/XhMJ0/324f39Nu+bG7bb7fn9Yuq/Z4/4fH
rX6/j1M5SC2XO4qL3tF+zzWaU/Ep9uhb+UVYMo3KNxrrehL1N6vhdBFPFUN0
luQkLOSciiP1FBfhrbJQvkoOp0f1yOklOfuzbk9p+BMP+k7mItJFWKgnRCPp
d+YZZVE6olqOIZsn4j31MmIhM033UV44H1VW1TvF3C/KknmT+UJqkp4rpko/
qwx9DpcvY6E5Xe9cfMWXbF6U58Sv0t0wOp65H0pnFOt0Ug2uX9HeCIvjixiq
Oqp9jWq8wrPME1InO0c8I/eDzkCDOck9qcw61UJqO59GZqWSU2kgzKMzX50r
p3VkNtVS/Yv+u9qUpdKLnrP/X+2n0u764nzP2Kv5FJfLFX07rYolOk9WNg+v
vC/PPL8sVzSMRWM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 607->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FqAkEQRId8iNeQ3CAeQHIFc4INmC9B0A/Jn0dPTER00lX9epXgwrou
s1P9qrpn9r5Zfjy11nbT75/lsH/dbofPt8nxZTWs5y/r4+Lz6W7tsGjn5yPc
7urXz3tOt9IgtZS22hc9o/UrzoTFaUrvgj16j+pRlsyjyo3udT3peSM958d5
rjJE3xJNwkK+U/tIPcVFeKsslK+i4fyoHjm/RLP/1q0pD9F+0nvin2am8sn0
CK/LkmRGWZSPqJZjyOaJZE+zjFjITNN1qkvmo8qqeqeY+4uyZNlkuZCapOeK
qdLPKkOv4fQyFqrpeuf2V3LJ5kVlTvKqng3l45bzoXxGe51P6sH1K1obw+L4
Ioaqj2pfoxr3yCzLhNT5uYx3khk5H3QGGtQk56Qy69QLqe1yGjMrFU3lgTCP
nfmsD72+80o13JlQ9aozoDQIe7bWc/b/q/1U3l1fXO4Ze1VPcbUs80BXeVUs
0fd/rgsWp0P78Z/3L8sXVXdGng==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 608->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG8QDBK8QT/CFuAoIcSHuPLpGJUjTVf16EoID85P/
u6e6qrrn9ull83w1xni9+XpslreH/X55f7w+vGyX3f1qdwje/e4xPtbj+Psf
tlsxTjFIHsX+65fyL+LF7zOYip/inr1n9SiXSqPyjZ51PYl8Mzynx2nucshy
CSbhQvLUOVJP8SJ8u1wovw6G06N65PQSzJjrYkpDdp70nuinnil/KjzC13lJ
PKNclI6sluNQzRPxnnqZcSEzTeM238wh6Rf1gPRyrMNucKm8qXyJ8SHqkt50
eqp4zdRVNSl25k2lI1vufMeXal6U58QvcjfInJxyP5TO7KzTSTW4fmWxGS6O
X8ahq6Pb16zGOTyrPCF1vpfRTjwj96MzAwST3JPOrJ9al2qamZUOptJAOM/O
fNWHiO+0Ugx3J1S97gwoDMK9ikWe8X+3n0q764v0HXBv4RFemeeCi9KquGT5
6RI8jvmNflxy/3D5BHGoSBg=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 609->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlUFKA1EQRD8uxGuIN9ADDF4hniCCrgJCXIg7j65BEf1WVb+eZOHAJBP+
/9WvqnvI5f3T5vFsjPF88fGx2b7c7vfb17vzw4+H7e7mendYvPq6x3hbxvf3
f7jTNa9TDbKPav/MK+U3lr9aFUupKfgcu/qt6lEWd36+HHN1NvVk5lV6yU/y
3GVQe4kmYSH73DlSz3ER3i4L5etoJD+uR8kv0Zz3pjXnQZ0nvSf+aWYun0qP
8KYsSWaUxflQtRJDNU8ke5qlYiEzTdepLpmPLqvrnWRexq//xA5LlU2VC6lJ
eu6YOv3sMswaSa9ioZpqX8qT6hFmp5P0Kp+dvlZZUF3nU51NPqmH1C+1toYl
8SmGro9uX1WNU2RWZULqVPtIZuT96MwA0STvSWfWj61LPa2ZlY6m80CY1858
d66S1zWz6S7XP/WcalOWmEWR+/zc7afzTlk6c5SyTVlKrSpzoeu8Oha1X17F
bM61Tvm+HHN/srwDXSRIHA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 610->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0Fqw0AQBBcfQr5h8oPkAcFfUF6gQHIyBJyD8c1Pt0WCCOvpnhpZhyzI
RuxuT3XPaPv+NXxuWmvfj9efYTzuDofx9PYwvXyM+5fn/bT59Pu0dn5t8/9/
eNzq96kGOUe1/+aV5ddrZSyZZsSn2KP3qB5lUff7lWXgmB135NnVcL5Ipooh
Oks0CQs5p+6ReoqL8FZZKF9Fw/lRPXJ+iWZ/1u0pD9F90nvin2am8sn0CK/L
kmRGWZSPqJZjyOaJZE+zjFjITNN9qkvmo8qqeqeYG8zZ5Rfdy3IhNUnPFVOl
n1WGXsPpZSxUM+ydyZPqEWal4/Qyn5W+ZllQXeUzuut8Ug+uX9HeEhbHFzFU
fVT7GtVYI7MsE1InO0cyI99HZQaIJvlOKrN+b13qacmsVDSVB8K8dOarc+W8
LplNtVT/Zs1kBpQGYb/RcrOSzCPpp/Lu+kLZydySPlIPad+EV8USnScrY1vz
e7nn+WG5AH3iR98=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 611->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqAkEQRZssJNcIuUE8gOQK5gQjxJUQ0IVkl6MnRhHtqf/r1ejChlG0
u36//6vmZfW1XD+11nbPfx/LYf++3Q7fH7PDj89hM3/bHDZfT09rP4t2/n6E
x61+n2qQc1T7Mi+VX+v0+7opmopPsZ+XuLvKour7pZizWteTnjfSc36c5ypD
dJZoEhZyTtWR+xQX4a2yUL6KhvOjeuT8Es3+rNtTHkb1oO9kLiJfhIVmQjyS
fmeZURblI7rLMWTzRLKnWUYsZKbpPtUl81FlVb1zzCRnl19Ul+VC7iQ9V0yV
flYZVH6RXsZCNaNzLk+qR5iVjtPLfFb6mmVBdZXPqNb5pB5cv6K9KSyOL2Ko
+qj2NbrjHpllmZB7/tfi9EDNSCurozPQoCZ5TyqzTr2Qu11OU2aloqk8EOap
M5/1odd3XqmGeyfUfaO+JzOgNAj7SKuQO/3PZVFlqcyRy9ZlGWrBzK/6Jrwq
lug8Wdk83PN9ueU5svwCGYpImg==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 612->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG+gBxCvEE3xBVwEhLsSdR9egBDN0Vb3+ycKBn0+Y
nppX1f2vn143LxdjjLer75/N8v6w2y0fj5f7P8/L9u52u9+8+X3G+Lwfh/d/
eNya96kGqaPaf/NK+c1aiSVpVnyK/WgVel0WdX5eLoMRmJWPmbdicX6c5y5D
VUs0CQupU+fIfYqL8HZZKF9Hw/lRPXJ+ieZc6/aUh+o86T3xTzNT+SQ9wuuy
JJlRFuWjussxpHki2dMsKxYy03Tf1ps5JP2iGZBepsxoftW5lAu5k/RcMXX6
2WVQ+VV6iYVqVnUuT6pHmJWO00s+O31NWVBd5bM663xSD65f1d4aFsdXMXR9
dPta3XGOzFIm5J5URzIj3wedgQE1yXfSmXXqhdztclozKx1N5YEwr5357lw5
r2tmUy3Vv4NmmAGlQdjTnsrA1Xdmj/TlFPaOHuFKmR/1TXhVLFU9WYntnN/L
Kc8Pyxed9Uge
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 613->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRD8uxGuIN9ADiFeIJxjBrAJCXIg7j65BEfmpqn49ycKBMYm/
p/pVdc/108tmezHGeL36+rNZ3h72++X98fLw43nZ3d3uDoc3P/cYH/fj9/M/
3Omaz6kGqaPaf/Oq8hvTWcVSaSo+x350mX6UZa53fRzznEvyM/uYeRVL8pM8
dxlULdEkLKTOPUf6OS7C22WhfB2N5MfNKPklmnNtOnMejp4Hcyd7oXwRFpoJ
8UjmXWVGWZwP1SsxVPtEsqdZKhay0/Q81oc9JPOiGZBZVpnR/NRzVS6kJ5m5
Y+rMs8vg8lN6FQvVVHUpT6pHmJ1O0qt8duZaZUF1nU/1bPJJPaR5qbM1LIlP
MXR9dOeqepwjsyoT0qeqI5mR96OzA0STvCedXT+1L/W0Zlc6ms4DYV678929
Sl7X7Ka73PzU99SbssQsGrnT/6UsuiydPUrZpiylFsx8npXSdCyqnlzVPpzz
fTnl/mb5BHJeSZo=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 614->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRD8uxGuIN9ADiFeIJxhBVwEhLsSdR9doEPOpqn49ZuHAGOT3
r35V3XP58Lx5OhtjvFx8/tksr3e73fJ2f77/53HZ3lxv94dXh3eM99vx8/sf
3vTM51SD1FHt33lV+Y3prGKpNBWfYz96DiyqH2WZ62WfwFzdTTOZeZVe8pM8
dxlULdEkLKTO3SP9HBfh7bJQvo5G8uNmlPwSzbk2nTkP6j6ZPfFPM3P5VHqE
N2VJMqMszofqlRiqfSLZ0ywVC9lpek51yX50Wd3sEjPJOeWn7lW5kJ5k5o6p
M88ug8tP6VUsVFPVpTypHmF2Okmv8tmZa5UF1XU+1d3kk3pI81Jna1gSn2Lo
+ujOVfU4RWZVJqTP1xO8k8zI90F3YEBN8p10dp16Ib1TTmt2paPpPBDmtTtf
zWHWT16pRvomXL/uDjgNwl6duQxSfWf3Yl1Du2IhWUSvMPN5VkrTsah68lT7
cMrv5S/vN8sH2tRKGg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 615->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01Ow0AMha0uENeouAEcAPUK4QRBglUlpLKouuvR20CE0on9/DllkZGm
VTue5/fj2b5/dZ8bM/t+vH50/XF3OPSnt4fhx0e/f3neD4dP4zY7v9rf9xq2
Wu05xSB1FHvqV+afNWcZlwzT4xdx95bXj3KJ7qselbsqk5avh6f0KM1VDl4t
wSRcSF10j/SLeBG+VS6UXwVD6YkyUnoJZlurziINs/sgdzIXni7ChXpCNJK8
M88ol0iH10txyOaJeE+99LiQmabnsl7MIcmLekCytJEP8Vn5593LfGnPTeha
wqmSZ+ZrhqHwMi4U06uTfkI8wjnCUXiZzkqumRcUN9Lp3VU6qQaVl3e2hIvi
53Go6qjm6vX4D88yT0ifnyW0E8/I+6jMAMEk76Qy6/f2pZqWzEoFM9JAOC+d
+SyHFl9ppRjqTUT9ZrmPm2ROuFSycHkm9ZXZC+smfe7hHvmkvJz933BRnt/k
FmiNuHj1s5V4GHFZw/7lcgEOQkhX
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 616->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcXkmuIN9ADiFeIJ/iCrgJCXIg7j65BCTLpqn71dZEPX6PT
U/2qunP1+LJ9vhhjvG6+fmyXt/v9fnl/uDz88bTsbm92h8Prn3eMj7tx/H0O
r3vmc6pB6qj277y6/GatjqXTrPgUe/VU/SiLuu96JHfdTGbeSs/5cZ5ThqqW
aBIWUqfukX6Ki/CmLJQv0XB+1IycX6I517oz5eHkPpg72YvKF2E5PkCv80jm
3WWm+roslWb3WXmhXhWD8+52LmGozqku2Y+UVc3OMZOcXX7VvS4X0pPMXDEl
80wZVH6VXsdCNas6lyfVI8xKx+l1PpO5dllQXeWzuut8Ug9uXtXZGhbHVzGk
PtK5Vj3+I7MuE9KnqyOZke9HsgNEk3xPkl3/a1/qac2uJJrKA2Feu/PpXjmv
a3ZTPWp+1WfXm7Iks1AZuPpk92xdoN2xkCwUV8XhtOf8u3q1I+X/mwwVyzm8
3yyfKRRJnA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 617->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG+gBxCvEE3xBVwEhLsSdR9dgCDpWVb/+usiHSUhm
pvpVdf/Lh+fN09kY4+Xi82OzvN7tdsvb/fn+x+Oyvbne7jevDmuM99tx/D6F
lZ55n2qQc1T7e15VfrNWxVJpKj7Hrh5Vj7K4+6lG527qycyr9JKf5LnLoM4S
TcJCzrl7pJ7jIrxdFsrX0Uh+XI+SX6I5n017zoO6T3pP/NPMXD6VHuFNWZLM
KIvzoWolhmqeSPY0S8VCZpruU10yH11W17vETHJO+al7VS6kJum5Y+r0s8vg
8lN6FQvVVOdSnlSPMDudpFf57PS1yoLqOp/qbvJJPaR+qb01LIlPMXR9dPuq
avxHZlUmpE51jmRG3o/ODBBN8p50Zv2vdamnNbPS0XQeCPPame/OVfK6Zjbd
4/p31Dws0nPCErNo5E7/S1nYc5Nvwk7mlvRRasHMf/TNeHUs6vyvp8jQsZzC
+mL5AANuSNs=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 618->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhZssxGuE3EAPILnCeIIRkpUgjIuQXY6eqEGS5tWrryYBbWh/
pqtfvZ+ax91heH1orR2XXx/D+PY8TeP7dnH68zLu16v96fDpe7f2sWnX73vY
bvXnFIPUUeyffmX+9VgZlwxT8Yu4/1qby1b9KJe+XvYxnLO7LpOer8Jzepzm
KgdVSzAJF1IX3SP9Il6Eb5UL5VfBcHqijJxegtnXurNIg7pPsif6qWeRPxke
4eu8JJ5RLpEO1ctxyOaJeE+9VFzITNNzW2/mkORFPSBZnhf02fmn7mW+kJ4k
84hTJc8qhx7D4WVcKKbMzvhJ8QjnCMfhZToruWZeUNxIp7rrdFINLi91NoeL
46c4VHVUc1U9/sOzzBPSJ6sjnpH3ozIDBJO8J5VZ/2tfqmnOrFQwIw2E89yZ
r86V0zpnNqMV5ad+u96Ui/Wi4Dt95rywtQXsjAvxwmqFnvdZKcyIi6qnz8gM
3XpfuHwCbwFKGg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 619->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRD8uxGuIN9ADBK8QTzCCrgJCshB3Hl2DIuGnqvr14CIDk8nw
/69+Vd1z+/y2fb0aYxxuvn+2y/vjfr98PF0fX16W3cP97rh493uP8bkZf89L
uNM1r1MNso9qn+ZV5TdrVSyVpuJz7OpS9SiLO59qdM6mnsy8Si/5SZ67DGov
0SQsZJ87R+o5LsLbZaF8HY3kx/Uo+SWa89605jzM50nfyVwoX4SFZkI8kn5X
mVEW50PVSgzVPJHsaZaKhcw0Xae6ZD66rK53iZnknPJT56pcSE3Sc8fU6WeX
weWn9CoWqqn2pTypHmF2Okmv8tnpa5UF1XU+1dnkk3pI/VJra1gSn2Lo+uj2
Vdb4h8yqTNR/OS8bz0MyI98HnYEBNcl30pl16oXUTjmtmpWGpvNAmNfOfNWH
WT95pRrpm3D1ujPgNAh7NT8uA6eV9FUWndmo2Mnckj52tdR78lrlfLp+dhUZ
OpZLuH9YvgAwAEjd
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 620->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA0EQRZssJNcI3kAPELxCPMEIugoIcSHucvQYSYaZtv6vVxMXNrQx
dPev939VNi/vu7dVa+1j/f1nN3w+HQ7D1/Pd+cvrsH982J8P7y+7teO2jZ//
YbvVn1MNco9qT/PK8mvdWcaSaUZ8in22LixRPcrS3w/rGOY+F+en99HzRizO
j/NcZYjuEk3CQu6pd6Se4iK8VRbKV9FwflSPnF+i2d91Z8rD7P1k/m/Zyhdh
GRfQyzySfmeZqbouS6WZ/a+8UK+KwXl3M1dhiM6pLpmPKqvqnWMmObv8ondZ
LqQm6bliqvSzyqDyi/QyFqoZ3XN5Uj3CrHScXuaz0tcsC6qrfEZvnU/qwfUr
OlvC4vgihqqPal9/1bjuGzPLMnH50XkhmZHfB52BBjXJ76Qy69QLqe1yKs9K
UVN5IMxLZ746V87rktlUS/Vv1JzMm6tNWSozqTJQWk4/yqIyGxk7mVvSx6pW
9N15zXKens/WdRaErmP5692WvPlhOQF6kEkW
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 621->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhRsXIdcQb5AcIOQK5gQjmJUQMIvgzqOr8QenrfenGxvGRLv7
1fde1UwXP/PvSWvt93X/MR/+PtfrYfP1cviyHFbvb6vD5uz0tLb9aJe/z/Cw
1e+7Gs45V/s6L5Vf6/YUi9Ks+BD7aJF6Lkt/vqxDmNVd1pOet9JjfpjnlKE6
62gm+bNz6J5TD3E5vCmLy5doMD+oR/8rYEFL1WUeRveNnrtz0dd2WS7L0FMe
nX6rzFBdliXSVP8jL65XxMC8s5lLGKp9V9eZj5QV9Y4xOzmz/Kp7KhenptNz
xJT0M2VA+VV6isXVrM6xPF09hxnpMD3lM+mrysLVRT6ru8yn64H1q9q7h4Xx
VQypj7SvNzXOz4OZqUxYfqM7xLuTmfN+JDPgaDrvSTLrj9Z1PcWzEmoiDw7z
vTOv+tDrM6+uBnsnUL2bvosZQBoOu5oflAHSYvpVFslsKHZnbp0+plrVd+ZV
5Xy97/6mWJ7hObLsAPyXS1c=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 622->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01OwzAQha0uUK9RcQM4QMUV0hMECVaRkMICsevR2wRUBWfez7gsYslt
U9tvvvc8Obx+dO+7Usrn/vrR9V8v49h/nx6mh7d+eH4apsXH31nK+Vhu31uY
bNTrroazz9Ve5qXyq7UUi9KM+BD7aoB6Lku9H9WRGSwn8FP7qHkjFuaHec4y
RHsdTYfF2YfOOfUQl8ObZXH5MhrMD7qjeSRY0FB1mQflpWVGtV0WdBb9p/hZ
lk5mLgvyEdViDKqfnOzdLCMWp6fddbo/0Ycot2xvoyzmYebM8ovOqVzq9UJ8
tTBl7pPtdzSYnmJxNcO7Y3maeg4z0mF6ymfmXlUWri7yGZ1lPl0P7L6itRYW
xhcxZH1k7zWs8Q+ZqUyi32G/EO9OZs77kekBR9N5TzK9fm9d11NTryQ0kQeH
ubXn1T3U+syrq8HeCVRvde+iB5CGw676B2WAtJh+lEWmNxS707fOPf45Z2hF
z8yrynm5vhoiQ8SyhfnDcgHqtEfZ
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 623->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA0EQRZssxGsEb6AHEK8QTzCCWQWEuBB3OXrMMEimqf/rVZuFDZNk
0t2/3/9VvX372O03rbXP+5+P3fT1cjxO3693l5f36fD0eLhMPixPa6fn9vv9
Hx43+nmqQdZR7eu8svx6rYwl04z4FPtqBHpVFrW/H2kGhln56HkjFufHea4y
RGuJJmEh69Q+cp7iIrxVFspX0XB+VI3mUWBRIzvXeci8jDzR2ZRF7VX/Zfwu
S5IZZVE+orMcQ9ZPJHuaZcRCeprOq/VteWgfqtyqva2ymAfM2eUXek1y6eeb
8TXCVKmnW080nF7GQjXD2rk8oR5hVjpOL/NZqWuWBdVVPqO9zif14OoVzY2w
OL6IoeqjWtfwjBtklmUS/a72IcmM3I9KDxBNck8qvf7Xc6mnoV4paCoPhHm0
57M69PrOK9Vwd0KdV+0BpUHYs/5RGSgtpx9lUemNjJ30Lanjah/Qit6d1yzn
6/nVWHiUbtZDN703I3tmljPexUhZ
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 624->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA0EQRAc/xGuIN9ADiFeIJ1jBfAWE+CH+eXSNLrLbVFe/XgUd2Ohm
ZqpfVXcuH552+7MxxvPFx8duerk7HqfX+/PTy+N0uLk+nDav5meMt9vx/fc/
PG7FfapBzlHtZV5VfiPsVSyVpuLL2FdrZlH1KEs8L+sY5piL8xN9RF7F4vw4
z10GdZZoEhZyLrtH6mVchLfNAvmcRsWiPMn3MP+OJVtVXedhdR/0nM5FrE1Z
srvZd043q7u8V2VGWTIfqpZjqOaJZE+zVCxkpum+PW/mkPSLZkB6+blgzi4/
da/KhdQkPc+YOv3sMkQNp1exUE3ZO5Mn1SPMmY7Tq3x2+lplQXUzn+qu80k9
uH6pvS0sjk8xdH10+ypr/EJmVSbq/9X5xUNzTrWKe50ZIJrkd9KZ9Z/WpZ42
zUpDM/NAmLfOfNWHqO+8Ug33m8jqdWcg0yDs1fxITqPl9FUWndmo2Mnckj52
tdS781rlvNxfrTn7TLeaob9+vljeAZmrSNU=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 625->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhZssgtcIuUE8gHgFc4IJxJUg6ELc5eiJImGmrVfvq4mLDLR/
3f3qe6/Kl4/9ZvvUWjsufl42w2l9OAzn9+fLl89ht3zbXTZfb6u1r1X7ff8P
K3v6fapBzlHtcV4uv17LsTjNiE+x3z2iHmXpz6s6LoPrb8ZP76PnjVgyP5nn
KkN0lmgSFnJO3SP1FBfhrbJQvopG5kf1KPNLNPuz2Z7yMLkPek7nIvJFWGgm
xCPpt8uMsigfUa2Mwc0TyZ5mGbGQmab76nwbzVrP4uaJsqreZczOo8sv9Gpy
ITVJzxVTpZ9VBpVfpOdYqGZ0LsuT6hFmpZPpOZ+VvrosqK7yGd3NfFIPWb+i
vTksGV/EUPVR7WtY4wGZuUyiz3f6t0VzVlruXmUGiCb5n1Rm/a91qadZs1LQ
VB4I89yZd33o9TOvVCP7T6h61RlQGoTdzY/iVFqZfpRFZTYcO5lb0sfJPaCV
5aPyy2qP9ycPyFCxPHq1OXeuLN+oY0jZ
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 626->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0tuAjEQRK0solwj4gbJAVCuACcYJFghRSKLKLscPfyEBqe76vXMBksG
BtvlV9U9r5vP1e6ptfb1cvxYDd8fh8Pws34+PWyH/fvb/rS4uM7Wfpft9v0I
U41+nWqQfVR7nJfLr9dyLE4z4svYoxHdR1my8+qO7Kzz0/voeSMW5Ud5rjJE
e4kmYSH7XJZT3gnCW2WhfBUN5Ser0XksL5OwZMPdqzzcnQc1p33R301ZsrPZ
f0qX1NtlRlkyH9FdisH1E8meZhmxkJ6m63K/6ENSL5oBqaXLjOYXnXO5kDtJ
zTOmSj2rDFl+kZ5joZrRPpUn1SPMmY7Scz4rdXVZUN3MZ3RW+aQeVL2itSks
ii9iqPqo1lWxzMnMZRL9pj02pe9IfZSfimbFA+n1ufdST3N7hXBk74Rjntrz
rg69vvJKNdQ7kd33r+7jKe6mLJWeDDkTFlLPzDvpDcdO+pbUsaoVPSuvLufx
+t0AGWYsjzAvLH8hcUoY
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 627->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlE1OAkEQhSsuiNcw3AAPQLzCeIIxgRWJybgw7jy6IkKGpt5PNQvopCEz
3f36e68Knt7eh+1DRHw8/n4M4+fLNI1fr4v9w2bcPa92+8Xl/4z4Xsfp+x4m
G+26q+Hsc7Xnean8Wi3FojQzPsSejew+lwWdZ3dUzrKatLyZHvMDz3UwZHud
OimWI49kBprOfYjL4a2yuHwVDeYH1ehvFFjQUPcyD8pLz8zudlnQWfRO8bMs
ncxcFuQju4sxqH5yskdnTgPsdXvaXUf7o5lOf1RZUe0Ycxj6LYvKRuXCzrqT
MVXqWWW4yI/oKRZXM9vH8nT1HGakw/SUz0pdVRauLvKZnWU+XQ+sXtlaDwvk
W8fZf4zS7ZnIS8pyZWYqE5af6rGevnPqw/xUNCsenF6/9l7XU1evFDSRB4e5
t+dVHVp95tXVYL8JdF+au1lzh6XSkykn0WL6WRaV3lDsTt86daxqZc/Mq8p5
vu6+c3ro1vPA8gOfqEpV
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 628->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01Kg0EQRAcX4jXEG+gBxCvEE3yCWQWEuBB3Hl2jISRtd9XryUI/mPxN
T82r6s7108tqfTHGeL36elktbw/b7fL+eLn78rxs7m43u82b/Rrj434c3v/D
Uk/cpxqkjmof5+XyG2HPsTjNjK9iP3n2LNl9lCXWp/cI5piL8hN9RN6MRflR
nrsMWS3RJCykrjpH7qu4CG+XhfJ1NJSfqkfKL9GMtWqv8uC8zKzKF2GhmRCP
pN8uM8pS+cjuUgxunkj21ZnDU9TSmab7rv77Hc5Hl7XqnWIeQD+yuGxcLuos
XYqp088uw6/8hJ5joZpZncqT6hHmSkfpOZ+dvrosqG7lMzurfFIPql/Z3gyL
4hti5juZzcyv8jiTmcsk+0xnbGbuSH+Un45mxwOZ9XPvpZ7OnRXCUf0nHPPs
zLs+RH3llWqo/0R1X3cGKg3C7uanyqDSUvpZFp3ZcOxkbkkfT84Brey78upy
Pt6nv5EZ+uv1w/IJ+/dMFg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 629->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlEFKQ0EQRAcX4jXEG+gBPrlCPMEXdBUQ4kKyy9GTYAw/Q1f168lCP3TC
T/dUV1X35PHtc/1x11r7ejh+rOfv1XY7717vTy/v8+bleXNKPp2jtf3ULt//
IdzT5ykGqaPYS78y/3qsjEuGGfFT3KMn6ke5qPOuhzqb6el19HwjLk6P09zE
nBSHqJboolyyuszLkTtB+Fa5UH4VDKdHzcjpJZh9rcspDZmWkVC6CBfqCdFI
5p15RrmEOqZ2ucOqL9FCtVIvVS3daZrP6vdnf8h+VLmq2TnOxOe+PjuX+UJ6
kpkrTpV5Vjko/9yuuXkRzKjO+UnxCGeF4/AynZW5Zl5QXKUzOut0Ug1uXlFu
hIvkN7Wr/5gMdySUlquaZdzgWeaJ8y/bsZG9I/NxeiqYFQ1k12/tSzWVd6WI
qTQQzqM7n82hx3daKYa7E6pf6PtvmN6US2UnlQcKy+FHXlR2I+NO9pbMsfc9
w4rendbM52We/kZ26K/jh8sBeMpN0Q==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 630->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uqAjEQDC7Ea4g30AOIV9ATjPBcCYIuxJ1HV/GDxq5Pxwc6EGWSTnVV
dc1wuZmveqWU3eD8M+/2s+22Oyz6l5e/bj0Zry+Ho9sq5Tgtj/9fWOypz10M
p87FfvZL+VdjKS4KM+KHuEdP1M/lgu6zHuiu0lPrqPlGXJgepjnLIap1MB0u
Tp3ysuWbcPhmubj8MhhMD5pRlgt6VF+mQWlpWVFvlwu6i/YUf+Wx8szlwnTU
+4yDypPjvfQS1LqZds9l/fSdi8qTyxXNjnF2fK7r1T3li9PTmTnilJlnlgPy
L8JTXFzMqI756eI5nBEOw1M6M3NVXri4SGd0l+l0NbB5RWctXBi/QjKf8awl
vy/7/+CZ8oT5pzLWkjtnPkxPBjOjwcn6p31dTU1ZSWAiDQ7n1syrOdT4TKuL
wb4J1C/0/b5Ib5dLJpPIA4TF8CMvMtlQ3J3cOnPMYkXvTKvy+fnc3XMy9O11
5XICZaxN1Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 631->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01uwjAQhS0WFddAvUF7AMQV0hOkUllFqhQWiB1Hp1HTKjjzfsbtgkgG
Edtvvvdm2L1/dsdNKeW0/fro+vNhHPvL29P046MfXl+GafN5XqVc9+X3+xEW
e+p9V8M552ov81L51VqKRWlGfIg9eqJ6Lgu6z2rAu8JP7aPmjViYH3jvZyUY
orNOnxTLMhfKDDSdeojL4c2yuHwZDeYH9SjLgh5Vl3lQXlpWVNtlQXfRu9X7
ZL9VZi5L6GPmqd8zBjVPTvYyS3DWnWl3X55f9IvVR7llZzvMItDOsKh7Khen
ptNzxJTpZ5YB5RfpKRZXMzrH8nT1HGakw/SUz0xfVRauLvIZ3WU+XQ+sX9Fe
CwvjK2TmM5m1zO/d+3/ITGXC8lMz1jJ3Tn+Yn4xmxoMz63+t63pqmpWEJvLg
MLfOvOpDrc+8uhrsP4Hqrfo+L6fnDktmJlEGSIvpR1lkZkOxO3Pr9PHunqEV
/WZeVc7L/dUjMkQsj7C+WW5+2UrT
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 632->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlk1qAkEQhQsXIdcIuUE8gHgFPcEIcSUEdCHucnSV6DC29X6qs3GgFfvn
9fde1YAfm5/VdhYRh/fLx2o4Lvf74bR+u/74Hnbzr9118fM2In4XMX6/wmBP
u+5qOPtc7WleKr9WS7EozYwPsWdPdp/Lgs6zO9BZ5af10fJmLMwPPNfBkO11
fCmWO49kFln2vBMOb5XF5atoMD9Zjcb6FljQo+5lHpSXnpHd7bKgs2juab5Y
b5WZy4J8RDLPGFQ/OdnLLMFet6fddbnf7EOUW7W30ywS7QqLOqdyce50ao6Y
KvWsMqD8Mj3F4mpm+1ierp7DjHSYnvJZqavKwtVFPrOzzKfrgdUrW+thYXyx
CPh/qpJZT/+O89NxY+rJTGXC8lM91tN3Tn2Yn4pmxYPT6/+91/VU7pWiJvLg
MPf2vKpDq8+8uhrsnUD3PdVd9ADScNhV/6AMkBbTz7Ko9IZid/rWqePDOUMr
+828qpyn6+6cYnmF8cdyBgoiSVU=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 633->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVUlqw0AQbHII/kbID5IHiHxBfoEM9kkQkA8htzw9kQnGGrqWHucQgSw0
M11dVV3CT4f38fQQEefdz884fbwty/S5f1xfjtP8+jKvm8+/d8TXENfnf7jZ
1e67GM45F/vWL+Vfi6W4KMyMH+KeXVk/lwuqZz1QrdLT6mj5ZlyYHlVX4ZCd
dXQpLhXOTtYq34TDt8rF5VfBYHo2M0qeLhd0qb5Mg9LSc2e9XS6oFq0p/sxL
xzOXC9IRyTrjoPLkeC+9BGfdTLv76rybQ+RbNdupFwl2hYuqU744PZ2ZI06V
eVY5IP8yPMXFxczOMT9dPIczwmF4SmdlrsoLFxfpzGqZTlcDm1e218OF8QuS
+YpnPfndrA+x+T/o8Ux5wvxTGevJnTMfpqeCWdHgZP3evq6mrqwUMJEGh3Nv
5tUcWnym1cVg3wTqV80AwnC4q/wgDxAWw8+8qGRDcXdy68xxU2dgZe9Mq/L5
dt9dczL0p99NT82FyzfDhkuW
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 634->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0Fqw1AQQ4csSq8RcoP2AKZXcE/gQrsKFJxF6C5HTx1CMD8aSfPTRQ0/
wf7+mifNePvxPX5tIuLw/PszTse3eZ5+3p+Wm89p//qyXzZ31xVxGuL2/x8W
u9p9V8N5z9Ve56Xya7UUi9JEfBk7ulA9lyU7z2pkZ5Wf1kfLi1iYH3WuwoDe
dXwplgqzM2uVb8LhrbK4fBUN5gf1iNVkz5mGo4++EafXlYVquyzZ2exZphtm
v1VmLkvmI4bVAnUtL2LfzRLds5kr5W3UU5k58+SyZr1jzMojYlHnVC5OTafn
GVOln1WGLD+kp1hcTfQey9PVc5gzHaanfFb6qrJwdTOf6Czz6Xpg/UJ7PSyM
L8jMVzLrmV/E8khmKhOWn5qxnrlz+sP8VDQrHpxZf7Su66l7VkzNzIPD3Dvz
qg+tPvPqarBvIqt313cxA5mGw67mB3ISLaaPsqjMhmJ35tbpY1UL3TOvKuf1
vvtMsfz1ip4zF5Yz7jFJ2Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 635->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlE1qAkEQhQsX4jUkN0gOIF7BnGACyUoQdCHuPLoxiIw99X6qzcKBVsae
fvW9VzUuv3abn1lEHBa/H5vhuN7vh9Pn/HrzPWw/3rfXzbfbijiv4v79Cotd
7b6r4Tznao/zUvm1WopFaWZ8iD27snouCzrPaqCzyk/ro+XNWJgfda7CkD3r
+FIsFWZn1irvhMNbZXH5KhrMT9YjVpP9zjQc/ewdcXpdWVltlwWdRb8h3TD7
rTJzWZCPaFjaZywvYt/NMrtnM1fK26inMnPmyWVFvWPMymPGos6pXJyaTs8R
U6WfVQaUX6anWFzN7DmWp6vnMCMdpqd8VvqqsnB1kc/sLPPpemD9yvZ6WCDf
Kib/vz0+qn2d1BivJzJTmbD81Iz1zJ3TH+anolnx4Mz6s3VdT+VZKWoiDw5z
78yrPrT6zKurwd4JVG/SdzEDSMNhV/ODMkBaTD/LojIbit2ZW6ePD+cMreye
eVU5j/cfrtEsZLqM5b9X9Jz5Y7kALJ1K1Q==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 636->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlE1qAkEQhRsXkmtIbmAOIF5BTzABXQkBs5DscvRETMRp31+NGwc6YWa6
X33vVY2L94/NftZa+3z5/bMZTuvjcfjazs83u+HwtjycX77+rda+V+36/xmW
uvr3qUayL9W+zcvl12s5FqeJ+Bg7ulC9lIWdVzXYWeen99HzIhblx52rMKC9
iS/HUmFOZq3yTSS8VZaUr6Kh/KAeqZrqudJI9NE3kvS6slDtlIWdZc8cv8vY
ZZayKB/9c8Xg5inJnp1B92rmKgxJPcgZzkeVlfVOMTuPiMWdc7kkNZOeM6ZK
P6sMLD+k51hSTbRP5ZnqJcxMR+k5n5W+uixSXeYTnVU+Uw+qX+jdFBbKt2qj
3xinO2UxL6M9/+vBzFwmKj83Y1PmLumP8lPRrHhIZv3Ruqmn8qwUNZmHhHnq
zLs+9PrKa6qhvglW767vZgaYRsLu5odlwLSUPsqiMhuOPZnbpI+jc4EWulde
Xc6370dXkCFjeYZ1YfkBemtMlg==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 637->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlE1qAlEQhJssJNcIuYE5wOAV9AQjmJUQMAtx59H9iYp5VldVPzcOPHVm
3qv+qrrxY/kz/36LiN/348d83M42m3G3mJxuVuP6a7o+vfy8rIj9ELfvV1js
at+7Gs4+V/s+L5Vfq6VYlCbiy9jRheq5LNl5VgNmYPhpfbS8iIX5QefiuooM
aK/TJ8bS5kL3JZpOvYzL4a2yuHwVDebnfA1gFVmyi+1ReSkvPQvVdlmys9kz
xa8yVpm5LMxHkLqOF9eryhLds5mrMDj1VGbOPLmsWe8Ys/KIWNQ5lYtT0+l5
xlTpZ5Uhyw/pKRZXE+1jebp6DnOmw/SUz0pfVRaubuYTnWU+XQ+sX+hdD0vK
N8TD/2+Pj2pfH2pc15OZqUxYfmrGeubO6Q/zU9GseHBm/dm6rqfyrBQ1Mw8O
c+/Mqz78+y28OhosG6QN78mMpmcES2UmW84QWkwfZVGZDcXuzK3Tx6oWumde
Vc73791niuUV1h/LAfVCSlM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 638->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lOAzEQtDggvoH4ATxglC+EFwwSnCIhhUPEjadDRiwZU1ubHLDkTMbu
rq6q7rl+eN4+XbTWXq4+frbzYbPfz6/3l8eXx3l3d7s7Xt587tbepvb9/A9b
rf4+xUjiUuxTv5x/PZbj4jARP8YdLVQv5cLyVQ3nAdPT60B5qobTtfwX3BUH
pUfpUly++ERxBDOpx3glfKtcUn4VDKVnWVP3FDXVOVoqxvnltIxsVDvlwnLZ
2a/zYr+dZykXqGP62axuMuPuPvGydbxQbDrT6b2LP+2Xqs98q842ekfYFS4u
z/mS1Ex6zjhV+lnlwPxDeI5LionilJ8pXsKZ4Sg8p7PSV+dFist0olylM9Wg
+oXuRrgwfstTzHzFs5H5XZ2fwTPnifLPzdjI3CX9UXoqmBUNyaz/tW6qaWhW
CphMQ8J5dOZdH3p8pTXFUN8Eq8dmMOl5wqUykz1PxK/ST6Y9mQ3HPZnbpI+r
vAALvSutjAuKX63AQ8bl3LuN5Cxc3gF+O0fX
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 639->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0EOgjAURBsXxmsYb6AHIF4BT4CJrkxMcGHceXRFDErz/8z8sqFJIUA7
fTP/sz5e6/MipXRbvS91c9+3bfM4LLuHU3PZbS/dx813pvSs0nCfw0Qj/65q
KOtU7f+8WH65FmNhmhafxz4aVT+t81SWfL15DmAengU/uY+c12JBfti+CIO1
VqkTZQkwK70W+ScU3iiLyhfRQH5GNSKe2HtPG52LPDAvJdM6W2Xx9nrvGD/L
mGWmsiAfCZyreFG9siyH4axVe1r9ztbn2Sj9pLJ6tUPMzKPFwvaxXJQzlZp7
TJF6Rhm8/Cw9xqJqWutQnqqewuzpID3mM1JXloWq6/m09iKfqgdUL+tbCYvH
97mDno9kVtK/yGNJZiwTlB/rsZK+U+qD/EQ0Ix6UXp96ruppaq8oHN4/wZhL
e57VIddHXlUN9E9453k9qNRcYYn05GhUv7unhfStLMw1IOdIH6FsUZZDfv8T
aFnPyKvHYq1X3zGWOcye5QW3tkhX
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 640->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhQsX4jXEG+gBxCvEE4ygq4AQF+LOo2vQEdN5f9XZJNAJme5+
9b2qN9dPr5uXi6p6u/r+2izvD7vd8vF4uf/zvGzvbrf7zZvfVfV5X3+/57DU
Z9yH94FGUivR/n8P/R5pD3uOJdIsrKm8rCyoXsoynmd1GHPSf+Zj5EUsyo+7
12FAZxNfjqXDrHqZZF31YYYlyRbTV34cC/JU6xKe3HOmreoqD87LzEK1UxZ2
lz1z/K7Hrmcpi/JRom7iJfXqennEBViSTKf77vzYmyRPKSubnWJ2HhGLu+f6
ktRMZs6YOvPsMrD+IT3Hkmqic6qfqV7CzHSUnvPZmavrRarLfKK7ymfqQc0L
7c2wMD6X+U7PZvKrPM70zPVE9c9lbCZ3yXyUn45mx0OS9VPrpp5OzUrCwd4J
xzybeTeHUV95TTXUO8HqsQwmM09YOpkcORFfZ57Me5INx57kNpnjwb11CS30
X3llLOh8+syxnMP6YfkCCeRKGA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 641->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLKQXCN4Az2AeIV4ghF0FRCShWSXo2tQZOyp3+vZpKGn6c+r
V/Veze71Y/++aa2dtt+f/fT5fDxO55e76+ZtOjw+HK6X97+ztctT+1tvYarR
38N4gJHkSrDncWhV2K7OazGVFoZV4dK/r+RhuZieXkfPF3FRelxchQN6m+iq
1N9xVrVMvK7qMMIl4cjwlR7HBWmaryqnOmfYKq/S4LSMTJQ75cJi2Znj72rs
apZyUTqayJtoSbU6DoszwCXxdHrv3qc+ZHWrehvtEXaFi4tzdUlyJj1nnCr9
rHJg9UN4jkuKid6peqZ4CWeGo/CczkpfXS1SXKYTxSqd8D3Jgwbr5QiXhabZ
VJ6v1GzEv0qjw2Mj9WSiKcVEWC6u4oEEs6Ih8fravKmmtV5JeLB/wnEe9bzr
Q4+vtKYY6p9g+ZgHk54nXCqe/DeILyv9ZNoTbzjuiW+TPi7iDBbaK62MC3qf
njkutzB/uHwBMqNHnA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 642->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbFyEXENyg+QAkiuYE0wgrgTBLII7j55IPoyd+r2ejUI7TPfr
elX1atavh+1u1Vp7v//6204fz8fjdHq5u7y8Tfunx/3l8OFntXbetL/nLSz1
689TjKQuxZ77pfxDWI7LEkylhWFVuPT1lT5XfAM9vY6eL+Ki9KB77XcVOaDa
ZE7Of1bL6hrpOfJNJHyp7zMvE0/SHCZckKb5U/VU+wxb9VUanJaRhXqnXNhd
tvdvP5jV/J7zLOUCdXT5Q32TjLvzxMuG9gCXJNPpuatPc8h8q2YbvSPsChd3
z/mS9ExmzjhV5lnlwPxDeI5LionqlJ8pXsKZ4Sg8p7MyV+dFist0ortKZ6pB
zQudjXBh/FzmK56N5FdpHPHMeaL8cxkbyV0yH6WnglnRkGR9ad9U09KsJDzY
N+E4j2bezaHHV1pTDPVNsH4sg8nMEy6VTF79SC4r82Tak2w47klukzki/xQW
eldaGRdUn+45Lrewvrl8AkwCRZw=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 643->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqwzAUFF2EXqPkBukBTK/gnsCFdmUoOIvQXY/emhTXEW8+T9rEoARL
T/Nm5o2f3j7Hj4dSyvnx92ecLi/LMn29HtaX92l+Ps3r4fFvlfI9lO3/HhZ7
6nMXw6lzsfd+Mf8iLMWlB5NpQVgZLnV9pg/qhfTUOmq+ERemR93LcIhqHV0O
l9461Q/xcvj2cGb8MhhMz35GSpPaR9isL9OgtLSsqLfLBd1Fe4q/8lh55nJB
Ooro62hxtTIvS7QXcHEy7Z6rejeHyLdstqP3CDvDRd1Tvjg9nZkjTpl5Zjkg
/yI8xcXFjOqYny6ewxnhMDylMzNX5YWLi3RGd5lOVwObV3TWwgXxU5nPeNaS
X6axxTPlCfNPZawld858mJ4MZkaDk/Xevq6m3qw4PNA3oTi3Zl7NocZnWl0M
9k2gfiiDzswdLplM3jwgl5l5Iu1ONhR3J7fOHDf/qhk4nkdzU/UoI9v+8L+U
h4jLPawrlx9Gc0oa
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 644->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVEtuwlAQe+oCcY2qN6AHiHoFOEGQYIVUCRYVO47OpwjBxB57kg1PeqAk
8zy2x8nn+ne5/WitHeaXn2X/97Pf98fV7Hqx6Xffi9314dd9t3bq2uP/HXa2
4nMXw6lzsZ/9yvxDWIrLFMxMC8OqcIn1lT6sF9MTdUS+iEumR52rcEC1ji6H
y9Q61Y/xGugtco71mSduDjMtSM9tdU87mYG6j1ZWo2astIzZqLfLhZ1l9xR/
5bHyzOVS1cE4qDw53rMz8R7i4mTafa7q3Rwy36rZRtcIu8JFnVO+OD2dmTNO
lXlWOTD/EJ7i4mKiusxPF8/hzHAyPKWzMlflhYvLdKKzmU5YT/qgxWY5hstA
E+GicMdspiXLq4PHlptJR5OLibDUuUoGHMyKBifrU/u6mqZmxeHB3gnFeWzm
1RwifqbVxcjeCdaPZdCZucOlksmX1bWX7xPCyvCRF5VsDK4LXBwvIq8WZuB4
juam6llGGAbDzbi8w/7ncgZDL0ea
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 645->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN9ADDF4hnmAEXQWEZCHuPLrGqBmb91c9mwx0hnRX
v/peVc3N0+v25aq1dth8/Wznt4f9fn5/vD7+eZ5393e74+Htz2rtY2p/70tY
6unPU40kLtVe1kvVD2k5ljWaygvTqrD08ZU8LBfz0/voeRGL8uPuVRhQbOIr
YVkb5/IxroR3DbPiq2goP9/PdFrOk9tHj4qBfMtlvIwslFvl+T1j3GrP8bsa
u5qlLFUfjMHNU1J7dqffQyzJTKfnLh693TylrKx3itl5RCzunqtLkjPpOWOq
9LPKwOqH9BxLqoniVD1TvYSZ6Sg957PSV1eLVJf5RHeVz9SD6hc6G2FhfG7m
KzUbmV/lcaRmriaqfm7GRuYu6Y/yU9GseEhmfW3e1NPaWUk42DfhmEdn3vWh
11deUw31TbB8bAaTnicslZn890znN9NS+qgWMEbUGcUlLEkteq6lX6WF/iuv
jAXFp3uO5RLWieUTNB5HWw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 646->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tOAkEQ7PhBvIbxBngA4hXwBGuCX5uY4Ifhj6MDamAYux69yweTDBtm
e6qrqmuf3j/XHw8R8fV4/FkP36/b7bB7W5z+bIbxZTmeXj7/7Yj9Ks7Pe9hs
9e9dDKfOxW79Yv5lWIrLHEymBWFVuPT1lT6oF9LT6+j5ZlyYHnWvwiGrdXQx
LtFshzPzcso34fCtcnH5VTCYnp/VeMg0qfNssZqUH8jurXbWm/VpuaC76Ozf
eXHeyjOXC9IRoq+TcfXe8TLaDfi6mXbf03rgncqTyxXNjnF2fO7r1T3li9PT
mTniVJlnlQPyL8NTXFzMrI756eI5nBEOw1M6K3NVXri4SGd2l+lM60GfbKFZ
TuGC+KnMVzybkl+mUeGh5WbS0eRiZljqXiUDDmZFg5P1uX1dTXOz4vBA34Ti
PDXzag49PtPqYrBvAvVDGXRm7nCpZPJqrS5PhMXwMy8q2VDcndw6c8zuMazs
P9OKuGT17pnicg/7l8sBXghG2Q==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 647->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0kKAjEQDB7Eb4g/0AeIX9AXjKCnAUEP4s2nuzJI6Fo6c3Egykw61VXV
lfn+tD1OSimX2fNn210353N3201fL4euXy371+biu0q5r8vw/w+LPfW+i+HU
udi/fjH/IizFZQwm04KwMlzq+kwf1AvpqXXUfCMuTI86l+EQ1Tq6LC5mHfOy
5U4gvWO4uPwyGEzPwN2YgfqOsFlfpkFpaVlRb5cLOou+Kf7KY+WZywXpKKKv
o8XVyrwsvwvwdTPt7qt6N4fIt2y2o/cIO8NFnVO+OD2dmSNOmXlmOSD/IjzF
xcWM6pifLp7DGeEwPKUzM1flhYuLdEZnmU5XA5tXtNfCBfFTmc941pJfprHF
M+UJ809lrCV3znyYngxmRoOT9bF9XU1js+LwQHdCcW7NvJpDjc+0uhjsTqB+
KIPOzB0umUzWPN8PwWL4kRe0NoGtuDheRLyGx/Q8mpuqRxlBGAiXcfmH9eHy
AHuFSRo=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 648->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQbPwIuYZ4g3iAkCuYE6yQfAmCfkj+PLpRN0EmXY+ezccujLIz
PdVV1bXL7X7zuYiI4/P3z2Y4vR0Ow9f70/XlY9itX3bXw9W4Is6v8fs/h8We
9tzFcOpc7Ee/mH8ZluIyBZNpQVgVLm19pQ/qhfS0Olq+GRemR92rcMhqHV0O
l6l1qh/i9UfvuP6LM+NXwWB6HrmrGah9hM36Mg1KS8/Kertc0F20p/grj5Vn
LhekI0RfR4urVXnZ7mVcnEy756rezSHyrZrt7D3DrnBR95QvTk9n5ohTZZ5V
Dsi/DE9xcTGzOuani+dwRjgMT+mszFV54eIindldptPVwOaVnfVwQfxU5iue
9eSXaezxTHnC/FMZ68mdMx+mp4JZ0eBkfWpfV9PUrDg80DehOPdmXs2hxWda
XQz2TaB+KIPOzB0ulUy2PG8PwWL4mRe0toCtuDheZLx+9EZS585N1aOMIIwQ
2cy4zGHduVwAEZdJ2Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 649->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk00KwkAMhQcX4jXEG+gBxCvoCSroqiDoQtx5dP9FxryftC4cGGXazMv3
knS83i23g1LKYXT9WTbHxX7fnFbD22HTtLNpe3s5ee5SzvPy/v+HzVb93tVw
4lztz3qx+kVaiqWPJvOCtDIsdXwmD8qF/NQ+at6IhflR9zIMUazjy2HpG6fy
IS7k91fMjC+jwfy82Y0eqOdIm+VlHpSXLjvK7bKgu+iZ4lc1VjVzWZCPIvI6
XlyvqpbltQGvO9PuexXvziGqW3a2o3OknWFR91RdnJxOzxFTpp9ZBlS/SE+x
uJpRHKunq+cwIx2mp3xm+qpq4eoin9Fd5jOMB3mihXrZheXL0ytezHymZl3m
l3lUemi5M+l4cjUjLXUvMwOOZsaDM+t987qe+s6Kw4G+CcXcdeZVH2p95tXV
YN8Eyodm0Om5w5KZyZrzvogW049qkZkNxe7MrdPH6B7Tis7MK2KJ4t1niuUf
9oPlAtRBSBw=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 650->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqAkEQRZssgtcIuUE8gHgFc4IJxJUg6EKyy9HVRESb+vVfzbiwoRWd
7l/vV/15+9qu1i+ttf3s9LEaDsvdbvj5fD3/+B4284/N+eH7Zbf2u2jX72fY
2eqfUw1yjmrf9ivrX6TlWKZoZl6UVoWlP1+po2opP72Pnjdiyfy4exWG6Czx
RVimnnP1FJfy+yjmjM9pNOjHeaIsatG613Miu4/ayrPLm+tXNcdk3q5nlKXq
QzG4PJHeqzt/K+ElM60wuvPRt8sTZVWzy5idx4jF3XN9ITXJzBVTZZ5VBtW/
SM+xUM3oXNZPqkeY73Rgdp3PylxlLy6b6iqf0d2eQT27ZYnqREvNcgwL6W9U
u9KzMfnNPDo9tVxGqjkgmpGWu1fJANGseCBZn1qXepqaFcKh3gnHPDbzbg69
fuaVamTvhKqnMkhmTlgqmew5MxYyT+WdZMOxk9ySOUb3Mq3od+ZVsUTn6X+O
5Rn2P8sRUf1InA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 651->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FqwzAQREU+Sq5ReoPmACFXcE/gQvplCLgfJX89euq2mEadnZmV8hGD
YiKtZt/srh9fT8PbppTyvv36GcaPwzyP55eH5c9xnHbP03L49LtK+dyX9X0P
iz31uavhxLnaf+vF6oe0FEuPJvMSaWVY6vhMnihX5Kf2UfMiFuZH3cswoFjH
l8PSG6fyRVwObw8z48toMD8ZT2qfaau8KIfy0rIiz6p3ql63mAvkn9XMZcn6
iBjUPDm1j+7Ue4jFmWn3XMWjtzOvDmvUO8asPCIWdU/Vxcnp9DxiyvQzyxDV
D+kpFlcTxbF6unoO85WOObvKZ6avqhaubuQT3a21ozOVBz1RL1tYnPqi3Jma
tcwv89hSM1UTVj81Yy1z5/SH+cloZjw4s96b1/XUOysOR/RNKObWmVd9qPUL
mTVXg30T//KB/yuH2XOHJTOTNef3Q7SYPqoFjU1oKxanFoiL7cm+BV4jFhTv
7imWe1g/LBeA2Eqa
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 652->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1tOAmEMhRsfjNsw7kAXQNwCrmBM5ImEBB8MbywdiGiG2nPpjw9MUi4z
/U+/03Ye3zfL1V1EfD4cP5bT1+t2O+3e7k9/Pqb1y/P69PDpHBH7Rfx+30Kw
Kz93NZw8V3veL9a/SkuxXKPJvCCtDkvO79RBtZCf7CPzVizMjzrXYahyHV+M
JWbhMLNejrwTDm+XxeXraDA/HU/qPtNWdS9mGp6XkUCe1exUv/5jL7Ke6pnL
0vWBGNQ+Ob1HZ/K9isXZafe5yq++1T65rGh2jFl5rFjUOdUXp6Yzc8TUmWeX
AfWv0lMsrmaVx/rp6jnMSIfpKZ+duapeuLrIZ3WW+cz5QepUF5rlCMtFrZ8A
55WPbiAv874g70wPXe5OOp5czUpLnevsgKPZ8eDs+rV1XU+dXRnRRB4c5tGd
V3PI+syrq8HeCVTvz9zP4czcYensZObMv7vzRN7L3Ia2YnF6UXGxe3JuwCti
qfLde4rlFuKb5QAAfEga
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 653->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcXkmuIN9ADSK4QT/AFXQWEZBHceXQNisSmu+r1/E2EMZrp
X/2quv/dy/vu7WaMcdx8/9otp+3hsHw8357/eV32jw/78+X97xnj82n8fV7D
UT/xnmqQOqp9mZfKL9NyLGs0lZdKq8MS6zt9ql6Vn+gj8mYsyo97rsOQ1RJf
iAXWqSxn3gnC22WhfB0N5afjyX2vtF3frIfzMnMqz252Li+SYdxTl7HLjLKk
PgJP1pfsuLsnWY7LU/DSnab3sr7IjuwrYa1mp5hJzrHePedyIT3JzCumzjy7
DFV+mZ5joZpZncqT6hHmSkfpOZ+dubosqG7lM3tW+aQe1LyyuxmWf73M8zM+
unNVvddk5jLJ/qY7NrN3ZD7KT0ez44Hs+tq+1NPaXSEc1TvhmGd33s0h6iuv
VEO9E1W/agfJzAlLZycjp2Ih86y8p7UNbcdCssi41Hd0bq6+2pFKo9JVLNdw
fli+AHioR9s=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 654->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhZssxGsEb6AHEK8QTzCCWQWEuBB3OXpMFAmd91fdmzR0hkxX
v/peVc367WOzXbXWPu9/fjbL18t+v3y/3p3+vC+7p8fd6fDhb7d2eG7/z1vY
avXnqUYSl2pf1kvVD2k5lhlN5YVpVVj6+Eoelov56X30vIhF+XH3KgwoNvGV
sMzGuXyMK+GdYVZ8FQ3l57xCT+49WirmSqfL4byMbJRb5blkYXfZO8fvauxq
lrIwH6jvisHNU1J7dKehd4Almen03MWjp5unlJX1TjE7j4jF3XN1SXImPWdM
lX5WGVj9kJ5jSTVRnKpnqpcwMx2l53xW+upqkeoyn+iu8pl6UP1CZyMsSX1R
7krNRuZXeRypmauJqp+bsZG5S/qj/FQ0Kx6SWZ/Nm3qanZWEg30Tjnl05l0f
ev0mZi3VUN/EVT7wX80ou+NYKjPZcyqWpJ/MO4wtaDuWpBaI67w6FlVz1DcX
z2aEaTTCqlhuYf+yHAEe6khb
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 655->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN9ADiFeIJxhBVwEhWYg7j65REam8v+pxkYHOJN3V
r75XVbl6fNk+X4wxDpvPj+3yer/fL28Pl8cfT8vu9mZ3PLz+WWO8343f9zks
9dTzVCOJS7X/1kvVD2k5ljWaygvT6rDU+E4elov5qT4qL2JRfty9DgOKTXwl
LGvjXD7GlfCuYVZ8HQ3lp+PJ7Sttl/crpuRwXmYW8+x65+r1H3NR9VzNUpau
D8bg5impPboz0B5gSWY6PXfx6O3mKWVlvVPMziNicfdcXZKcSc8ZU6efXQZW
P6TnWFJNFKfqmeolzExH6Tmfnb66WqS6zCe6q3zW+CHyoIf1coblxJPgdT66
i3mpLCx/p2auJqp+bsZm5i7pj/LT0ex4SGZ9bd7UU2dWZjSZh4R5duZdH6q+
8ppqqP8Ey3fSdzMDTCNhd/NTOev3bj+Zdxjb0HYsSS0Ql9qzfSNeGQuKh3tm
NhHLOaxvlg+BTEgc
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 656->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01OAkEQhSssDNcg3kAPQLwCnmBMdEViggvjjqMjiGYo6/1Us6GTpsNM
9avvVdWsXt43b4uI+Fh+/2ymz6fdbvp6vjv+eZ22jw/b48v7847Yr+PvvIXN
Vn7vajhxrva8Xqx+lZZiuUaTeUFaHZYc38mDciE/2UfmrViYH3Wvw1DFOr4Y
S5y3y8xqOfJNOLxdFpevo8H8nJbpST2vFov5p5NyKC8ju8rNajlnQXfRM8Wv
aqxq5rLkU/lwfHe9MobKY8XizLT7XsVXpzsjbg2cXqKaOSzqnqqLk9PpOWLq
9LPLgOpX6SkWV7OKY/V09RxmpMP0lM9OX1UtXF3ks7rLfOb4IHmqhXo5wnKR
63eD+8pHdyMv87og70wPLXcmHU+uZqWl7nVmwNHseHBm/dq8rqfOrIxoIg8O
8+jMqz5kfebV1WDfBMqHZtDpucPSmcnMyVicfiLvZWxDW7E4tai4TiuxsJpX
fVPxaEaQRojZrFhuYf+wHAAPZ0Yc
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 657->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhRsXwWuIN4gHCLmCnmCEuBICugjuPLq/DLGn3k91b2xoh7Gr
X32vqmax/V3vZqWU4/z6sx7+vg+H4bT5uL38DPvV5/52uHzuUs5fZXy+w2ar
Pnc1nDhX+3+9WP0iLcXSo8m8IK0MSx2fyYNyIT+1j5o3YmF+1L0MQxTr+HJY
euNUPsTl8PYwM76MBvNzX6Yn9X+0WMxEp8qhvLTsKDespZhhpoc8Zvr9sp48
aq6Qt4wPxKDmyak9ujN6BLzuTLvnKj56qnlyWVHvGLPyGLGoe6ouTk6n54gp
088sA6pfpKdYXM0ojtXT1XOYkQ7TUz4zfVW1cHWRz+gu8+l6YP2KzlpYJp4I
b4uPbF9Z7p6aqZqw+qkZa5k7pz/MT0Yz48GZ9d68rqfeWXE40DehmFtnXvWh
1i9k1lwN9k1M8gXvI4fZc4clM5M1530RLaYf1SIzG4rdmVunj9E9phW9M6+I
JYoP/yPfA2J5h/1guQBJcUnX
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 658->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsX4jXEG+gBxCvEE4ygq4AQF+LOo2s0SKy8ej89mwx0Jkn3
vPreq5rrp9fNy8UY4+3q+2OzvD/sdsvH4+X+x/Oyvbvd7jdvDmuMz/vxdz+H
xa6672o451zt47xYfkhLsazRZF46rYSlnk/qdLU6P9VH5UUszI96LmFAZx1f
kiVgZlnOvBMOb8ri8iUazE/iSf3PtFVdVEN5mVmdZ3hWzDDTYx7dfp9cxlx1
3qCmqOt4cb12DMc517ps5hIGtK/Oo7szrw5r1zvGrDwiFvWcysWp6fS8Y0r6
mTJ0+SE9xeJqonMsT1fPYe50mJ7ymfRVZeHqdj7Rs8yn64H1C+3NsDj5otpJ
ZjPzyzzOZKYyYfmpGZuZO6c/zE+imXhwZn1tXdfT2llxOLp3QjHPzrzqQ9Vn
Xl0N9k509U76flhOzx2WZCYrZ/2e9rPzDs8G2orFyQJx/VyFhWX+r2+N144F
nYf/idlELOewflm+ABYESZg=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 659->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhZssJNcI3kAPIF4hnmAEXQWEZCHZ5egalTDTVNX7XsdFGjrz
V/3qe1WVzevH9n3VWjusv3+20+fzfj8dX+7OD2/T7vFhd/54/7dbOz21y/UW
drX671SDxFHteb2q+kVaiuUazcpLpuWw9PFOnixX5qf30fNGLJUfdc5hiGKJ
L8pC4qpajvwnCK/LQvkcjcqP40m9r7RV3iiH8jKyM8+EparXf8xFlfNngbnK
vDk+iG/Xa8XQoncBC5lp+l3FR1c6I7QGpJdZzQiLOqfqQnKSnmdMTj9dhqx+
kZ5ioZpRXFVPqkeYM51KT/l0+qpqQXUzn9HZymcf34o80cp6OcKyyCXOKx/u
zrzM65J5r/SyRWeSeKKakZY658wA0XQ8kFm/Ni/15MzKiGbmgTCPzrzqw+Je
eCUaVW0i7ej5wgJ7Tlicmew5+3u3n5n3MNbQViykFhHXvAek5oszideMJYqn
7xTLLexfli/6tUcc
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 660->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhZssgtcI3iA5gOQK5gQj6GogoAvJLkdPRBmcot5P9bhwoJ2f
7n79vVfl2+57e3hprZ1W/z/b4fx5PA4/X6+Xl/0wfryPl8n1bbT2u2nT/RkG
u+K8q+Gsc7Xv82L5ZVqKZYkm84K0KixxfeUcdBbyE31E3oyF+WH7sv2MIVvr
+HJYkJZTN+c8xOXwVllcvooG81PxpL4zbXXutA707qMG8gxZRC7VDCv1nl13
LKyvkLdMU53reHG9Kob4LWNxetqdV+uzu+onlxXVjjErjxmL2qdycc50ao6Y
KvWsMqD8Mj3F4mpm61ierp7DjHSYnvJZqavKwtVFPrO9zKfrgdUrm+thcfLN
zq5k1tO/zGNPZioTlp/qsZ6+c+rD/FQ0Kx6cXl96rutpaa84HOg/oZh7e17V
YfYsvDoaLJtMO3ufWMyaOyyVnoyc8blaT+R9mgfPDrvTt04dY+4tcpHMZ3UD
XhFLtt79plieYVxZ/gBjK0mW
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 661->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN9ADiFeIJxhBVwEhWYg7j65BGWY6Ve991bPJQGd6
+ufV+6ncvX7s329aa6fd789++nw+Hqevl9vzx9t0eHw4nDfv/0dr309tfl/D
UE+/TzHIOYq99Ev5F2E5LlswlZYMq8KlP1+ps+IL9PQ6er4RF6UnuteWo8Ah
Oktycv4r/0hupF7Gi/CtcqH8KhhKT0WTW1fYrm5Uw2kZGZlmwkX5RTxsxbxX
D7ivtF1ggrqkx91+xqW/069FXEhP0313PnrTHqEekCyVZ46Lu+d8ITVJ5hmn
Sp5VDpl/EZ7jQjGjc8pPikc4ZzgKz+ms5Oq8oLiZzuiu0kk1qLyivREuq1rm
/oiOaq6q9hbPnCfRnPbYSN+RfJSeCmZFA+n1rXWppq29Qnhk/wnHebTnXQ6r
udFKMJQ3EXb0Pa/DzAmXSk/2PPt5Nc9M+7xvfK70kfJWeTnrW/BRWNG30ppx
ic7TNcflGsYflx9FlUaa
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 662->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0sOAUEQhjsW4hriBhxAXIETjISVRMJC7Bwd8Yhp9T+qbUxSeqYff39/
VRmv98vtoJRyHN1+lt1pcTh059Xw/rHpdrPp7r44eUYpl3l5j/8Q7KnXXQ1n
n6v9mS+Wv0hLsfyiybwgrQxLvT9zD7oL+al91LwRC/MDz32GyRDxOr4kS3lw
OPtYLlv+Ew5vlsXly2gwPxlPap5pq3ujO5SXlkCe4V6Rl2wOM/XuPfPy1ecu
Sz0qH4hB9ZOTe3SmnotYnJ5219X+aHT61WFFtWPMymPEos6pvDh3OjVHTJl6
ZhlQ/iI9xeJqRvtYPl09hxnpMD3lM1NXlQtXF/mMzjKfrgdWr2ithaV31yvA
+RYf2br25oDHlpypnLD8qR5r6TunPsxPRjPjwen1X+91PWV6pUUTeXCYW3te
1aH3Lrw6Giw3kXb0jXqBnVEsmZ6sOev3bD2Rd6c3FLvTt04d3/6eobSib+YV
sUT73TnF8g/xYLkCCcZJVw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 663->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk11KA0EQhIc8iNcI3kAPEHKFeIIV9CkgxIfgm0fXqCxxUt319awPCUx2
dn6qq6pr10+vu5dVa+3t9utvNx23h8P0/nhzenme9g/3+9Pm3e9o7WPT5uc1
jOzX71MMco5in/uV+aewHJclmJmWCKvCpT9fqRPVivT0Onq+ikumx91rAj/i
oPgSXZQLOZd5OfJNEL5VLpRfBSPTU9Hk1jNsV1fVcFpGRqSZcMn8+o9cZDWj
s1Rbj/k9N3WJFqpVcTjncbEmuJBM0313Xj1pRqgHpJeRZ4SLu+d8ITVJzyNO
lX5WOUT+KTzHhWKqc5mfFI9wjnAyPKez0lfnBcWNdKq7mU6qIeuX2hvhEtVy
ma94NpLfTOOIZ84TNacZG8kd6U+mp4JZ0UCyvrQu1bQ0K4RH9E04zqOZd334
MzdaCUbmjcJW7/M67DnhUslkz7OfV/sZaSfZcNxJbkkfZ30b7Xvm+UXfhNaI
izpP1xyXaxg/XD4BvXlH3Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 664->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0sOQUEQnFiIa4gbcABxBU7wJKwkEhZi5+gI8RnVVdXDgmS8mTfd1VXV
/YbL7XzdK6XsB5e/eXeY7XbdcdG/HlbdZjLeXC9H91XKaVoez39Y7FffuxhO
nIv96hfzD2EpLt9gMi0RVoZLHZ+pE9WK9NQ6ar6IC9Oj8jIcUKyjy+XixDEv
W74Jh2+Wi8svg8H0ZDSp9wxb1UU1lJaWFWl2uDC/fjEXrGYU62p7w5w+F6vr
aHG1fnCocup3iIsz0+69ikdPd0ZcD5xeMs8UF5WnfHFqOj2POGX6meUQ+Yfw
FBcXE8UxP108h3OEw/CUzkxflRcubqQT5TKdrgbWL3TXwuWtlshv0ZHt6yuX
SGOLZ8oTtHdnrGXunP4wPRnMjAZn1r+t62pyZ6UVM9LgcG6dedUHtI+0OhjM
G4SNztEssBzFJTOTNc96n+1npN2ZDViP3RFvmZdZLHRmWiMuKN59p7j8w7px
OQMekkhd
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 665->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOAkEU7LgwXsN4Az2A8QpwgiGRFYkJLow7jy4IIdDU7/W4YJJmZujX
9arq1TyuPhbru9ba58PuZzF9vW230/fyfv/yPm1enjf7zafjau3ntZ3ut7DU
1e+nGEldin3ul/IPYTkuczCVFoZV4dLXV/qwXkxPr6Pni7goPe5chQOqTXSl
XJI65eXIN5HwrXJJ+VUwlJ6KJve/wnZ9T3Uku/+1mGbKxfhS9bAyb+dXyqW/
/11B30RLqhVyaBwHcUkyne67enR3eUq5stkpzk4j4uLOOV+SnsnMGafKPKsc
mH8Iz3FJMVGd8jPFSzgzHIXndFbm6rxIcZlOdFbpTDWoeaG9ES6sl8t8xbOR
/CqNI545T9BzmrGR3CXzUXoqmBUNSdbn9k01zc1KwoN9E47zaObdHNAz05pg
KG8QNnpnWVBnHJdKJnue/XN1nkx7kg3HPcltMseLcwEWeldaGRdUf3UF2URc
bmEduPwCc7NJHA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 666->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01OAkEQhSssDNcg3kAPYLwCnmBMdEViAgvDjqMripOeTr2falg4SQMz
0/3qe6+KzevH9n0VEYf198d2+nze76fjy9355m3aPT7szi/vLyvi9BTz939Y
7OrfuxrOPle7zYvll2kplms0mRekVWHp91fqoFrIT++j581YmB94rl0mQ8br
+JIs8cvh7GNZjvwnHN4qi8tX0WB+Kp7Uc6at6mY1lJeRhTw7LCyvW8wFq4n2
ut56Taeu48X1mjG0Z/pnirfCwOopTjWHKDcnA6eXLDPFos6pXJyaTs8RU6Wf
VQaUX6anWFzNbB/L09VzmJEO01M+K31VWbi6yGd2lvlcvBN1sgv1coRlfn9h
YeeZ7shCXtpckPdqZiqT7Lc7YyNz5/SH+aloVjw4s35tXdeTOyujmsiDwzw6
86oP2W/k1dFg2WTa2f383Oy5w1KZyZ7zjyWAFtNXuSotxe7MrdPHxTlDK7tn
XhFLtn9xNblnuozl1itGzvywfAHsHkeY
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 667->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNV0tKA1EQbFxIriHeQA8weIV4ghF0FQjEhbjz6JoQhtiprqp+48KBl/m8
7uqq6h6Y3L3st283EfG++fnZzh9Ph8P8+Xx7vHmdd48Pu+Pm/XlFfE2xnP/D
YkfedzGcOBf70i/mH8JSXNZgMi0VVodLju/UqWpVerKOzBdxYXpo3nReJgfE
19HlcnHimJcj74TDt8vF5dfBYHo6mtRzhq3qohpKy8iqNJexwpeuh51+K79c
LvkcBZdc19Hiar3ikHLyM8TFmWl3X8WjszOvDteqd4yz0oi4qDzli1PT6XnF
qdPPLofKP4SnuLiYKI756eI5nCschqd0dvqqvHBxK50ol+l0NbB+ob0RLsv+
FMs3U5U/oqPbV1Z7jWfKE3TtztjI3Dn9YXo6mB0NzqyvretqWjsrDo/qnVCc
R2de9QFdV1odDOYNwkb31SywHMWlM5OZ5+mY4uo/ntvPSvuvGKK1M0fMW+bl
ovVyESx0z7RWXFC8+0xx+esVIzknLt9/8UgY
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 668->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhQsXkmuIN9ADiFeIJxhBVwEhWYg7j65BGbR5f9WzSaAzP139
6ntVNTfPb/vXq6o67b7/9sv74/G4fDxdnx9elsP93eG8efu7qj4far1ewlK/
cT/VSOJS7b/1UvVDWo5li6bywrQ6LGN8Jw/LxfyMPkZexKL8uHMF9BkD4k18
pSxJnKrlzDeR8HZZUr6OhvLT8eTeK22XF+VwXmYW80xjTV3SGhbRd/5VvVKW
8VqAB+VNZtztM5b1R3QQSzLT6b6LR9dkXhNW1jvF7DwiFnfO1SXJmfScMXX6
2WVg9UN6jiXVRHGqnqlewsx0lJ7z2emrq0Wqy3yis8pn6kH1C+3NsKz7olbu
fWf20/lVHmdq5mqC7tMZm5m7pD/KT0ez4yGZ9a15U09bZyXhYN+EY56dedcH
dM+8JhqqNkgbPbNZUGccS2cmR87xvttP5j2ZDceezG3Sx3/nAi30rLwyFhSf
vnMsl7B+WL4AVFZIHA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 669->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNUktOwzAQtbqouAbqDcoBUK8QThAkWEVCCgvUHUcvKSFKzbzPOJtGcpx4
PG/eezOPrx/d+66U8vnw8+r6r9M49ueX/fTz1g9Px2EKHuZVyvdzWfZ7WOyp
4y6Gc8/FXvvF/IuwFJctmEwLwspwqe9n6qBaSE+to+YbcWF6YN56mRwivo4u
yYX45/TNqYd4OXyzXFx+GQymJ6NJnTNsVTeqobS0LKTZ4cL8Uh6Whn4rv1wu
9X59jLrOjKs44vLPn+os4uLMtBtX96PdnRHXA6eXzDPFReUpX5yaTs8Rp0w/
sxyQfxGe4uJiRveYny6ewxnhMDylM9NX5YWLi3RGuUznTUzUiR7UyxYuS3zm
wvIZbstCWta+IO1Zz5Qn0bc7Yy1z5/SH6clgZjQ4s761rqvJnZVWTKTB4dw6
86oP0TfS6mAwbyLs6H85N3vucMnMZM3zj0sBWAxf+aqwwnosRrxlXtZ5Covl
IExWex13zxSXe1i/XC6NCkZb
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 670->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVkkKAkEQazyI3xB/oA8Qv6AvGEFPgqAH8ebTXRmkSSWpHg8OtDPdVZ1K
UnVwuj2u96NSynny+Fl3l9Xp1F034+dm1x0W88MzOPusUm7L0r//YbGnjrsY
Tp6L/e0X8w9hKS5DMJmWCCvDpc7P1IlqRXpqHTVfxIXpoffAfcYB5Tq6HC5D
81S9iJfDdwhnxi+DwfRkNKlzhq3qohpKS8uKNDtcmF+/mAtWM8p1tUFMUdfR
4mqNOLz26AxwcWbajat89HZnxPXA6WXkmcNF3VO+ODWdnkecMv3Mcoj8Q3iK
i4uJ8pifLp7DOcJheEpnpq/KCxc30onuMp2uBtYvFGvh0seXBf5vYh46OrJ9
7XkSjS2eKU/QtztjLXPn9IfpyWBmNDizPrSuq8mdlVbMSIPDuXXmVR/Qd6TV
wWDeIGy0j2aB3VFcMjNZ83w9BIvhK18VluLuzK3TR+Q3w2J3IkxW+zvuniku
/7DeXO6mtkfd
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 671->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tuwkAUG7Goeg3EDcoBKq4AJ0ilskJCoouKHUfnqyiZ+Nl+kw2RhiTM
Gz/bz1n+HLf7RSnl7/P2s+3+N6dTd9593F9+u8P663DfXL1WKZfv0t/fYbGr
3ncxnDoXe+gX8w9hKS5zMJmWCCvDpa7P9Il6RXpqHTVfxIXpUecyHFCto4tx
KYPlcGZetnwTE70J/5w6xi+DwfQoTS6X6HL7oh5KS8uKNMPawUyVX46HdT6U
x6PLzFWkbYJZ8UF9VR6c/YjLqAf6D3BxMu3uq3p0d/LqcI1mxzgrjYiLOqd8
cXo6M484ZeaZ5RD5h/AUFxcT1TE/XTyHc4TD8JTOzFyVFy5upBOdZTpdDWxe
aK+Fy6iXON+iIztX1nuOZ8oT9OxmrCV3znyYngxmRoOT9bl9XU1zs+LwiL4J
xbk182oO6DnS6mAwbxA2eo+ywM4oLplM1jwfF8Fi+MrXvoZozeSIecu87LUO
9DIs9M60RlxQvfuf4vIO68nlCgACRlk=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 672->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qw0AMhYcsSq5ReoP2ACFXcE/gQrsyFJxFyK5HT01LsFW9H9ldZGCS
2KN5+p6kPL59dh+71tpp//3R9efjOPaX14fp4b0fXp6H6fDpd7f2dWi373vY
bMVzV8OJc7Xn9WL1y7QUyxZN5gVpVVhifCUPyoX8RB+RN2NhftS9CkMW6/hy
WLbGqXyI64/ff2ZmfBUN5kd5clnQcvNmOZSXNRt5TmPFDDM95tHt92KZc4W8
RU0nr+PF9ZoxzO/Ed4q3wsDyKU41h6huTg2cXrKaKRZ1T9XFyen0HDFV+lll
QPXL9BSLq5nFsXq6eg4z0mF6ymelr6oWri7ymd1lPhdnIk+2UC/XsNzOSa3U
+8rsu/PLPCo9tNyZdDy5mpmWuleZAUez4sGZ9a15XU9bZ8XhQP8Jxbx25lUf
st/Iq6PBapNpZ89oFtgdxVKZycgZf1f7ibw7s6HYnbl1+qi8Rq3smXlFLFm8
+06x3MP+YbkCFYZIHg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 673->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVltqAkEQbPwIuUbwBvEA4hXMCVbQLyFgPoJ/ObrxwaJjdVX17I8D47pO
b3VVdS34sfle72YR8fP+/7EefleHw3D8ejvfbIf94nN/PpzfdsTfMsbrK2y2
2nMXw6lzse/9Yv4hLMVlCibTkmFVuLT1lT5Zr0xPq6Pli7gwPeq5CgdU6+hi
XOJuO5yZlz3vxJPegn9OHeNXwWB6lCaXS7bcvqiH0tKzM82wVmSY4TGN7rwf
lpmrTNsTZpNX1NfR4mqFHCLHQVycTLvnqh5dnbw6XLPZMc5KI+KinlO+OD2d
mWecKvOscsj8Q3iKi4uJ6pifLp7DOcNheEpnZa7KCxc304meZTpdDWxe6KyH
y3hOvFK/V7Lv5pdp7PFMeYK+uxnryZ0zH6anglnR4GR9al9X09SsODyyd0Jx
7s28mgP6nml1MJg3CBvdZ1lgzygulUy2PC9rGQ//gSvzzLQ72YD92Bnxlnk5
aiUzUPdMa8YF1Y+r0YpwGZdX2FcuJ/jDRtk=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 674->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN9ADBK8QTzCCrgKBuBB3Hl2DEk3n/VW3izR0Zoau
rvreq8rN027zctVae119/WyWt4f9fnl/vD58PC/b+7vt4fD2Z7f2sW7H5yVs
tfrzNEcSl+b+65fyD+VyLDM5lRaWq8LSx1fqsFpMT6+j50UsSo+7V2FAsYmu
hGU2ztVjXCdr/fv8L2bF53IgDqRHaaqwsJXWRTVYzMxmms/iAIvyqzrHSb+P
i/QzZemfTofS3XOkWh3DWR3A4nrK4lQ9x+nmkPmWeJD0UnnmWNw950tSM+k5
Y6r0s8rA/EP5HEuaE8UpP9N8CTPLo/I5nZW+Oi/SvEwnuqt0phpUv9DZCAur
5Wa+4tnI/CqNI545T9B7OmMjc5f0R+mp5KxoSGZ9tm6qaXZWEg72n3DMozPv
+oDemdYkh/IG5UbfbBbUHcdSmcmes3+v9pNpT2YD1lNnwlvlpdPa50LfSitj
QfEnK/CQsVzC/mb5BIUBRV8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 675->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVEFOAzEQG3Go+AbiB+UBq36hvGArwakSUnuoeuPpUEBRCbbHk+XQSOlu
msRje6x92L1tX+8i4nj/+bOdT5vDYT4/ry6Ll3n/tN5fNh9/ZsT7FO15C1ON
ft/FcM652Nd+Kf8QVsZlCabSwrAqXPrzlTqsFtPT6+j5Ii5KT3avwgGddXQ5
XJaey+oxXkhv/CNnxa+CofRkmlwubLh1UY1My8hkmh0uyq9qjp1+t2HeV9oQ
ZiR1YcZF7x3vGeaf/wAXJ9PufnYePd2MuB44vWSeOVyye5kvTk2n54xTpZ9V
Dsw/hJdxcTHROeWni+dwZjgKL9NZ6WvmhYvLdKK7SqerQfUL7Y1waftT/PrW
ZZmveDaaX6ZxxLPME/TuZmwkd05/lJ4KZkWDk/WldV1NblZGMZkGh/No5rM+
oHem1cFQ3iBstGZZUHcyLpVM9jy/xhTte1XtJ9PuZAPWU3vCW+Ul8k9hobXS
yrig8210WhGu4nIL85vLB1mCRZw=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 676->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlk1KA0EQhRsXkmuIN9ADDF4hnmACugoIyULceXTNaELsvL+acZGGzkyn
u199r6oIudu8rV9vWmv71ffHenx/2u3Gj+fbw+Jl3D4+bA+b97+ztc+hnZ7X
MNXo91ON5FyqfZ4vlT+k5ViWaCovTKvC0p+vxGGxmJ/eR8+LWJQfd6/CgM4m
vhKWpedcPMbF/P4Xs+KraCg/zlPKwkYaF8VwXuZM5jlhUfmq9nFS79MI7ytv
SLOZuImX1CtkOK7Rd4Al6el0351Hz7RH0hwktWQ5S1jcPZeXJGZSc8ZUqWeV
geUP6TmWVBOdU/lM9RJmpqP0nM9KXV0uUl3mE91VPlMPql5obw4Li+V6vpKz
av9OY2gXv70uFvKRsLP3tMfm9F1SH+WnolnxkPT60ripp6RXlmgyDwnz3J53
dUDvzGuioXKDtNGa9YK641gqPdlzTkNoKX2XV6cF44UsSS4uvIoauLXyyljQ
+WkM7c//cqarWK5h/rB8AfwjRts=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 677->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNkk1qAkEQhRsXIdcQbxAPILmCOcEIcSUIZhHceXQ1ikjz/momCwfacWaq
X3/vVc03+/V21lr7eb/8rIffz8NhOH69XR++h93yY3f9uLiv1k6r9ri/wlJX
/z3VSOpS7ee8VH5Iy7FM0VRemFaFpa+vnMPOYn56Hz0vYlF+3L4KA6pNfCUs
U+vceYwL+W3/yKz4nAbiQH6cp5SFXem56AxWM2UxzwmLyqs6x0m/k6xSbxUf
VYbEq2Po3yEW19MKo6tH93RG0gySXqrMHIvb53JJzkx6zpgq/awysPyQnmNJ
NVGdyjPVS5iZjtJzPit9dVmkuswn2qt8ph5Uv9C3MSx/78RsJ+8rsy/7unpa
xP/YzFwmKj83Y2PmLumP8lPRrHhIZn3quaknOStgT1WTeUiYx8686wP6z7wm
GiobpI2e2SyoPY6lMpM9Z/+/2k/mPZkNx57MbdJH57XXQs/KK2NB9Y8r0FUs
r7BuLGfCy0ce
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 678->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNV0tOwzAQtVggroG4ARwg4grlBEGCVSWkskDsODo0oADm/cZhUUtu4njm
zXszb9PL+6fd41lr7fni42c3v9weDvPr3fnx8DDvb673x8urr93a29TW5yls
tfr7FCOJS7F/9kv1D2E5LlswlRaGVeHSx1fqsFpMT6+j54u4KD0ur8IBxSa6
Ei5b41w9xuvX+icuKb8KhtKjNFW4sJXWRTWclpHNNDsvun5VfZzMe11hvtJW
0aF091xSrY7DnzqAS+Lp9N7Fo2fi14Qrm92I/xQXl+f6ktRMZs44VeZZ5cD6
h/AclxQTxal+pngJZ4aj8JzOylxdL1JcphPlKp2pBjUvdDfCZfkmvJ18r3hf
ztX40NViOUlP0HvqsRHfJfNReiqYFQ2J17fWTTVJr4CcKibTkHAe9bybA3pn
WhMM1RuEjc7MCyrHcal4sue5rKnR/zUK3/XVYTnuiW+TOa5axQzcWWllXFD8
sqbvnXgTcTmF/cnlHSkBRpw=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 679->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNkk1KA0EQhZssxGsEb6AHEK8QTzCCrgJCXIi7HD1G4xCb91c9WWSgM5nu
6lffq6r1y/vmbdVa+7j9/tlMn0+73fT1fHP8eJ22D/fb4+HdabW2f2zz+xqW
evrzVCOJS7XP66Xqh7QcyxJN5YVpVVj6+Eoelov56X30vIhF+XH3KgwoNvGV
sCyNc/kY17/nQiwpX0VD+VGeKizsSfPOcWR2L7WYZ8hhZljpKY9pv+cnvK+8
VXxAhnZWkwGvjqHfQyzJTKfnLh693TylrKx3itl5RCzunqtLkjPpOWOq9LPK
wOqH9BxLqoniVD1TvYSZ6Sg957PSV1eLVJf5RHeVz9SD6hc6G2H52ROznexX
Zt/O74mH+R+tmasJ+p/O2MjcJf1RfiqaFQ/JrC/Nm3qys0Jyp5rMQ8I8OvOu
D+g/85poqNogbfQ974c9T1gqM9lz/rE0oqX0XV2dFsynzkRtVS1R/ZQW+lZe
GQuKT/ccyzWsX5YDUtFEnA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 680->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOAzEQi3pAfAPxA3gA6hfKCxYJTpWQygH1xtNLC4pKanvsXQ6NFNjd
TDy2x717ed+8rVprH7fffzbT53q3m/bPN8eX12n7+LA9Ht7/7ta+nlr/fw1b
rfHcxXDqXOxzv5R/CKvisgRTaWFYCZexPunDejE9o46RL+Ki9FT3Eg6o1tHl
cFlaV/VjvP6sf+Li8kswlB6lKeHCltuX/UaqbKabab6oG2orv9IcO/Puy7yv
tCEdreir6lOtjEP3+sxzVOtm2j2X9UEOmW9pttE7wk64VPcqX5yezswZp2Se
KQfmH8KruLiYqE756eI5nBmOwqt0JnOtvHBxmU50V+l0Nah5obM5XE7fRLad
70n2nfwiPU4vdsfxBD27GZuTO2c+Sk+CmWhwsr60r6vJycoSTKbB4Tw389Uc
0DPT6mAobxA2eu/fzZk7XJJMjjzH53SeTLuTjYq7k1tnjl3fMAPH84u5Aa2M
C6o/LcAF4Sou17B/uBwAlmhGmg==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 681->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNV0tqAkEUbLIQrxFyA3MAyRXMCSYQV0JAFyG7HF3NR7St35tx4UA7n35d
r6pebXx8+1itH1pru/nhZzV8vmy3w9fr7PjyPmyeF5vj5tPfau172U73e1jq
6vdTjKQuxT73S/mHsByXKZhKC8OqcOnrK31YL6an19HzRVyUHneuwgHVJroS
LlPrXD/G6+K6EZeUXwVD6fmvb8EM3HeGrfpeYZHs3mqh3k6T8kV9c/ydx9ar
kEt/P12mb8oh0co4nM+876syV+GA9mU98c7lKeXKZjcmf4qLO+d8SXomM2ec
KvOscmD+ITzHJcVEdcrPFC/hzHAUntNZmavzIsVlOtFZpTPVoOaF9sZwYb1c
5iueVfOL9CS92JnEE/ScZmxM7pL5KD0VzIqGJOtT+6aakqxMwWQaEs5jM+/m
gJ6Z1gRDeYOw0TvLgjrjuFQy2fP8uZaN/q9R+M5XhwX7qT3hrfIS+aew0LvS
yrig+vSb43IP65fLHvmCQ+E=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 682->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNkksKwkAQRAcX4jXEG+gBxCvoCSLoShB0Ie48uoohyND16YkLA2MS01Pz
qrvm+/P2OCmlXGevn21321wu3X03fb8cutNqeXp/XPSrlMe6DPd/WOyqv7sa
Tp2r/d0v1r9IS7GM0WRekFaGpa7PnIPOQn5qHzVvxML8qH0ZhqjW8eWwjK1T
5yEu5PdXzIwvo8H8KE8uC7rcc4e6fjleWhbyrLKo+pXNsTNv2SuTpb4rH1kG
xytjKKDfLHMZhui7qo/uKk8uK5pdS/4Yi9qn+uKc6cwcMWXmmWVA/Yv0FIur
GdWxfrp6DjPSYXrKZ2auqheuLvIZ7WU+XQ9sXtG3FhZ0lsp8pmfZ/EZ+nLPQ
Hqcn0bObsZbcOfNhfjKaGQ9O1see63pysjJGE3lwmFszr+YQPSOvjgbrTaQd
vaMssD2KJZPJmrN+zs4TeXeyodid3DpzVF5rreideUUsUb37n2L5h/VheQLi
WEYi
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 683->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNkksKwkAQRAcX4jXEG+gBxCvEE0TQlSDoQtx5dI1KkKHr04kLA6MJ01Pz
qrvmu1NzmJRSLrPnT9NeN+dze9tOu499e1wtj93m4rNKua9L//8Piz31vqvh
1Lna3/1i/Yu0FMsYTeYFaWVY6vrMPegu5Kf2UfNGLMyPOpdhiGodXw7L2Dp1
H+JCfn/FzPgyGsyP8uSyoMe9t68D2f3VQp5VFlW/sjl25i17ZbLU/8pHlsHx
yhjK19wRr5tpd5/Wg96pPLmsaHZD8sdY1DnVF+dOZ+aIKTPPLAPqX6SnWFzN
qI7109VzmJEO01M+M3NVvXB1kc/oLPPpemDzivaGsKC7VOYzPcvmN/Lj3IXO
OD2J3t2MDcmdMx/mJ6OZ8eBkfey9ricnK2M0kQeHeWjm1Ryid+TV0WC9ibSj
b5QFdkaxZDJZc9bv2Xki7042FLuTW2eOvT8yA/XNvCKWqP71BCyRLmP5h/Vm
eQDlSUce
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 684->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEQbbIQrxFyA3MA8QrmBBMwK0HQhWSXoydOgsSm3m/GhQXtTE9X
v3qv6vn8fth+PLXWTsufn+1w3hyPw+fb4rLZDfvX1f5y+PK3Wvtat+vzERaL
/tzFcPJc7P/9Yv2rsBSXOZhMC8JKuPT5SR1UC+npdfR8Ky5Mj7qXcKhyHV0O
l7l5qh7idRN34uLyUxjN1MM0JVxQuHXRf0R5M11Is/Ki6lfqY2feCsfl0j+V
jpSDo5Vx6KPKdWaacFT5rg9R31JvV3vUI5eLuqf64tR0Zo44JfNMOaD+VXiK
i4tZ5bF+ungOZ4TD8JTOZK6qFy4u0lndZTpdDWxe1dkULuM34m3ne+J9x7+V
HqcWuuP0pHp3PTbFd858mJ4EM9HgeH1uXVeT45U5mEiDw3mq59Ucqnek1cFg
vamwqz3yArujuCSe7HmOQbAYvuqrwlLcHd86c7xqJTNQe6YVcanyxwi9WXF5
hPXL5Rt4fUYg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 685->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNUktOAkEU7LggXsN4AzyA8QpwgiGRFYkJLow7jy4gIaSp3+txQSfNzNCv
61XVq6fNx2r70Fr7fDz8rKavt/1++l4vjh/v0+5luTsePp93az+v7fK8h61W
f55iJHUp9rVfyj+E5bjMwVRaGFaFS19f6cN6MT29jp4v4qL0uHsVDqg20ZVw
mVvn+jFeTO9/cVb8KhhKz4V7MAP3P8NWfW+wrrfRMrJRb6dJ+aL+c/ydx9ar
kEv/dDqqHBKtikO/UG2a6fTc1aOny1PKlc1uJH+Ki7vnfEl6JjNnnCrzrHJg
/iE8xyXFRHXKzxQv4cxwFJ7TWZmr8yLFZTrRXaUz1aDmhc5GuLBeLvMVz6r5
RXqSXuxO4gl6TzM2krtkPkpPBbOiIcn63L6ppiQrczCZhoTzaObdHNA705pg
KG8QNvpmWVB3HJdKJnuepyWwFL7z1WE57klukzki/xQW+lZaGRdUf1rFbCIu
97D/uPwCrXNFYQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 686->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVVtqAkEQbPyQXCPkBnoA8Qp6gg3olxDQD/EvR1dJlN2h69G7fjgwuuv0
VFdVF/j5/bPZzyLi9HH72HTn9fHYXbbz+8uuOywXh/vh1/+O+F3F8/sdNlvt
uYvh1LnYfb+YfxmW4jIFk2lBWBUubX2lD+qF9LQ6Wr4ZF6ZH3atwyGodXQ6X
qXWqH+KF9L6KM+NXwWB6lCaXC1pu3wHeYwstYzbSDDX1uDC/qjl25t3ihJEr
pA1hsr6OFlcr49B6nNW6mXbPaT3wTuXJ5YpmxzgrjRkXdU/54vR0Zo44VeZZ
5YD8y/AUFxczq2N+ungOZ4TD8JTOylyVFy4u0pndZTpdDWxe2dkYLqiXynzF
s1J+VzH4f0Xaq54pT7JnN2NjcufMh+mpYFY0OFmf2tfVJLMCeruYSIPDeWzm
1RyyZ6TVwWDeZNjZ+/N3c+YOl0omW54PLgGwGL7yVWGl/dgZ8ZZ52d5TWOwO
wmS9++eDZXiIuLzD/uNyBWnORho=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 687->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNUkuKAjEUDC7Ea4g30AMMcwU9QQvOShjQxeDOo2uriBNffV7aRQdid5uX
elX1ar79Xf9MSinH2fVn3f19Hw7daTPtP3bdfrXc94eLxy7l/FWezzFstupz
F8Opc7Ff/WL+RViKyxBMpgVhZbjU9Zk+qBfSU+uo+UZcmB51L8MhqnV0OVyG
1ql+iBfS+ynOjF8Gg+lRmlwuaLl9/+GZWlo20qyyqPzK5tiZ9xsHI1dIW0aH
ozurlXG4raAvy1yGQ3Su6qOnypPLFc2uJX+Mi7qnfHF6OjNHnDLzzHJA/kV4
iouLGdUxP108hzPCYXhKZ2auygsXF+mM7jKdrgY2r+ishQvqpTKf8aw1v0hj
i2fKk+jdzVhL7pz5MD0ZzIwGJ+tD+7qa3Ky0YiINDufWzKs5RO9Iq4PBvImw
o2+UBXZHcclksub5XACL4StfFZbi7uTWmWPkN8NidxAm6/167v6nuIxh37lc
ABSARyA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 688->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNkk1qAkEQhZssxGsEb6AHkFzBnGACuhIEXYTscvTEKE1o6v1UjQsbev66
5tX3qur147Q7vLTWLsvfy276fDufp6/3xfVlPx036+P1cHXfrX1vW78/w2Zr
PHc1nDhX+3+9WP0iLcUyR5N5QVoZljE+kwflQn5GHyNvxML8qP8yDFGs48th
mRun8iEu5PdRzIwvo8H8KE8uC1pu3oqXykae1SyqemXn2Om30nFZxrvykWVw
vDKGv7W9b8DrzrR7ruKju5onlxX1rjJ/jEX9p+ri5HR6jpgy/cwyoPpFeorF
1YziWD1dPYcZ6TA95TPTV1ULVxf5jP5lPl0PrF/RWYUF5VIzn6lZdX6Rx0rN
VE2iZ3fGKnPn9If5yWhmPDizPjev68mdlaom8uAwV2de9SF6Rl4dDVabSDt6
79/NnjssmZkcOfsCWkxf1bXHEK9uLJpbp4/dK9AftaJ35hWxRPHuN8XyDPvG
8gOxlkae
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 689->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsX4jXEG+gBBq8QTzCCrgJCXIg7j65BHTNNvb9pFxno9CRd
/ep7VZXrx5fd80Vr7fXq62M3v90fDvP7w+Xxy9O8v7vdHw9vflZrH1Nb9nNY
7OnPXQ0nztU+rRerX6WlWEY0mReklbD08UkelAv56X30vBUL86PuJQxVrOPL
YRmNU/kQ1+qZ/tZ/MTM+pVFxVH6Yp4QFPW7elZ7wOLKQZ+jpt6+iXukcO/1W
Oi5LvysfKYPjlTEsD+F1epowqvhqV/PksqLeMWblsWJR91RdnJxOzxFT0s+U
AdWv0lMsrmYVx+rp6jnMSIfpKZ9JX1UtXF3ks7rLfLoeWL+qsy0sKJea+aRm
6fy2qdtB/qRmqibV+xIrZmzL3Dn9YX4STed/ksz6aF7XkzMrI5rIg8O8deZV
H6p35NXRYLWptKvvaBbYHcWSzGTP2b+n/UTeVzHEqxuL5tbpY1VvpsXuIE2W
+/Tc/U2xnMP6ZvkEgjhEHg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 690->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQHPwIXkO8QXKAkCuYE2wg+VoIrB/BP4+uElmWoevRvT87MO7q
9FRXVZeHr9/Tz661dt7fP07D38c0DZfPl8eX72F8ex0fh8fnbu363ubnFjZb
/bmL4dS52Eu/mH8RluKyBpNpQVgZLn19pg/qhfT0Onq+ERemR93LcIhqHV0O
l7V1qh/iNS9jXhXOjF8Gg+mBmpJc0HL7VrRUNtKssqj8yubYmbfCcbn0T6Uj
y8HRyjj0K6p1M+2eq/roqfLkckWzq+SPcVH3lC9OT2fmiFNmnlkOyL8IT3Fx
MaM65qeL53BGOAxP6czMVXnh4iKd0V2m09XA5hWdVbigXirzGc+q+UUaK54p
T6L3uVZkrJI7Zz5MTwbT+Z9ksr62r6vJzUoVE2lwOFczr+YQvSOtDgbzJsKO
vqMssDuKSyaTPc/+PTtPpN3JhuLu5NaZY+Q3w2J3ECbrvTx3f1NctrD/udwA
EhxHYQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 691->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNUktqwzAUFFmUXCP0Bu0BTK/gnsCFZmUoOIuSXY7eui3GEW8+T+7CBsVy
9DRvZt6c3j7686GUcjl+//TD58s0DdfXh/njfRifn8b58PFvlXLryvLew2JP
fe5iOHUu9tov5l+EpbhswWRaEFaGS12f6YN6IT21jppvxIXpUfcyHKJaR5fD
ZWud6od4/Tzdav0DF5cfxDBmKTWRnmpuCFv1jTSwmtaFNKssKr+yOXbmrXBc
LvVb6chycLQyDmW9AF830+45rQfeqTy5XNHsWvLHuKh7yhenpzNzxCkzzywH
5F+Ep7i4mFEd89PFczgjHIandGbmqrxwcZHO6C7T6Wpg84rOWrigXirzGc9a
84s0tnimPIn2bsZacufMh+nJYGY0OFnf2tfV5GalFRNpcDi3Zl7NIdojrQ4G
8ybCjr5RFtgdxSWTyZpnvc/OE2m/qyFaMzli3jIvF31kBuqbaUVconr3P8Vl
D+uXyxf+YUga
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 692->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0kKwkAQHDyI3xB/oA8Qv6AviKAnQdCDePPprkQZupaeXAyMSZye6qqu
ynR7XO9HpZTz5PGz7i6r06m7bsbPl113WMwPz83ZZ5VyW5b+/g+LXfW+i+HU
udi/82Lzi7AUlyGYTAvCynCp6zN9UC+kp9ZR8424MD3qXIZDVOvocrgMrVP9
EK9en+FXC2fGD2IYXipNrCf7n2Grvu48hi6kWWVRzSubY8dvheNyqe9KR5aD
o5VxeF2f7CK+bqbdfVUf3VWeXK7Iu5b8MS7qnJqL09PxHHHK+JnlgOYX4Sku
LmZUx+bp4jmcEQ7DUzozvqpZuLhIZ3SW6XQ1ML+ivRYuqJfKfGZmTfklGltm
pmYSPfe1ImMtuXP8YXoymM53ksn60L6uJjcrrZhIg8O5NfPKh+gZaXUw2Gwi
7OgdZYGdUVwymax51s9ZP5F2JxuKu5Nbx8deH/FAvTOtiEtU/7qW3+VkM+Ly
D+vN5Q41bklZ
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 693->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNl0FOQkEQRDssjNcg3kAP8OMV8ATfRFckJrgw7Di6gkqgra6qHlwwyfD5
/JmaV13N4i+f31avi4h4v/36WM0fj5vNvH262d+8zOuH+/X+4d3PjNhNcbxe
w2QjP3c1nHWu9mm9WP2QlmK5RJN5qbQ6LHl955zqrMpP9pF5EQvzo/Z1GNBa
xxdjCZIHYma17P4nAs1/YHH5/mgmLtcPYmNnst+ZtjoXeiFrRmflufR0ki2r
V7ePnbyzTs7VZclX5YMxsOyd2kNfv4PwOpl2GNV6dFX95LJW2TFm5RGxqH2q
Ls6ZTuYVUyfPLkNVP6SnWFxNtI7V09VzmCsdpqd8dnJVtXB1K59oL/PpemB5
oWcjLNVZquc7NRvt38rjSM1UTdB3t8dG+s7Jh/npaHY8OL1+6bmuJ7dXRjUr
Dw7zaM+rHND3yqujwWqDtNF91Qtsj2Lp9GTmPIwpyvcapq/qqrQUu9O3To5H
ryQDdc+8Vixo/WFMcfb+VukylmuY3yyfcplF1w==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 694->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVkFqwzAQFDmUfCP0B+0DTL/gvsCF5BQIuIfSW56e2jWhUWdnZuUcIpBl
WavZmd0JZPdx6g+bUsrn9ufRD19v4zh8vz9Nm/1wfH05TofPyyzl3JXr+giT
jfrcxXDiXOy/9WL1Q1iKyxpMpiXCynCp4zN5olyRnlpHzRdxYXrUvQwHFOvo
YlxUjZy+OfkiXvPolnknLi6/DAbTAzWRnOw7w1Z5b/BMLS0z0qy8qOqV9bHT
b4XjcqlXpSPLwdHKONQDxbqeds9VPFqVn1yuUe9a/Me4qHuqLk5Op+cRp0w/
sxyi+iE8xcXFRHGsni6ewznCYXhKZ6avqhYubqQT3WU6XQ2sX+ishUuUS3k+
U7Osf0tX/v13cXIhHQ736P0aKzzW4junP0xPBtP5nWS8vjavq8nxyhrMSIPD
udXzqg/oPdLqYLDaIGy0j7zA7iguGU/WPOdBsBi+qqvCUtwd3zp9RPVjWGjP
tEZcUPw8kt5EXB5h/nK5ADHiRV8=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 695->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNV0tKA0EUfLgQryHeQA8QvEI8wQi6CghxIe48uiaKJE39Xs8mDZPJpF/X
q6pXs8jt89v29aqq3m9+PrbLx+N+v3w+XR8eXpbdw/3usHn3d1V9ber/fgmX
WuN+ipHUpdinfin/EJbjsgZTaWFYHS5jfacP68X0jDpGvoiL0uPOdTig2kSX
4lJiHoiz8nLmnTiuEx7V8C+pU/w6GEoP1CR6qt8Vtus7o2XmYppdFp1f3Rwn
83Y4KZfx7nR0OSRaFYdxodo00+m+q0d3l6eUK5vdTP4UF3fO+ZL0TGbOOHXm
2eXA/EN4jkuKieqUnylewpnhKDynszNX50WKy3Sis0rn2Z7pgxab5QwX1stl
vuPZTH6VRofHVprJRFOKibDcuU4GEsyOhiTra/ummtZmJeHB3gnHeTbzbg7o
O9OaYChvEDZ6ZllQZxyXTiZHnse1KfofS+E7Xx0W7Kf2hLfKS+SfwkLPSivj
gurT3xyXS7h+uXwDNIBGng==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 696->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuwkAQG/VQ8Y2qPygPqPoF+oJUghNSJThUvfXpQFsQGjy2Z3Mh0pKE
nfXYY+fp43O1eYiI/eL4s5q+3na76fv98fSynrbLl+1p8/l/Rfy8xuV+D4td
ed/FcOpc7Ot5sfkhLMVlDibTUmF1uOT6Tp+qV6Un68h8ERemR53rcEC1ji7G
JYgfiDObZfebiOt1vhrzc+oYvxtMI59ID+LGerL/Gbbq685j7qo0l5qyx8W8
ujl2/M44OV8ul3xXOhgH5r3r542uwP+xzHU4oH1Vj+4qTy7XyjvGWWlEXNQ5
NRenp+N5xanjZ5dDNT+Ep7i4mKiOzdPFczhXOAxP6ez4qmbh4lY60Vmm09XA
/EJ7I1yqXirznZmN5JdpHJmZmgl6djM2kjvHH6ang9nR4GR9bl9X09ysODyq
b0JxHs288gE9V1odDDYbhI3eqyywM4pLJ5OZZ37u+llpd7KhuDu5dXy86CMe
qHemteKC6n8vwAXhMi73sP64HACGNEbb
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 697->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KxEAQhRsX4jXEG+gBxCuMJ4igqwFhXIg7j66DQxgr76+SzTR0/rr7
1feqKrcv77u3qzHGx83vZTd9Ph0O09fz9fHlddo/3O+Pi3enOcb345jvlzDV
qOupRrIv1T7Pl8of0nIsWzSVF6bVYan7O3FYLOan+qi8iEX5cec6DGhv4kux
DFEPxKxy2f0nzmPPo5G/ZJ/iW2gG/Yn8IDYVU31X2i5umo+tk3mmnkxeujns
1Lvq1P5KWerd+VAMqvZpPRe+xlj0L2JJejpdl/sJi+unlJXVTjE7j4jFnXN5
SWImNWdMnXp2GVj+kJ5jSTXRPpXPVC9hZjpKz/ns1NXlItVlPtFZ5fPfmomD
BqvlGpZ5/cSizivdNZN5Uf2a6LGR9mTiKdVEWu5cpwcSzY6HpNe3xk09be2V
hIP9E455bc+7OqBn5jXRULlB2uid9YI641g6PVk563O3nsx70huOPenbpI7O
a9VC78orY0H702+O5RLmH8sPPY1HWw==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 698->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk00KwjAUhIML8RriDfQA4hX0BBV0JQi6EHceXcUfJJ03My/dWIi2TTL5
Zt7rdHtc70ellPPk8bPuLqvTqbtuxs+HXXdYzA/Pydl7lHJblu//Pwx21fOu
hrPO1f7Ni+WHtBTLEE3mJdLKsNTrM+dEZ0V+ah81L2JhftS+DANa6/hiLIXU
AzGzLFu+iZ6/RH7OOsaX0WB+EBs7k71n2urcFi8tI/IcehK5ZDPM1LvWqfvL
ZYG9SvYyBlZ7t549X59r+TMAi9PT7jxdH2Sn+slljWrHmJVHxKL2qVycM52a
R0yZemYZovyQnmJxNdE6lqer5zBHOkxP+czUVWXh6kY+0V7m0/XA6oXmWlii
s1TPZzJr6V/msSUzlQm6d3uspe+c+jA/Gc2MB6fXh57rehraKw5H9E0o5tae
V3VA95FXR4Nlg7TR8/e9WXOHJdOTNeeHpQRaTF/lqrQUu9O3Th1RfkwLPTOv
EQta775TLP8wXix31ZtHWw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 699->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNUktOw0AMHbFAXANxAzhAxBXKCYIEq0pIZYHYcXRoKWkYvZ+nm47kJunY
z+89+/b5bfN61Vp7v/n52cwfj7vd/Pl0vf94mbcP99v95d0xWvua2vK8hFCn
v08xkrwUe+2X8g9hOS7nYCotDKvCpc+v9GG9mJ5eR88XcVF6XF2FA8pNdCku
zqNkbkk/xqvXV/EvyVPYFQylB3FTPdX/Ctv1HdEyEkwz1WR8qXpYmXeP00y9
0sYw/3BR30RLqlVxWM60CsAl2en03uWjp9unlCubneLsNCIurs75kvRMZs44
VeZZ5cD8Q3iOS4qJ8pSfKV7CmeEoPKezMlfnRYrLdKJapfPfnemDDpvlCJfl
/shF1SvckWBa1r4w7VXPnCfoPd2xkb1L5qP0VDArGpJdP7dvqindlVFMpiHh
PLrzbg7onWlNMJQ3CBt9s11QNY5LZSd7nocjsBS+89VhOe7J3iZzXLSKGbhv
pZVxQfmHM50i2U3E5RLil8s3UA5HmA==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 700->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEUhJssgtcI3iAeQHIFc4IJxJUg6CK48+gqkUHa+nszGwfa+enu
el9VPz9+9pvtW2vtuLj+bIa/r8NhOH2/315+h93qc3ebXN5Ha+d1G++vMNTV
z6caybpU+zEvlR/ScixzNJUXplVh6ddX6rBazE/vo+dFLMqP21dhQGsTX4rF
ZZScW1IP8j+OArNjSfmeNIP+RH4Qm6qpvittVzfNY+5gnqknk0s1w8p59zrN
7FfemKaqm3hJvSqG8RK8aU+n8249urt+SlnZ2Slm5xGxuH0ul6RmcuaMqXKe
VQaWH9JzLKkmWqfyTPUSZqaj9JzPyrm6LFJd5hPtVT5TD+q80NwUlnFeZOW+
V3o/7V/lcUpmLhP0nPbYlL5Lzkf5qWhWPCS9Prdu6mluryQc7D/hmKf2vDsH
9My8JhoqG6SN3lkvqD2OpdKTPed4ES2l73J1WqqeY0myYF6dFnpXXhkLWp9+
cyyvMP5ZLikJRV8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 701->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNUksKAjEMLS7Ea4g30AOIV9ATjKArQdCFuPPoKsowU/I+qRsLdVqTvrz3
kvn+vD1OSinX2etn2902l0t3303fl0N3Wi1P7+Diu0t5rEv//YfNVh13MZw8
F3voF/MvwlJcfsFkWhBWhkudn6mDaiE9tY6ab8SF6VHvMhyiXEfXKD7YjkdO
35QHSOuIj4HhcnH5ZTCYnogbq8n+Z9iqbouWlo00Q03Cl6yHmX7XOEW8Z9oQ
JqvraHG1Mg71Ocp1Z9qNq/zoq+bJ5Yp6xzgrjcxH9E754tR0eo44ZfqZ5YD8
i/AUFxczymN+ungOZ4TD8JTOTF+VFy4u0hm9ZTpHMVEnWqiXLVxGtcR7htuy
kZahL0h71jPlSXR2Z6xl7pz+MD0ZzIwGZ9Z/retqcmelFRNpcDi3zrzqQ3RG
Wh0M5k2EHd3RLLA3iktmJmue9TnbT6TdmY2wHosRb5mXvT7SA3VnWhGXKL9f
Bi7j8g/7w+UJaG9HGg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 702->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIIXiPkBvEA4hXMCSYQV4KgC8kuR1dJCKat3+vZKLTTY7+u
V1WvfPnYb7ZPrbXj4vK1mU7rw2H6en++vnxOu+Xb7nr4+rta+161v+cjLPXp
z1OMpC7FvvVL+YewHJc5mEoLw6pw6esrfVgvpqfX0fNFXJQed6/CAdUmumBN
6FEyt6gf4dXrq/iX1CnsCobSg7ipnup3he36jmgZWUwz1WR8qXpYmXeP08x9
pY1hqr6JllSr4tDvUW2a6fTc1aOny1PKlc1OcXYalY/snvMl6ZnMnHGqzLPK
gfmH8ByXFBPVKT9TvIQzw1F4Tmdlrs6LFJfpRHeVzlSDmhc6G+HCernMVzwb
ya/SOOKZ8wTt04yN5C6Zj9JTwaxoSLI+t2+qaW5WEh7sP+E4j2bezQHtmdYE
Q3mDsNE7y4K647hUMtnz/LcfmCfTnmQD1bebleQ2mSPUKrDu3o1WxgXVp7+5
DD3C+uFyBk6ESBw=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 703->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNUktKA0EUbFyI1xBvoAcQrxBPMIJZBYS4EHceXeMnDM/6vc4mA52eSb+u
V1Wvrp9eNtuLMcbr1dfPZnl72O+X98fLw8fzsru73R0Ob37XGB/347ifw1JP
PU8xkroUe+2X8g9hOS6nYCotDKvDpdZ3+rBeTE/VUfkiLkqPu9fhgGoTXbAm
9CiZW9SP8BpldfxL6hS/DobSg7ipnup/he36zmiZWUwz1WR86XrYmXfFqRlL
udS91g3SN9GSalUcjs9KI+KSZDo9d/Vod3lKubLZKc5OI+Li7jlfkp7JzBmn
zjy7HJh/CM9xSTFRnfIzxUs4MxyF53R25uq8SHGZTnRX6Uw1qHmhsxkurJfL
fMezqfwKjTOeOU/Qe5qxmdwl81F6OpgdDUnWT+2bakqzMovJNCScZzPv5oDe
mdYEQ3mDsNE3y4K647h0Mll51vfuPJn2JBuw398yXBIv/mkVM3DfSivjguq/
n5XOJJuIyzmsHy6fOHxHVw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 704->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlk1OAlEQhDssjNcg3kAPQLwCnmBMZEViggvDjqMjEUfSqaqufrNhksf8
vH7VX3X3gvX753a3ioivx5+f7fT9ejhMx7eHy8vHtH953l82n64r4rSJ+X4P
S11539Vw4lzt23qp+iGtimWJpvLCtDosOb6Th+VifrKPzItYlJ/qXIcBxTq+
YIxZI6dvVj7CFX/rhmkpi8vX0VB+EJvKqb4r7SrviJeRxTxTT0VdujXs9LvS
cVnyvfLRZXC8Kob8jGLdmXb3q3h0r+bJZWW9U8yVR1VHdq6qi5PT6Tlj6vSz
y8Dqh/QqFlcTxal6unoOM9NRepXPTl+rWri6zCc6q3w6NUD8OQ/63mWZ9zfx
/3+BnFe6I4t5OV1ZmMdKj13uTDqeXE2kVZ3rzICj2fHgzPrSvK4nd1ZGNZkH
h3l05qs+oGfm1dFQtUHa6J3NgjpTsXRmMnPm524/mXdnNli+MFicWrhesxZ6
V14ZC4qf/Zk1ZCz3sH5ZzlUoR1s=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 705->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FOw1AMRC0WqNdA3AAOUHGFcoIg0VUlpLJA7Dg6VED1a82Mxz+bfuk3
SeM/fmM7dy9vu/1NRLxvfn52y8fT8bh8Pt+eHl6Xw+PD4fTy/m9HfG3jfL2G
rVZ+72o4ca72WC9VP6RVsazRVF6YVoclx3fysFzMT/aReRGL8lOd6zCgWMcX
jDFr5PTNyke44n8PTGtZXL6OhvKD2FRO9b/SrvKONXW9zGzmmc1ZnjVWr+4c
O/0ua2Wy5GuOC5LXZXC8KoaL+4FHzVyHAXou4tG1mieXlfVOMVceEUt1rqqL
k9PpOWPq9LPLwOqH9CoWVxPFqXq6eg4z01F6lc9OX/OZmPw+mE90Vvk8r4GF
5UGL9XKGheWqZr5Ts5n5VR4rPbbcmXQ8uZpIqzrXmQFHs+PBmfW1eV1Pa2fF
4WDfRMU8O/NVH9A98+poqNogbfTMZkGdqVg6M5k58323n8y7MxssXxgsTi1c
r1kLPSuvjAXFXyyjhozlGvYvyzfNS0Vb
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 706->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0tKA1EQRR8OxG2IO9AFBLcQV9CCGQWEZBCcuXQNfrDL+6vuSRpe+vPq
3Tq3qnL7/LrdXY0xjjefP9vp9Hg4TG9P1+eXl2n/cL8/b959rzHeN+P3fglL
XXU/1UjiUu2/9VL1Q1qOZY2m8sK0Oiw1vpOH5WJ+qo/Ki1iUH3euw4BiE18w
JqxR0rcoH+EaPyvQSFlSvo6G8oPYVE71XWm7vEu8LFnMs5ozVZduDTv9djop
S707H12GxKtimD2T2HSm030Xj+5unlJW1jvF7DwiFnfO1SXJmfScMXX62WVg
9UN6jiXVRHGqnqlewsx0lJ7z2emrq0Wqy3yis8pnUgPEX/Og710WlsvNfKdm
S+ZXeXR67EpnMvGUaiItd64zA4lmx0My62vzpp7WzkrCwf4TjnnpzLs+oGfm
NdFQtUHa6J3NgjrjWDozWTnrc7efzPssRniFegFLUgvodfNfv2qhd+WVsaD4
2RXUkLFcwvpi+QBO1Ucc
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 707->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLKQXCPkBnqAkCvoCSYQV0LALII7j66iBKep35tx4UDP93W9
qno1b18/6+1La+339XxaD3+f+/1w2CwuD9/DbrXcXT6+31Zrx4/2f32GpY7+
e4qR1KXY934p/xCW4zIHU2lhWBUufX2lD+vF9PQ6er6Ii9Lj9lU4oNpEl/LF
eZTMLe2H6lqBc8ol5VfBUHoQN9VTvVfYru+9p6mWKYtpppqML1UPK/O2XoVc
+qvTUeWQaFUcRvekNs10+t3Vo6vLU8qVzU5xdhoRF7fP+ZL0TGbOOFXmWeXA
/EN4jkuKieqUnylewpnhKDynszJX50WKy3SivUpn4gHi3/dB76tcWC+X+Ypn
U/KrNDo8dqSZTDSlmAjL7atkIMGsaEiyPrdvqmluVhIe7J9wnKdm3s0B3TOt
CYbyBmGjZ5YFtcdxqWSy54lqKvNk2kc1QivFC3ObzHGk9cZHYTEtTCvjgupH
R+Ah6vXI/2XOunI5AXL4Rt0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 708->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0luAjEQtDhEfAPlB+EBiC+QF0yk5ISEBAfEjacDWWdM19J2Dlgy9uB2
dVV1e/G223zMSimH+fVnMxzX+/1wen26fbwP2+XL9nb4/D1LOa/K7/oIk436
3MVw4lzssV/MvwhLcenBZFoQVoZLHZ/Jg3IhPbWOmm/EhelR9zIcolhHF/NF
eeTUzc0XxZUEZ5eLyw9iGLWkmoge9T/DVnldP3on0gw1CV+yHmbqrXBcLvWq
dGQ5OFoZh8kexLo97Z6r+GhV/eRyRbVjnJXGiIu6p3xxcjo1R5wy9cxyQP5F
eIqLixnFMT9dPIczwmF4SmemrvWd0vg+kM7oLtN5l5fkiQaqZQsXlEv1fMaz
lv5lGhUeGm5POppczAhL3cv0gIOZ0eD0em9eV1Nvrzg80JtQnFt7XtUh2iOt
DgbzJsKOvifrTwypucMl05M1z8m+oZ5Iu9MbUTzDYt6yOo71jXU7njtaEZco
/nOs/qbTm3Wu/3wvPfOLywXm/kZb
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 709->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQfGQhuUbwBnqA4BXiCUbQVUBIFpJdjq5RidLUr2c2GXiZz+tX
XVVd2by8795WY4zj+utnN308HQ7T6fnu8vI67R8f9pfN+981xnk7rvdbWOqq
+ylGUpdi//dL+YewHJclmEoLw+pwqfWdPqwX01N1VL6Ii9LjznU4oNpEl/LF
eZTMLe2H6kaDc8ol5dfBUHoQN9VTfVfYru8cLXMW0+zqnF/dHCd9nV8pl3p3
OhgHl6d0nvVMfUa1aabTfVeP7i5PKVc2O8XZaVQ+snPOl6RnMnPGqTPPLgfm
H8JzXFJMVKf8TPESzgxH4Tmdnbk6L1JcphOdVToTDxD/2gd973JhvVzmO57N
ya/S6PDYlWYy0ZRiIix3rpOBBLOjIcn60r6ppqVZSXiw/4TjPDfzbg7omWlN
MJQ3CBu9syyoM45LJ5OVZ33uzpNpT7LB+jEs5a3y8qpPzEC+G62MC6r/vrZ/
K8km4nIL64fXJxb0Rx4=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 710->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOwzAUtFggroG4ARyg4grlBEGCVaVKZYHYcXRoQVHqzu85LLDkJmme
583Mm9w+77evV621t5vvn+30/ng4TB9P18eHl2n3cL87vrz73a19btp8/Q9b
rf59ipHUpdhLv5R/CMtxWYOptDCsCpe+vtKH9WJ6eh09X8RF6XHnKhxQbaJL
+eI8SuaW9kN1bbkNRsol5UcxgllKTWIG7n+F7fqmfqzdTDPykfFP8BKNzuPT
WmQsyRXTdobZzwb1FfUjWhWHeS10Ii5JptP3rh5dXZ5Srmx2irPTiLi4c86X
pGcyc8apMs8qB+YfwnNcUkxUp/xM8RLODEfhOZ2VufZn2uD3wXSis0rnRV/R
By02yxEurJfLfMWzkfwqjQ6PrTSTiaYUE2G5c5UMJJgVDUnW1/ZNNa3NSsKD
fROO82jm3RzQPdOaYChvEDZ6ZllQZxyXSiZ7nv19dZ5Me5IN1o9hKW+Vl7M+
MQOHrbQyLqj+tAAXpvui1x9+K2v3D68vNgJHVw==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 711->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOAzEUi1ggroG4ARwA9QrlBIMEq0pIZVF116P3A61o8O9lWBApnUyT
+Nl+nvvXj+X7TWvt8+7ws5w2i/V62r7cHl/eptXT4+q4+fA9W9s9t8vzP0w1
+v0UIzmXYv/0S/mHsByXOZhKC8OqcOnPV+qwWkxPr6Pni7goPe5ehQM6m+hS
vjiPkr6l9dC5dp4BRsol5VfBUHoQN1VT/a+wXd0RLSOTaWZ9db5UPaz0+zQA
F5Urpu0K0+hA6zMX1fu0n/2dq7XgkmQ63Xfn0dPlKeXKeqc4O42Ii7vnfElq
Jj1nnCr9rHJg/iE8xyXFROeUnylewpnhKDyns9JX50WKy3Siu0rnr7qiDhqs
lyNcWC2X+YpnI/lVGh0eG2kmE00pJsJy9yoZSDArGpKsz62bapqblYQH+yYc
59HMuz6gNdOaYChvEDZ6Z1lQdxyXSiZ7nv262k+mPckGq8ewlLfKy4s+0QOH
rbQyLuj8aRSz2df6y+9lzvzisgcHAEXd
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 712->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lOw0AQHOWA+EbED+ABEV8ILzASnCIhhQPKLU+HCAjOUFuPOWCp7bGn
p7qqur1+fNk+r1prr9cft+30dr/fT4eHq9PL07S7u92dNm++orXjpp2f/yHU
1e+nGEleij33S/mHsByXJZhKC8OqcOnzK3VYLaan19HzRVyUHneuwgHlJrqU
L86jpG9pPZTXCpxTLim/CobSg7ipmuq7wnZ1R7SMBNPsPHB+Vec46ff52vxE
whvl/MIUZyGHuRcDWhWHi/V3gL1kptN9l4+ebp5Srqx3irPTiLi4c86XpGbS
c8ap0s8qB+YfwnNcUkyUp/xM8RLODEfhOZ2VvjovUlymE51VOhMPEP++Dvpe
5cJquZmveDYyv0qjw2NXOpOJphQTYblzlRlIMCsakllfWjfVtHRWEh7sn3Cc
R2fe9QGtmdYEQ3mDsNE7mwV1xnGpzGTPs19X+8m0J7PB6jEs5a3y0mntsVR9
xI9xQfmMC9N9kTeLv/xnRuOT1zu2gUTf
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 713->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPIhXiN4Az1A8ArxBCuYr4AQPyR/OboGRUynXr0L4sJkZ7M9
1VXVtevn1+1uNcZ4u/382U7vj4fDdHy6OT+8TPuH+/355d33GuO0GT/3/7DU
Vd+nGEldiv3bL+UfwnJclmAqLQyrw6XWd/qwXkxP1VH5Ii5KjzvX4YBqE13K
F+dRMre0H6obZXX8S+oUP4oRzFJqEjNw/yts1zf1Y+limp0Hzq9ujpN5X+zB
bFMu9U45Cw4XXmyua51WxeFqD/ApZsABajD16O7ylPjAMNEzwu5wceecL0nP
ZOaMkztTec3py3qm2MgbpwNdyUwTX1xemOeJX8m30c1JR5/Sic4qnYkHiH/t
g/7vcmG9XOY7ns3Jr9Lo8NiVZjLRlGIiLHeuk4EEs6MhyfrSvqmmpVlJeLBv
wnGem3k3B7RnWhMM5Q3CRs8sC+qM49LJZOVZ9915Mu1JNlg/hqW8VV46rRVL
9Uf8GBdUP8RcFU73+/qL9cXlA5E3Rpo=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 714->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0tKA1EQRR8OxG1IdqALELcQV9CCjgJCHIizLD2JRGnK+6tuBwZe0p+q
W+dWVW6f37avV2OM95vT13b6eNzvp8+n6/PNy7S7v9udX24uZ4zDw/j5/Q9H
fer7VCOJS7Xn/VL9Q1qOZY2m8sK0Oiw1vlOH1WJ+qo/Ki1iUH5Q3BLtiQLGJ
LxozY3HMam5xPRA3ykn651hSvo6G8oPYVE31XGm7uku8LDnMs+uB61d3j5N5
/7oO9op5q5owVzAwL6lXxQDrmZ3rMKD3Lh79un1KWdnsFLPziFhcnutLUjOZ
OWPqzLPLwPqH9BxLqoniVD9TvYSZ6Sg957MzV9eLVJf5RLnKZ9IDxF/roOdd
FlbL7XynZ0v2V3l0euyT7mTiKdVEWi6vswOJZsdDsutr66ae1u5KwsH+E455
6c67OaBr5jXRUL1B2uie7YLKcSydnayc9bo7T+Y92Q1Wj2mp3qpeOq9VS9VH
fIwFxY/vA7iUzmGW92f/lbX5XyxHBd1FHA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 715->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVFtKA0EQbPIhXiN4Az1A8ArxBCvoV0CIH+Jfjh6DazCdrkfPgrgw2Um2
p7qqujbr57ft6yoi3m+/PrbTx+N+P30+3Zy+vEy7h/vd6eHdvCIOmzjf/8Ni
V37uYjh1LvZvv5h/FZbisgSTaUFYHS65vtMH9UJ6so7Mt+LC9KhzHQ5VraML
1hgeOXOz+xV18bNmPh3/nDrGr4PB9FTcWE/2O8NWfUe0jCykWXmg/Orm2Jl3
3ju5Qtoy5lXdvBCHCy8GtDIOV3vAxcm0+1zVV3eVJ5crmh3jrDSivLBzyhen
pzNzxKkzzy4H5F+Fp7i4mFUd89PFczgjHIandHbmqrxwcZHO6izTeb42cfF/
UvWpLjTLES6ol8p8x7OR/DKNCg9dbiYdTS5mhaXOdTLgYHY0OFlf2tfVtDQr
Dg/0TijOo5lXc6j2SKuDwbypsKvvKAvsjOLSyWTmmffdeSLtTjZQP4TFvGVe
Kq0Zi/Wv+CEuVX2QuTKc7vv1F+ubyxHzU0Zb
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 716->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQfLiQXEO8gR4geIV4ghHMKiDEhbjz6BocxHTq1zObDLzMm5l+
1VXVlbuXt93+Zozxvvn52U0fT8fj9Pl8e3p4nQ6PD4fTx/t5jfG1HX/3a1jq
qt9TjKQuxf7vl/IPYTkuazCVFobV4VLrO31YL6an6qh8ERelB50bgrvigGoT
XcoX51Eyt7QfqjvzIvTPcUn5dTCUHsRN9VTvFbbru0TLksU0Ow+cX90cJ/Ou
+yRXTFvFvKibF+PAtKRaFYezveCSZDr97urR3eUp5cpmpzg7jSwv6pzzJemZ
zJxx6syzy4H5h/AclxQT1Sk/U7yEM8NReE5nZ67OixSX6URnlc7EA8S/9kHv
u1xYL5f5jmdL8qs0Ojx2pZlMNKWYCMud62QgwexoSLK+tm+qaW1WEh7sP+E4
L828mwPaM60JhvIGYaNnlgV1xnHpZLLyrPvuPKn2IBusH+LNcpvMccx8mNYL
7qI/1Eq4oPoBzjBclaFrWL9cvgFGUUbb
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 717->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNlk1Ow0AMhS0WqNdA3AAOUHGFcoIg0VUlpHaB2HF0aBVQ4vr9OGFBpGkm
Gc/z9zyO1LuXt93+JiJOm++f3fD+dDwOH8+354fX4fD4cDgv3o8j4nMbv/f/
MNiV110NJ87VntaL1a/SUixrNJkXpNVhyfGdPCgX8pN9ZN6Khfmp9gVhZwxV
rOMLxkxYFDM7NztfEReJx6mfYnH5OhrMT8XGcrL3TFvlXeJlyUCeVQ1Uvbp9
7Jx3njt9hbxlzau4cSAG5MX1yhhm859RrDk97a6r+Oqu+sllRWfHmJVH1C9s
n6qLk9M5c8TUOc8uA6pfpadYXM0qjtXT1XOYkQ7TUz4756pq4eoin9Ve5tOp
QcWf81Tvuywol+r5Ts2W9C/zqPTQ5fak48nVrLTUvk4POJodD06vr83relrb
Kw4H+iYU89KeV+dQzZFXR4PVptKunlEvsD2KpdOTmTPPu+eJvDu9gfIhLVZb
VsvLRbxmLZa/4kMsV9c2Zv97pyzI9yxuHH/2razdf+H6AurJRNs=
                    
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 718->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKxEAUbFyI1xBvoAcIXmE8QQRdDQjjQtx5dB0/mdip30sW2tAmsV/X
q6pXc3n/tHs8a609X3z82Y0vt4fD+Hp3fvx4GPc31/vj4dX3bu1taNPzP2y1
+vMUI6lLsed+Kf8QluOyBVNpYVgVLn19pQ/rxfT0Onq+iIvSg+41wV1xQLWJ
LuWL8yiZW9oP1bXgfpVLyq+CofQgbqqn+r/Cdn3XaFmzmWbngfOrmuNk3tMa
TjvhjWoWmH3dDB9yIFpSrYrDr/efDc6STKfnrh49XZ5Srmx2irPTiLi4e86X
pGcyc8apMs8qB+YfwnNcUkxUp/xM8RLODEfhOZ2VuTovUlymE91VOqc1nJ6s
D1pslmu4sF4u8xXP1uRXaXR4bKWZTDSlmAjL3atkIMGsaEiyvrVvqmlrVhIe
7DfhOK/NvJsDemdaEwzlDcJG3ywL6o7jUslkz7N/r86TaU+ywfoxLOWt8vJz
Ca091uLbaGVcUH2PlWRzfrcNS1/+an/xegfKakTb
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 719->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0luwkAQHHGI8g3ED8IDIr5AXmCkcEJCIoeIG08nLIqsdtfS40My0mAb
91RXVZeXu+N2v2itfb3+/GyH783pNJw/Xm4Pn8Nh/Xa4vVw9d2uX9/Z7/Q+b
rfjexXDqXOyxX8y/DEtxmYPJtCCsCpdYX+mDeiE9UUfkm3FhetS5Coes1tHF
fFEeOXNz+2V1zfSwwsXlV8FgejJurCf7n2Grvj1aejbSrDxQflVz7Mw73ju5
Qtoi5qTuuREHpMXVyjiwfg52D0dVn11VnlyuaHaMs9KI8sLOKV+cns7MEafK
PKsckH8ZnuLiYmZ1zE8Xz+GMcBie0lmZq/LCxUU6s7NM56Qv6ZMtNMseLqiX
ynzFs578Mo0KDy03k44mFzPDUucqGXAwKxqcrM/t62qamxWHB/omFOfezKs5
ZPdIq4PBvMmws2eUBXZGcalkMvKM99V5Iu1ONlA/hMW8ZV7eF9EasSbPQivi
ktVHLCeb47NthPHX+8HrChzZRZ4=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 720->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhQsX4jXEG+gBgleIJxhBVwEhLsSdR9eoxNC+v+oBsaEzM5mu
V9+rqrm8f9o+nlXV88XHz3Z5ud3vl9e788PDw7K7ud4dXl5976q3TR2v/2Gr
Nb5PNZJzqfZpvVT9kJZjWaOpvDCtDst4vpOH5WJ+Rh8jL2JRflxchwGdTXyp
upToB2J2et1vooL4LkvK19FQfhCbyqn+V9ou74yXmc08uxq4enXnOOn3cW1+
dsKNzvzSRLGK4bQWE14Vg8qXaDsG6MGcR1c3Tykr651idh4Ri4tzdUlyJj1n
TJ1+dhlY/ZCeY0k10TlVz1QvYWY6Ss/57PTV1SLVZT5RrPKZ1ADxj3nQ/10W
lsvNfKdmM/OrPDo9ttKZTDylmkjLxXVmINHseEhmfW3e1NPaWUk42DfhmGdn
3vUB3TOviYaqDdJGz2wWVIxj6czkyDned/vJvCezwfIxLVVbVcvPJbyOWio/
4mMs6HyJviqd7vf1F/uL5R38yEYe
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 721->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQbPwQryHeQA8gXiGeYAXzFRDih+QvR0+iRrJt16NnP3RgsrOZ
meqq6trbl7fV+ioi3m+OP6vp42m7nXbP16eX12nzcL85bd59z4j9Y/w8/8Nk
I++7GM45F/vSL+ZfhaW4LMFkWhBWh0s+36mDaiE9WUfmW3Fheqp7QbgzDtVZ
RxfzJQAO0qrwut/EzAvTP8XF5dfBYHoqbqwm+59hq7ojWkYm0qw8UH51c+z0
O6+dXCFtGfPXOcEBaXG1Mg6z9XkWe06m3X11vnqqPLlcUe8YZ6UR5YXdU744
NZ2eI06dfnY5IP8qPMXFxazOMT9dPIczwmF4Smenr8oLFxfprO4ynbM9Uaca
qJcjXFAtlfmOZyP5ZRoVHhpuJh1NLmaFpe51MuBgdjQ4WV9a19W0NCsOD/RN
KM6jmVd9qNZIq4PBvKmwq3eUBXZHcelkMvPM624/kXYnG6gewmLeMi8/B9Ga
sVj9ih/iUp0P0leGc74bFxh/Pb94HQBnk0ca
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 722->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLKQXCN4Az1A8ArxBCPoKiAkC8kuR9foKLGp3+tZaENnZjKv
61XVq9k8ve5eVq214/rjZze9PRwO0+nx5vLwPO3v7/aXl7fzbu28bT/X/7DV
6t+nGEldin3tl/IPYTkuSzCVFoZV4dLXV/qwXkxPr6Pni7goPe5chQOqTXTR
mu28hUfJ3OJ+oK4F56tcUn4VDKUHcVM91f8K2/Ud0TKymWbngfOrmuNk3r/u
553wRjU9pvIAcWBaUq2Kg+qXYI9wdPXo6vKUcmWzU5ydRsTFnXO+JD2TmTNO
lXlWOTD/WN7dvCrZRCuZaeKLywvzPPEr+TaqOanoUzrRWaUz8QDx7/ug/6tc
WC+X+YpnI/lVGh0eW2kmE00pJsJy5yoZSDArGpKsL+2balqalYQH+yYc59HM
uzmge6Y1wVDeIGz0zLKgzjgulUz2PPv76jyZ9iQbrB/DUt4qLz+X0Npjqf6I
H+OC6puYq8L5Pot4/dX+4vIOdm1Gng==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 723->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQbPIhXiN4Az1AyBXiCVbQr0AgfgT/PLpGRTadrkfPfujAZGey
M9VV1bXrp8PuZRURr7efP7vptD0ep7fHm/Pmedo/3O/PL+9+ZsT7Jn6f/2Gy
kd+7GM45F3vuF/OvwlJclmAyLQirwyWf79RBtZCerCPzrbgwPdW9INwZh+qs
o4v5EgAHaVV43W/iwgvTP8XF5dfBYHoqbqwm+59hq7ojWkYm0qw8UH51c+z0
+2pt5Appy5jMg4oD0uJqZRxYPQd7hKM6Xz1VnlyuqHeMs9JYcVH3lC9OTafn
iFOnn10OyD+Ud9WvTjar4fTU8UXlBXnu+OV8G92cdPQxndVdpvPinahTDdTL
ES6olsp8x7OR/DKNCg8NN5OOJhezwlL3OhlwMDsanKwvretqWpoVhwf6JhTn
0cyrPlRrpNXBYN5U2NUeZYHdUVw6mcw887rbT6TdyQaqh7CYt8zLr0G0Zqyr
vdCKuFTnM5aTzfndmGH89fzm9QGswkVd
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 724->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHFyI1xBvoAcQrxBP8ARdBYS4EHceXYMSkk79et4mA5O8l+mp
rqqu3L68b96uxhgfN78fm+Xzabdbvp6v9y+vy/bhfrs/vPvfY3w/jsP3JWy1
6nmKkdSl2Md+Kf8QluOyBlNpYVgdLrW+04f1YnqqjsoXcVF63L0OB1Sb6FK+
OI+SuaX9UN04Pm/6l9Qpfh0MpQdxUz3V7wrb9Z3RMrOZZueB86ub42TehyVq
U21nmLXOcRi61mlVHE6eBZck0+m5q0ffLk8pVzY7xdlpRFzcPedL0jOZOePU
mWeXA/MP4TkuKSaqU36meAlnhqPwnM7OXJ0XKS7Tie4qnSdnpg9abJYzXFgv
l/mOZzP5VRodHltpJhNNKSbCcvc6GUgwOxqSrK/tm2pam5WEB/tPOM6zmXdz
QM9Ma4KhvEHY6J1lQd1xXDqZrDzrc3eeTHuSDdaPYSlvlZdOa8U6ezdaGRdU
X7GSbCIul7D/eP0ArH5IGg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 725->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLIQrxG8gR5g8ArxBCPoKiDEhWSXo2tE4tip3+vZ2NDJJP26
XlW9mu3z2+5101p7v/362M0fj4fDfHy6Of94mfcP9/vz4d3Pbu00tcv3f9hq
9ecpRlKXYi/9Uv4hLMdlDabSwrAqXPr6Sh/Wi+npdfR8ERelx92rcEC1iS7l
i/MomVvaD9W15XnRv6RO8atgKD2Im+qp/lfYru+IlpHNNDsPnF/VHCfzvqzp
dye8Uc0VpvAAciBaUq2KA3tWmatwQOeuHn27PKVc2ewUZ6cRcXH3nC9Jz2Tm
jFNlnlUOzD+WdzevBBPVKT9TvIQzw1F4Tmdlrs6LFJfpRHeVzj9npg9abJYj
XFgvl/mKZyP5VRodHltpJhNNKSbCcvcqGUgwKxqSrK/tm2pam5WEB3snHOfR
zLs5oGemNcFQ3iBs9JtlQd1xXCqZ7Hn2z9V5Mu1JNlg/hqW8VV46rT2W6o/4
MS5Xa1pswEvhVN+v6F1Ze/+byycqI0Zd
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 726->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqwzAQFPkIuUboDdoDhF7BPYELzVeg4HyE/uXoqakpzbLzWBlKBIrl
SJqdmR3v3z+H46a1dt59/wzj5XWaxq+37fzyMZ5enk/z5tMyW7se2u/zESYb
cd/FcM652H/9Yv5lWIrLGkymBWFVuMTzlTqoFtITdUS+GRemR92rcMjOOrqY
L8ojp29uvexcMz2scHH5VTCYnowbq8n+Z9iqbo+Wnok0Kw+UX9UcO/2OaydX
SFvEZB5kHJAWVyvjgNYscxUO2b46f/dcpsqTyxX1jnFWGlFe2D3li1PT6Tni
VOlnlQPyD+Vd9cvBzM4xP108hzPCYXhKZ6WvygsXF+nM7jKdd3uiTjZQL3u4
oFoq8xXPevLLNCo8NNxMOppczAxL3atkwMGsaHCyvrauq2ltVhwe6JtQnHsz
r/qQrZFWB4N5k2Fn7ygL7I7iUslk5BnX1X4i7U42UD2ExbxlXiqtEYvVz/gh
Ltn5RvrKcKrf13/MHy43ZIBI3Q==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 727->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQHPwQrxFyA3MA8Qp6gg0kX0JAP8S/HF1Ngux2uh49++PA6K7T
U11VXb68f+0+F6210+r2sRvO2+NxuOyX95eP4fC2PtwPX/92a9+b9vh+hs1W
PHcxnDoXe+wX8y/DUlzmYDItCKvCJdZX+qBeSE/UEflmXJgeda/CIat1dDFf
lEfO3Nx+WV0zPaxwcflVMJiejBvryX5n2LJvh5aejTRPZjqarfKl6mFl3j9r
xMfJFdI2wVQeRA5Ei6uVcUDPLHMVDtm5qp98m3lyuaLZMc6PRfjEeuWN8oXd
Vb44nCrzVL4qDIanuLiYWR3z08VzOCMchqd0VuaqvHBxkc7sLtM5ORN9soVm
2cMF9VKZr3jWk1+mUeGh5WbS0eRiZljqXiUDDmZFg5P1uX1dTXOz4vBA/wnF
uTfzag7ZM9LqYDBvMuzsHWWB3VFcKpmMPONzdZ5Iu5MN1A9hMW+Zl0prxPr3
LrQiLlk94pLhsgw9w/7lcgVXIkdZ
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 728->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU8tNQzEQtDgg2kB0AAUgWggVPCQ4RUIKB8SN0iHio2Qzv33mgCXn2fF6
dmZ2ffnwvHk6G2O8XHz+bJbXu91uebs/328el+3N9XZ/ePU9x3i/Hb/f/zDV
qOcpRhKXYh/6pfxDWI7LDKbSwrA6XGp8Jw/LxfRUHZUv4qL0oHtDcFccUGyi
S/niPErqluZDcaPMxD/HJeVHMYJaSk2iBu5/he3ypn7MTqYZ1pTwT/ASjc7j
wy+LTbVVLOnB8PFdrYoDWyvtHQ7o3MWn/ae4d7DRfg12xVfeOF/U3XQqTp16
djk4/1Js5I3TgYa63/HF9QvzPPEreRvdPunoUzrRXaXz6MzkQYPVcg0Xlsv1
fMezNf2rNDo8NtKeTDSlmAjL3ev0QILZ0ZD0+mzeVNNsryQ82JtwnNf2vKsD
WjOtCYbyBmGjPesFdcdx6fRk5VnX3Xoy7UlvsHwMS3mrvHRaK9bJ3mhlXFA8
44JwT+J+9n/4XmbmF68PgWpImA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 729->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQbPyQXENyAz1AyBXiCTagX4FA8hH88+gaTCS23fWYBXFhsruZ
nuqq6tqH7X7zehcRx8Xnz2Y6rQ+H6e35/vzyMu2eHnfnzeVlRbyv4vv+Hxa6
8r6KodSp2Ld+If8qLMZlDibS0mE5XHK906fr1enJOjLfigvSw845HKpaRRfy
hXmkzE3tV9XFdQkYKheVn4OB9FTcUE/0P8JmfUe0jKxO86+Z5v+JX26OlXnf
3rtaVVvGgh4Er3e1Ig7dM9LucKj2Wb2aP8Tdwa7eR7AzPvKG+YLOqgtxcubp
cmD+qdiVN0xHdaHzji8sL53nil/Kt+HmxNGHdFZnkc4fe6RPdXWzHOHS9WKZ
dzwbyS/SyPC6S82koknFrLDYOScDCqajQcn63L6qprlZUXh03wTjPJp5Nofq
udOqYCBvKuzqvcsCOsO4OJnMPPOzO89Ou5KNrl+HhbxFXjKtGQv1r/h1XKr6
AHNFOO739Rfri8sH66pKGg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 730->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbFwEryG5QXKAkCuYE0wgWQkBXQR3Hj2RSBjbV7+ejQPtzNiv
61XVq9m8f20/V621w/r3Zzt9v+730/Ht4fzyMe2en3bnzcfLau300v7v97DY
1e+7GE6diz33i/lXYSkuSzCZFoSVcOnrkz6oF9LT6+j5VlyYHnUu4VDVOrqY
L8ojZ25uv6quBZxdLi6/BIPpqbixnux/hq36jmgZWUjz1f5stsqX1MNk3vM7
qnW19VjSA1GfamUc0DPTnnCo9lX9PAtunlyuaHaMc+KDM2/HF3bWXYxTMs+U
g/LPxa68UTqqi51PfFF5QZ47fjnfRpqTRB/TWZ1lOq/2Lgv1qS40yxEuqJfK
fOLZSH6ZRoWHLjeTjiYXs8JS55IMOJiJBifrS/u6mpZmxeGBvgnFeTTzag7V
M9LqYDBvKuzqHWWBnVFckkz2PPvndJ5Iu5MN1A9hMW+Zl0prj3XzLrQiLlU9
4lLhsgzdw/rj8gPWHkfd
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 731->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKAjEUDC6GuYZ4Az3A4BWcE7SgK0FwFoM7j+4oKu3z1eeZzQSi6U5S
r6pe9XS9X20nrbWfz7+f1fC7PByG4/fH5WEz7Bbz3WVzdputnb7a4/8/TDbi
vovhnHOxx34x/zIsxaUHk2lBWBUu8XylDqqF9EQdkW/GhelR9yocsrOOLuaL
8sjpm1svO9fu+7d1xT/nHOMHMYxeUk2kB+o9w1Z1XT96J9KM8qV8qXpY6fd1
FDLAtD1hFj1gWlytjANas8xVOGT76vzYfzdPLlfUO8b5MQpclDfKF3pX+OJw
qvRT+aowGJ7i4mJm55ifLp7DGeEwPKWzmnvmhYuLdGZ3mc6nPZDXjH+sk72v
ckG1VOYrnr2TX6ZR4aHhZtLR5GJmWOpeJQMOZkWDk/Xeuq6m3qw4PNA3oTi/
m3nVh2yNtDoYzJsMO3tGWWB3FJdKJiPPuK72E2l3soHqISzmLfNSaY1YL89C
K+LyMkIG4prh3Hm0EZ/ub6X3/pXXGXK2RZo=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 732->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuwkAQW3Go+AbqD8oDEF+AF6QSnJCQ6KHixtOBiiI0sT2ebA+NtCRh
Zz22x1l8Hjf7WWvta3772Qzf69NpOG/f7i+74bD8ONw33x+rtcuqPe//Yakr
7rsYTp2L/eqX8g9hZVx6MJUWhlXhEusrfVgvpifqiHwRF6UnO1fhgGodXcqX
zCNnbm4/VNd+981cOFxcfhTjsVw9iJvqqf5X2Flf14/exTSPeLL/iV/VHDvz
fr2zWldbxHI8QPUxW65WxYE9K+0VDmg/q3fzp7hXsNE7wo7+u9lBvDJf1Fl3
KU6VeVY5MP9Y3rN5OZioTvnp4jmcGY7Cy3RWc6+8cHGZTnRW6Rz1FX3QxWY5
hQvrlWW+4tmU/CqNGR673Ew6mlxMhJWdq2TAwaxocLLe29fV1JsVhwf7JjLO
UzOfzQE9M60OhvIGYaN3lgV1JuNSyWTkGZ+r82TanWywfgxLeau8zLRGLNUf
8WNcUD3jwnSPev3lt9J7/ofXFYVTRxw=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 733->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0kKAjEQDB7Eb4g/0AeIX9AXjKAnQdCDePPpLoho7Fp64sFAnIlJqquq
a8br/XI7KKUcR7efZXdaHA7deTW8Lzbdbjbd3Tcnz1nKZV5ez3+YbNT7LoZz
zsV+94v5F2EpLi2YTAvCynCpz2fqoFpIT62j5htxYXrUvQyH6Kyji/miPHL6
5tZD5x7DzIXDxeVH9YheMk1SK/mfYau6rh+tE2n+4jn/9FH5lc2x0+/3Jzrr
aquxHA8cLa5WxgG9M+0ZDtG+Ou/mj3HPYEfrCLskuChvlC/srjsZp0w/sxyQ
fyjvql8OZnSO+eniOZwRDsNTOrO5Z164uEhndJfp/NgTdaKBetmHC6qlMp/x
rE9+mUaFh4abSUeTixlhqXuZDDiYGQ1O1lvruppas+LwQN+E4tw386oP0TvS
6mAwbyLsaI2ywO4oLplM1jzr92w/kXYnG6gewmLeMi+V1hqL1Y/4IS7R+UL6
ynBe619+K633H7yumvZJGg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 734->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKwkAQWzyI3xB/oA8Qv6AvqKCngqAH8ebTtSqi4yST6fZgYdvddjaT
ZNPp9rDej0opp8n9tm7Oq+OxuWzG3WLXtIt5232cvUYp12V5P/9hsMt+VzGU
OhX70y/mn4cVcanBZFoQVoaLrc/0Qb2QHqvD8vW4MD3RvgwHr1bRxXyJPFLO
Te2H6qzWWi4qv6H0eNxYT/aeYUd9VT9qB9L8wxO9B35lc6yc9+cT1araLJbi
gaJF1co4oLmS574co3o1f4x7Bttbe9glwSXyJvKF7VUH45Q5zywH5B/Ke3Re
CqZXx/xU8RTOCIfhRTqzuWdeqLhIp7eX6VQ88PjbPt77LBfUK8p8xrM++WUa
Izx0qZlUNKmYHla0L5MBBTOjQcl6bV9VU21WFB7on4g49818dA7eHGlVMJg3
Hra3RllgeyIumUxannaePU+kXckG6oewmLfMy0irxWL9PX6Ii1f/uJLZ/Oo1
4L9SO568bgPvSJ4=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 735->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwkAQW/wQryHeQA9QvIKeoIJ+CYJ+iH8e3SdSp5NMpuuHhW2329lM
kk2nm8NqNyqlnCb326o9L4/H9rIeP1627X4x3z8+zt6jlGtTPs9/GOyy31UM
pU7F7vrF/POwIi41mEwLwspwsfWZPqgX0mN1WL4eF6Yn2pfh4NUqupgvkUfK
uan9UJ3VWstF5fcrPR431pOtM+yor+pH7UCaezzROvArm2PlvLtPVKtqs1iK
B4oWVSvjgOZKnodyjOrV/DHuGWzvvYfdvIbKJfIm8oXtVQfjlDnPLAfXP4AX
cVExvTrmp4qncEY4DC/Smc0980LFRTq9vUyn4oHH3/bx1rNcUK8o8xnPhuSX
aYzw0KVmUtGkYnpY0b5MBhTMjAYl67V9VU21WVF4oH8i4jw089E5eHOkVcFg
3njY3jvKAtsTcclk0vK08+x5Iu1KNlA/hMW8ZV5GWi0W6+/xQ1x6V9MZDi+G
87X2q3+ldv+T1w1MD0gc
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 736->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3oo+UbpD9oHhH7BfYEL7SkQcA4ltzw9MXVNmEgajX2xYeO1
PauRNMrL17H7eWqtnXa3n67//RiG/vz5PD5894f3t8P48XVarV32bb5vYakr
fncxnDoX+94v5R/CyriswVRaGFaFS6yv9GG9mJ6oI/JFXJSe7FyFA6p1dClf
Mo+cubn9UF2blpsLh4vLD75boAdxUz3Ve4Wd9XX9WLuY5gee7D3xq5pjZ973
d1braotYjgeOFler4sD2SnuFA/qe1c81hTy5XNnsFOd/LopPrM+8yXxRZ92l
OFXmWeUA/SN4GRcXE9UpP108hzPDUXiZzmrulRcuLtOJziqd8VJ90KVwqlxY
ryzzFc+W5LfileNZ5gnauxlbkjtnPkpPBbOiwcn62r6uprVZcXiw/0TGeWnm
szmgPdPqYChvEDZ6ZllQZzIulUxGnnFfnSfT7mSD9WNYylvlZaY1Yqn+iB/j
guoZF6abcdnC+uN1BQPFR90=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 737->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOAzEUi1igXgP1BnCAiiuUE0wlWFVCahcVO44OVT8aXp/97KQLIqWT
aRI/28/ztPlcfzy01vaL35/1dHjd7aavt8fjy/u0fXneHjeX59na96pdn/9h
shH3VQzlnIo994v5l2FVXEYwmRaE5XCJ5506qBbSE3VEvhkXpqe653DIziq6
mC+VR0rf1HrZuXaeai4ULiq/e+nJuLGa7H+GXdYV/RidSPOf/UtvAX8FD3nl
9PvKBWCpXOJT8qA472plHNBayXMvx+q8mj/G3cHO3nuwIz7zpvKF3VUn4+T0
0+VQ+adiZ95UOrLB7ju+VHlBnit+Kd+GmxNHH9OZ3WU642B1ssFwXC6oVpV5
x7Oe/DpeKZ5VnmRrNWM9uVP6w/Q4mI4GJeujdVVNo1lReKBvouLcm/mqD9ka
aVUwmDcZdvaOssDuVFycTEaece32E2lXsoHqISzmbYo/m0xrxGL1M36Iy82Y
cwpckO6bWnf8VkbnidcPt4RH2Q==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 738->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqAzEQMz2EfKP0B8kDQr+QvmALzSkQSA+ltz69DQ1hmZU0GjuHGLxr
e22NJGuf30/7w1Nr7XP999hPX6/n8/T9trpMPqbjdnO8fHy59tZ+du32foSu
WvzuYjj7XOy5X8o/hJVxGcFUWhhWhUvcX6nDajE9UUfki7goPdm5Cge019Gl
fMk8cu7NrYf2tSR3PVxcfnCtQw/ipmqqdYWd1XX9GO1M84InWyd+VXPs3Pf8
zfa62iKW44GjxdWqOLCx0l7hgL5n+938Ke4VbDTvwY74ypvMF3k28aUnzxkv
p57rn4uNvMl0oKbOV3zJ8sI8d/xy/o1yTgr6lE50VumMTdVBTeFUubBaWeYr
nvXkt+KV41nmCRq7GevJnXM/Sk8Fs6LByfpoXVfTaFYcHuyfyDj3Zj67BzRm
Wh0M5Q3CRnOWBXUm41LJZOQZx9X7ZNqdbLB6DEt5C/FnXWmNWKo+4se4LJrg
wnQvat3xXxnt/7x+AREXR9s=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 739->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0GKAkEQazyI35D9gfsA8Qv6glnYPQmCHsSbT98VZZGykkq6Lzb0TM9M
dypJZZZfh+3PrLV2WvxdttN5czxOl9389vA97T9X+9vHj8ds7bpu//d3mGzE
7yqGsk/FfvaL+ZdhVVxGMJkWhOVwifudOqgW0hN1RL4ZF6anOudwyPYqupgv
lUdK39R62b72mGouFC4qv/Rdh56MG6vJ3jPssq7ox+hEmlG+Kl9cD51+P9/R
XlVbxHI8YFpUrYwDWjPtDofse7VfzR/j7mBnzz3YEZ95U/minHX9Uc4iXnC/
gMHwKi5uT7LBzju+VHlBnit9cnrLdIz8H0hndpbpjIPVyQbDcbmgWlXmHc96
8ut4pXhWeZKt1Yz15E7pD9PjYDoalKyP1lU1jWZF4YH+iYpzb+arPmRrpFXB
YN5k2NkzygI7U3FxMhl5xrXbT6RdyQaqh7CYtyl+vAOtEYvVz/ghLi+DcEG6
EZd3mHdev6RXR5w=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 740->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwkAQW/wQryHeQA8gXkFPUEG/BEE/xD+PrlbRMk4yma4fXdg+trOZ
JJtOt8f1flRKOU8el3VzWZ1OzXUzfr7smsNifnh+nL1nKbdl+dyHMNmw31UM
pU7F7vrF/POwIi41mEwLwspwsfWZPqgX0mN1WL4eF6Yn2pfh4NUqupgvkUfK
uan9UJ3VWstF5fcvPR431pOtM+ywr+hH7USaf3guv5P5kvUwc97dO6pVtVks
xQNFi6qVcUDPSp77cozq1fwx7hls770PtsVn3kS+KHuz/ih7Ea+oV8Y/Fdvz
JtLhDbY/40uUF+S54lfmbJmOmv8D6fT2Mp3tCHp6/G29t57l0q6RbCvrmeyr
+WUaIzw01EwqmlRMDyval8mAgpnRoGS9tq+qqTYrCg/0T0Sc+2Y+OgfvGWlV
MJg3Hrb3jrLA9kRcMpm0PO1z9jyRdiUbqB/CYt66+PYOtFos1t/jh7j8DMIF
6UZchjBfvO4f20ia
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 741->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKwjAQDB7Eb4g/0AcUv6AvqKCnglAP4s2nqyii253Z2dSDgTRJm8zO
TKbz3XFzmJRSTrP7Y9Oe133fXrbTx2Lfdqtl9/i4ePVSrk15j//QWbPfVQxl
n4r96Rfzz8OKuIzBZFoQVoaL3Z+pg2ohPVaH5etxYXqicxkO3l5FF/Ml8ki5
N7Ue2lcSuVC4qPx+pcfjxmqy9ww7qqv6MbYjzQOe6D3wK5tj5b4/R7RX1Wax
FA8ULapWxgHNlTzXcoz2q/lj3DPY3roG2+IzbyJfpLNJfxQtiBet03xzifxT
sT1vIh1eY+czvkR5QZ4rOVb+jdqcqLhIp3eW6bSN1fEaw8lyQbWizGc8q8lv
xivFs8gTb65mrCZ3yv0wPRnMjAYl62PrqprGZkXhgf6JiHNt5qN78OZIq4LB
vPGwvTXKAjsTcclk0vK08+x9Iu1KNlA9hMW8dfHtCLRaLFbf44e4DBrhgnQj
Lv/Qn7xu8KJHnA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 742->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKwjAQDB7Eb4g/0AeIX9AXVNCTIOhBvPl0rYrUdWd2NvXQQNokTWZn
JtPp9rjej0op58njsW4uq9OpuW7G7WTXHBbzQ/tx9u6l3Jbl8x5CZ81+VzGU
fSp21y/mn4cVcemDybQgrAwXuz9TB9VCeqwOy9fjwvRE5zIcvL2KLuZL5JFy
b2o9tO/ZxFwoXFR+/9LjcaNayTrDjuqqfvTtSPMPT7QO/MrmWLnvLg+0V9X2
hSl6oGhRtTIOaKzkuZZjtF/NH+OewfbmNdgWn3kT+SKdTfqjaEG8aJ0Ag+FF
XLJ34jV2PuNLlBfkuZJj5d+ozYmKi3R6Z5nO0u2gpsff1vHWs1xQrSjzGc9q
8ss0RnioqZlUNKmYHlZ0LpMBBTOjQcl637qqpr5ZUXigfyLiXJv56B68MdKq
YDBvPGxvjrLAzkRcMpm0PO04e59Iu5INVA9hMW9dfPsGWi0Wq+/xQ1x+GuGC
dCMuQ+gvXnefW0ea
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 743->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIQrxFyA3MAyRXMCSZgVoKgi+DOo6skBHm++rzuWTjQMz0z
3fWq6lW/fu033y+ttePyettMPx+Hw3T6XNxettPufbW7/Xz7G62d1+3/+QyD
XfG/i+Gsc7Hv/WL+ZViKywgm04KwKlzi+kodVAvpiToi34wL06P2VThkax1d
zBflkdM3tx5aF7WOcnH5zaUn48Zqsu8MW9V1/RgdSDPKl/Kl6mGl3/dPtNbV
FrEqHjAtrlbGAc2dPPdyVOvd/DHuFezsvQc74jNvlC/VvVVOlX6qOgqD4Sku
1Z5kF9tf8UXlBXnu+OWcjd6cuLhIZ7aX6WxGRjP+cX32vcoF1XLOE+Pf21dW
W9VinilPsrmbsZ7cOf1heiqYFQ1O1kfruppGs+LwQGdCce7NvOpDNkdaHQzm
TYadvaMssD2KSyWTkWecV/uJtDvZQPUQFvM2xY9PoDVisfoZP8Tl4RIZYzhz
npG5xi+vCzDWSV0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 744->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKwkAUbFyI1xBv4BxAvIJzggw4K0HQhbjz6CojgzxffV7ahYFOupPX
9aqqK/Of/eZ30lo7zm63zXBaHw7D+Xt6X2yH3ddyd/+4eIzWLqv2//yEwa74
3cVw6lzsZ7+YfxmW4tKDybQgrAqXWF/pg3ohPVFH5JtxYXrUvgqHrNbRxXxR
Hjnn5vZDdVFrLxeX37v0ZNxYT/aeYau+rh+9A2l+4YneA7+qOXbO+/mJal1t
EcvxwNHiamUc0NzJ81iOqt7NH+Newc7W0COTi/JG+VLdW+VUOU/VR2EwPMXF
xczqsnq1drk4OWR4Smc198wLFxfpzPYync3IaMY/1mfvq1xQL+d/YvzHnivr
rXoxz5Qn2dzN2JjcOefD9FQwKxqcrPf2dTX1ZsXhgf4JxXls5tU5ZHOk1cFg
3mTY2Rplge1RXCqZjDzjvHqeSLuTDdQPYTFvU/z4BFojFuuf8UNcXi6RMYYT
NX3C+ON1BfMTR90=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 745->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKAjEUDC7Ea8jcwDmAzBX0BD2gK2FAF4M7j67iMDTPV5+XdmEgnaQ7
qVdVqV5+/2z2s9baaXF7bIbfr+NxOG/n98VuOHyuDvePH3+9tcu6/Y/v0FmL
310MZ5+LPfaL+ZdhKS5TMJkWhFXhEvdX6qBaSE/UEflmXJgeda7CIdvr6GK+
KI+ce3ProX3NxHC5uPxepSfjxmqy9wxb1XX9mNqRZpQv5UvVw8p9j0e019UW
sSoeMC2uVsYBzZ0893JU+938Me4V7Gzdgx3xmTfKF+vs+tF7OFXuU2m/BB7K
Pxc780bpyBo7X/FF5QV57uTY+Td6c+LiIp3ZWaazjTuomfGPdbL3VS6olsp8
xbOe/DKNCg81N5OOJhczw1LnKhlwMCsanKxPretqmpoVhwf6JxTn3syre8jm
SKuDwbzJsLM1ygI7o7hUMhl5xnn1PpF2JxuoHsJi3qb4cQRaIxarn/FDXJ6a
yBjDiZreoT94XQG1z0ga
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 746->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOw1AMtLpAvUbFDeAAFVcoJwgSrCohlQVi16OXCoKC4/k4WcCTXvK+
45mx3+7p9fCyiYi37efnMLw/nE7Dx+PNdfI8HO/vjtfN2+8ecd7Hz/8/dNby
vovhnHOxp34x/yosxWUNJtOCsDpc8vlOHBQL6ck6Mt+KC9Oj7nU4VGcdXcwX
5ZGTNzceOhdjFxguF5cf1SNyyTRRrWKdYcu4ph9rO9I844nWgV/dOnbyPeWB
zrrafmGaHjhaXK2MAxqzmutwqPbVebf+GPcOdjVfgp3xmTfKl+7dLqdOPlUc
hcHwFJduTqrG7nd8UfWCPHf8ct7G0jpxcZHO6i7TGeM+8aDin+NU610uKJbz
nqq17jtwYzixmGfKk2rs1tiSunPyw/R0MDsanFpfG9fVtLZWHB7oTSjOS2te
5aEaI60OBvOmwq7mqBbYHcWlU5OZZx5384m0O7WB4iEs5m2Jn/9Aa8aazYVW
xGXWRI0xnJFHTPj8df/idQF0U0Ya
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 747->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOwzAUtFggrlFxA3oAxBXKCYIEq0qV2kXFrkeHioKC++bnsMCSkzix
583Mm6xedpu3m9ba4e7zspmOT/v99P58e168Ttv1w/b88f4yWzs9tp/7f5hs
9N9dDGefiz33i/lXYSkuSzCZFoSVcOn3J3VQLaSn19HzrbgwPepcwqHa6+hi
viiPnL659dC+ZmK4XFx+CQbTU3FjNdl7hq3qjmgZmUjzFc9Lb5UvqYdJv+d3
tNfV1mM5HjhaXK2MA3pm2hMO1Xe1380f455gV+sR7B6feaN8Sc+mnJJ+qjoK
g+EpLmlPqsHOJ76ovCDPHb+cf2M0Jy4u0lmdZTrbfIKaFf++TvU+5fLNh3ml
3ifZd/PLNCo8NNxMOppczApLnUsy4GAmGpysL63ralqaFYcH+icU59HMqz5U
z0irg8G8qbCrNcoCO6O4JJnsefbPaT+RdicbqB7CYt6W+CIbjueOVsTlaoiM
MZxf6z/8X5bML14ffQVJWQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 748->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVUFqw0AQW3II/UboD5IHhHwhfYELzclQSA8ltzy9TWtMGEYaaZ1DFjb2
2rsaSSOTzfvn8bRqrX29/P4ch+/D+Txc3ta3xccw7rbj7eXrNFu77tt8fYbJ
RnyvYij7VOx7v5h/GVbFZQkm04KwHC5xv1MH1UJ6oo7IN+PC9FTnHA7ZXkVX
ukf0SOmbVI/waiKGykXl52AwPRk3VpM9Z9hV3R4tPRNpTnlO/WW+uB46/b6/
or2qtoileKBoUbUyDuieaXc4ZO+r/Wr+GHcHO1v3YEd85k3li3vW5eT0s6pT
YTC8iovbk2yw844vVV6Q54pfyrfRmxMVF+nMzjKdf2Pf5v9nVicbqJc9XK4T
D+ZV9dzJvppfprHCQ0PNpKJJxcywqnNOBhRMR4OS9aV1VU1Ls6LwQN9Exbk3
81UfsnukVcFg3mTY2RplgZ2puDiZjDzjvdtPpF3JBqqHsJi3KX6RDcVzRSvi
wryJXJR98/qB38uS+c/rBwh5SRo=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 749->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8guUI8wQi6CgjJIrjz6BqUEB716tPjwoGe6Z55
Xa+quubu5X33djPGOG6+b7vltD0clo/n2/Piddk/PuzPH+9/xxifT+Py/A+D
XfW7i+HUudjXfjH/EJbisgaTaemwEi61PunT9er0VB2VL+LC9Kh9CQdU6+iC
NaZHzrlZ/QivYWK4XFx+CQbTg7ixnuw9w1Z9Z7TMjE5zzddA74lfaY6d875+
drWutoolPRD1qVbGoZsz7QkH9F3Vu/lj3BNstG49Mrkob5Qv1l7CJ82z4iXP
wvQP5V2dl4OJ6lC9WrtcnBwyPKUzzT3zwsXtdKK9TGe9WB90MZyUS9dLZT7x
bCa/iVeOZ8oTNHczNpM753yYngQz0eBkfW1fV9ParDg8un9CcZ7NvDoHNO+0
OhjMG4SN1l0W2B7FJclk5Vnn6Xl22p1sdP06LOYtxBfZcDx3tHZcmDeVi1N3
Wf/h/7Jm/PD6At03R9s=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 750->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKwkAUbFyI15C5gR5AvIJzggzMrARBF+LOozuOIvHNq89LFhropJN+
Xa+qujL/2m1+Jq21w+z3tumO6/2+O31Ory/f3Xa52F4XP+6jtfOqPZ7vMNgV
110Mp87F7vvF/MuwFJcxmEwLwqpwifWVPqgX0hN1RL4ZF6ZH7atwyGodXcwX
5ZFzbm4/1UthuFxc7AoG05NxYz3Zd4at+g7RMmQgzU/rSZ3yq5pj57z7T1Tr
aotY0gNRX9XKOKA5017hkK2r+n+eGHlyuaKzY5yf5oBPrFfeKF/cvcibap4V
L5kv078s7+q8HMw+j8cgfrp4DmeE4/iGdKp6pGPM/4F0ZnuZzr9L9Mz4x/rs
e5VLP5tZD+e7c4bV/DKNCg9dbiYdTS5mhqX2VTLgYFY0OFkf29fVNDYrDg/0
TyjOQzOvziGbI60OBvMmw87eURbYHsWlksnIM86r54m0O9lA/RAW89bBR1oj
Fuuf8UNcmDeRi1PHuL1i3HhcAJ+KR1s=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 751->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKxEAUbFyI1xBvoAcYvMJ4ggi6GhDGhbjz6Do4SHjW73UWGuikk35d
r6q6cv34sn++GGO8Xn3d9svb/fG4vD9cnl6elsPd7eG0eHMeY3zsxs/zPwx1
1fUUI6lLsdd+Kf8QluOyBVNpYVgdLrW+04f1YnqqjsoXcVF63L4OB1Sb6FK+
OI+Sc0v7uV4OI+WSYncwlB7ETfVU3xW26zujZWYwzd1sO7xEo/N4/WS1qbaK
lXiQaEm1Kg5srrR3OKB1V5/mT3HvYKN36tF5dLKDeDlf0r2Iy0yeHS97FqF/
KO/uvBLMNY+x+13D9nd8cXlhnic5Tv6N2ZykuEwn2qt0Jj0R/1qPvne5sF4u
8x3PZvKrNDo8dqWZTDSlmAjL7etkIMHsaEiyvrVvqmlrVhIe7J9wnGcz784B
zZnWBEN5g7DRO8uC2uO4dDJZedZ59zyZ9iQbrB/DUt4m+ExrxVL9ET/GRXlT
uSR1ittfjG8en33HSF0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 752->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA0EQRAc/xGuIN9ADiFeIJ1hBvwJC8hH88+gajUtou6te737owGRn
dnuqq2oq10+vm5eLMcb+6vNnMx0edrvp7fHyuHmetne32+PHm9Mc4/1+zM//
MNWI3ykGqaPY534p/zIsx2UNptJSYXW4xPpOn6pXpSfqiHwzLkqPO9fhkNUS
XcoX5xG5N9rP9XIYlAvF7mAoPRk31VO9V9iu7xItS2aluZtth0c0Oo/np6il
2s6f1AOihWpVHKq1ylyHQ/bd1dP8Ke4d7GxPPZLZEd44X+hZpVlx6tynqp9r
oH9Z3t19EcxfdSdOsd7tKReSQ+JbpbObe+UFxa10ZmeVzq9hemb8Y332vsvl
J5sj4LnMdzxbkl+l0eFVg2aSaKKYGZY718kAwexoIFlf25dqWpsVwqP6TzjO
SzPv7iFbV1oJhvImw872VRbUGcelk8nIM66791lpJ9mo+lVYyluCX2mNWKp/
xq/ioryJXEid4vYX85vHB6wKRl8=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 753->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KBFEMhB8uZK4h3kAPIF5hPEELuhoQZhbizqProDRDqFS+vF5ow+vf
vEpVpfrm+W3/ejXGOO2+T/vl/fF4XD6ers8PL8vh/u5w/nj7u8b4fBjr9T8s
d8TvFIPUUexLv5x/CqvisgXTacmwOlxifadP1ivTE3VEvoqL01Pt63BQtUSX
rIEekbmhfoYX5Uy5UH4dDKdHcau0EsxYW/Wd0TKzMs0xX0O9N351M0HmvV5N
LdV2eUUeFPVdrY5Ddu8y1+Ggvlf1NH+OewdbPVOPbHaMN5UvdK/T7Dh15unq
1xron8p7NS+CKb0Bue/4UuUl85zkmPwbszmhuJlOtdfpJD0V/1iv3ne5ZL2q
zHc8m8mv01jhZQfNJNFEMRVWta+TAYLZ0UCyvrUv1bQ1K4RH9k9UnGczX81B
3WdaCYbzRmGr5ywLbk/FpZPJyDPed+eZaSfZyPplWM7b1EszV+I50Zpxcd5E
LqROafrL9cPrC4S3Rp4=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 754->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKwkAQWzyI3xB/oA8Qv6AvqKCngqAH8ebTVdRSlkySaQ8qrO22s5kk
k873p+1xUkq5zJ5/2+a6OZ+b22762hyadrVsXy8Xn1XKfV266z8s9qvfuxhO
nYvd94v5h7AUlzGYTEuEleFS12f6RL0iPbWOmi/iwvSocxkOqNbRxXxRHjlz
c/tFdeW7BIbLxeWXwWB6EDfWkz1n2KrvEC1DVqQ5m22F52hUHndXUutq619d
DxwtrlbGIbpnmctwQO9VvZs/xj2DjfauRzQ7xBvli3VW+MQ4ZebJ6rsa0z+U
dzUvBxPVoXq1d7k4OWR4Smc2991+xPcR6URnI52lv0hPxL+uR88zXO49Huyb
Us+dGWbzyzQqvOjnZtLR5GIiLHUukwEHM6PByfrYvq6msVlxeCANDuehmVdz
QPeRVgeDeYOw0T7KAjujuGQyWfOs77PzjLQ72Yj6RVjM29BLMlfHc0drxIV5
U3Nx6pCmX643rwewI0Se
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 755->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA1EQhB8ugteQ3MAcQLxCPMEIZhUIxIW48+ga8kNouqq/zizMwMvM
y/SrrqqueXrfrTcPY4zPx7+f9fT1ut9P32+Lw+Zj2q6et4eXy9Ma4+dlXO73
sNwV31MMUkexr/1y/mVYFZc5mE6LwupwifWdPqqX0hN1RL4ZF6enOtfhkNUS
Xc6XyiMyN9pP1VHOlAvl5/pVs3SaiFaCGWurvtSPuUtp7ma7wiMaK4+v76qW
aotYxAOihWp1HNSz097hkL2v6mn+HPcOdranHpHsuHrlCz3rNDtOnXm6+ksN
9C/LezUvgqm8ifXVnnIhOXR4lc5u7p0XFFfpzM46neO8TM+Mf6zP/u9yUb2q
zHc8uyW/TmOFpy6aSaKJYmZY1blOBghmRwPJ+ty+VNPcrBAe6puoON+a+WoO
2bPSSjCcNxl2tldZcGcqLp1MRp7xuTtPpZ1kQ/VTWM5b6aWZK/GcaFVcnDeR
C6lz3P5jHXn8Ap2qRaI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 756->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk11KxEAQhAcfZK8h3kAPIF5hPUEEfVoQdh/EN4+u608ITXfV18mDDsxO
ZtNTXVVTuXp82T9fjDFOu8+f/fR6fzxObw+X583TdLi9OZxfXv/MMd7vxrz+
h6lGfE8xSB3FXvql/MuwHJctmEpLhdXhEus7fapelZ6oI/LNuCg97lyHQ1ZL
dClfnEfk3mi/qo5yplwoP9XP3aXSRLQSzHnAvtSPtTPyqPr8ch6LM8qXroed
+55XUUu4xBV5YOq7WhWH6lllrsMhe+/qaf4U9w52tqceyewIb5wv9uxipf4Q
nype9i6gf1ne3X0RzKwuq3d7yoXkUOE5nd3cKy8obqUzO6t0fg3TM+Mf67P/
u1yqXi7zHc/W5FdpdHjVoJkkmihmhuXOdTJAMDsaSNa39qWatmaF8Ki+Ccd5
bebdPWTPlVaCobzJsLN9lQV1xnHpZDLyjM/d+6y0k2xU/Sos5e0aL0kd0Vpx
Ud5ELqROcfuL+c3jA5oARZ4=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 757->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRD9ZSK4RvIEeIHiFeIIRdBUQkoVkl6NrUDQ2XdWvZxY68DMz
+f2rq6prNk+vu5fVGOO4/vjZTW8Ph8N0ery5vDxP+/u7/WXz9muNcd6O7/t/
WO6K+xSD1FHsa7+cfxlWxWUJptOisDpcYn2nj+ql9EQdkW/GxempznU4ZLVE
l/Ol8ojMjfZTdZQz5UL5SQwwS6eJaCWYsbbqS/1YupTmX/tJXeVXNxNk3td3
VUu1RazSg6K+q9VxUM9Oe4dDtl/V0/w57h3s7J16RLLj6pUv5dntz6L+EJ8U
r3IW0L8s79W8CGZW5/ykeISzwnF4lc5u7p0XFFfpzM46naRnxj/WZ/93uahe
VeY7ns3Jr9NY4amLZpJoopgZVnWukwGC2dFAsr60L9W0NCuEh/omKs5zM1/N
IXtWWgmG8ybDzt5VFtyZiksnk5FnfO7OU2kn2VD9FJbzdo6XpI5oVVycN5EL
qXPc/mJ98ngHoMdGIA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 758->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FOw1AMRL+6QFwDcQM4AOoVygmCBKtKSGWBuuPopQKqyHjGzwkLIv0m
v/Efz4wnN0+vu5fNGOPt+vNnN71vD4fp+Hh13jxP+/u7/fnl7fca4+NhXO7/
YbkrvqcYpI5iz/1y/mVYFZc1mE6LwupwifWdPqqX0hN1RL4ZF6enOtfhkNUS
Xc6XyiMyN9pP1VHOlAvlJzHALJ0mopVgxtqqL/Vj7VKau9mu8IjGyuP5XdVS
bRGLeEC0UK2Og3p22jscsvdVPc2f497BzvbUI5IdV698oWedZsepM09Xf6mB
/mV5r+ZFMJU3sb7aUy4khw6v0tnNvfOC4iqd2Vmnc/ws0zPjH+uz/7tcVK8q
8x3PluTXaazw1EUzSTRRzAyrOtfJAMHsaCBZX9uXalqbFcJDfRMV56WZr+aQ
PSutBMN5k2Fne5UFd6bi0slk5Bmfu/PMtA+YDdUv461yW85xxkdpjViuf8ZP
cfl1FRlzOFHTX34zS9cXrxNp1kPh
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 759->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOwzAUtLpAXKPiBnCAiCuEE6RSu4qEFBaoux4dElCVWG8+L15AJDdx
/TyemTc+nt77y6GU8vH4/dMPn6/TNFzfHubJeRhfnsd58el3lHLryv39HwZ7
6nUXw6lzsdd+Mf8iLMWlBZNpQVgZLnV95hx0FtJT66j5RlyYHrUvwyGqdXQx
X5RHTt/c81Cdy9nl4vKDGEYvmSZHq4O5PCs+6lzXj9aBNG/WgzrlVzYTTr/X
b1TraquxpAeiPquVcUDfTHuGQ7Su6t38Me4Z7GgOPdqRHVaPfJF7u7K5444/
jk+Il+yF6V+Ud9UvBzOqY366eA5nhMPwlM5s7u/zhvuBdEZ7mc7lIXcF3ZH6
nOj/LBd0lsp8xrM9+WUaFR563Ew6mlzMCEvty2TAwcxocLLeeq6rqTUrDg90
JxTnvZlXfYi+kVYHg3kTYUdzlAW2R3HJZLLmWX9n+xlpL2Y20HkRb5Rb2UfS
V8dzpTWTEZUxVce4/cX44fEFJ+JFHA==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 760->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA0EQRId8iNcI3kAPELxCPMEK5isgxA/JX46uUYmh6ap+vfuhA5Od
yfZUV9XUrp9ft7vVGOPt9vNnO70/Hg7T8enmvHmZ9g/3+/PLu585xmkzLs//
MN2I7ykGqaPY1345/zKsissSTKdFYXW4xPpOH9VL6Yk6It+Mi9NTnetwyGqJ
LudL5RG5N9pP1VHOlAvl5/pVd+k0Ea0E8zJgX+rH0qk0d7Nd4RGNlcfXT1VL
tUUs4gHRQrU6DmrttHc4ZO+repo/x72Dne2lRzOy4+qVL+XZze+k/hCfFK/y
LqB/Wd6r+yKYWZ3zk+IRzgrH4VU6u7l3XlBcpTM763R+DfOtqG8k9sn+73JR
varMdzybk1+nscJTg2aSaKKYGVZ1rpMBgtnRQLK+tC/VtDQrhIf6JirOczNf
3UO2VloJhvMmw872KgvuTMWlk8nIM66796m0k2yofgrLeTvHS1JHtCouzpvI
hdQ5bn8xv3l8AFsQRd8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 761->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA0EQRAc/xGuIN9ADiFdITrCB5CsgxA/xz6ObqCyh6ap+vfuhA5Pd
yfRUV9XU3u9eN4ebMcbb3flnM72/nE7Tx/b2sthPx6fH42Xz4XeO8fk85ud/
mG7EfYpB6ij2tV/Ovwyr4rIG02lRWB0usb7TR/VSeqKOyDfj4vRU5zocslqi
y/lSeUTujfZTdZQz5UL5SQxwl04T0Uow5wH7Uj/WTqW5m+0Kj2isPL5+qlqq
LWIRD4gWqtVxUO9Oe4dDtl/V0/w57h3sbE09Itlx9coXetZpdpw69+nq5xro
X5b36r4IpvIm1ldryoXk0OFVOru5d15QXKUzO+t0fo+iZ8Y/1mf/d7moXlXm
O54tya/TWOGpQTNJNFHMDKs618kAwexoIFlf25dqWpsVwkN9ExXnpZmv7iF7
V1oJhvMmw87WKgvuTMWlk8nIM75371NpJ9lQ/RSW83aJl6SOaFVcnDeRC6lz
3P5i/vD4AiscRCQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 762->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FOw0AQQ1d8IK6BuAEcAHGFcoIgwVclpPKB+OPo0FJF7TD2vEn4YKVN
ssmsx/Y610+vm5eLMcbb1fdlM70/7HbTx+PlfvE8be9ut/uPN8c5xuf9mO//
YboRv1MMUkexT/1y/mVYFZc1mE6LwupwifWdPqqX0hN1RL4ZF6en2tfhkNUS
Xc6XyiNybrSfqqOcKRfKT2KAs3SaiFaCeRgnfKq+1I+lM/JQfWbeI3lv/Opm
gpz3fDe1hEu8Iw+K+q5Wx0E9u8x1OGTfq3qaP8e9g52tqUc2O8abyhe612l2
nDrn6eoJhsOruFBM5U2sr9aUC8mhw6t0dnM/r1f8H0pnttfpPIwjF9Uz4x/7
ZO+7XM74JD1U5jueLcmv01jhqUEzSTRRzAyr2tfJAMHsaCBZX9uXalqbFcJD
/RMV56WZr84he1ZaCYbzJsPO1ioLbk/FpZPJyDM+d89TaSfZUP0UlvN2iZek
jmhVXH6NImMO52z9h//LmvnD6wsjfUPf
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 763->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKxEAQRAc/ZK8h3kAPIF5hPUEE/VoQdj/EP4+uixKWpqv6dcYPA5Nk
Mj3VVTWVm+e3/evVGOO0+77tl/fH43H5eLo+T16Ww/3d4bx4+zvG+HwY6/M/
DHfFdYpB6ij2pV/Ovwyr4jKD6bQorA6XWN/po3opPVFH5JtxcXqqfR0OWS3R
5XypPCLnRvupOsqZcqH80m/FOWZ6Mm6VVoI5Ap+qL/VjyxhJFlWfS+6Kf+UJ
1Vh5vD5NLeESn8iDor6r1XFQ7y5zHQ7ZelVP8+e4d7CzOfXIZsd4U/lC9zrN
jlPnPF09wXB4FReKqbyJ9dWcciE5dHiVzm7u1/nE/6F0ZnuVzgGzlvGP9dn3
DhfFR+13uFuG0uLySvDURTNJNFHMDKva18kAwexoIFmf7Us1zWaF8Mg0EM5b
M1+dQ/autBIM502Gnc1VFtyeiksnk5FnfO+ep9JOsqH6KSzn7RYvSR3Rqrg4
byIXUrfO//B/mRk/vL4AmHNEng==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 764->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKxFAQRD8uxGuIN9ADiFcYTxBBVwPCuBB3Hl0n6iBNd9Xrn4UG/uQn
6V9dVV1z+fC8ezobY7xcfP7slte7w2F5uz8/Pjwu+5vr/fHj1fca4/12nO7/
YakrfqcYpI5i//ZL+ZdhOS5bMJWWCqvDJdZ3+lS9Kj1RR+SbcVF63LkOh6yW
6FK+OI/I3Gi/qo5yplwoP/rO6cm4Oa0Ec70afakfM2skWaz6VBydX91MkHmf
7nDeSlvUTzwgWqhWxaHaq8x1OGTfXT3Nn+Lewc6eqUcyO8Ib5ws9qzQrTp15
qnqCofAcF4pZeRPr3TPlQnKo8JzObu6VFxS30pmdVTrXy/TM+Mf67H2Xy/ru
ZyU9lIeK/+xcVW/XS3nmPMn2NGMzuSPzUXo6mB0NJOtb+1JNW7NCeFT/Ccd5
NvNuDtm+0kowlDcZdvZcZUGdcVw6mYw84747z0o7yUbVr8JS3s54SeqI1oqL
8iZyIXWK21+sLx4fZXtD4w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 765->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tuwjAUtFhUXAP1BuUAiCvQE6RSu0JCggVix9EpBSL0+ubznC5qyUmc
PM+bGU8WH7vN16y1dph/XzbDcb3fD6f3l+vic9gu37bXj6/32dp51cb7f5hs
xO8uhlPnYj/7xfzLsBSXKZhMC8KqcIn1lT6oF9ITdUS+GRemR+2rcMhqHV3M
F+WRc25uP1TXHlNguFxcfoiLc5ZME9Uq3v8ahb6uHz3zcUZIw/MacVR+VXLc
kr4o3yN/UOtwiXfXA0uL+I64ZD0yDQ52D0dV7+aPca9gZ2vXI5od4o3yRe4l
2XQ4Vc6T1TsYDE9xcTGzuqxerV0uTg4ZntJZzT3zwsVFOrO9TOfPED0z/rE+
e1/lgnqpzFc868kv06jw0HAz6WhyMTMsta+SAQezosHJ+tS+rqapWXF4oH9C
ce7NvDqH7BlpdTCYNxl2tkZZYHsUl0omI8/4XD1PpN3JBuqHsJi3PV46dY5W
xIV5E7k4deP6D/+XKfPG6wIh3kVd
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 766->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKxEAUbFzIXEO8gR5g8ArjCSI4qwFhZiHuPLqOyhge9XuJCwOdpNOv
61VVV26eXnb7qzHGafN5202vD8fj9PZ4fZ48T4f7u8N58fZnjPG+HZfnfxjq
quspRlKXYs/9Uv4hLMdlDabSwrA6XGp9pw/rxfRUHZUv4qL0uH0dDqg20aV8
cR4l55b2Y3Up55RLyg9+M+eI9CBuTqvF3P6OtG/qx5Ix58I0d7OtPEk1Oo/n
T1abcEFYiQeJllSr4sDelfYOB7Tu6tP8Ke4dbDRPPUqyo+qZL3Zv+bcSfxKf
GC93Fql/KO/uvBJMVKf8TPESzgxH4Tmd3dwrL1JcphPtVTq/LtMT8a/16HuX
C+vlMt/xbEl+lUaHx640k4mmFBNhuX2dDCSYHQ1J1tf2TTWtzUrCg/0TjvPS
zLtzQO9Ma4KhvEHYaM6yoPY4Lp1MVp71vXueTHuSDdaPYSlvE3ymtWKp/ogf
46K8qVySusv8D/+XNeOb1wdv30ac
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 767->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVUtuwjAUtFhUvQbqDeAAEVegJ0glukJCogvUXY/e0laBPt6bT8yilkJi
/DxvZjxRli+H7euitfb2+PWzHU+b43F8f344T3bjfr3anxeffq/WPoY23f/D
hUZcVzGUOhX72i/kX4bFuPRgIi0VlsMl1jt9ql6Vnqgj8s24ID1sn8Mhq1V0
IV+YR8q5qf2qOpWzykXlh/qxs0SaFK0KZjP7qn7M0jxc+FSa//BM6phfbiaU
857uoFbhEu+SB6Te1Yo4VM8ocw6HbJ3Vq/lD3B3sbK56BLMDvGG+qHuRZsTJ
OU9Ur2AgPMZFxay8ifVsrnJRcojwmE4399O84/2odGZ7kc7vQXpm/GN99r/L
perFMu94Nie/SCPDq4aaSUWTiplhsX1OBhRMR4OS9d6+qqberCg8qneCcZ6b
eXYO2XOlVcFA3mTY2bzKAtrDuDiZjDzjs3ueN8PIRtUv413lFuIPDX6jFM+R
VtVntK5k86bXHd+XnuuH1yfdzEXd
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 768->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFwEryG5gR5AvEJyggnEVUCIC3Hn0TUkhPCo35tZmIGemZ5+
Xa+quuZp97F5fxhjfD7+3TbT19vxOH1vV6fJfjq8PB9Oi+vLGOPndVyf9zDU
VddTjKQuxb71S/mHsByXJZhKC8PqcKn1nT6sF9NTdVS+iIvS4/Z1OKDaRJfy
xXmUnFvaj9WlnFMuKT/4zZwj0oO4Oa0JZq11fVM/5owBssj6JPydJ6lG5eXt
+hC1CZf6TD1ItKRaFQf2rjLX4YDWXX2aP8W9g43mqUcyO8Ib50u01/ikOHXO
U9UnGArPcUkxUR2qd/OUS5JDhed0dnN/nS/4P5hOtFfpTHoi/rUefe9yYb1c
5juezcmv0ujw2JVmMtGUYiIst6+TgQSzoyHJ+tK+qaalWUl4sH/CcZ6beXcO
6J1pTTCUNwgbzVkW1B7HpZPJyrO+d8+TaU+ywfoxLOVtgs+0VizVH/FjXJQ3
lUtSp7j9xzjz+AWK7UUi
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 769->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNkk1OAkEQhTssjNcg3kAPQLgCnmBMdEViggvDjqMrSowp3l/NLLSTAZqp
fvW96rd+et29rMYYb7efH7vpfXs4TMfHm/Pmedo/3O/PL+8uzxinzfj5/g+P
WvV9qpHUpdq/56Xmh7QcyxJN5YVpdVhqfacP68X8VB+VF7EoP+5chwHVJr7U
XNyMkntL+7G6lDllSflUP3eXylPiNdGsta5vOo9Zni8P86A43Vy6MzwVFpfv
TgaUt6qVzCDyYt4zFtQDeUi05zC6+jR/ir2jjfbpjJLsqHo2F3s28KyYOvep
6hMNpedYUk1Uh+rdPmVJcqj0nM9u7tUsUl3mE51VPr+W6Yn4az36v81CernM
d2Y2J7/Ko9NjK81k4inVRFruXCcDiWbHQ5L1pX1TT0uzknAgDwnz3My7e0C/
mddEQ80GaaM9y4I641g6mayc9Xf3Pq9WIxusH+JmuaXvN9cszGvVUv0RH2Nh
9d1sJmx/8XxzfAAA20Ph
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 770->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqQkEQRIcsxGuE3CA5QPAK5gQ/YFZCQBfizqOrJARpuqpf+xfxw+jM
n57qqpr6z5/f66+nMcZ+eflZT4fVbjcdPxbXxWbavr1ur5svv2OM0/v4+3+E
4Z64TzFIHcW+9cv5l2FVXOZgOi0Kq8Ml1nf6qF5KT9QR+WZcnJ7qXIdDVkt0
OV8qj8i90X6qjnKmXCg/16+6S6eJaCWYsbbqS/2Yo1lpSHmq98KvbibIfTvO
KldKW8QiHhAtVKvjoOZOe4dDtl/V0/w57h3sbE09Itlx9coXetZpdpw69+nq
CYbDq7hQTOVNrK/WlAvJocOrdHZz77yguEpndtbpJD0z/rE+e9/lonpVme94
dk9+ncYKTz00k0QTxcywqnOdDBDMjgaS9bl9qaa5WSE81DdRcb4389U9ZHOl
lWA4bzLsbK2y4M5UXDqZjDzjvHufSjvJhuqnsJy3KX6RDeI50aq4OG8iF1Ln
uP3H+OFxBoOkReM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 771->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0tqAzEQREUWwdcIuUF8gJArOCcYQ7wyBOxFyM5H998Mcnf1K88iEcgz
slrVVaWal+X3YvXUWtvODj+L4edjsxl+P5+Pi69hPX9bHzdfL7O13Xu7Pf/D
VKPfpxikjmKP/VL+RVgVlymYSkuG5XDp650+Wa9MT6+j5xtxUXqqcw6HqJbo
Ur5UHpF7o/2yOsqZcqH8VL/qLpUmopVgnobRl/oxRXOmYby+8r7OyhfXQ+e+
b09RS7j0T+RBUe9qVRyyd5U5h0O0X9XT/CnuDna0ph7J7AhvKl/Ks8F34nBy
7lPVEwyFV3GhmFGd8pPiEc4ZjsKrdLq5V15Q3ExndFbpPI2iZ8S/r4/+d7ns
Rt9I1IP872Sf5ldprPCyQTNJNFHMCKs652SAYDoaSNan9qWapmaF8Mi+iYrz
o5mv7iF6z7QSDOVNhB2tsyyoMxUXJ5M9z/7dvc+7YWQj6xfxznKb7o9m5iXx
XGmlPqt9kk3C7S/mmcceqCRF2w==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 772->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KQ0EQhAcX4jUkNzAHEK8QT/ACySogxIW48+iaH0Nsuqq/9i10YJI3
83qqq2rq3a9fVtubMcbr3dfPanp72u+n9+fbw2Iz7ZYPu8PLxXmO8fE4Lv//
YboR31MMUkexr/1y/mVYFZc5mE6LwupwifWdPqqX0hN1RL4ZF6enOtfhkNUS
Xc6XyiNyb7SfqqOcKRfKz/Wr7tJpIloJZqyt+lI/5mhWGn7w/J6Gf+UJ1Vh5
7DirXCltEct6kPiltFCtjoN6dto7HLL3VT3Nn+Pewc7W1COSHVevfCnPAs2O
U+c+XT3BcHgVF4qZ1WX11ZpyITl0eJXObu6dFxRX6czOOp3HUfTM+Mf6bL/L
5bhnsk32O9mn+XUaKzw1aCaJJoqZYVXnOhkgmB0NJOtz+1JNc7NCeKhvouL8
28xX95A9K60Ew3mTYWdrlQV3puLSyWTkGZ+796m0k2yofgrLeUvwldaI5fpn
/BQX503kQuoct7+YJx6f5VtF4Q==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 773->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQbPIhXiN4g+QAIVfQE6yQfAkB/Qj58+jxlWVpuh7t5sOF0Z2d
nuqqmprn7df68ykiDsvTz3r4ft/vh5/N4jz5GHavL7vz4uo2Io5vMf4/wmBP
XncxnDoXe+oX86/CUlzmYDItCKvDJdd3+qBeSE/WkflWXJgeta/Doap1dDFf
lEfOubn9UJ3L2eXi8mP91FkyTY5WBzOK7KG+Yfp275j2Q5r/eIwjcxR+dTPh
nDfjjHIFtYXWwfxCWlytjAN6Z9o7HKp1Ve/mj3HvYFdz1yMnO6we+SL3Tu6K
64/jE+KlzsL1r8q7Oi8Hs6qr6tXc5eLkkOEpnd3cMy9cXKSz2st0Xh7Rs+Kf
66vvXS7H2z1hXqnvney7+WUaFR563Ew6mlzMCkvt62TAwexocLI+t6+raW5W
HB7oTijO92ZenUP1jrQ6GMybCruaoyywPYpLJ5OZZ37vnifS7mQD9UNYzNsS
X2TD8dzRirgwbzIXp26c/+N9mTOuvH4Bu+ZF3Q==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 774->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKA1EQRBsX4jXEG+gBxCvEE4xgVgEhLsSdR9egSGi6ql/PLHTgJ/Pz
+1dXVVeun152+4uIeL36+tgtbw/H4/L+eHnaPC+Hu9vD6fDmZ0V83Mfv939Y
7snnFIPUUexzv5x/FVbHZQum06KwJlxy/aSP6qX0ZB2Zb8XF6enuTThUtUSX
86XziMyN9lN1lDPlQvm5ft0snSailXgURfZU34C+rV3nXJTm87oo6jq/ppkg
83acVa6ktuh1KA5OC9XqOKh3p33CoTrv6mn+HPcJdrWnHpHsuHrlC73rNDtO
k3m6eoLh8DouFFN5k+u7PeVCcujwOp3T3DsvKK7SWd11OknPin+ur36fclG9
usxPPFuTX6exw1MPzSTRRDErrO7eJAMEc6KBZH1rX6ppa1YID/Wf6DivzXw3
h+pdaSUYzpsKu9qrLLg7HZdJJjPP/D6dp9JOsqH6KSznLcFXWjOW61/xU1yc
N5kLqXPc/mJ98/gE0zdF4Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 775->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOAkEU7LggXMN4AzwA8QrjCcYEVyQmw8K48+iAGsI8X33eNAs6aejO
vK5XVV39+PYxvD+01g7r088wfr5M0/j1ujpvduP+ebM/f3z6m619b9vl/x4m
G/G7i+HUudjXfjH/MizFpQeTaUFYFS6xvtIH9UJ6oo7IN+PC9KhzFQ5ZraOL
+aI8cu7N7YfqXM4uF5cf66fukmlytDoexVrV1/WjRzPS8I+n4K88cTUqjxln
lCukLWJJD0R9VSvjgNZMe4VD9l3Vu/lj3CvY2d71yMkOq0e+uGeZZsapcp+s
3sFgeIqLi4m8ifVq73JxcsjwlM5q7mcYC98H0pmdZTp/xnY+UZ9ssJxXuaBe
KvMVz5bkl2lUeGi4mXQ0uZgZljpXyYCDWdHgZL23r6upNysOD/QmFOelmVf3
kK2RVgeDeZNhZ3uUBXZGcalkMvKM6+p9Iu1ONlA/hMW8dfCR1ojF+mf8EBfm
TeTi1F32N3wvPfOX1xH5Y0Wg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 776->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOwzAUtLqouEbFDegBKq6QniBIdBWpUlggdhwdUlBEX998XrKgltLE
9fO8mfF493LuTpvW2tvD90/Xvz+PY/9x3E6T137YPw3T4uPv09rnoc3ve3jY
iOsuhlPnYv/1i/mXYSkuazCZFoRV4RLrK31QL6Qn6oh8My5Mj9pX4ZDVOrqY
L8oj59zcfqjO5exycfmxfuosmSZHq+NRrFV9XT/WaEYaIk/FX3nialQeM84o
V0hbxFIeqPqqVsYBfTPtFQ7Zuqp388e4V7CzOfRoQXZYPfJF7Z25FPxxfEK8
1Fm4/mV5V+flYGZ1zE8Xz+GMcBie0lnN/RXGwvuBdGZ7mc7LIHcF3ZEbHcn/
VS6ol8p8xbMl+WUaFR4abiYdTS5mhqX2VTLgYFY0OFlf29fVtDYrDg90JxTn
pZlX55B9I60OBvMmw87mKAtsj+JSyWTkGb+r54m0O9lA/RAW89bBR1ojFuuf
8UNcmDeRi1PHuP3H88PjC4BdR54=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 777->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVEtOAkEU7LAwXsN4Az3AhCvgCcZEViQmuDDsPDqiZIT21W/GhZ00TGde
16uqV3D3/LrZrlprb7efH5vxfb3fj4enm9PhZdw9PuxOL+/Pu7WPoU3f/2Gz
1b93MZw6F/vSL+ZfhaW4LMFkWhBWwqWvT/qgXkhPr6PnW3FhetS9hENV6+hi
viiPnLm5/VCdy9nl4vK78lLMj+mpuCmtFPPMp69lfRF/5mmyL/shzVe1gr/y
hHmYzJtxRrlC2nos6YGoT7UyDuiZaU84VO9VvZs/xj3Brs6uR052WD3yRd11
NDNOyTxZvYPB8BQXF7Oqq+rV2eXi5JDhKZ1p7it+iT6ms7rLdH6toU3/5axP
tdAs53BBvVTmE8/m5JdpVHhouZl0NLmYFZa6l2TAwUw0OFlf2tfVtDQrDg/0
m1Cc52ZezaF6RlodDOZNhV2dURbYHcolzGTPs39O5zmt4We72UD9Kt4otwk+
0so8Z3N3fWbvnWz+6vWHv5cl+5vXEUd9RV0=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 778->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0luAjEQtDhE+QbiB+EBiC+QFwxSOCFFggPixtMJi0jSdC09ziGWzIxx
u7qqXDNdf642k9ba/vXrZzUclrvdcHx/uSw+hu38bXvZnN1na6dFezz/w2Qj
7rsYTp2L/dMv5l+Gpbj0YDItCKvCJdZX+qBeSE/UEflmXJgeda7CIat1dDFf
lEfOvbn9UJ3L2eXi8mP91F0yTY5Wx6NYq/q6fvRoRhoiT8VfeeJqVB4zzihX
SFvEUh6o+qpWxgG9M+0VDtm+qnfzx7hXsLO165GTHVaPfFFnHc2MU+U+Wb2D
wfAUFxczq8vq1drl4uSQ4Smd1dz/whj5fSCd2Vmm8zruPFDPjP+TjuT/KhfU
S2W+4tmY/DKNCg8NN5OOJhczw1LnKhlwMCsanKz39nU19WbF4YG+CcV5bObV
PWTvSKuDwbzJsLM1ygI7Q7kUMxl5xvfqfT7G4nu62UD9Mt4otxV8pJV5zu7d
9ZntO9l86vWH30vPvPE6A6kLR10=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 779->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0luAjEQtDggvoHyg+QBiC+QF0yk5ISEBAeUW56eTJYR0+paepwDlgy2
pl1dVS5vX06Ht1Vr7bL5+jkM1/35PLw/r8fN63B8ejyOHx9+Z2sfuzb938Nk
I353MZw6F/vWL+ZfhqW49GAyLQirwiXWV/qgXkhP1BH5ZlyYHnWuwiGrdXQx
X5RHzr25/VCdy9nl4vJj/dRdMk2OVooJalVf14+SVjMzM54Gf+WJq1F5zDij
XCFtEYt6kPiFtLhaGQe0ZtorHLLvqt7NH+Newc72rkdOdlg98oWe/ZtCM+NU
uU9ab2AwPMXFxczqsnq1d7k4OWR4Smc19zOMhe8D6czOMp3f4yajrE820F0u
4YJ6qcxXPFuSX6ZR4aHhZtLR5GJmWOpcJQMOZkWDk/Xevq6m3qw4PNCbUJyX
Zl7dQ7ZGWh0M5k2Gne1RFtgZxaWSycgzrqv3yfQrLNQP4TBvHXykNWKx/hk/
xIX5Erk4ddP+H99Lz/zh9Qk3MUWe
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 780->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOAkEU7LAwXsN4AzmA4Qp4giGR1SQkuDDsPDoiSJjHq8+bduEkzUzT
r+tVVVc/bXbr7aK19vH4/bMePlf7/XB4ezhN3odx+TKeFp8vo7Wv13Z9/4fB
nrjuYjh1LvatX8y/DEtx6cFkWhBWhUusr/RBvZCeqCPyzbgwPWpfhUNW6+hi
viiPnHNz+6E6l7PLxeXH+qmzZJocrY5HsZb1baZvcwfjNcnp77rgrzxhHlbO
m3FGuYLamtbB/EJaXK2MA/pm2iscsnVV7+aPca9gZ3PXIyc7rB75Ivcamhmn
ynmyegeD4SkuLmZWl9WrucvFySHDUzqruZ9gzLwfSGe2l+n8eS48UM+M/52O
5P8qF9RLZb7i2Zz8Mo0KDz1uJh1NLmaGpfZVMuBgVjQ4We/t62rqzYrDA90J
xXlu5tU5ZN9Iq4PBvMmwsznKAtujuFQyGXnG7+p5Iu1ONlA/hMW8dfCR1ojF
+mf8EBfmTeTi1F3nf3hfesaZ1xHHNEUg
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 781->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOwzAUtFigXgNxAzhAxBXKCYJEV5WQ2gXqrkdvCxEiz28+L2GBJVMb
P8+bGU8e3j62u7vW2nFz/bMdP18Oh/H0en/bvI/756f97fBxmq2dh/bz+x8m
G/HcxXDqXOzffjH/MizFZQ0m04KwKlxifaUP6oX0RB2Rb8aF6VH3KhyyWkcX
80V55Lyb2w/VuZxdLi6/mZfi/ZiejJvSSjEnPrFW9XX9qMw29LyR5rhm/JUn
rkblMeOMcoW0RSzlgaqvamUc0Jppr3DIzlW9mz/GvYKd7V2PnOyweuSLuuto
Zpwq78nqHQyGp7i4mFldVq/2LhcnhwxP6azmfoax8PtAOrO7TOfXmHignhn/
Tkfy/yoX1EtlvuLZkvwyjQoPDTeTjiYXM8NS9yoZcDArGpysr+3ralqbFYcH
+iYU56WZV++QrZFWB4N5k2Fne5QFdkdxqWQy8ozr6nt2o5AN1C/jjXJL8Yc5
H6Q1YnV7oNX1mZ072ex6/eH3smZ+87oAkaBEng==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 782->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uqAjEQDC4eXkO8gR5AvIKeYB7oShB0Ie48uorik7br0zML30CcxHSq
qyo1k9/9ajtqrR3Ht59Vd1oeDt15/XNfbLrdfLa7b06fo7XLor3e/2GwJ+67
GE6di/3uF/Mvw1JchmAyLQirwiXWV/qgXkhP1BH5ZlyYHnWuwiGrdXQxX5RH
zr25/VCdy9nl4vJj/dRdMk2OVom5+BtuX9ePXpqTLKI+qE75Vc2Ec9+MM8oV
0haxlAeqvqqVcUBzpr3CIdtX9W7+GPcKdrZ2PXKyw+qRL+qso5lxqtwnq3cw
GJ7iQjFF74yDWrtcPnoSzx2/nG/DzUmmycFFOrOzTKfjQcY/0xH/r3JBvVTm
K571yS/TqPDQozJSzYGDmWGpc5UMOJgVDU7Wh/Z1NQ3NisMDfROKc9/Mq3vI
5kirg8G8ybCzNcoCO6O4VDIZecZ59T6RdicbqB/CYt5WuCos1j/jh7gwbyIX
p45x+8Z48LgCan9IXQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 783->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIQrxFyg+QA4hXMCSZgVoKgC8nOoycSCWNbvzeThQPtTDuv
61XVq3n+2G8+n1prx+XPz2Y4rQ+H4et9cdlsh93b6+7y8uW6Wjuv2t/9EZa6
+vcpRlKXYo/9Uv4hLMdlDqbSwrAqXPr6Sh/Wi+npdfR8ERelx52rcEC1iS7l
i/MomVvaj9WlnFMuKb87TDNDpgdxc1ot5pXPuFb1ZdyVp+nquTDN51FdA3XO
r2omknkrzixXVFvzOhgHpSXVqjiwZ6W9wgG9d/Vp/hT3Cjbapx4l2VH1zBd2
1n1PU/PseLlZpP6hvLt5JZioDtW7fcolyaHCczqruUf8KvqUTnRW6Uw8QPyR
jv7/KhfWy2W+4tmU/CqNDo9daSYTTSkmwnLnKhlIMCsakqzP7ZtqmpuVhAf7
JhznqZl3c0DPTGuCobxB2GjPsqDOOC6VTPY8++fqPJn2JBusH8NS3kJ8k43E
80Qr43J3mYwpnJv9P34vc9Yvr29VRUPf
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 784->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhQsXkmuIN9ADBK8QTzCCWQWEZCHucnQNiEw6769mNg4kmclU
v/pe9euHt4/d/q6qTpufr930+XI8Tl+v95eH9+nw/HS4vHz8/VSdt/X3+x8+
6hrfpxpJXao9n5eaH9JyLGs0lRem1WEZ6zt9WC/mZ/Qx8iIW5cet6zCg2sSX
moubUbJvaT9WlzKnLCmf6uf2UnlKvCaaBbLH+lY4t0V+t9cszPN5Vlegzs2r
m4lkvxUzyxX1Vt4HY1BeUq+Kgd0r7x0G9N7Vp/lT7B1t9JzOKMmOqmdzkWvn
50V4Vkyd/ZT1gYbScyxS0/RW83SMjgXtB5t5kuPkbKQ5YSwJD/KJ1iqfyQwQ
/40P8H+XhfVyme/MbEl+lUenxy6XkW4OEk2k5dZ1MpBodjwkWV/bN/W0NisJ
BzsTjnlp5t0+oHvmNdFQs0Ha6JllQa1xLJ1MjpzjfXc/mfckG6wf01Kzhfom
G8nME6+M5eoaeEYW5jtla52RFWtv5/0NOjtEWw==
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 785->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FKQ0EQRAcX4jXEG+gBgleIJ4igq4AQF+LOo2tQxEy6ql7nC/ph8mcy
PdVVNfUv75/Wj2djjOeLj5/15uV2t9u83p3vFw+b7c31dr959TXGeFuN7/d/
GO6Z9ykGqaPYP/1y/lVYicsSTKdFYXW4zPWdPqqX0jPrmPlWXJyedK7Doaol
upwvySNyb7SfqqOcKRfKz/VLd+k0Ea0EcxTZS17+lsYDjNUhF6U5ZSv51c0E
uW/HWeXKaUs6FAenhWp1HNTcae9wqPZTPc2f497BrtbUI5IdV698SWeJZsep
c5+unmA4vMSFYlZ1VX1aUy5HPY3nxC/ybdCcVJoIrtJZnXU6iQcV/0rH/H+X
i+qVMt/x7JT8Oo0JTz0pI90cEMwKK53rZIBgdjSQrC/tSzUtzQrhob6JxPnU
zKd7qOZKK8Fw3lTY1VplwZ1JXDqZnHnO8+59Ku0kG6qfwnLelvghG8RzolVx
cd7MXEid4/YX45PHO+pSReE=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 786->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FOAzEUQyMWiGsgbgAHQFyhnGCQYFUJqSwQO44OhQqV6Nt+v7OAkdIm
kx9/2/FcPjxvns7GGC8Xnz+b5fVut1ve7s/3i8dle3O93W9eHcYY77fj5/8/
DPfM+xSD1FHsY7+cfxVW4rIG02lRWB0uc32nj+ql9Mw6Zr4VF6cnnetwqGqJ
LudL8ojcG+2n6ihnyoXyc/3SXTpNRCvFPK5Nfakfbb0gM19PqEt+dTNB7ttx
Vrmq3lVYqq7i4LRQrY6DmjvtHQ7Vfqqn+XPcO9jVmnpEsuPqlS/pLNHsOHXu
09UTDIeXuFDMqq6qT2vK5dfeYSjPiV/k2zglJ1Sf01mddTqJBxX/uU/1vstF
9UqZ73h2Sn6dxoSnHnL3VBPFrLDSuU4GCGZHA8n62r5U09qsEB7qm0icT818
uodqrrQSDOdNhV2tVRbcmcSlk8mZ5zzv3qfSTrKh+iks522Ha8Jy/St+iovz
ZuZC6hy3vxjfPD4Aus9HIA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 787->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lOw0AQHHFA+QbKD+ABEV8ILzASOUVCSg4RN54OWRQ5k9ra5sBIjj1x
T3VVdfnp/XO9eWit7Re/P+vh8LrbDV9vj8fNx7B9ed4eXy4vV2vfq3a9/4dL
rf59ipHUpdhjv5R/CMtxmYOptDCsCpe+vtKH9WJ6eh09X8RF6XHnKhxQbaJL
+eI8SuaW9mN1KeeUS8pP9XOzVJoSrSnmuJbWFHI3SW+QmdMa1aI651c1E27e
iovKFfqvv6u6HsdpSbUqDuxZaa9wQO9dfZo/xb2CjfapR4yL88b5ws5WNCtO
lXmq+gRD4TkuKSaqQ/Vun3JJZqLwnM5q7m8wJn4fTCc6q3Rel/AA8b/TAf6v
cmG9XOYrnk3Jr9Lo8NhKM5loSjERljtXyUCCWdGQZH1u31TT3KwkPNg34ThP
zbybA3pmWhMM5Q3CRnuWBXXGcalksufZP1fnybQn2WD9GJbyFuKbbCSeJ1oZ
l7tlMqZwbvZ/+L3Muc68fgAvNkNh
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 788->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk11Kw1AQhYc+SLch7kAXULqFuoII9qkg1Afpm0uvRZFwOX+TPGggTdLc
e+Y7Myf3L2+H46aq3rdfP4fpY38+T5fnu9vD63R6ejzdXj78nFWfu/q9/odT
HeP7VCNZl2rP+6X6h7QcyxpN5YVpdVjG9Z06rBbzM/oYeRGL8uP2dRjQ2sSX
6ovrUTK3tB5blzKnLCmfqudmqTwlXhPNAtlDdauRu0V+g8zMWdg6169uJpJ5
K2aWK+qtvA/IEMwo8aoY2L3y3mFA7916l002r4SVzU4xz+fA6owsrjeuL2yv
+k7W5NlxuVnI/gk9x5JqonVovXtOWZIcKj3ns5t71YtUl/lEe5XPpAeIf6yD
/u+ysFou852eLcmv8uj02JFmMvGUaiItt6+TgUSz4yHJ+tq6qae1WUk42Dfh
mJdm3s0B3TOviYbqDdJGzywLao9j6WRy5Bzvu/Nk3pNssHpMS/W2w+q0VH3E
x1jQoeaqdBzbX5zfHFf1wkcc
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 789->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUfGQhuUbwBnoA8QrxBCPoKiDEhbjL0WNQxHTq92aysGGSafp1
vap6NZvnt+3rqqre118/2+njcb+fPp9uTpuXaXd/tzsd3v48VYeH+v3/D49a
43mKkdSl2H/9Uv4hLMdlCabSwrA6XMb6Th/Wi+kZdYx8ERelx93rcEC1iS7l
i/MomVvaj9WlnFMuKT/Vz81SaUq0JpgFsue8vJbGM4wgM+hsrHN+dTORzFtx
ZrlS2pwOxqHCPKXzHO+wd6W9wwGdu/o0f4p7BxvtU4+S7Kh65gu7WwA/9adz
Z+TlZpH6h/Lu5pVgojpU7/YplySHCs/p7OZeeZHiMp3ortJ50Vf0QYvNcg4X
1stlvuPZnPwqjQ6PrTSTiaYUE2G5e50MJJgdDUnWl/ZNNS3NSsKDfROO89zM
uzmgd6Y1wVDeIGy0Z1lQdxyXTiZHnuN7d55Me5IN1o9hKW87XB2W6o/4MS5o
qbkqnLP9Fb+XJc83ryP9sUYg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 790->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKAjEUDC4GryFzg5kDNF6hPUEPjCthQBfizqNrg9gaXn1esplAa4e8
1KuqV735+Rv3q1LKaX3/Gafz9nicLruPefM7Hb6/DvPh5+Mp5TqU5/9/eNiq
z10Mp87FfvWL+RdhKS49mEwLwspwqeszfVAvpKfWUfONuDA96l6GQ1Tr6GK+
KI+cubn9UJ3L2eXi8mP91CyZJkerxByWx+3r+tGjGWmIzuo65Vc2E868GWeU
K6ZN6YB+VbNs0co4oHemPcMhOlf1bv4Y9wx2tHc9crLD6pEv6G4xstmSZ8VL
zcL1L8q7mpeDGdVF9WrvcnFyyPCUzmzu3zAavw+kM7rLdD7XsPyjPtFCs2zh
gnqpzGc8a8kv06jw0HIz6WhyMSMsdS+TAQczo8HJem9fV1NvVhwe6JtQnFsz
r+YQvSOtDgbzJsKO9igL7I7ikslkzbN+z84TaXeygfohLOYtxCNzdTx3tCIu
4SJzZTiKW/o76by/eHgDZm1D3w==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 791->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOAzEMjVigXqPiBnCAiiuUEwxSuxqpUruo2PXoUIqqGeP38WQBkdJJ
Guf5Pftl/X7Y7h9aa6fV1892OL8ej8PH2+N1sxvGl+fxevj0M1u7bNr9+x8m
G/HcxXDiXOxpvVj9MizFpQeTaUFYFS4xvpIH5UJ6oo7IN+PC9Kh7FQ5ZrKOL
1UXVyOmbmw/FuZxdLi4/lk/1kmlytDqYMVbldevRoxlp+B4iTtWr6gn5Bibn
CMvlEr8sLq3X5jaVn9x+xjtozbRXOGTnKt71H+Newc72M+xJD1CeyEXVRtUF
3XW86XCq9JPFOxgMT3FxMbO4LF7tXS6ODxme0ln1/Qxj4ftAOrO7TKdTg4z/
Lx3J/1UuKJfyfKVmS/zLNCo8NFxPOppczAxL3at4wMGsaHC83pvX1dTrFYcH
ehOK81LPqz5ka6TVwWC1ybCzPfICu6O4VDwZecZ1tZ9Iu+MNlA9hsdpWuCos
lj/jh7igUfWmw+0v5o3HJ1/NRGE=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 792->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EQLVxIriHeQA8QvEI8wQi6CgjJQtx5dE0U0Z73qxkXNnSmO1P1
6r2qN1cPz7uni6o6bj5+dtPL3eEwvd5fni6P0/72Zn96ef21q9629f38D1ut
8X2KkcSl2D/7pfqHsByXNZhKC8PqcBnjO3VYLaZn1DHyRVyUHpfX4YBiE12q
L65HydzSeiwu5ZxySfmpem6WSlOiNcGs7ed2dctwXaJxhgO8iOqoONevrieS
eSvOzFdUW3kdjMN5BX5KvIdy2Flp73BA71186j/FvYON7mmPEu+oeNYXltvR
rDh15qniEwyF57ikmCgOxbt7yiWZicJzOru+/4Wx8PtgOlGu0pn0APGf6QD/
d7mwWs7znZ4t8a/S6PDYSj2ZaEoxEZbL63ggwexoSLy+tm6qaa1XEh7sm3Cc
l3rezQGdmdYEQ/UGYaM784LKcVw6nhx5jufuPJn2xBusHsNSve1wdViqPuLH
uNDV9Oas1l99K2vzz7zeAczwRCA=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 793->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lqw0AQHHwI/obJD5IHhHxBfoECyUkQkA/BNz89kQnBbrqWnrlEMJbk
6amuqi4d3j6nj11r7bT/+Znmr9d1nc/Hh+3lfV6en5Zt8/F3tXZ5aX/3/7DY
FfddDKfOxb71i/mXYSkuI5hMC8KqcIn1lT6oF9ITdUS+GRemR52rcMhqHV3M
F+WRMze3H6pzObtcXH6sn5ol0+RodTBjLdprhdz1rrt+QLOqU35VM+HMm3FG
uWLalA7mF5qTq5VxQM9Me4VDtq/qVTbdbDEPnFlmXFCfyEV5o3xBZ5uRzZ48
K15qFtQ/gqe4uJhZXVav3l0uTg4ZntJZzT3zwsVFOrOzTKfjQcY/9sn+r3JB
vVTmK5715JdpVHjocjPpaHIxMyx1rpIBB7Oiwcn6aF9X02hWHB7om1CcezOv
5pA9I60OBvMmw87eURbYGcWlksnIMz5X54m0O9lA/RAW87bCVWGx/hk/xAVd
1Ww63Lq+ldHzVx7fdaZFYQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 794->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOw0AMtbpAXKPiBnCAqlcoJwgSrCohlUXFjqNDBaoS4/fxZAEjTTKT
8Ty/Z79sn14PL5uIeLv9ehym8/50mt4fby6b5+n4cH+8HN79zIiPXVzf/2Gy
kc9dDCfOxZ7Xi9WvwlJc1mAyLQirwyXHd/KgXEhP1pH5VlyYHnWvw6GKdXSx
uqgaOX1z86E4l7PLxeXH8qleMk2OVgczCu9VeaPhu9G5yIc075acc5yqV9cT
qt+MC/NV9S2/WRyqF+qTq5VxQGumvcOhOlfxrv8Y9w52tf+FLbjneFUbVRd0
N+ZTaGacOv2k8QYGw1NcXMwqropXe5eL40OGp3R2fb/AGPw/kM7qLtN5HTOv
ojzVQL0c4YJyKc93ajbiX6ZR4aHhetLR5GJWWOpexwMOZkeD4/W1eV1Na73i
8ED/hOI86nnVh2qNtDoYrDYVdrVHXmB3FJeOJzPPvO72E2l3vIHyISxW2w5X
hcXyV/wQFzS63nS4/cX85vEJizJCXw==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 795->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUfLgIuYZ4g3iAIVfQE4wQV4JgFsGdR1dRhtC++rzpLNLQ2k2/
rldVXbPcHTf7RUR8v99+NuPP5+k0nrdv983XeFh/HO6Hq+eMuAwx/f+HyUZ7
7mI4dS72b7+YfxmW4tKDybQgrAqXtr7SB/VCelodLd+MC9Oj7lU4ZLWOLuaL
8sh5N7cfqnM5u1xcfqyfekumydHqYMbwmG5f148ezUjDdJZkVvlS9bDy3owz
yhXUFloH8yuIBkcr44DWTHuFQ3au6t38Me4V7Gz/gi24t/XKG+ULuhuD5jIn
z4qXegvpH8BTXFzMrC6rV3uXi5NDhqd0VnPPvHBxkc7sLtM5jSavWZ9soLec
wwX1UpmveDYnv0yjwkPDzaSjycXMsNS9SgYczIoGJ+u9fV1NvVlxeKBvQnGe
m3n1DtkaaXUwmDcZdrZHWWB3FJdKJlue7br6nki7kw3UD2ExbytcFRbrn/FD
XNCoZvOl1x9+Lz3zwesK81NF3Q==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 796->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOwzAQtbpAXKPiBvQAiCu0J0ildhUJqSwQO44OVUuUTud9xlmAJSd2
PH7z3szLev+2Pa5aa++PP4/t8PF6Og2fu4fz5jCMm+fxfPh0na19vbTp/R8m
G/HcxXDiXOx5vVj9MizFZQkm04KwKlxifCUPyoX0RB2Rb8aF6VH3KhyyWEcX
q4uqkdM3Nx+Kczm7XFx+LJ/qJdPkaHUwYyw6awXf9c6bfEjzlQuKU/WqekL1
m3Fhvsq+xTeLQ/VCfXK1Mg5ozbRXOGTnKt71H+Newc72d9iCe4xXtVF1QXd/
/xVHM+NU6SeLdzAYnuLiYmZxWbzau1wcHzI8pbPqe1YLFxfpzO4yndOYeRXl
yQbqZQ8XlEt5vlKzHv8yjQoPDdeTjiYXM8NS9yoecDArGhyvL83ralrqFYcH
+icU517Pqz5ka6TVwWC1ybCzPfICu6O4VDwZecZ1tZ9Iu+MNlA9hsdpWuCos
lj/jh7igUfWmw+0v5oXHN63FRCA=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 797->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQbPwQryHeQA+weIV4ghX0KyAkH8E/j64hInFSr94FcWB0h+mp
rqqu3D6/bV6vqmp/8/VnMx8ed7v5/en6eHiZtw/32+Pl3feu+pjq5/9/2GqN
9ylGUpdin/ul/ENYjssaTKWFYXW4jPWdPqwX0zPqGPkiLkqPe9fhgGoTXcoX
51Eyt7Qfq0s5p1xSfqqfm6XSlGhNMGs6bde3DNclGi9wQBZRH1Xn/Opmws3b
cWa5otrK60A453xcnpLsoTfsW2nvcED3rj7Nn+LewUbnC2zDfax33jhf2Nua
PJeEU2eeqj7BUHiOS4qJ6lC9O6dckhwqPKezm3vlRYrLdKK3SuevO9MHLTbL
JVxYL5f5jmdL8qs0Ojy20kwmmlJMhOXedTKQYHY0JFlf2zfVtDYrCQ/2m3Cc
l2bezQF9M60JhvIGYaMzy4J647h0MjnyHL+782Tak2ywfgxLeau4FvEy8TzR
yrjAJeaqcNJ5/OU+cfkENm9GWw==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 798->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLIQryHeQA8w5ArxBCPoKiDEhWTn0WM0RO3U7/W4sKHNtPO6
XlW9mpvHl83zqrX2ev3xZzO/rXe7ef9wdTw8zdv7u+3x5e1pt/Y+tfPvf9hq
9e9TjKQuxf7pl/IPYTkuSzCVFoZV4dLXV/qwXkxPr6Pni7goPe5ehQOqTXQp
X5xHydzSfqwu5ZxySfmpfm6WSlOi1WJO3zvtm/oxpBlkEfVRdc6vaiaSeSvO
LFdUW/M6GIfPFeQpnWd/hz0r7RUO6L2rT/OnuFew0fkC23Dv6503zhd2t02e
y0ieHS83C+sfwXNcUkxUh+rdOeWS5FDhOZ3V3P/CGPw+mE50V+lMPED8L3SA
/1e5sF4u8xXPRvKrNDo8ttJMJppSTITl7lUykGBWNCRZX9o31bQ0KwkP9k04
zqOZd3NAz0xrgqG8QdjozLKg7jgulUz2PPvn6jyZ9iQbrB/DUt5WuDos1R/x
Y1zYqmbzXHfaf/m9LNlfvA51xEbb
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 799->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAlEQbLIQryG5gR5gyBXMCSYQV4JgFiE7j55IZJC269MzGx88ncf0
q66qrtl8nPaHl4j4Wv/97Mfvt/N5/HlfXQ+f43G3PV5fvt52xGWI6f8ZNlv5
vYvh1LnY934x/yosxWUJJtOCsDpccn2nD+qF9GQdmW/FhelR9zocqlpHF/NF
eeTMze2H6lzOLheXH+unZsk0OVol5nDb4fd1/ViiGWmo3uU65Vc3E868GWeU
K6ZN6WB+hZEnd575Dnpm2jscqveq3s0f497Brs4P2IJ7rlfeKF/Q3Rg0lzl5
VrzULKR/AE9xcTGruqpenV0uTg4ZntLZzT3zwsVFOqu7TOe00rdT9akWmuUc
LqiXynzHszn5ZRoVHlpuJh1NLmaFpe51MuBgdjQ4WV/a19W0NCsOD/RNKM5z
M6/mUD0jrQ4G86bCrs4oC+yO4tLJZOaZn7vzRNqdbKB+CIt52+GqsB7OQivi
glY3m1PdHZdn2P+8fgFp8UUe
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 800->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHFyI1xBvoAcQrxBP8ASzCghxIe48ukYkSFu/ntk48JI3TE91
VXW966eX3f5ijPF69fWz294ejsft/fHytHneDne3h9Phzc8zxsf9OP//h0et
ep5iJHUp9m+/lH8Iy3FZwVRaGFaHS63v9GG9mJ6qo/JFXJQed6/DAdUmupQv
zqNkbmk/VpdyTrmk/FQ/N0ulKdGaYNZa1zf1Y0Uz04DOFH/nSapRecl4uVwp
bU6H8msEeUrnWe+wd6W9wwGdu/o0f4p7BxvtK7bjjuqVN84XeB5ymcmz45V+
Qy5jyE83rwQT1aF6t0+5JDlUeE5nN/fKixSX6UR3lc7zCrKDFpvlDBfWy2W+
49lMfpVGh8dWmslEU4qJsNy9TgYSzI6GJOurfVNNq1lJeLBvwnGezbybA3pn
WhMM5Q3CRnuWBXXHcelksvKs7915Mu1JNlg/hqW87XB1WH/2RivjQlczm07X
9Leyev+b1yfxPUSi
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 801->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOAzEUi7pAvUbFDeAAiCuUEwwSXVVCaheoux4dyqcaBf9eZgGR0sk0
L36249k8v253q9bacf3xs53eHg+H6fR0c3l5mfb3d/vL5u33bO380K7P/zDV
6PdTjKQuxZ77pfxDWI7LEkylhWFVuPT1lT6sF9PT6+j5Ii5KjztX4YBqE13K
F+dRcm9pP1aXck65pPxUP3eXSlOi1WKCWtc39WNIM8gi6jPfU/ydJ6lG57Hi
zHKltDkdjMPnCPKU3md/hq2V9goHtO/q0/wp7hVs9N5jO+6oXnnjfGFnUx+r
eXa8ftXNpsNQeI5LFRMNdb7ii8sL8zzJcXqnaU5Gvg+mE51VOq/ZED0R/74e
/V/l8sPHfVMOd2QyLay366U8c56gdZqxkdwl96P0VDArGpKsL+2balqalYQH
+yYc59HMu3tAa6Y1wVDeIGz0zrKgzjgulUz2PPt19T6Z9iQbrB/DUt5WuDos
1R/xY1zoKGbT6fqr+cXrHQvuRZ4=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 802->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FOAzEQizggvoH4ATwA8YXygkWCUyWkckDceDoUyqqM7LHdcCBS2mwy
8dgzzuXD8+bpbIzxcvH5s1le73a75e3+fP/xuGxvrrf7w6vDHOP9dqz//2F2
o567GE6ci31cr65+CEtxmcHstDCshEuNT/KwXExP1VH5Ii6dHnUv4YBiHV1d
XVSNnL65+Vicy9nl4vLr8qledpocrQ5mjWVnI/DdzFzzMc0HLixO1Sv1hNPv
jjPzFdpDWCwOcfipj/JT2gOkr2I52IoDOlfxrv867gk2+q7YijuK72qj6sLu
unVM/ax4uW9IeQxpUP1KMNHo7id1UX5Z14a2U3vq+gRxcfggnehu5YDydjkR
/xqP9lMuX3uNt519p4epfzuNCo8N5ZHUBw4mwlL3Eg84mIkGx+uzeV1Ns15x
eLA3oTif6nnVB7RmWh2MrjYIG30zL3R3FJfEk5VnXaf9ZNodb7B8DKurbcd1
kFo6NXe0Mi50hN78lesP38rs/Ob1AX1ZRR4=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 803->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8QvEI8wQhmFRDiQtx5dM2gIo9Xv+mNDZOZybyu
V1Wv+ubp5XC8GmO87r5+Dsvbw/m8vD9eX16el9P93eny8fb7GuNjP37v/+Fi
q353MZw6F/uvX8y/DktxmcFkWhBWwqXWJ31QL6Sn6qh8Oy5Mj9qXcOhqHV3M
F+WRMze3H6pzObtcXH6sn5ol0+RodTBrrerr+rH1+sFCmtc7qVN+pZlw5s04
o1xBbUPrQBzWZeQpnUGnr2I52IpD913Vu/lj3BPs7r1iK+5dPfNG+YL2uj6m
eVa83DOkMtZpUPNKMLvF9ie+qLwgz50cuzN1c7LlfCCd3V6msy7Wp1sMJ+Wy
/key7fzvzDDNb+KV45nypHt2M7Yld858mJ4EM9HgZH22r6tpNisOD3QmFOet
mVdz6J6RVgeDedNhd+8oC2yP4pJksvKsz+k8kXYnG6gfwmLeMq4DeOl47mhF
XNBKs4l0TZ+V2f0rr0+8BEXh
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 804->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tuQjEMjFhUXAP1Bu0BEFegJ3iVygqpEiwQO45OQX3Vk+X5ONk0UngJ
ie2Z8WTz+b0/rFpr5/XPz3667E6n6frx8th8Tcf3t+Pj8PV3tnbbtr/vf5hs
xHM3h3PPzb3Ui+mX5VJYRnIyLihXBUu8X6mDaiE+kUfEm2FhfFRcBUN21+HF
dFEaOX1z66F7LmYXi4uP1VO9ZJwcrk7OeFfVdfXo4jzXBxzm/fKM4VeauByZ
lgiX8hXjpnggDM9h+MntZ4xBa8a9giE7V/dd/zHsldzZPuZW2LP7TBulC4p1
daz6WeFy35DyWMZB9auSMxssvqKL8gvS3PGx21PXJz3vA/HMYhnPtpygZoY/
1sn+r2KZ8ag3pfL2TMQF1Va1mGZKk2zteqzHd05/GJ9KzgoHx+ujdV1Oo15x
cKA3oTD3el71IVsjrk4Opk2WO9sjL7AYhaXiyYgzrqv9RNwdb6B6KBfTlmFt
QEtHc4crwgJH0ZuI1/BbGY1/4roDI7VE3w==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 805->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8gXiGeYARdBYS4EHceXROiyEv93rQLBybpmX5d
r6pezdXjy/b5Yozxuvn62S5v9/v98v5weXh4Wna3N7vD5vXpHuPjbvz8/4db
XXU/xUjqUuzffin/EJbjMoOptDCsDpda3+nDejE9VUfli7goPe5chwOqTXQp
X5xHydzSfqwu5ZxySfmpfm6WSlOiNcGstWyv49vMfbyIBrSn+DtPWG133oyL
yhV6h7BYHeLw7Y/LUzIDdIatlfYOB7Tv6tP8Ke4dbPRcsR13VK+8cb6ws6mP
3Tw7Xuk35DKGNLh5RZigDtW755SLzGGgbe1M05wgLgkfpBOdrRzY/FlPxL/W
o/ddLqyXy3zHszX57XiVeOY8Qes0Y2tyl8xH6elgdjQkWZ/tm2qazUrCg30T
jvPazLs5oDXTmmAobxA2emZZUGccl04mK8+67s6TaU+ywfoxLOWt4jqIl4nn
iVbGBV4nPpUL033W6y+/ldnzR16f1K5DoA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 806->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHFyI1xBvoAcQrxBP8ASzCghxIe48uiZqCE39+o0LByZ5b6a7
uqq73vXTy2Z7McZ4vfr62SxvD/v98v54eXh5XnZ3t7vD5c3PHuPjfpz+/8NW
q96nGElcin3eL9U/hOW4zGAqLQyrw6XGd+qwWkxP1VH5Ii5Kj8vrcECxiS7V
F9ejZG5pPRaXck65pPxUPTdLpSnRmmDWWHbX6dvMlpp/d+HF+LuesNho3mfn
jIvyFTpDWCyu4pxW0NdkBiiHPSvtHQ7o3sWn/lPcO9jovWI77ihe9cb1heWm
fXScOvNk8eocaWEa3Lw6mGip/E5fnF9YzxMfpzNNfbLm+2A6Ua7SeVyhd9BC
M1/L5XgmvJ2cJzPs+ldpdHhspZ5MNKWYCMvldTyQYHY0JF6frZtqmvVKwoN9
E47zWs+7OaBnpjXBUL1B2OideUHlOC4dT1ae9bk7T6Y98Qarx7BUbztcHZaq
j/gxLnQ1vVlr/eX3MrO/uXwCSSRE4Q==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 807->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcQrxBPMIKuAkKyCO48ugY1TJ71ezMubOgkk35d
r6pezfXT6+blYoyxv/r82EyHh91uenu8PD48T9u72+3x8OZ7j/F+P07f/2Gr
Vc9TjKQuxZ77pfxDWI7LGkylhWF1uNT6Th/Wi+mpOipfxEXpcfc6HFBtokv5
4jxK5pb2Y3Up55RLyk/1k7P82YR3otV5hDDY2Wjkbs2uun/xN9lyfnUyMWZ1
kOc4P2dYKReExeoqzmmJGSmtjAvqoXx3uKoOnbv6NH+KewcbPVdsxx3VK2+c
L+xu6qPj1Jknq1f/Iy1Mg5tXhAnqUL17TrnIHAbals40ycmZFw1cphPdrRzo
2YwP6oMWmvlSLqyXy3zHsyX5VRodHlsuI90cJJgIy93rZCDB7GhIsr62b6pp
bVYSHuydcJyXZt7NAf1mWhMM5Q3CRs8sC+qO49LJZOVZf3fnybQn2WD9GJby
tsPVYan+iB/jQlczm7XXX74va/YXlw+AJkTb
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 808->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQbPIhuUbwBnoA8QrxBCvoV0BIPiR/ObpGZIlN16NnfhzY7G6m
p7qqunb3+rF/30TEafv9s18+n4/H5fxyd315Ww6PD4fr5v3vFXF5ivX+Hy62
8r6L4dS52Ld+Mf8qLMVlBpNpQVgdLrm+0wf1Qnqyjsy34sL0qHMdDlWto4v5
ojxy5ub2Q3UuZ5eLy4/1U7NkmhytDmauRXvRyN3MtfZDmkW2lF/dTMB5J66d
DCAuFRaqyzjrMvLUnUGlL2O5PrK6al/Vu/lj3DvY1XvGVtyreuaN8gWddX1U
nDrzRPXs/0oL0qDm1cGsFjvf8UXlBXnu5NidqZOTGPw+kM7qLNP5Z0/0qVY1
81EuqJfKfMezkfwyjQoPLTeTjiYXs8JS5zoZcDA7Gpysz/Z1Nc1mxeGBvgnF
eTTzag7VM9LqYDBvKuzqHWWBnVFcOpnMPPNzd55Iu5MN1A9hMW8Z1wBeOp47
WhGXcpG5MpxbLVFoHPpWZs//8PoCW4ZEXw==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 809->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FKBEEQazzIfkP8gT5A/ML6ghH0tCDsHsSbT9dFGZYiqSTTHmyY3Znp
6lSSytw8v+1fr8YYp933z355fzwel4+n6/PDy3K4vzucN29/rzE+H8b6/x+u
btV9F8Opc7Ev/er8Q1iKywxmp4VhJVxqfdKH9WJ6qo7KF3Hp9KhzCQdU6+jq
fFEeOXNz+7E6l7PLxeXX9VOz7DQ5Wh3MWsv2RpC7mWvtxzSLbCm/kkyMwqnu
XXJIMsC4ICxWV3HWZeQpnQHSV7EcbMUB7at6N38d9wQbPVdsxR3Vd94oX9hZ
10fFKZknq+/eIy1Mg5pXgolWdz7xReWFee7k2J2pm5Mt3wfTic52Oh0PEP/a
B71PubBeKvOJZ1vy22lUeGy5mXQ0uZgIS51LMuBgJhqcrM/2dTXNZsXhwb4J
xXlr5tUc0D3T6mB03iBs9Myy0J1RXJJMVp71Pp0n0+5kg/VjWJ23CVeF1fVH
/BgXttJs1l5/+b3MXD9cvgDVYUUi
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 810->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPwQryHeQA8QvEI8wQrmKyDED/HPo2tQVmnq1bMgDkySzfRU
V1XXXj8+7w8XY4yXq8+P/fJ6fzotbw+X54en5Xh3ezwf3nzvMd53Y/3+D1ut
ep5iJHUp9m+/lH8Iy3HZgqm0MKwOl1rf6cN6MT1VR+WLuCg97l6HA6pNdClf
nEfJ3NJ+rC7lnHJJ+al+bpZKU6I1way17Gw0crdlr/2YZpMt51c3E3TehWsn
A4wLwmJ1FWddQZ66M0D6Klbqo6pD564+zZ/i3sFGzxXbcUf1yhvnC7ub+ug4
debJ6tX/SAvT4ObVwURL3e/44vIyk+HuTNOczLwfTCe6W7Hh/Hc/m/VBC818
lgvr5TLf8Wwmv0qjw2MrmX2qKcVEWO5eJwMJZkdDkvWtfVNNW7OS8GDvhOM8
m3k3B/SbaU0wlDcIGz2zLKg7jksnk5Vn/d2dJ9OeZIP1Y1jKW8V1EC8TzxOt
jAtcYq4KJ53HX+4vLh+Iv0Vf
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 811->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKBEEQK/wQryHeQA8gXmE9wQj6tSCsH+KfR9f1MYxtUklmQGzonZ7t
qlRSlTm/e9w9nFTV09n7z256vjkcppfb0+PL/bS/utwfLy++dtXrdc3P/7C7
Nd67GE6ci73sV9c/hKW4bMHstDCshMsYn9RhtZieUcfIF3Hp9Ki8hAOKdXR1
fVE9cubm1mNxLmeXi8uvq6dm2WlytDqYYyy7q8B3a3ctN9MsvKX6lXiiFnGQ
a/28Z1guF4TF4kaceRl+cryHcti50x71G9yreNd/HfcEG72P2Io7iu96o/rC
ct0+Kk7JPFl89z/SwjSoeSWYaHX5SV+UXz7OoYfTmTo+qeU29XU6Ue7Igc2/
FpxQHbQgzkourJbyfNKzNf7tNCo8tpRHUh84mAhL5SUecDATDY7Xt9Z1NW31
isODfROK81rPqzmgM9PqYHS9QdjonXmhy1FcEk+OPMdzOk+q3fAGq4d4M99K
vO/YRusv7k19qJVwYSv15hwXfF9/sT+5vAGn3EAg
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 812->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPyQXEO8gR4g5ArxBCuYr4AQPyR/OXoSlGXp7Xr0jB8ujNl1
eqqrqmue3j/3h4fW2tfm9mc/fe9Op+n89nj/+JiOry/H++bz72rtsm3z739Y
7In7LoZT52Iv/WL+ZViKywgm04KwKlxifaUP6oX0RB2Rb8aF6VHnKhyyWkcX
80V55MzN7YfqXM4uF5cf66dmyTQ5Wh3MWIv2WiF3I2vuhzSLbCm/KplogVPc
W3KoZABxybBQXcSZHyNP1Rlk+iKWg604ZPuq3s0f417Bzr4jtuKe1TNvlC/o
rOuj4lSZJ6pn/8+0IA1qXhXM7GHnK76ovPRkuDpTOycd9wPpTPED9qr3YiHP
2LyyvR4ul8CBnWe4PQtpQb1VL+aZ8iR7dzNWyZ26H9ETlQEHs6LByfpoX1fT
aFYcHuhOKM69mVdzyN6RVgeDeZNhZ98oC+yM4lLJZOQZ36vzRNqdbKB+CIt5
y7gqrRFr9S20Ii7oqWZz1esP78vI+uF1BUrzQ18=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 813->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FKBEEQazzIfkP8gT5g8QvrC0ZwTwvCehBvPl0XZZAiSSU9HmyY3Znp
6lSSytw8vRyOV2OM193Xz2F5ezifl/fH68vD83K6vztdNm9/rjE+9mP9/w+X
WnXfxXDqXOzffin/EFbHZQum0sKwEi61PunDejE9VUfli7goPd25hAOqdXQp
XzqPnLm5/Vidy9nl4vJT/bpZKk2OVgez1rK9EeRuy7X2Y5qbbHV+pZmg8y5c
kwwwLgiL1VWcdRl5SmeA9FUs10dVh/a7ejd/inuCjZ4rdscd1StvOl/YWdfH
jlMyT1av3iMtTEM3rwQTLXU+8aXLy0yG05m6OZn5PphOdLZiO7lDfdBCM5/l
AnsZmU88m8nv+r6ZoetZ54nyr8vYTO6c+Sg9CWaiwcn61r6upjgrISbT4HCe
zXw3B3TPtDoYyhuEjZ5ZFtSZjkuSycqz3qfzZNqdbLB+DEt5q7gO4qXjuaOV
cWErzWbt9Zffy5brm8snqylFoA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 814->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNUltqAkEQbPIhXkNyg+QAkiuYE6ygX4KgH5I/j55IElk7XY9eIbgwOrvT
U11VXYv1frV9iojj/OtnNZzeDofh4312edkMu9eX3eXw+WdFnJdx/X+ExZ58
7mI4dS722C/mX4WluNyDybQgrA6XXN/pg3ohPVlH5ltxYXrUvQ6HqtbRxXxR
Hjlzc/uhOpezy8Xlx/qpWTJNjlYHM9eis45vU1f89gcaxlyqPfOFfUP8g807
8elkQGlTOiocqUWcM58rfRnLwZ7CUdW7+WPcO9jVe8ZW3Kt65o3yBd11fVSc
OvNE9ex7pQVpUPOCmCLfFQf17nK5OVtiLirD3Zk6OQlS1+WC7mZsdAY9K/j/
0VF873JBvVTmO55Nye9NdsCZo8PhjvZuxtzcsVmP73Uy4GB2NDhZv7evq6md
lSYm0uBwnpp5NYdqj7Q6GMybCrt6R1lgdxSXTiYzz7zvzhNpd7KB+iEs5i3j
GsBLx3NHK+KCnm42r3XGPP5zfXP5BAzlRF8=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 815->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPwQryG5gR5AvEI8wQaSr4AQP8Q/j64hIYRO12sXxIFJdjM9
1VXVlcfN+3p3N8b4ePj9WE+fr4fD9PV2f3zZTvvnp/3xcHXeY3y/jMv3f9hs
1XMXw6lzsa/9Yv51WIrLEkymBWElXGp90gf1Qnqqjsq348L0qHsJh67W0cV8
UR45c3P7oTqXs8vF5cf6qVkyTY5WB7PWorPEt7l7NFns+lReiL/yBNWm82ac
Ua6YNqUDcWBaXK2MA3pm2hMO3bmqd/PHuCfY3XvFVty7euaN8gXddX1M86x4
uf8hlbFOg5pXgtktdj/xBeblvOdkOJ2pk5NB6lIu6G7FRmfQs4b/jY7m95QL
6qUyn3g2J79Mo8JDS2UkzYGD2WGpe0kGHMxEg5P1pX1dTUuz4vBA/wnFeW7m
1Ry6Z6TVwWDedNjdO8oCu6O4JJmsPOtzOk+o3cgG6tfxRrmVeNcbaL3hDrRA
rYALWmk2L3XGPP5yn7j8AGOJQqI=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 816->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU8FNA0EQW/FAtIHoAAqIaCFUcEjkFSlSeCB+lA6BKEoG22Pf8WClTe60
sx7b47t93q03V2OM15uvn/X09rjfT+9P14eXl2n7cL89HN4d9xgfq3H6/w9b
rXruYjh1Lva5X8o/hNVxWYKptDCshEutT/qwXkxP1VH5Ii5KT3cv4YBqHV3K
l84jZ25uP1bncna5uPxUPznL8w2wHa2dRwiDnY0gd0v2qR/R3GWL+ZJ6mMxb
cWa5Uto6HYyD0uJqVRzYs9KecEDnXb2bP8U9wUbvFbvjjuqVN50v7K7rY5rn
jpf7DXUZQxq6eSWYaKn7iS80L8c9J8PpTJ2cDFGXcmF3KzY9K5zceaGzOVwu
eoFZMQ8Tz+bk9yI75IzqIKvLSJoDBxNhdfeSDDiYiQYn60v7uprirISYTIPD
eW7muzmgZ6bVwVDeIGz0zrKg7nRckkxWnvU5nSfVbmSD9UO8WW4drt9LaP3F
XfSHWgkXttJs1l5/+b0s2T9cPgEdAkYa
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 817->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FKA0EQbHIQvxH8gT4g+IX4ghX0FBCSQ/CWp8dgkLXT1VU168GBSXaZ
nuqq6tr168f2fRURh/uvn+10fN7vp8+Xu8vL27R7etxdDh+uO+K0iZ///7C7
lc9VDKVOxZ771flXYTEuSzA7LQjL4ZLrnT6oF9KTdWS+FZdOD7vncKhqFV2d
L8wjZW5qP1Sncla5qPy6fmyWsbnuAlvRyjyqMNBZGLkb3THrgzSzbCFfXA+d
eSMuXa46bUwH4tBpUbV2HNBzp93hUJ2zejV/HXcHu3rP2Ix7Vd95w3xBd1Uf
3TwzXuo3xDJWaWDzcjCr1d13fGnzMphhd6ZKTqKpc7mguxkbniVO6ryqsxEu
v3rNNsu849lIfjuNDA8tlhE3BwpmhcXuORlQMB0NStaX9lU1Lc2KwgN9E4zz
aObZHKpnpFXB6LypsKt3lIXuDuPiZDLzzM/uPKF2IRuoX8Ub5VbhyrTecAda
oFbABS03m7nXX34vS/Y3lzOXu0Uc
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 818->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFwEryG5QTyAeIV4ggnEVUCIC3Hn0TWYhElTv9ezycBLpunu
elX1ap52H9v3h9ba5+Pfz3b6ej0ep++31Wmxnw7Pm8Npc32u1n5e2vX/Hko9
/X6KkZxLsed+Kf8QluOyBFNpYVgVLv35Sh/Wi+npdfR8ERelx92rcEBnE13K
F+dRMre0HzuXck65pPxUPznLeQHsRKvzCGGwvYpvS2rej82j58X4O0+Uh5V5
K84sV0qb08E4KC2pVsWBvSvtFQ5o351P86e4V7DRusd23NF55Y3zhd1Nfazm
2fFKvyGXMaTBzauCiR51v+KLy8tIhqszTXMy8n0wnehuj033hGdqXmhvhMtN
r0uR+wp3pJgW1tv1Up45T5R/LmMjuUvmo/RUMCsakqwv7ZtqWpqVhAf7Jhzn
0cy7OaB3pjXBUN4gbLRmWVB3HJdKJnueN+8D86TaAyyEjbBUbhOuUKvAQmup
lXBhTzWbiMs91D+XX819RSA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 819->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNV0tqAkEUbLKQXCPkBvEAkivoCSYQV4JgFiG7HF3FjMw8Xn1eTxYOtDr0
63pV9aoXvnwct/un1trX8+VjO3y/n07Dz251ffkcDuu3w3Xz9W+19rtp9+9H
WOyJ+y6GU+diT/1i/mVYissSTKYFYVW4xPpKH9QL6Yk6It+MC9OjzlU4ZLWO
LuaL8siZm9sP1SnObbIcLi4/xpnOcsQk+VRalUcZBtpjOno1MiykWWUL+VL1
cJyBM2/GGWWcaVM6EAeqRewznzN9EcvB7uGo6t38Me4V7Ow9YivuWT3zRvmC
zro+VvOseDE/FQbDU1yqmNnDzld8UXnpyXB1pm5Oeu4H0pmdjdjMD1TD5pXt
9XCZ9RoXOO/oqCykBfVWvZhnyhPmn8pYT+6c+TA9FcyKBifrS/u6mpZmxeGB
7oTi3Jt5NYfsN9LqYDBvMuzsHWWBnVFcKpmMPO/Pps3+u7jzRNqdbGT1Uz5O
bh2umX8Ma1aXnGf1Tkaq2Yy9/vO+LFk3LmfxdkPf
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 820->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqQkEQHFyI15DcQA8QcgVzghfQlRDQRXDn0ROTINp0fXrGhQ9G32N6
qquqa5Yfn5vdrLV2XPz8bKavt8NhOr3PLx/bab9e7S+bL/+rtfNru/4/w2JP
3HcxnDoX+9Yv5l+GpbiMYDItCKvCJdZX+qBeSE/UEflmXJgeda7CIat1dDFf
lEfO3Nx+qE5xbjfL4eLyY5ydeSLejlaFl2GgPaZjRCPCQppVtpRf1Uw482ac
UcaZNqUDcaBaxD7zOdMXsRzsHo6q3s0f417Bzr4jtuKe1TNvlC/orOtjNc+K
F/NTYTA8xaWKmT3sfMUXlZeeDFdn6uak534gndnZiM38QDVsXtleD5e7XmJ+
jo7KQlpQb9WLeaY8Yf6pjPXkzpkP01PBrGhwsj7a19U0mhWHB7oTinNv5tUc
snek1cFg3mTY2TfKAjujuFQyGXnG9+o8kXYnG6jf72Pm1uGqtEasu7rkPKt3
MlLNZuz1yPsysv64fAOiBETh
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 821->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKBDEUDC7Ea4g30AOIVxhP0IKuBoRxIe48ug7K0POo30u7sCEzCXmp
VNWrXD+97l4uxhhvV98/u+X94XBYPh4vj4vnZX93uz9u3vyOMT7vx+n/Pwz1
1f0UI6lLsdd+Kf8QluOyBVNpYVgdLrW+cw+7i+mpOipfxEXpcec6HFBtokv5
wmoH4ezwZt6E3FsPo9150skh1RJoSrQ6jxAG21M6ZjQ6LKbZZcv51c1x0m/F
GZ132pwOxkFpSbUqDmyutHc4oH1Xn+ZPce9go3XFdtxRvfLG+cLOpj528+x4
pW/IZQxpcP3qYKJPne/44vIyk+FuT9OczLwPphOdrdjKD1aj+oX2Zric3WX6
l+joDKaF3e3uUp45T5R/LmMzuUv6o/R0MDsakqxvvTfVtDUrCQ/2Jhzn2cy7
PqA505pgKG8QNlqzLKgzjksnk5Xn2Xyin1R7gIWwT1+YW4tXfF/PI8/BeVWf
ZKSbzXrXX76XLeOHyxfShULh
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 822->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQbLIQrxG8gR5AvEI8wRN0FRDiQrLL0TUqMrZdn57nwgeTvMf0
VFdV12wfnndPm4h4uXz/2S2vd4fDcry/OH88Lvub6/158+prRZxu4/v/Pyz2
5H0Xw6lzsUe/mH8VluKyBpNpQVgdLrm+0wf1Qnqyjsy34sL0qHMdDlWto4v5
gmoDcFZ4M3dCcQ7DT8eTTg6hlsKjyielVXlUYbA9N3ezK8YFNKtsId5dD8c5
KI8RF+SP0qZ0IA5Ui9hnPlf6MpaDPcNR1bv5Y9w72NV3xlbcq3rmjfIFnXV9
7OZZ8WJ+KgyGp7h0MauHne/4ovIyk+HuTN2czNwPpLM6m7GZH6iGzavam+Hy
o5eYn6Ojs5AW1Fv1Yp4pT5h/KmMzuXPmw/R0MDsanKyv7etqWpsVhwe6E4rz
bObVHKp3pNXBYN5U2NU3ygI7o7h0Mpl55vfuPKF2Ixuo38dj5lbijQto/cV9
rEtzK7UCLujpZjP3+sv7smZ9cnkDGZpEnA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 823->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVk1KgzEUfLgQryHeQA9QvEI9wSfoqiDUhbjr0bUo5WuYv5duGkjbkJd5
M5MJ9P71Y/t+U1Wfd78f2+Xreb9fvl9uj4u3Zff0uDtuPvzPqsOmTt/XMNUY
91OMpC7FXvul/ENYjsslmEoLw+pwGes7fVgvpmfUMfJFXJQed67DAdUmupQv
rLYIZ4c38yYc5wr8TDzp5DC5xyLYiVbnEcJQe2nuZuc6D1SzyRbj3fZwlQnl
5cFwRucZF4R1WqNsAB9Q/2SfcUE9lO8Ot8vR1af5U9w72Gg9YjvuqF5543xh
Z1Mfu3l2vJSfDkPhOS5dTDTU+Y4vLi8zGe7eaZqTmffBdKKzI7byg9Wo+0J7
M1zOepn7S3R0JtPCerteyjPnifLPZWwmd8n9KD0dzI6GJOuX9k01XZqVhAd7
E47zbObdPaDfTGuCobxB2GjNsqDOOC6dTI48T2NTZ/9Z0/uk2oNsIGyEpXKb
cC1wRmGhtdRKuLDRzSbicg3zj8sPhEBDng==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 824->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUfLgQryHeQA8gXiGeYARdBYS4EHceXYNGkrZ+r2eThk6mmdf1
qurVXD+9bl4uqurt6vtns7w/7HbLx+Pl/vC8bO9ut/uXN7+76vO+/v7PYas1
vk8xkroU+9gv5R/CclzWYCotDKvDZazv9GG9mJ5Rx8gXcVF63L0OB1Sb6FK+
sNo62m5uaT/aK+EcZkjhd3KY8CiRT6fVeYQw/q2E74RGpvuA5TSzOuZLx8OD
7jo6u3x3MsB6IizFBfmA+qf5R1xQD+W7w+1ydPVp/hT3DjY6j9iOO6pX3jhf
2N3Ux26eHS/lp8NQeI5LFxMtdb/ji8vLTIa7M01zMvN9MJ3o7oit/GA1al7o
3QyXk15mfomOzmZaWG/XS3nmPFH+uYzN5C6Zj9LTwexoSLK+tm+qaW1WEh7s
m3CcZzPv5oCemdYEQ3mDsNGZZUHdcVw6mRx5js/deTLtSTZYP4alvFVci3iZ
eD7ODfFjXNjqZhNxOYf9w+ULEyFDng==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 825->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQHPyQXENyAz2A5ArmBBuIX4JgPoJ/Hl0l2ZBtux49++PA6A7b
U11VXbv6OO72i9ba18vtZzd8v51Ow/l9eT98DofN+nB/+fq7W7ts29//M2y2
4nsXw6lzsf/7xfzLsBSXOZhMC8KqcIn1lT6oF9ITdUS+GRemR92rcMhqHV3M
F8cjNTe3H6pzOLsZYviVHMK+Bm9Hq/Iow3hYM3zq2SOW0ozqlF+Oh23cbcqJ
5buSAcQlw0J1GQfUv5p/hBk9QVwYbpWjqnfzl3nleuDMMqtHfbJ65o3yBd11
fazmWfFifioMhqe4VDGzxe5XfFF56clwdaZuTnq+D6QzuxuxmR+ohs0re9fD
ZdJLzM/RUdlIC+qtejHPlCfMP5Wxntw582F6KpgVDU7W5/Z1Nc3NisMDfROK
c2/m1RyyZ6TVwWDeZNjZGWWB3VFcKpmMPONzdZ5Iu5MN1A9hMW8h3lhLtEas
7My0Ii5oVbOZcXmG/cPlCnaoRGE=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 826->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLIQrxG8gTlA8ArxBCPoKhCIC3Hn0TV+wtip3+vZZKCTafp1
vap6Neunw+5l1Vp7vf362U1vD8fj9P54c9o8T/vN/f50ePe7WvvYtvP/NSz1
9OcpRlKXYs/9Uv4hLMdlCabSwrAqXPr6Sh/Wi+npdfR8ERelx92rcEC1iS7l
S+SRmVvaj9UlnL/r5ktwSfm5foyD451odR4hDHkW5m7J+sOCmsFsFH/nCa0F
+XX5rmSAcUFYvedIa5Jvd65mcN4HvjvcKkdXn+YPeZV6kMwS1bM+qF5543xh
d1Mfq3l2vJSfDkPhOS5VTPSo+xVfXF5GMlydaZqTke+D6UR3e2zlB6tR80Jn
I1z+9TLzS3RUFtPCerteyjPnifLPZWwkd8l8lJ4KZkVDkvWlfVNNS7OS8GDf
hOM8mnk3B/TOtCYYyhuEjfYsC+qO41LJZM+zf6/Ok2oPssH6Id4stxZvvojW
C+5gL7USLuypZhNxuYb1w+UTEbBCHg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 827->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1wjeQA8weIV4ghHMKiDEhWSXo2uMkaSp3+vZZKCTafp1
vap6Nau3j/XmrrX2+fDzs56/Xna7ef96f9y8z9vnp+3x8PFvtXaY2v//LSz1
9OcpRlKXYl/6pfxDWI7LEkylhWFVuPT1lT6sF9PT6+j5Ii5Kj7tX4YBqE13K
F+vRdFpqbmk/VpdwPkw5l5Sf65fMFGEnWp1HCEOehblbqpdp+H3OMyJ1zq/I
W5Bfl+9KBhgXhMXqEAfWv5J/xYG9K+0VDujc1af5U9wr2GjfYzvuqF5543xh
d1Mfq3l2vJSfDkPhOS5VTPSo+xVfXF5GMlydaZqTke+D6UR3e2zlB6tR80Jn
I1yuepn5JToqi2lhvV0v5ZnzRPnnMjaSu2Q+Sk8Fs6IhyfrSvqmmpVlJeLBv
wnEezbybA3pnWhMM5Q3CRnuWBXXHcalksufZv1fnybQn2WD9GJbyluKda4XW
HgvtlVbGhT3VbCIut7BOXL4B7+JC4Q==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 828->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQHPwIXkNyg3gA8QrmBBvQL0HQD8lfjp6YRFnbrkfP/rgwusP0
VFdV1y4+DpvdrLV2mv/8bIbz+ngcPt9fLpvtsF++7S+Hr/+rta9Vu/0/w2JP
PHcxnDoXe+wX8y/DUlymYDItCKvCJdZX+qBeSE/UEflmXJgede+Bw2gxjytz
Yr44Hqm5uf1QncN57I3i4vJT/ZyZZtiOVuVRhkHPzNxN1Ys0/D7XGYE65VeP
h+45w3K4ZFhXzRlW5ID6V/KPOKB+KnMVDtm5qnfzx7hXsLN9xFbcs3rmjfIF
3XV9rOZZ8WJ+KgyGp7hUMbOH3a/4ovLSk+HqTN2c9HwfSGd2N2IzP1ANm1d2
1sPlrpeYn6OjspAW1Fv1Yp4pT5h/KmM9uXPmw/RUMCsanKxP7etqmpoVhwf6
JhTn3syrOWTvSKuDwbzJsLM9ygK7o7hUMhl5xvfqPJF2JxuoH8Ji3jKuSmvE
yvZMK+KCnmo2My7PsP64fANa0kTf
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 829->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOQkEQnLgwXMN4AzkA4Qp4gmcCKxISWBB3Hl1RJI9O16dnXDjJwHuZ
nuqq6npPb4fN7qG1dlp8/Wym8/p4nN5fHy8v22m/fNlfDp+vu7WPVbv9/4fN
Vjx3MZw6F3vuF/Mvw1JcRjCZFoRV4RLrK31QL6Qn6oh8My5Mj7qX6rtu5nFl
TswXxyM1N7cfqnM4I1+cbLG+am5qphm2o1V5lGGoM9ePEb1Iw/f6nRGoU37Z
HoYeKt+VDCAuGRaqyzig/pX8Mw7omWmvcMjOVb2bP8a9gp29R2zFPatn3ihf
0F3Xx2qeFS/mp8JgeIpLFTNb7H7FF5WXngxXZ+rmpOf7QDqzuxGb+YFq2Lyy
sx4ud73E/BwdlY20oN6qF/NMecL8UxnryZ0zH6anglnR4GR9tK+raTQrDg/0
TSjOvZlXc8iekVYHg3mTYWfvKAvsjuJSyWTkeffcMU+o3cDKsDMslluJN+MS
dVuezzfSCrigVc1m7PWX38vI/uHyCbqDRJw=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 830->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1wjewBxAvEI8wQi6CgTiQtzl6JooMjb1e90ubOhkhn6v
XlV1zebpsHu5aq293nz+7Ja3h+NxeX+8Pr88L/vt3f58ePu9Wzvdt5///7DV
6s9TjKQuxV77pfxDWI7LDKbSwrAqXPr6yhw2i+npdfR8ERelx/VBfesNtCof
lR+Ic+SRubd0HqtLOK99cVxSfm5ecqcIO9HqPEIY7iz1Y0Yv03BZJLOpX5G3
IL8u35UMMC4Ii9UhDmx+Jf+KA3tW2isc0LmrT/OnuFew0XuP7bijeuWN84X1
pj5W8+x4KT8dhsJzXKqYaKn+ii8uLyMZrt5pmpOR74PpRL09tvKD1aj7Qmcj
XNRslfmKZyP5VRodHlvJ3aeaUkyE5foqGUgwKxqSrM/OTTXNZiXhwb4Jx3k0
8+4e0DPTmmAobxA2emdZUD2OSyWTPc9fzwP3SbUHWAj7soL+ihdQq8BiWqhW
woWtajb7WX/5vczsLy4fF1ZFHA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 831->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcQrxBPMIKuAkJciDuPrvETwkv9Xo8LGyaZoV/X
q6pXffnwvHk6G2O8XHz+bJbXu91uebs/3388Ltub6+1+8+rnGeP9dhz+/8Oj
Vt1PMZK6FPvYL+UfwnJc1mAqLQyrw6XWd/qwXkxP1VH5Ii5KjzsH9QkfFJdu
RmOPzNzSfqwu4XzwJeCS8nP9kpki7ESr8whhuL3UjymtIIsn/E2d8yvyFvRw
+e5kgHFBWL+aEVblwPp38s84sH4ucx0OaN/Vp/lT3DvY6LtiO+6oXnnjfGFn
Ux+7eXa8lJ8OQ+E5Ll1MtNT5ji8uLzMZ7s40zcnM/WA60dmKrfxgNWpeaG+G
i+qtMt/xbCa/SqPDYyuZfaopxURY7lwnAwlmR0OS9bV9U01rs5LwYHfCcZ7N
vJsDemdaEwzlDcJG3ywL6ozj0slk5Vnfu/Ok2oNssH6IN8ttwvVrCa0n3IkW
qpVwYaubzdrrL+/LmuebywdfxUNf
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 832->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuAjEQizhUfKPqD+gDEF+AFywSnJAq0UPFrU8H1HaFZj22J8uhKwUS
ZeKxHed1/7E9Llprn8vbz3b42pzPw2X3cl8chtP76nTffPsdrX2v2/j/Hwb7
4r6L4dS52I9+Mf8QluIyB5NpybAqXGJ9pU/WK9MTdUS+iAvTo85l+jIfGJdq
Rl2P1L25/bI6h/NYa3Bx+Tn91J0ibEer8ghhqD3Xjy6tIIsT/qJO+WV5C3qo
fFcykHFBWH+aEVbkkPUv5z/BzOZMe4UD2lf1bv4Y9wo2WkdsxR3VM2+UL9lZ
18dqnhUv5qfCYHiKSxUTfex8xReVl54MV+/UzUnP+8h0orMRm/mR1bD7Qns9
XFhvlvmKZz35ZRoVXvY5d+9qcjERljpXyYCDWdHgZH1uX1fT3Kw4PLI3oTj3
Zl7dA5pnWh0M5g3CRussC+yM4jLOjUxGnnFevU+kvT0M5XMlF8xbxlVpjViT
NdHak5FqNmOvZ76XOeOHyxUsFUMg
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 833->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8gXiGeYARdBYRkIe48ugZF4kv9Xo8LGyaZpl/X
q6pXc/X4sn2+GGMcNp8/2+X1fr9f3h4uj5unZXd7szseXn8/Y7zfjZ////Co
Vc9TjKQuxT71S/mHsByXNZhKC8PqcKn1nT6sF9NTdVS+iIvS4+6dcSiYSKvy
UfmBOLPaykPNLe1HewWcT3k5Lim/pJ+bKcJOtDqPEIY7S/2Y0gqyeMbf1Dm/
ZjxMzxVWwgVhsTrEgfVv559gsnelvcMBnbv6NH+Kewcb7Su2447qlTfOF3Y3
9bGbZ8dL+ekwFJ7j0sVES93v+OLyMpPh7kzTnMx8H0wnuluxlR+sRs0Lnc1w
Ub1V5juezeRXaXR4bCWzTzWlmAjL3etkIMHsaEiyvrZvqmltVhIe7JtwnGcz
7+aA3pnWBEN5g7DRnmVB3XFcOpmsPOt7d55Ku8NiNYg3y23C1WlF3H/tA62I
C1vdbNZef/m9rHm+uHwAhytEIg==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 834->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcIXiGeYASzCghxIe48ugZ/4Vm/17NJQycz9Ot6
VfVqrh+ft7uLMcbL1efPdnm9PxyWt4fL48vTsr+73R8Pb773GO+b8ft/Dlut
ep5iJHUp9qlfyj+E5biswVRaGFaHS63v9GG9mJ6qo/JFXJQed+8fh4KJtCof
lR+Ic+KRm1vaj9UlnE/9cVxSfkk/N1OEnWh1Ho3N36Y1w2tZqzHNzA9nlNnU
rxkP03OFlXBBWKyO+YX6t/NPMNmz0t7hgM5dfZo/xb2Djd4rtuOO6pU3zhd2
N/Wxm2fHS/npMBSe49LFREvd7/ji8jKT4e5M05zMfB9MJ7pbsZUfrEbNC53N
cFG9VeY7ns3kV2l0eGwls081pZgIy93rZCDB7GhIsr62b6ppbVYSHuybcJxn
M+/mgJ6Z1gRDeYOw0TvLgrrjuHQyWXnW5+48lXaHxWoQb5bbhKvTirgjLUor
4sJWN5uIyznsLy4fszVFYQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 835->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQfLgQryHeQA8QvEI8wQi6CgTiQtx5dA1+iG39+o0LB55xeN3V
VdU1l/f77ePZGOPp4v3Pdnm+PRyWl7vz48vDsru53h0vrz7PGK+b8f37H456
6n2KkdSl2Kd+Kf8QluOyBlNpYVgdLrW+M4fNYnqqjsoXcVF6XN8vDgUTaVU+
Kj8QZ+mR0Z56wLSmnEc5jkvKT3GWuzS8E63Oo6+aEdR0/ZjSfMqJaS4zEUfl
14yH6b3CSrggLFbH/ELzk3vGBc1Qvif77XB09Wn+FPcONnqv2I47qlfeOF9Y
b+pjN8+Ol/LTYSg8x6WLiR7V3/HF5WUmw92dpjmZ+T6YTtRbsZUfrEbtC93N
cFGzVeY7ns3kV2l0eOxJdp9qSjERluvrZCDB7GhIsr52bqppbVYSHuybcJxn
M+/2gP5nWhMM5Q3CRu8sC6rHcelksvJENZ19Ku0Oi9UwTspbxRVpVVg/6kC/
qk8y0s1mnfWX38ua88HlDX+JRCA=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 836->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQfGQhuUbwBnqA4BXiCUbQVUCIC3GXo8dgCJm2qrq6x4UDbz68
ftVV1TWbl/fd22qM8bH+vu2mz6fDYfp6vjt/vE77x4f9efP+ssY4bsf1+R+W
uuK+i+HUudi3fin/EFbGZQmm0sKwKlxifaUP68X0RB2RL+Ki9GTnfnEImEir
8lH5gTiz2hGeam5uP9pL7YGVcXH5Kc5Ui8Hb0Zp5dJ2PUVP1o7NmnJjm0BNx
VH51PHT3FZbDBWGxOuYX6u/sMy6oh/LdmW+FY1bv5k9xr2Cj74idcUf1ypvM
F3bW9bGa54yX8jPDUHgZlyomutT5ii9ZXjoZrs7UzUnn/2A60dmIrfxgNWpe
aK/DRfVWma941smv0pjhscuZvavJxURY2blKBhzMigYn60v7upqWZsXhwf6J
jHM389kc0DvT6mAobxA2+p49L0vN3OFSyWTkOXtvzBNpH+Scw33cLCe3Dleo
VWAxLUhrJyPVbMZef/m/LFk/XE5BOUNb
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 837->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1wjeQA8QvEI8wQi6CgTiQtzl6Br8IM/6vR4XNnQmQ7+u
V1WvZvNw2D1djDGer95/dsvL3fG4vN5fnl8el/3tzf58eP25xzhtx/fzP2y1
6nmKkdSl2D/9Uv4hLMdlDabSwrA6XGp9pw/rxfRUHZUv4qL0uHu/OBRMpFX5
qPxAnG1tMLe0H6tznEfZjkvKT3FO5sh4J1qdR1811X/mZcePtuYgM4gL4qj8
mvEwPVdYCReE5Txw9Wn+GRfUQ/nucLscXX2aP8W9g43eK7bjjuqVN84Xdjf1
sZtnx0v56TAUnuPSxURL3e/44vIyk+HuTNOczHwfTCe6W7GVH6xGzQudzXBR
vVXmO57N5FdpdHhsJbNPNaWYCMvd62QgwexoSLK+tm+qaW1WEh7sm3CcZzPv
5oD+M60JhvIGYaN3lgV1x3HpZLLyRDWdeSrtDovVjEZuE65Iq8Ji/iitiAtb
3WzWXn/5vazZH1zeAM4LRV8=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 838->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FqAkEQHDyI35D8QB8g+YJ5wQaSkyDoQXLz6UaSyNqprqqe9eDAuC7T
U11VXbt8328/Z6214+L7ZzucXg+H4ettfn35GHbr1e56+PK7Wztv2u35DJut
eO5iOHUu9tgv5h/CUlymYDItGVaFS6yv9Ml6ZXqijsgXcWF61L1/HAIm0sp8
ZH4gzrLWmJvbL6tTnG9rxIfVuvwYZ9cPhO1oVR5Vayp+9Oxxv0xz/I84Mr96
PHTPGZbDBWEpD1S9m/+MC+rBfHfmW+Go6t38Me4VbPQesRV3VM+8Ub5kd10f
q3lWvJifCoPhKS5VTLTY/YovKi89Ga7O1M1Jz/eR6UR3IzbzI6th80JnPVxY
b5b5imc9+WUaFV62nNm7mlxMhKXuVTLgYFY0OFmf2tfVNDUrDo/sm1CcezOv
5oD+Z1odDOYNwkbvd8+/Le4oLpVMRp6opjJPpD1qYj47nFluHa5IK8PK/EFa
ezJSzWbs9cjvZcr+4XIBmA9EYQ==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 839->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKRDEQDC7Ea4g30AOIVxhP8ARdDQjjQtx5dB388Gzr13kuDMQxpFNd
VV3v/O5x93Ayxng6e/+zW55vDofl5fb0eLhf9leX++Plxece4/V6fP/+h61W
vU8xkroUe+2X8g9hOS5bMJUWhtXhUus7fVgvpqfqqHwRF6XHvfvFoWAircpH
5QfibGuDuaX9WJ3j/GMFXFJ+ijPz4msr3olW59FaK/MhnU1H42xm1mdW5/ya
8TC9V1gJF4TlPHD1af4ZF9RD+Z7Mt8PR1af5U9w72OhcsR13VK+8cb6wt6mP
3Tw7XspPh6HwHJcuJlrqfccXl5eZDHdnmuZk5vtgOtHbiq38YDVqXuhuhovq
rTLf8Wwmv0qjw2MrmX2qKcVEWO5dJwMJZkdDkvWtfVNNW7OS8GDfhOM8m3k3
B/Q/05pgKG8QNjqzLKg3jksnk5UnqunMU2l3WKyG9VTeKq5Iq8Ji/iitiAtb
3WzWXn/5vWzZH1zeAAisRKA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 840->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuwkAQW3FA/QbqD9oHVP1C+oJUKqdIlcKh4sbTAbWq0sFjezY9sNIC
YWc9tsfZvX8O+01r7fBw+RjGr9d5Ho9v2+vDxzg9P03Xw8ef3drppf1+38Nm
K567GE6di730i/mHsBSXNZhMS4ZV4RLrK32yXpmeqCPyRVyYHnXvhkPARFqZ
j8wPxFnWGnNz+2V1ivOfZXBx+cX/GsBjdzLejlbl0VIrq3FmozQ5e9kv0xx/
I47Mrx4P3XOG5XBBWMoDVe/mP+OCejDfnflWOKp6N3+MewUbPUdsxR3VM2+U
L9ld18dqnhUv5qfCYHiKSxUTLXa/4ovKS0+GqzN1c9LzfmQ60d2IzfzIati8
0FkPF9abZb7iWU9+mUaFly1n9q4mFxNhqXuVDDiYFQ1O1tf2dTWtzYrDI3sn
FOfezKs5oN+ZVgeDeYOw0XOWBXZHcankJ/JENZV5Iu1tsZXPbH5Obh2uSCvD
yvxBWnsyUs1m7PWf78ua/c3lDINCQuM=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 841->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKBDEUDC7Ea4g30AOIVxhP0IKzGhDGhbjz6DooYj/r99IuDGS6e/JS
r6pSuXx42u3PxhjPFx8/u+Xl7nhcXu/PTx+Py+Hm+nBavPqaY7zdju/nf5hq
1PUUI6lLsX/6pfxDWI7LFkylhWF1uNT6Th/Wi+mpOipfxEXpcft+cSiYSKvy
UfmBONva4NzSfqzOcV6NgEvKr/43AJ7aw3gnWp1HA/BR6x0/uhNlUnnH6pxf
Mx6m6wor4YKwWB3iwPon64wL6qF8d7hdjq4+zZ/i3sFG3xXbcUf1yhvnC9ub
+tjNs+Ol/HQYCs9x6WKiofZ3fHF5mclw90zTnMzcD6YT7a3Yyg9Wo84Lrc1w
Ub1V5juezeRXaXR4bCRnn2pKMRGW29fJQILZ0ZBkfWvfVNPWrCQ82J1wnGcz
784BvTOtCQb0RmCj79UzOPOESyc/lefqfeI8lXaHxWpYT+Wt4gq1Cizqj9CK
uLDRzWbt9Zf3Zcv85PIOCHNDXw==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 842->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNV0tKQ0EQHFyI1xBvoAcIXiGe4Am6CghxIe48ugYlJG39ep4LByaZ8Hqq
q6rrLXL9+LJ9vhhjvF59fWyXt/v9fnl/uDz8eFp2d7e7w8Obnz3Gx2Ycv//D
Vqs+TzGSuhT71C/lH8JyXNZgKi0Mq8Ol1nf6sF5MT9VR+SIuSo+794tDwURa
lY/KD8TZ1gZzS/uxOsf5bAVcUn6KczJHxjvR6jzq1nT8mNmn/ZjmekYclV8z
HqbPFVbCBWE5D1x9mn/GBfVQvifz7XB09Wn+FPcONvpdsR13VK+8cb6wu6mP
3Tw7XspPh6HwHJcuJlrqfscXl5eZDHdnmuZk5v1gOtHdiq38YDVqXujZDBfV
W2W+49lMfpVGh8dWMvtUU4qJsNy9TgYSzI6GJOtr+6aa1mYl4cHeCcd5NvNu
DujMtCYY0JvNOPs/hLxlcx+md8rleA4yWXnWc3eedal7inuSeeWt4uq0Iu7s
DtOKuLDVzWbt9Zfvy5r9zeUTSw5EIg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 843->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHFxIriHeQA8QvEI8wRPMKiDEhbjz6BoUMW39ep4LBybJy3RX
V9XUu3p42u0vxhjPm4+P3fJydzwur/eXp4fH5XB7czgdXn/tMd624/v7P2y1
6nmKkdSl2D/9Uv4hLMdlDabSwrA6XGp9Zw6bxfRUHZUv4qL0uL5fHAom0qp8
VH4gzrY2uLd0HqtznM9WwCXlV/8bAE/1MN6JVufRAHzUeceP7kaZVN6xOufX
jIfpucJKuCAsVoc4sPnJOeOCZijfHW6Xo6tP86e4d7DRc8V23FG98sb5wnpT
H7t5dryUnw5D4TkuXUy0VH/HF5eXmQx37zTNycz7wXSi3oqt/GA16r7Q2QwX
NVtlvuPZTH6VRofHVnL3qaYUE2G5vk4GEsyOhiTra+emmtZmJeHB3gnHeTbz
7h7Qb6Y1wVDeIGz0zLKgehyXTn4qz7PfE/eptDssVsNmKm8VV6hVYFF/hFbE
ha1uNuusv3xf1uxPLu+uNEOg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 844->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVkFqAkEQbHIIfiPkB/oA8QvmBRuIJ0HQg+SWpyeSEGJbXVU96yEDq7tO
d3VVTS349HrY7h4i4rT4+thO583xOL2/PF4e3qb9arm/bD7/XBEf6/j9/g8X
W3nfxXDqXOy/fjH/EJbiMgeTaamwOlxyfWdONavSk3VkvogL06P6Kn2VD4xL
N6MO/zDOzZ1X1SnOV8vg4vLLvwXAYz0Vb0er8igAH7Scs1GapGYjM4gL4sj8
GvHQ3WdYDheEpTxQ9W7+Ky5oBvNd4XY5qno3f4x7Bxs9Z2zFHdUzb5QvVa/r
YzfPihfzU2EwPMWli4kW6+/4ovIykuHumbo5GXk/Kp2oN2MzP6oadl5ob4QL
m80y3/FsJL9Mo8KrlnP2riYXE2Gpvk4GHMyOBifrc+e6muZmxeFRvROK82jm
1Tmg+0qrg3HDXehBz1UWWI/i0slP5nl1vw74f76TPdbHuDNvWW4drlArwSr9
IVoRl2p1s5ln3fN9mXN9c/kE4VtEIA==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 845->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHFyI1xBvoAcIXiGe4Am6CgTiQtx5dA1+iG39ep4LB8Y4THd1
VU29y/v99vFsjPF08f5nuzzfHg7Ly9358fCw7G6ud8fLq889xutmfP/+h61W
vU8xkroU+9Qv5R/CclzWYCotDKvDpdZ35rBZTE/VUfkiLkqP62P6mA+KSzej
CX83L8VQvBznHyvgkvJTnKmWgHei1XnUren4MbNP50HNYCbiqPya8TC9V1gJ
F4TF6phfaH5yz7igGcr35H07HF19mj/FvYONzhXbcUf1yhvnC+tNfezm2fFS
fjoMhee4dDHRUv0dX1xeZjLcfdM0JzPfB9OJeiu28oPVqPdCdzNc1GyV+Y5n
M/lVGh0eW8nbp5pSTITl+joZSDA7GpKsr52balqblYQH+yYc59nMu3dA/zOt
CcYv7l9nogedWRZUj+PC8CV3UFNrk/esS/Up7knmmS+Oq9OKuLMephVxYaub
zTrrL7+XNfuDyxuPWkUi
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 846->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOw1AQe+qi4hqIG8ABql6hnCBIsKqEVBaoO45eyk/t1PZ4Jiz6pDRJ
3xuP7XFun143L4sxxtvN589mel/vdtP+cXl8eZ62D/fb4+bdzzXGx2r83a/h
UivuuxjOORf71C/lH8LKuMzBVFoYVoVLPF/pw3oxPVFH5Iu4KD1ZHdPHfFBc
qhl1+Gf9XAzFK+N8tgwuLr/43wB4FzUGb0dr5lH1TMWPznXaD2oGPRFH5VfH
Q7i/utxXWA4XhMXOsVmh/k7+GZfoA9PqYHc4Zufd/CnuFWz0HrEz7ui88ibz
hdW6PmacKvNk59X/SAvTkM2rgomWqq/4kuWlk+HqTN2cdL4PphPVRmzlBzuj
5oX2OlxUb5X5imed/CqNGR5bzuxdTS4mwsrqKhlwMCsanKzP7etqmpsVhwf7
JjLO3cxnc0DPTKuDAb0RetA7y4Kqybh83X/3QdaV72fPjXnGpeoYdzfzzJeM
K9QqsKg/QiviwlY1m7HXf34vc65vLgedrkMi
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 847->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lqw0AQHHww/obJD5IHmHxBeYEC8ckQkA8mNz/dEQkhbrqWHungAVmS
p7umqrq0f/8cjpvW2nn3/TOMl9dpGr/etvPLx3h6eT7Nm0+/V2vXQ/u7P8LF
Vtx3MZw6F/u/X8y/DEtxWYLJtCCsCpdYXzkHnYX0RB2Rb8aF6VF9SB/ygXGp
ZtThr85zMRgvxfluGVxcfoyz60eG7WhVHsmawmyqGtfKTKxTfvV46O4zLIdL
hoXq7mqK+XbzF3vQszMvh0O2r+rd/DHuFezsPWIr7lk980b5gnpdH6t5VryY
nwqD4SkuVcxssf6KLyovPRmuztTNSc/3gXRmvRGb+YFq2LyyvR4u7GyW+Ypn
PfllGhUeWs7sXU0uZoal+ioZcDArGpysLz3X1bQ0Kw4P9E0ozr2ZV3PInpFW
B4NxZ/+xubOzXS4o9w73rK8yz7hYH+LuZh75orgqrRl31IO0ZlzQqmYznrXm
97Lk+uFyA+HRRKQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 848->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKAjEUDC5kriHeYOYA4hWcE7QwroQBZyHuPLrKiOjz1eelXRiIdnde
KlX1KrP172ozaa39fZx/VsN+udsNh+/p5eVn2H59bi+L8+ts7bhot/93mGzE
dRfDqXOx7/1i/mVYissYTKYFYVW4xPrKOegspCfqiHwzLkyP2of0IR8Yl2pG
Hf7qPBeD8VKcH4bBxeXHOLt+ZNiOVuWRrCn0pqrxVZmJdcqvHg/huuCC/EFc
MixU91CzuJvAM6ZVeZvpi1gOtuKQrat6N3+MewU7e4/YintWz7xRvqC9ro+K
U6WfqJ59z7QgDapfFcxssP0VX1ReejJc7ambk577gXRmeyM28wPVsH5laz1c
2Nks8xXPevLLNCo8NJzeu5pczAxL7atkwMGsaHCyPvZcV9PYrDg80J1QnHsz
r/qQPSOtDgbjzr6xvrOzXS4o9w73p+diP+Ng+xB3N/PIF8WVeVTxnGnNuKBR
zWY865X3Zcz853IC8NZE4Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 849->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhRsX4jUkN0gOIF7BnGACyWpA0IW48+iJRIJT1vupnixsaJ2Z
rn711evq9cd+97VorR1XPz+74bQ9HIbz+/L68jmMb6/jdfHlNlu7bNrf/zNM
NuK6q+HEudr3fjH/Mi3FMkeT1YK0KiwxvpIH5UL1xDoib8bC6lH7UH3IB8ZS
7VGHX+VzNRiXYp4Mg8XlY8wPscCPTNupVXlEY248kcX1o2feM02eSc5Yh/Kr
x0N3nWk5LJkWiuvpWcSnvM3qi1qOtmLI1lW823+MvaKdvUdtxZ7FM2+UL2iv
62O1nxUX81NpMD3FUtXMBttf8UX1S08PV8/U7ZOe+4HqzPZGbeYHimHnla31
sLDcrOcrnvX0L6tR6aHhnL1bk6uZaal9lR5wNCs1OL0+N69b09xecTjQnVDM
vT2vziF7RrU6GoydfWPnznK7LKjvHfaWzMp5xsH2IfbJN5KTectYmUcVz1mt
GQsa1d6Muf7zvsyZvyzfWcREng==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 850->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lOw0AQHHFAfAPxA3hAxBfCC4IEp0hI4YC48XQIm0xTW485MJLj2NNT
XVVdPr992N6fjDEez95+trun68Nh93xzeny42+2vLvfHzYvPa4yXzfi+/4dL
rbqfYiR1KfbSL+UfwnJc1mAqLQyrw6XWd/qwXkxP1VH5Ii5KjzvH9DEfFJdu
RhP+rl+KoXg5zj9WwCXlpzinfiDsRKvzyNY0ZtPV2MnMED2rDufXjIdwf/N7
X2ElXBAWq2OZR/2T/Ctvkb6KlWA7Dmjf1af5U9w72Oi5YjvuqF5543xhZ1Mf
HafOPFm9eo+0MA1uXh1MtNT5ji8uLzMZ7s40zcnM98F0orMVW/nBatS80N4M
F9VbZb7j2Ux+lUaHx1Yy+1RTiomw3LlOBhLMjoYk62v7pprWZiXhwb4Jx3k2
824O6D/TmmAo7uqdmrvqnXJ5v39dM9yXZ5vzrGuJ6bKBsIfoqbxVXJEfCot5
SLUSLmx1s1l7/eX3sub64PIKvihFHg==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 851->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lOA0EMtDigfAPlB/CAiC+EFwwSnCJFCgfEjadDlEWJ41rcw4GWOpNp
u8tVZc/D63b9fhcRH4vfn/X0+bzbTV8v9/uXt2nz9LjZB5fHHfG9ivPzP2y2
ctzFcPJc7Eu/mH8VluIyB5NpQVgdLjm/UwfVQnqyjsy34sL0qHtIH/KBcenO
qMNf1XMxGC/F+WoZXFx++SwKPOVHhe1oVR5FwecmHliLOu/suKjdmZmcp/wa
8bCMr27jDMvhUmGhvHOOwdWZf+ZtpS9jOdiKQxVX+e78Me4d7Oo9YyvuVT7z
RvmC7ro+Kk6dfqJ8dl5pQRpUvzqY1WL3O76oeRmZ4W5P3TkZ+T6QzupuxmZ+
oBzWryo2woXVZjPf8WxkfplGhYeW03tXk4tZYal7nRlwMDsanFmfW9fVNHdW
HB7om1CcR2de9aH6j7Q6GIw7O1M5rOcOF6TP4R6nXeQ6/azqurOB8p1z5gW6
l73peo60Ii5odWcz1/rL72XOPnD5AcXERCA=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 852->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQHPwIXkNyg+QA4hXMCTYQv4SAfoh/Ht2Yh+w2XY+e9SMDo+xO
T3VVde3q/XO7W7TWjsuvn+1w2hwOw/nt6fbwMexfX/a3w+ff3dpl3e7//2Gz
Fc9dDKfOxR77xfzLsBSXOZhMC8KqcIn1lT6oF9ITdUS+GRemR91D+pAPjEs1
ow5/1c/FYLwU58kyuLj8GGfXjwzb0ao8kjWF2VQ1PiozsU751eOhe86wHC4Z
FqpL5ylmhPgpbzN9ESvlWuSQnat6N3+MewU7e47YintWz7xRvqC7ro/VPCte
zE+FwfAUlypmttj9ii8qLz0Zrs7UzUnP94F0ZncjNvMD1bB5ZWc9XFhvlvmK
Zz35ZRoVHlrO7F1NLmaGpe5VMuBgVjQ4WZ/b19U0NysOD/RNKM69mVdz+F5G
9pnvyhvn3f35bzevt8sF6XO4jznFWmeeWV83G6jeec+8mLwb5SB6U/UcaUVc
JmvktYuLuD3ye5mzf7hcAbocRF0=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 853->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8QvEI8wQhmFRDiQtx5dA2KmGf9Xs8mDZ3JdL+u
V1Vdc/P0sttfjTFeN18/u+Xt4Xhc3h+vTy/Py+H+7nDavP2ZY3xsx+/zEqYa
dT/FSOpS7L9+Kf8QluOyBlNpYVgdLrW+04f1YnqqjsoXcVF63Dmmj/mguHQz
mvB3/VIMxctxPhsBl5RfXRsAz/mBsBOtziNb07gbp8lqnsxMrXN+zXiY7ius
hAvCYnUs86h/kn/lLdJXsSDXJge07+rT/CnuHWz0XrEdd1SvvHG+sLOpj908
O17KT4eh8ByXLiYa6nzHF5eXmQx37zTNycz3wXSisxVb+cFq1H2hvRkuqrfK
fMezmfwqjQ6PjeTuU00pJsJy5zoZSDA7GpKsr+2balqblYQH+yYc59nMu3tA
/5nWBENxV2vq3lXvlAvTl3AfJmtoTeWkkw1Wn6wrL87WgEcOi3nItDIu/wbx
m+GqDF3C/ObyCUcRRKA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 854->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQbPwQryHeIDmA5ArxBCuYr0Agfkj+PLoGQ9g0XY+ezYcDk83u
9FRX1dQ8vx+2u4eI+Hz6/dlOX5vjcTq9PZ5fPqb9erU/L75cZsT3a1yf/2Gy
kdddDKfOxZ77xfyrsBSXJZhMC8LqcMn1nT6oF9KTdWS+FRemR+1D+pAPjEs3
ow5/1c/FYLwU55thcHH55W9R4Ck/KmxHq/Ko4pLXMxfXj+6MWe9OZnKd8mvE
Q3edYTlcKixUhzQgz5hW5W2lL2M52IpDta7q3fwx7h3s6j1jK+5VPfNG+YL2
uj5286x4MT8VBsNTXLqY1WD7O76ovIxkuHumbk5G7gfSWe3N2MwPVMPOq1ob
4cJ6s8x3PBvJL9Oo8NBwzt7V5GJWWGpfJwMOZkeDk/WlfV1NS7Pi8EB3QnEe
zbw6h+o/0upgMO7s28377OmcucMF6XO4B+jrnmfV180Gqne+My/cPHQ9R1oR
FzS62cy97nlflsw/Lj8pb0Rh
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 855->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqQkEQHFyI15DcIB5AcgVzghfQlSCYRXDn0VUSgna6Pj2ThQPj501P
dVV1veXHYbObtdY+F9ePzfT1djxOp/f57c922q9e97fDl5/d2nndfr+fYbMV
z10Mp87FvveL+ZdhKS4jmEwLwqpwifWVPqgX0hN1RL4ZF6ZH3UP6kA+MSzWj
Dn/Vz8VgvBTnh2VwcfnFZy3BU35k2I5W5ZGsKcxGaXL2PSfEL/aMdcqvHg/d
c4blcMmwUB3SgDxjWpW3mb6IFbPSwyE7V/WpJ4PZotjJ/4ituGf1zBvlC7rr
cOnJs+LF/FQYDE9xqWJmi92v+KLyonJW0anqkY6R9wPpzO5GbOYHqmHzys56
uLDeLPMVz3ryyzQqPLSc2buaXMwMS92rZMDBrGhwsj7a19U0mhWHB3onFOfe
zKs5ZL+RVgeDcWfP/sy9MHOHC9LncG+grzvPrK+bDVTvPGdeuHmoeo60Ii5o
VbMZe/3n+zKyv7lcAD1qRaA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 856->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqQkEQHFwEryG5QTyAeAVzghdIVoKgC3Hn0Y1EJWm6Pj0TSAbG57zp
qa6qqbd4220+Zq21w/zzZzMd1/v9dHp9ui7ep+3yZXvdfL7N1s6r9nj+h8lG
3HcxnDoX+7tfzL8MS3EZwWRaEFaFS6yv9EG9kJ6oI/LNuDA96hzSh3xgXKoZ
dfirfi4G46U4/xgGF5cf4+z6kWE7WpVHsqZwN1WNv5WZWKf86vHQ3WdYDpcM
C9U91vda444QP+Vtpi9ipVyLHLJ9VY88GckWxU7WEVtxz+qZN8oXdNbh0pNn
xYv5qTAYnuJSxcwGO1/xReVF5ayiU9UjHSPfB9KZnY3YzA9Uw+4r2+vhwnqz
zFc868kv06jw0HDu3tXkYmZY6lwlAw5mRYOT9dG+rqbRrDg80DehOPdmXt1D
9h9pdTAYd/aOecN6u1yQPpc7y1r2juWkkg1U77xnXrh5qHqOtDI/Y30F183Q
X80vLhf+vUee
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 857->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktKBDEUDC7Ea4g30AM0XmE8QQu6GhDGhbjz6Dogoc3U73U2Blrp5L1K
Vb1qmNvnt8PrVWvt/ebnz2H9eDyd1s+n6/PLy3p8uD+eD+9+n9a+ltb//4dH
rfE8xUjqUuytX8o/hOW4zGAqLQyrwmWsr9zD7mJ6Rh0jX8RF6XF9TB/zQXGp
ZjTh7+5LMRQvxznV7jyxMzEzRH4g7ESr88jWFGbjNCXPlhPjN9451jm/9ngI
z5fLc4WVcEFYrO6iL5gR4+e8RfpGrATbcUDnrh56MpktiQ3eR2zHHdUrb5wv
rDfhknCqzJPVq32khWlw86pgoqX6K764vLicVXS6eqZj5vtgOlHviK38YDVq
XuhsDxd1t8p8xbM9+VUaHR5byexTTSkmwnJ9lQwkmBUNSdZn7001zWYl4cG+
Ccd5b+bdHPpaWv+9xbQmeVbc1Z7yRt2dckHzqnBXWUN7KieVbLD6ZF950d+F
fwpL9SCtys++NnxS3DRD5W9ksv8vl29YWEdb
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 858->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcQrxBPMIJZBYS4EHceXQMSxpf6vZ6NA5PMdL+u
V1Wv5vblbbe/GmO83/z87JaPp+Nx+Xy+Pr28LoeH+8Np8+73HuPrcZz//8Ot
rrqfYiR1KfbaL+UfwnJctmAqLQyrw6XWd/qwXkxP1VH5Ii5KjzvH9DEfFJdu
RhP+rl+KoXg5zql254mdiZkh8gNhJ1qdRwPwudif9KN7j1XvTmZqnfNrxsOL
c2RfYSVcEBarW/M414t8Ka3OW6SvYiXYjgPad/Vp/hT3DjZ6r9iOO6pX3jhf
2NnUR8epM09Wr9aRFqbBzauDiS51vuOLy8tMhrszTXMy830wnehsxVZ+sBo1
L7Q3w0X1VpnveDaTX6XR4bErmX2qKcVEWO5cJwMJZkdDkvWtfVNNW7OS8GDf
hOM8m3k3B/TMtCYYirtaU96o3ikXpi/lrrKG1lROOtlg9cm68oJprc9dz5lW
5Sfi0M1m7bX5G9l4/i+Xb5B1RZ4=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 859->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqwzAQFP0ovUbJDZoDmF7BOYELzZeh4HyE/vXojUkIZdmdh1xoBYpj
aTWamR0/v32Mx4fW2unp8jNO59dlmT4Pj+vL+zTvX+Z1c3ebrX0N7f78DxON
uK9iKHUq9k+/kH8ZFuOyBRNpqbAcLrHeuae6q9ITdUS+GRekh52r9FU+IC5u
RhX+7D4VA/FinFXtzBMnh6ofGbailXlEa4zeuBp/KzOxjvnV46G6j7AULhlW
VZf6NVynmm/V20xfxFKwGYdsn9Wr+UPcHezsPWIz7lk98ob5Up1VfXTzzHgh
PxkGwmNcXMxsoPOOLywvPRl2e6rmpOf7qHRmZyM28qOqQf3K9nq4oLtR5h3P
evKLNDK8aii9VzWpmBkWO+dkQMF0NChZ33qvqmlrVhQe1TfBOPdmnvXhPkj2
ke/MG2UNeYPuVrlk/XK4o6xlaygnTjaqemUdeVFpjf9dzyutyM+Mg4qrZuiv
5pXLN/9cRyA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 860->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lOw0AQHHGI8g3ED8IDIr5gXmCk5GQJyTlE3Hg6WCBE2t21jC+xNInt
6amuqi4/vr0P54fW2mX//TOM15d5Hj9ed8vDaZyeD9Oy+fS7Wvs8tr//e1jo
ivsqhlKnYv/3C/mXYTEuWzCRlgrL4RLrnT5Vr0pP1BH5ZlyQHnau0lf5gLi4
GVX4s34qBuLFOKvamSdODlU/MmxFK/OI1hizcTWuMITMtKRnrGN+9Xio7iMs
hUuGVdVlHOK8nPxXXFY9Cq0KNuOQ7bN6NX+Iu4OdPUdsxj2rR94wX6qzqo9u
nhkv5CfDQHiMi4uZXei84wvLS0+G3ZmqOen5Piqd2dmIjfyoatC8sr0eLqg3
yrzjWU9+kUaGV13K7FVNKmaGxc45GVAwHQ1K1rf2VTVtzYrCY4Utcu7NPJvD
zT3RqmAg7ujdau7GzBUu2bwc7ihr2TuUEzUbCFt5j7yotMZ71/NKK/Iz5SDi
ogzdw/rh8gVXNUUg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 861->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcQrxBPMIKuAkJciDuPrsEQ5E29+vRs0tBJZvp1
vap6lduX993b1Rjj4+b3Y7d8Ph0Oy9fz9fHhddk/3O+Ph3enPcb34zh/X8Jm
q567GE6di/3fL+YfwlJctmAyLR1WwqXWJ326Xp2eqqPyRVyYHnWv09f5wLik
GXX4q34uBuOlOLvalSdJDl0/ELajVXkka4LZpBqV/1Az6FnrlF8zHrrnDMvh
grC6OsShzivJf8dl1aPR6mArDuhc1bv5Y9wTbPRcsRV3VM+8Ub50d10f0zwr
XsxPhcHwFJcUEy12P/FF5WUmw+lM3ZzM/D86nehuxWZ+dDVsXuhshgvrzTKf
eDaTX6ZR4XXLmb2rycVEWOpekgEHM9HgZH1rX1fT1qw4PFbYJufZzKs5nNeJ
C9Pq5JlxZ+9Wcw9m7nBB80q4s6yhdywnbjYYtvOeedFprb9TzzutzE/IwcRl
GbqE/cflB1cjRGE=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 862->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8gXiGeYARdBYRkIe48ugZkCM9Xvx4XDkzSn9f1
qqprbp7f9q9XY4zT7vtnv7w/Ho/Lx9P1efKyHO7vDufN2593jM+Hsf7/h5c9
dd/FcOpc7Eu/mH8dluKyBZNpQVgJl1qf9EG9kJ6qo/LtuDA96hzSh3xgXNKM
OvxVPxeD8VKcXe3KkySHrh8dtqNVeSRrgrtJNSr/W81Nz1qn/LI9vHyFx4xz
5w/i0mGtc5KNdSzuCPFDfH9xAGOmPeHQ7at6N3+Me4LdzSu24t7VM2+UL+is
62OaZ8WL+akwGJ7ikmJ2Dzuf+KLyMpPh9E7dnMx8H0hnd7ZiMz9QDbuvbm+G
C+vNMp94NpNfplHhoce5e1eTi9lhqXNJBhzMRIOT9a19XU1bs+LwQN+E4jyb
eXUP3RhpdTAYd7bGvGG9XS5In8udZa1bYzlJsoHqnXXmBdJax6nnSCvzs+OQ
ZrP2+stvZfv5L3vVROE=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 863->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lqw0AQHHII+UbID5IHhHxBfoEM8UkQUA7BNz/dFhgTd7prmblkQLak
6a6pqi4977+mw0Nr7fvp8jPNPx/rOh93j9vD57y8vS7b5sv1au303m7//+FC
K+6rGEqdiv3bL+RfhsW4jGAiLRWWwyXWO+dUZ1V6oo7IN+OC9LC+Sl/lA+Li
ZlThz85TMRAvxlnVzjxxcqj6kWErWplHtMaYjauR+V9pjvexjvnlZkKZN+Kc
9SNtEYt5cFdPZoS0Vlz+nFFoVbAZh2yf1av5Q9wd7Ow5YjPuWT3yhvlS9ao+
unlmvJCfDAPhMS4uZrZQv+MLy0tPht2Zqjnp+T4qnVlvxEZ+VDVoXtleDxd0
Nsq841lPfpFGhlctZfaqJhUzw2J9TgYUTEeDkvXRc1VNo1lReFTfBOPcm3k2
h9sStCp5RtzRO+QNOlvlks3L4Y6ylr1DOXGyUdUr75EXldZ473peaUV+ZhxU
XDVDI9/KeP8Z7DlGIg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 864->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktqAkEUbLKQXCPkBnqAIVfQE0xAV0LALII7j+6HMExeXn1ez8aGVmf6
db2q6mrw7fNre3hprX2/3j6248/H6TSed6v7w348btbH++L772ztMrTp+xkm
G3HdxXDqXOy5X8y/DEtxWYLJtCCsCpdYX+mDeiE9UUfkm3FhetQ+pA/5wLhU
M+rwV/1cDMZLcXa1K08qOfxTR/zIsB2tyiNYM8xmpx/VGTlNY+ZNxiXqUH6V
MmGeN+KC/EFcMixUl3GI51XRirj86wG0OtiKQ7au6t38Me4V7Ow5YivuWT3z
RvmC9ro+VvOseDE/FQbDU1yqmNlg+yu+qLz0ZLh6pm5Oeu4H0pntjdjMD1TD
zitb6+HCerPMVzzryS/TqPDQcM7e1eRiZlhqXyUDDmZFg5P1pX1dTUuz4vBA
d0Jx7s28OodpDG36b4O0Onlm3Nk75g3r7XLJzqvCnWUte8dyUskGqnfeMy+Q
1vi76jnSyvzMOLi4boa678rS/Q8uV7iFRR4=
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 865->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktqwzAUFF2UXKP0Bu0BQq+QnsCFZhUoJIuSXY6eBIop6puftKnAiW09
zZsZjcBPH1+7/UNr7bS5/eyW77fjcTm/P94fPpfD68vhPvn8c7V22bb1/z9c
bPTzLoZT52L/9ov5V2EpLjOYTAvCSrj09Ukf1Avp6XX0fCsuTI9ah/QhHxiX
NKMOf9XPxWC8FGdXu/IkyaHrR4XtaFUe0Zpwb1KNyv/+HnHpdSi/bA9BX5Tv
JAOIS4WF6ioODXB18o+4/OkBtDrYikM1r+rd/DHuCXb13GMr7lU980b5gta6
PqZ5VryYnwqD4SkuKWY12PrEF5WXkQyne+rmZOR8IJ3V2h6b+YFq2H5VcyNc
WG+W+cSzkfwyjQoPDWfvXU0uZoWl1iUZcDATDU7WZ/u6mmaz4vBAZ0JxHs28
2od1bNv6bYO0Onlm3Nk75g3r7XKp9ivhzrJWvWM5SbKB6p33zAuktb9PPUda
mZ8VBxfXzdDMWZlffwUwREUi
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 866->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktKA0EUbFxIriHeQA8QvEI8wQhmFRCShbjz6BqQIfS8+nVvbJgkM/26
XlW9GsjD28fheNdau+x+Pw7L58v5vHy93l9v3pfT89Ppuvn4d7X2vW/r93+4
2Or3XQynzsW+9Yv5V2EpLjOYTAvCSrj09Ukf1Avp6XX0fCsuTI86h/QhHxiX
NKMOf9XPxWC8FGdXu/IkyaHrR4XtaFUe0ZpwNqnGDcbNtckP4VLNjPlle9j1
UPlOMoC4VFioruLQAFcn/4jLpgfQ6mArDtW+qnfzx7gn2NV9j624V/XMG+UL
Ouv6mOZZ8WJ+KgyGp7ikmNVi5xNfVF5GMpzO1M3JyPuBdFZne2zmB6ph86r2
Rriw3izziWcj+WUaFR5azuxdTS5mhaXOJRlwMBMNTtZn+7qaZrPi8EDvhOI8
mnk1h3Xt2/rfBml18sy4s2fMG9bb5VLNK+HOslY9YzlJsoHqnefMC6S1/516
jrQyPysOLq6boZl3Zf78D2pLRh4=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 867->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktKA0EUbFxIriHeQA8QvEI8wQhmFRCShWSXoycBGbR59eve2DDJZPq9
6qp6NZCnj6/d/qG1dtrcPnbL99vxuJzfH+8/PpfD68vhvvn8c7V22bb1+z9c
bPX7LoZT52L/9ov5V2EpLjOYTAvCSrj09ck56Cykp9fR8624MD2qD+lDPjAu
aUYd/uo8F4PxUpxd7cqTJIeuHxW2o1V5RGvC2aQalf9/7gmXXofya8RDd59h
OVwqLFRXcWhiRogf4tv3oHumPeFQ7at6N3+Me4Jd/e6xFfeqnnmjfEG9ro9p
nhUv5qfCYHiKS4pZLdaf+KLyMpLhdKZuTkbeD6Sz6u2xmR+ohs2r2hvhws5m
mU88G8kv06jw0HJm72pyMSss1ZdkwMFMNDhZnz3X1TSbFYcHeicU59HMqzms
a9vW/zZIq5Nnxp09Y96ws10u1bwS7ixr1TOWkyQbqN55zrxAWvv71HOklflZ
cXBx3QzNvCvz/VdM0EUi
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 868->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLKQXCN4Az3AkCvEE4ygq0AgLiS7HF0joknz6tfjwoH59nvV
VfVqNs+H3euqtfa2/rzs5vft8Tifnu4uLy/z/vFhf1m8/z5bO0/t5/4fTnb0
6y6GU+diX/vF/KuwFJclmEwLwkq49PXJPmgvpKfX0fOtuDA9qg/pQz4wLmlG
Hf5qPxeD8VKcXe3KkySHrh8VtqNVeeT0jvoRa746kYaKS8WX+TXiobvOsBwu
FZby4KZezAjxQ3z7HvTMtCccqnVV7+aPcU+wq/ceW3Gv6pk3yhfU6/qY5lnx
Yn4qDIanuKSY1cH6E19UXkYynM7UzcnI/4F0Vr09NvMD1bB5VWsjXNjeLPOJ
ZyP5ZRoVHjqc2buaXMwKS/UlGXAwEw1O1pfu62pamhWHB/onFOfRzKs5tOn3
zrQw35U3zrfzdMsnmbnDpZpXwp1lrfrGcpJkA9U735kXSGv/nHqOtDI/Kw4u
LuL2Z//K0v4vLh8t/0gc
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 869->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKwkAQWzyI3xB/oA8Qv1BfUEFPBaEexJtP1xYRWWaSzOzFhWrbnckk
2XR9unaXRSnltnr/dP39MI7947icHs79sNsO0+bmc5Xy3Jfv/z9caNX7KoZS
p2L/+oX8s7AYlxZMpMXDinCp6yNzvFmenlpHzdfigvSwPk+f5wPiEs2owp/N
UzEQL8ZZ1c48ieRQ9cPCVrQyj5TerB8Zzb+zPc31vcUX+ZXxUN1HWAoXC4t5
wOrV/HtcrBnI98gZK/usXs0f4h7Btp5rbMbdqkfeMF+8XtXHaJ4ZL+Qnw0B4
jEsU01qoP+ILy0smw9EzVXOS+T48nVZvjY388GrQeVl7GS5oNsp8xLNMfpFG
huct5exVTSqmhcX6IhlQMCMalKy3zlU1tWZF4eF9E4xzNvPsHOYlZB/5zrxR
3iFv0GyVi6dP5Y6yZr1DOYlkw6tX3iMvPK31fdRzTyvy0+Kg4qoZSn8rrf0z
lxeybEai
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 870->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwkAQW/wQryHeQA9QvEI9QQX9EgT9EP88urYW0WUmyUx/XFgf3ZlM
kk2X+3N7nJVSrovXR9vdtpdLd9/N+z+H7rRZn/rD1bhLeTTl8/0PG636XMVQ
6lTsb7+QfxYW4zIFE2nxsCJc6vrIHG+Wp6fWUfO1uCA9rM/T5/mAuEQzqvBn
81QMxItxVrUzTyI5VP2wsBWtzCOlN+tHRnNp3vuHK8mJxRf5lfFQPUdYChcL
y6uzOHjzlXOPizUD+U7vOMiR1av5Q9wj2Nb/Gptxt+qRN8wXr1f1MZpnxgv5
yTAQHuMSxbQW6o/4wvKSyXD0TtWcZN4PT6fVW2MjP7wadF/WWYYLmo0yH/Es
k1+kkeF5S7l7VZOKaWGxvkgGFMyIBiXrU+eqmqZmReHhvROMczbz7B6G1Ywb
aEG+M2+UZ8gbNFvlYt1XhDvKmvUM5SSSDa9eeY688LTWv6Oee1qRnxYHFVfN
UPpdmdo/cHkC8OhGIA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 871->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOAzEUi1igXgNxAzjAiCuUEwwSrCohtQvEjqNDUUFteP4lGyKl05m8
+NmOc/P0un25aq0dNl8/2/XtYb9f3x+vjy/P6+7+bndcvD3N1j6W9vv8D5ON
ft3FcOpc7HO/mH8VluIyg8m0IKyES1+f9EG9kJ5eR8+34sL0qH1IH/KBcUkz
6vBX/VwMxktxdrUrT5IcXtQRPypsR6vyCNac8Rn1I51t+dv3hwvLSXVmzK8R
D911huVwqbBQXcUB9XfWEZeqB/Nd4aYcVb2bP8Y9wa7ee2zFvapn3ihf0F7X
xzTPihfzU2EwPMUlxawG25/4ovIykuH0TN2cjNwPpLPa22MzP1ANO69qbYQL
680yn3g2kl+mUeGh4Zy9q8nFrLDUviQDDmaiwcn6bF9X02xWHB7oTijOo5lX
5/A9ltMkWpjvyhvnG/OG9Xa5VOeVcGdZq76xnCTZQPXOd+YF0tr/Tz1HWpmf
FQcX183QzF2Z3/8Ja55FXw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 872->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbFxIriG5QTxAyBXMCSagq4GAWQR3Hj0xhCBtvfr0ZGFD60x/
6lXVq9m8ve8Oq9bax8P3z276fDkep9Pr+vKyn+bt03zZfPydrZ2f29//PUw2
+n0XwznnYl/7xfxDWIrLEkympcJKuPTnkzpVrUpPr6Pni7gwPepepa/ygXFJ
M+rwV/VcDMZLcXa1K09kT0QPkR8I29GqPGqAD/Mg8SOdzcgM4oL4Mr9GPHT3
GZbDBWEpD9R5N/8VF1SD+a5wU47qvJs/xj3BRu89tuKOzjNvlC/VXdfHNM+K
F/NTYTA8xSXFRIPdT3xReRnJcNpTNycj30elE93tsZkf1RnWL7Q3woXVZplP
PBvJL9Oo8Krh9N7V5GIiLHUvyYCDmWhwsr60rqtpaVYcHjfYJufRzKs+oOdK
q4PBuLO1m74HPXe4VPpc7ixraI3lxM0Gw3bWmReV1v459bzSyvxEHNJs9rX+
7VtZev+Hyxf820Th
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 873->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1wjeQA8QvEI8wQi6CgTiQtzl6BpRkeerX48LGyaZmX6v
XlV1zebhsHu6GGM8X73/7JaXu+Nxeb2/PD88Lvvbm/158/rzGuO0Hd///+Fi
q+67GE6di/3TL+Zfh6W4rMFkWhBWwqXWJ3PQLKSn6qh8Oy5Mj+pD+pAPjEua
UYe/mudiMF6Ks6tdeZLk0PWjw3a0Ko8+luid9SPW/HWNwlXkpOPL/LI9LDNU
vpMMIC4dFqrrOKD5zj7i0s1gvivclKOqd/PHuCfY3XPFVty7euaN8gX1uj6m
eVa8mJ8Kg+EpLilmt1h/4ovKy0yG0zN1czLzfSCdXW/FZn6gGnZe3d4MFzab
ZT7xbCa/TKPCQ8s5e1eTi9lhqb4kAw5mosHJ+tq5rqa1WXF4oG9CcZ7NvDqH
7h5pdTAYd/bu17kHZ+5wQfpc7ixr3TuWkyQbqN55z7xAWut96jnSyvzsOKTZ
rLP+8ltZ3/8GgSFFYQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 874->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIIXiPkBvEA4hXMCSYQV4KgC8kuR1chSGhe/bo3NozjTL9X
r6q65u3ruNu/tNbOq9vPbrlsT6fl5/P1/vC9HNYfh/vm+9/V2u+mPe7PcLHV
77sYTp2L/d8v5l+FpbjMYDItCCvh0tcnc9AspKfX0fOtuDA9qg/pQz4wLmlG
Hf5qnovBeCnOrnblSZJD148K29GqPHJ6R/2INYPMNJGTii/za8RDd59hOVwq
LFRXcUDznX3EpZrBfFe4KUdV7+aPcU+wq+ceW3Gv6pk3yhfU6/qY5lnxYn4q
DIanuKSY1WL9iS8qLyMZTs/UzcnI94F0Vr09NvMD1bDzqvZGuLDZLPOJZyP5
ZRoVHlrO2buaXMwKS/UlGXAwEw1O1mfnuppms+LwQN+E4jyaeXUOjyWyz3xX
3jjvmDdstsulOq+EO8ta9Y7lJMkGqnfeMy+Q1v5/6jnSyvysOLi4boZmvpX5
/iu8/0Vj
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 875->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1wjeQA8QvEI8wQi6CgTiQtzl6Br8IM9Xvx4XNnQyM/26
XlV19ebhsHu6GGM8X73/7JaXu+Nxeb2/PL88Lvvbm/158fpzjnHaju///zDZ
qOsuhlPnYv/0i/nXYSkuazCZFoSVcKn1SR/UC+mpOirfjgvTo/YhfcgHxiXN
qMNf9XMxGC/F2dWuPEly6PrRYTtalUe0JjybVOMvjK85sIaOS3dmzC/bw9JD
5TvJANNWsZQHqt7NP+LS9WC+K9yUo6p388e4J9jde8VW3Lt65o3yBe11fUzz
rHgxPxUGw1NcUsxusP2JLyovMxlOz9TNycz9QDq7vRWb+YFq2Hl1azNcWG+W
+cSzmfwyjQoPDefsXU0uZoel9iUZcDATDU7W1/Z1Na3NisMD3QnFeTbz6hy6
Z6TVwWDc2TfmDevtckH6XO4sa903lpMkG6je+c68QFrrc+o50sr87Dik2ay9
/vK+rJkfXN4A2ZRHIA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 876->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktqAlEQfLgIuYZ4g3gAyRXMCUaIK0Ewi+DOo6tEJ9J21+fNxgej8+lX
XVVdAzPf7NfbWWvt5/3ysx5+Pw+H4fj1dr34HnbLj9314eJ2tHZatfH/FQ60
4nMVQ6lTsR/9Qv5lWIzLFEykpcJyuMR6p0/Vq9ITdUS+GRekh+2r9FU+IC5u
RhX+rJ+KgXgxzqp25omTw7GG+JFhK1qZR0+Y95qO2TCNSnbbA1alOZ5nM0N+
yR6GHizfTgaQtojFPGD1av4rLlkP5DudscmR1av5Q9wd7Ow6YjPuWT3yhvlS
7VV9dPPMeCE/GQbCY1xczGyh/Y4vLC89GXZnquak5/2odGZ7Izbyo6pB88qe
9XBBvVHmHc968os0MrxqKbNXNamYGRbb52RAwXQ0KFmf2lfVNDUrCo/qnWCc
ezPP5jCuVfv/Ni20KnlG3NG9p7kbM1e4ZPNyuKOsZfdQTpxsVPXKfeRFpTWe
u55XWpGfGQcVF2XoFY4/LmdtgEXf
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 877->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQHPwIuYZ4g3gAyRXMCVbQL0EwH8E/j64SWaS3ux6zPw6Mrjs9
1VXV5XJ32h4WrbXfz/vHdvj7Pp+Hy8/H48d+OK6/jo/D1XO3dt208fsdNlrx
XMVQ6lTsV7+QfxkW4zIHE2mpsBwusd7pU/Wq9EQdkW/GBelh9yp9lQ+Ii5tR
hT/rp2IgXoyzqp154uRwrCF+ZNiKVuaRwrfXD3dHTpXm+BzrmF+yh6EHy7eT
AaQtYjEPWL2a/4pL1gP57sxYOWf1av4Qdwc7+x2xGfesHnnDfKnuqj66eWa8
kJ8MA+ExLi5mttB9xxeWl54MuzNVc9Lz/6h0ZncjNvKjqkHzys56uKDeKPOO
Zz35RRoZXrWU2auaVMwMi91zMqBgOhqUrM/tq2qamxWFxwRb5NybeTaHcT25
IK1KnhF39G4yd2PmCpdsXg53lLXsHcqJmg2ErbxHXlRa47PreaUV+ZlyEHFR
ht5h/3O5AbYtRaA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 878->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKAjEUDC7Ea8jcQA8gXqHnBC2MK0HQhbjz6E6POmh8rz7pjYFod/JS
qapXPd/su+2klHKc/f50/Wl9OPTn7+nw8tPvlovdsPl1n6VcVuX//xMmGvW+
iqHUqdjPfiH/IizGZQwm0pJhOVzqeuee7K5MT62j5htxQXrYuUxf5gPi4mZU
4c/uUzEQL8ZZ1c48cXL4t/84C/yIsBWtzCOFb6sf7ixPXmQaIi5Rz5BfLR6q
+46nmbYai3nA6tX8Z1yiO5DvDNflyOrV/CHuDnb0XmMz7lE98ob5kp1VfXTz
zHghPxkGwmNcXMxooPOOLywvLRl2e6rmpOX7yHRGZ2ts5EdWg/oV7bVwQXej
zDueteQXaWR42VB6r2pSMSMsds7JgILpaFCyPvZeVdPYrCg8sm+CcW7NPOvD
yzPRqmAg7mjtre9GzxUuUb8c7ihr0RrKiZONrF5ZR15kWutn1/NMK/Iz5CDi
ogx9wrxxuQK8AEWg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 879->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKBDEUDC7Ea4g30AOIVxhP0IKzGhDGhbjz6DqjSPN49Uu7MJCZ7s5L
vapK5frpZbe/GGO8Xn397Ja3h+NxeX+8PL08L4e728Np8eZnjvFxP37//8Nk
o667GE6di732i/nXYSkuWzCZFoSVcKn1SR/UC+mpOirfjgvTo/YhfcgHxiXN
qMNf9XMxGC/F2dWuPElyeF5fTeRHh+1oVR45fGf9SOd5rHxAmutzd2bML9vD
0kPlO8kA01axlAeq3s0/4tL1YL7LMw45qno3f4x7gt29V2zFvatn3ihf0F7X
xzTPihfzU2EwPMUlxewG25/4ovIyk+H0TN2czNwPpLPbW7GZH6iGnVe3NsOF
9WaZTzybyS/TqPDQcM7e1eRidlhqX5IBBzPR4GR9a19X09asODzQnVCcZzOv
zqF7RlodDMadfWPesN4uF6TP5c6y1n1jOUmygeqd78wLpLU+p54jrczPjkOa
zdrrL+/LlvnN5RNzs0bf
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 880->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAlEQfGQhXiPkBnoA8Qp6ggnoShB0Idnl6H5IRNvu+rzZOPBiZqa7
uqq65vN7v9p+tNaO08uf1XBaHg7Dz3pyvdkMu/lsd3359Xda+120++87HHTF
9yqGUqdiP/qF/MuwGJcxmEhLheVwifXOnGpWpSfqiHwzLkgP66v0VT4gLm5G
Ff5snoqBeDHOqnbmiZPDp17gR4ataGUeKXx7/XDPvwdt8cyVccl2hvySPQwz
WL6dDCBtEYt5wOrV/FdcshnId7pjkyOrV/OHuDvY2X3EZtyzeuQN86XqVX10
88x4IT8ZBsJjXFzM7EL9ji8sLz0Zdneq5qTn+6h0Zr0RG/lR1aB9Ze96uKDZ
KPOOZz35RRoZXnUpu1c1qZgZFutzMqBgOhqUrI+dq2oamxWFR/VNMM69mWd7
aI8HaEG+M2+UZ/d7wS+Egbhn+lTuKGvZM5QTJxtVvfIceVFpjf+7nldakZ8v
HMAMhKPuw/pWxvbfuJwB4sBHHA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 881->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIIXiN4g3iAkCuYE4ygKyGgi5Bdjq4SGYbne/XpziINrTPT
r+tVVVe/7D63h6fW2nl1/dlOX++n0/T98Xx72U/Hzevxtri+z9Z+3tr8/x8m
GnFdxVDqVOylX8i/DItxGcFEWiosh0usd/pUvSo9UUfkm3FBeti+Sl/lA+Li
ZlThz/qpGIhXXGsDeUb4Tg7nGuJHhq1oZR49YC6mezZMozKXvSvN8Tk7M+SX
7GHowfLtZABpi1jMA1avaK34xj3VM9LucMjWWb2aP8Tdwc7eIzbjntUjb5gv
1V7VRzfPjBfyk2EgPMbFxcwG2u/4wvLSk2H3TNWc9NyPSme2N2IjP6oadF7Z
Wg8X1Btl3vGsJ79II8OrhnL2qiYVM8Ni+5wMKJiOBiXro31VTaNZUXhUd4Jx
7s08Owc0nAwhb5Rv87vgF8JA3DN9KneUtewbyomTjape+Y68qLTGZ9fzSivy
M+Og4lbc/vK+jMxfLhcmnEbd
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 882->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEUhB9ZSK4RcoN4gJAr6AlGiCtBMIuQXY4eJSLh8V79dGfhwKhj
d1d/VV3ztDtu9g8R8fF4/tgsn2+n0/K1XV0e3pfD+uVwGXy+3hHfr3H7vocb
XXlc1VDmqdp/80L5VVqMZUYTeem0HJY839mn26vzk31k3ooF+WHrOn9dDojF
7ajCz/ZTNRBXHouJPiN9p4e3OSSPSlvxqmQUiYOxqHm4d1SdyXwFS3VmKC+n
x5kF9dvpQMdSaXXzKgbmBY23vos9UO5M12Vk89X+IXZHu3rO2oy9mo+yYbl0
a9Uc3T4zLpQn00B6jMXVrC603smF9WWkw+6Zqj0ZeT86n9XarI3y6Oag86rG
RljQ3qjzTmYj/UUemV53KWevelI1Ky22zumAoul4ULo+u6/qabYrCkf3TjDm
0c6zc0CX0yGUjfKfkxfSQOyVP5UdsSr8nabi1ekQy5Z5zb/dzDuvKM+KQdXt
2P7zfZm5f1l+AETNRt0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 883->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8QvEI8wQi6CghxIe48ukZ0SNpXv24XNrRxpl/X
q6pXc/XwvHu6aK29bD7/7JbXu8Nhebu/PD48Lvvbm/3x8Pp7t/a+bevvf9hs
9ecuhlPnYp/6xfyrsBSXGUymBWElXPr6pA/qhfT0Onq+FRemR91D+pAPjEua
UYe/6udiMF79WZvIM8NPcrjWCD8qbEfrkEeDs1EanX02H+HlaV3il+1h4DHi
gvxBXCosVFdxQP2dc8Sl6sF8d+abcFT1bv4Y9wS7eu6xFfeqnnmjfEF3XR/T
PCtezE+FwfAUlxSzWux+4ovKy0iG05m6ORn5PpDO6m6PzfxANWxe1dkIF9ab
ZT7xbCS/TKPCQ8uZvavJxayw1L0kAw5mosHJ+mxfV9NsVhwe6JtQnEczr+bA
VpIh5o3zbn02/GIYjHulz+XOsla9YzlJsoHqnffMC6S1/z/1HGllfv7i8LMN
XMTtz76V2ftfXD4AkkZGng==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 884->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0kKAjEQDB7Eb4g/0AeIX9AXjKCnAUEP4s2nuyCiobuWjAcDo8yku7qq
UpluD+v9qJRymtx/1t15dTx2l8348bLr+sW8f2zOXk8p12V5///Dg1a9r2Io
dSr2p1/IvwiLcRmCibRkWA6Xut6Zk83K9NQ6ar4RF6SH9WX6Mh8QFzejCn82
T8VAvBhnVTvzxMmh6keErWhlHhVRV4sfll6QScYlOjPkl52JD34o304GMi4R
VlYXcaBawH7GJZqBfGe4LkdWr+YPcXewo/cam3GP6pE3zJesV/XRzTPjhfxk
GAiPcXExo4X6HV9YXloy7J6pmpOW+5HpjHprbORHVoPOK9pr4YJmo8w7nrXk
F2lkeNlSzl7VpGJGWKzPyYCC6WhQsj50rqppaFYUHtmdYJxbM8/OAS0nQ8gb
5dv7XfALYSDukT6VO8pa9A3lBPVl3NWZyFvkZeQHwkI9mVY0+wtDyCnLw8/u
ytD+J5cbUt1H3Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 885->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktKA0EUfLgQryHeQA8QvEI8wQhmFRDiQtx5dI1KDE29+vQstGESZvp1
vap6NTDXj8/b3UVVvVx9/myX1/vDYXl7uDzePC37u9v9cfPm56p639Tp/z9c
bI37LoZT52Kf+8X8Q1iKyxpMpqXDSriM9UmfrlenZ9Qx8kVcmB51rtPX+cC4
pBl1+Kt+LgbjpTi72pUnSQ5PNcIPhO1odTwqtD8xG6XR8aDGLBo5QTNjftke
nnEYeaB8JxnouCCsrg5x6Po7+x0X1IP5rnBTjqrezR/jnmCj+xFbcUf1zBvl
S3fW9THNs+LF/FQYDE9xSTHRYucTX1ReZjKcztTNycz70elEZ0ds5kdXw+aF
9ma4sN4s84lnM/llGhVet5zZu5pcTISlziUZcDATDU7W1/Z1Na3NisOjeycU
59nMqzl8rU39fosRrU6eGXf2jHnDertc0LwS7ixr6BnLSao1yRDzlnmJ/GBY
7EynlfVm+wzXzdBfXd9cPgBhwUac
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 886->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tuwjAUtLpAXKPqDeAAEVeAE6QSrJCQYIHY9eiFFkJkvfk8ZwGWTIj9
PG9mPPn8Pqx3H6WU0/z6s+7Pq+Oxv2xmt5dtv18u9rfNr/ss5acrw/MdJhv1
vovh1LnYY7+YfxGW4jIFk2lBWBkudX2mD+qF9NQ6ar4RF6ZHnUP6kA+MSzaj
Dn/Vz8VgvBRnV7vyJJND148I29FKPeruM+rVcDdZjcPZ7tlvzLvmgbhEd8b8
sj0ccVAeIy7IH8QlwkJ1oV+gv7OPuEQ9mO8KN8tR1bv5Y9wz2NF7ja24R/XM
G+ULOuv6mM2z4sX8VBgMT3HJYkaDnc/4ovLSkuHsnbo5afk+kM7obI3N/EA1
7L6ivRYurDfLfMazlvwyjQoPDefuXU0uZoSlzmUy4GBmNDhZn9rX1TQ1Kw4P
9E0ozq2ZV/fARiZDzBtnjXnDertc/p6P2cCdZS1aYzkZ1o1sIGxnnXmBtNb/
s55DrYALqndx3Qy9av5z+QVn70Xd
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 887->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIIXiPkBskBJFcwJ5hAXAkBXQR3Hl0lRqR99eshkIZxGPt1
vap61U8fX6v1Q2tttzj9rKbvt+122r8/nj8+p83ry+a8+Xx5Wjss2/X9Hx62
+n0Xw6lzsW/9Yv5VWIrLHEymBWElXPr6pA/qhfT0Onq+FRemR51D+pAPjEua
UYe/6udiMF6Ks6tdeZLk8Foj/KiwHa3Uo0vfu16Ds1Eamfa2vOftcqlmxvyy
PbzhoDxGXJA/iEuFhepKv0B/Zx9xqXow3xVuylHVu/lj3BPs6rvHVtyreuaN
8gWddX1M86x4MT8VBsNTXFLMarHziS8qLyMZTmfq5mTkfiCd1dkem/mBati8
qr0RLqw3y3zi2Uh+mUaFh5Yze1eTi1lhqXNJBhzMRIOT9bl9XU1zs+LwQHdC
cY5yHmSJrSRD0BuQKzS/ijvr7XL5xW79f4y76OvOs1+p1iRDzFvmZeUHw2Jn
Sq2AC6p3cRG35L785fPD5QjKkkYa
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 888->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FuAjEQi3pA/QbqD8oDqn4BXrBIcEJCooeqN55eaCu0jMYeOzmUSGE3
ZMaxHe9ye1zvn1prH8+Xn/X0+X46TV+bxXWxmw6r18N18+VvtnZ+a7fnI0w2
4r6KodSp2HO/mH8ZVsVlBJNpQVgOl1jvnIPOQnqijsg348L0VH1IH/KBcXEz
qvCvzlMxGK+41wbyzPCdHN5qAp/IIcNWtFKPkjp0To8f6pxrv7ufwst5neOX
k2PVY8QF+cN8jlioLuPQqwXxjT3onWkf9buqV/PHuDvY2TpiV9yzeuZN5Qvq
VX1081zxYn5WGAyv4uJiZoP1O75UeenJsHunak56vg+kM+uN2MwPVMPuK9vr
4cLOZpl3POvJL9NY4aGh3L2qScXMsKo+JwMKpqNByfrouaqm0awoPNA3UXHu
zXx1D2w4Gaq8QXqytZs1hcvPM74L3JWsZf9VXjhanQwxb5mXmX8Mi/Ugrexs
ts9w1Qz91/zl8g3L8USg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 889->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU01KQzEYDC7Ea4g30AOIV6gneIKuCkJdSHc9eluU8ki/+UtcGEhf38uX
+WYmk/u3z83HTWvt6+70s1m+X3a7Zf96e355X7ZPj9vz4sPvbO3w3C7P/zDZ
6NddDKfOxV77xfyrsBSXGUymBWElXPr6pA/qhfT0Onq+FRemR+1D+pAPjEua
UYe/6udiMF79WpvIM8NPcnipEX5U2I5W6lFRh/qM+OHOttLPzgdxQRqQX0mO
116pfCcZYD73WKiu4mBpAeuIS9WD+a5wU46q3s0f455gV+89tuJe1TNvlC9o
r+tjmmfFi/mpMBie4pJiVoPtT3xReRnJcHqmbk5G7gfSWe3tsZkfqIadV7U2
woX1ZplPPBvJL9Oo8NBwzt7V5GJWWGpfkgEHM9HgZH22r6tpNisOD3QnFOfR
zKtzYCPJkPIG6bl6N/xiGIr7us7h7mSt+qa8QPsY9/S78qLS2v9PPWdaWW+2
znARt7+8LzPzh8sRDMJGng==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 890->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKBDEUDC7Ea4g30AOIVxhP0IKuBoRxIe48ug7K0Lx59UsvNJCeSeel
XlWl+vrpdfdyMcZ4u/p+7Jb3h8Nh+Xi8PC6el/3d7f64efM7x/i8H6ff/zDZ
qPsuhlPnYq/9Yv51WIrLFkymBWElXGp90gf1Qnqqjsq348L0qHNIH/KBcUkz
6vBX/VwMxktxdrUrT5IcnmqEHx22o5V61NShPjN+uHOs9K/7V08QF6QB+TWV
CSPfSQaYzxUL1XUcLC1gH3HpejDfFW7KUdW7+WPcE+xuXbEV966eeaN8QWdd
H9M8K17MT4XB8BSXFLMb7Hzii8rLTIbTO3VzMvN9IJ3d2YrN/EA17L66vRku
rDfLfOLZTH6ZRoWHhnP3riYXs8NS55IMOJiJBifrW/u6mrZmxeGBvgnFeTbz
6h7YSDKkvEF6unWaNYfLWa5IfpgHDj+VPcTFyXvyXnnRaa3/U8+ZVtab7TNc
N0N/NX+4fAGHhEae
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 891->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktqwzAUFFmUXCP0BskBTK7gnsCFdmUIOIvQXY/eui3FVt98npxFBUri
SJo3M28EPjxf+tddKeW6//zoh9t5moa3p4f54WUYT8dxXnz8maW8d+X3+z9M
Nup1F8PZ52Iv/WL+RViKyxZMpgVhZbjU+zN1UC2kp9ZR8424MD3qHNKHfGBc
shl1+Kt6LgbjpTi72pUnsicRnvAjwna0Ko0F1Grpjcqm7Fvw28lJzVn5lc4E
6tnSR8AFZoD4XGOttJF+WVrIOuIS1WC+W71OcFT73fwx7hns6LnGVtyj/cwb
5Qs66/qYzbPixfxUGAxPccliRoOdz/ii8tKS4WxP3Zy03A+kMzpbYzM/0B7W
r2ithQurzTKf8awlv0yjwkPD6b2rycWMsNS5TAYczIwGJ+tb67qatmbF4YHu
hOLcmnnVh6/RlfW7IdDq5Bl5g/T8eTb8YhiK+3Kfw93JWvSf8mLFQWjNZIh5
y7yM/GBY7AzSymqzdYaLuN3zvmyZ31w+ABLkRV0=
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 892->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVltqAkEQHPwIXkNyg+QAi1cwJ9hA8iUI+iH+eXRjEmR2tuvRsxCyMLrr
9FRXVdeCm/fD7nNVSjmtvz5243l7PI6Xt6f7w8e4f33Z3zeff1cp16E8vv/D
Yle772I4dS527RfzL8JSXJZgMi0IK8Olrc/0Qb2QnlZHyzfiwvSoc0gf8oFx
yWbU4a/6uRiMl+LsaleeZHLI5qZ4O1qzGlGfHj/cVfds752cRHqYXz2ZcHhn
MsB8brEm2si8XC1oH3GJeiguatYZjqrezR/S4XjgzDKqR32ieuaN8gWddX3M
5lnxYn4qDIanuGQxo4udz/ii8tKT4exM3Zz0vB9IZ3S2xWZ+oBo2r2ivhwvr
zTKf8awnv0yjwkOXM3tXk4sZYalzmQw4mBkNTtaX9nU1Lc2KwwO9E4pzb+bV
HL6voTz+azCtTp6RN0jP7Nnwi2Eo7nWd5G7mN/pNeTHhILRGvqCezFvmZd2n
GFiTM8E9q0e+zPaDOTEcdx5/uX643AD3Q0ga
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 893->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktqwzAUFF2UXKP0BukBTK/gnMCFZmUIOIvQXY/eOC3FVt98npxFDUpw
9DRvZt4I8vR26o8PpZTz7vrRD5fXaRo+Do/zy/swvuzHefP5Z5Xy2ZXf7/+w
2FPvuxhOnYu99Iv5F2EpLlswmRaEleFS12f6oF5IT62j5htxYXrUOaQP+cC4
ZDPq8Ff9XAzGS3F2tStPMjm87YO5Kd6OVupRt17qHmT9cNeKy6K/8nJZl/FL
ztzMXMQV1btcIqyaG+KHdLv5R1yiHlFuHewWjqrezR/S4XjgzDKqR32ieuaN
8gWddX3M5lnxYn4qDIanuGQxo4edz/ii8tKS4exM3Zy03A+kMzpbYzM/UA2b
V7TXwoX1ZpnPeNaSX6ZR4aHHmb2rycWMsNS5TAYczIwGJ+tb+7qatmbF4YHu
hOLcmnk1h9vTldV/Q6TVyTPyBun58274xTAU92Wdw93JWvSb8gJlHHGvfUE9
mbfMy8gPhsXOIK2sN9tnuIjbPe/LlvXN5QtknkSc
                    "], {{0, 35}, {
                    35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 894->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQbPyQXEO8gR5AvEI8wQrmKyAkH5K/HD2JGknarkfPgjgw2SzT
U11VXXv3+r5c3UTEdnH8WU4fz5vNtHu5Pb28TevHh/Xp8P57R+yf4uf5HzZb
+dzFcOpc7Eu/mH8VluIyB5NpQVgdLrm+0wf1Qnqyjsy34sL0qHtIH/KBcelm
1OGv+rkYjFc+ixl5ZvidHJ55ROKTOVTYjlbHg9y36jPih7Mj7/MquCEu1cyY
X0OZMPLdyQDzOWNdaQPZUHlwzhGXqgfzXeF2Oap6N3+Mewe7es/YintVz7xR
vqC7ro/dPCtezE+FwfAUly5mtdj9ji8qLyMZ7s7UzcnI94F0VnczNvMD1bB5
VWcjXFhvlvmOZyP5ZRoVHlrO7F1NLmaFpe51MuBgdjQ4WZ/b19U0NysOD/RN
KM6jmVdzYKuTIeUN0uPoY71dLihXiruTNYc/0v75FFo7GVLeKq1xwYdhXd0p
/rN65Muv82JODMedx1/uLy4HOUREWQ==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 895->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KAzEcxYML6TWkN9ADlF6hnmAKuioU2kVx59G1thWJ//eVcWEgLUOS
l9978+Zhu9+83rXWjovPn810Wh8O09vz/fnhZdo9Pe7Oi8vrbO191b7//8Nk
o193NZx9rvbPvFh+lZZimaPJvCCthKXfn9yD7kJ+eh89b8XC/KhzyB/KgbGk
HXX41X2uBuNSzK53lUnSQ9U9xu14VR7bdSYsbh7u/Bo3FsKGWHpmlddQJ4x+
Jx1gOfdaaF/FYHkB64iluoPl7nQ9YVT73f4x9kS7eu61FXu1n2WjckFn3RzT
PisulqfSYHqKJdWsBjuf5KL6MtLh9J26PRn5PpDP6myvzfJAe9j7qtZGWNjd
rPNJZiP9ZR6VHhrOu3c9uZqVljqXdMDRTDw4XZ97r+tpblccDvRNKObRzqv3
wEbSIZUN8uP4Y3e7LKhXkt3omsOPvCO+X3vMO1W2zGuVZZo588ruZutMF7H9
5fcyZ15YPgBW6ESg
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 896->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwjAQDH6I1xBvoAcQr6AnqKBfgqAf4p9H90mRsDuPFMRAWko2szOz
0+n2uN6PSinnyeOx7i6r06m7bsbPj113WMwPz8PZZ5dyW5b+/Q8brfpcxVDq
VOxvv5B/ERbjMgQTacmwHC51vdMn65XpqXXUfCMuSA+7l+nLfEBc3Iwq/Fk/
FQPxYpxV7cwTJ4cse4i3opVpLJ/dnycZavFD3a/11bvnJvgS1TG/hmYiy7eT
AaStxmIesHpVa8Yl6oF8V7LucGT1av4Qdwc7+q6xGfeoHnnDfMnuqj66eWa8
kJ8MA+ExLi5mtNB9xxeWl5YMuzNVc9Lyf2Q6o7s1NvIjq0Hzis5auKDeKPOO
Zy35RRoZXraU2auaVMwIi91zMqBgOhqUrA/tq2oamhWFR/ZPMM6tmWdzQMvJ
EPMm06PoQ71VLlmuGHclawr/TPvrTbQ6GWLeMq0l8MjxHGlFvcPzYE4IR53H
L/ebyx0AskXf
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 897->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk11KQzEUhIMP0m2IO9AFFLdQV3AFfSoI9UF8c+naWkUOZ/5yQQzEWpJM
vplMrx6ed08XY4yXzeef3fJ6dzgsb/eXxy+Py/72Zn9cvD7PMd634+fzP0w2
6rqr4exztX/nxfLrtBTLGk3mBWklLHV/cg+6C/mpPipvx8L8qHPIH8qBsaQd
dfjVfa4G41LMrneVSdJD1T3G7XhVHsd5JixuHu48jW8WwoZYKrPKa6YTTr+T
DrCcqxba1zE4vGgdsXR3sNydrieMar/bP8aeaHffq7Zi7/azbFQu6KybY9pn
xcXyVBpMT7Gkmt1g55NcVF9mOpy+qduTmd8H8tmdrdosD7SHvVe3NsPC7mad
TzKb6S/zqPTQcN7e9eRqdlrqXNIBRzPx4HR97b2up7VdcTjQb0Ixz3ZevQMb
SYdUNsiP44/d7bKgXil2p2sOP/J++hRekw6pbJXX+n+aOfPK7u7Wu3diOu57
/OX8YvkA1UVHHg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 898->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqQkEQHFwEryG5QXIA8QrmBE9IVoKgC3Hn0f2g4dF2fXpeFhkY5THd
1VU1NYvNbv0za60d5tef9XBc7ffD6evt9vE9bD8/trfD98du7bxsv///YbMV
z10Mp87FHvvF/MuwFJcpmEwLwqpwifWVOWgW0hN1RL4ZF6ZH9SF9yAfGpZpR
h7+a52IwXoqzq115Usmhyh7j7WhVGttjV7i4frj7vp5cov9GTl56hF89mUBc
xhwqGWA+RyzIOeHgaEHniEs2g/nuZL3CUdW7+WPcK9jZd8RW3LN65o3yBfW6
PlbzrHgxPxUGw1NcqpjZYv0VX1ReejJcvVM3Jz3vA+nMeiM28wPVsPvKznq4
sNks8xXPevLLNCo8tJy7dzW5mBmW6qtkwMGsaHCyPnWuq2lqVhwe6E0ozr2Z
V/fAViVDyhuk5+Xb8IthKO7jOsk98MlqnfvMvEAZR9yjL2gm85Z5mfnBsFgP
0spms3OGi7j95Xth2ZQ9dy4XwlZDIA==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 899->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0kKAjEQDB7Eb4g/0AeIX9AXjKAnQdCDePPpLqhI7K4l48FAnBmTrq6q
VMbr/XI7KKUcR7efZXdaHA7deTW8f2y63Wy6uy9OnrOUy7y8n/8w0ajXVQxl
n4r96RfyL8JiXPpgIi0ZlsOl3u/0yXplemodNd+IC9LD6jJ9mQ+Ii5tRhT/r
p2IgXoyzqp154uSQZQ/xVrQyjeU5HS6qH+p8jBeX2n8hJ181xC87E4FPUb6d
DCCfayxUG71DLWA948L6sczZfhu4n1yknCXcHezou8Zm3KP9yBvmS1ar+ujm
mfFCfjIMhMe4uJjRQPWOLywvLRl2z1TNScv9yHRGtTU28iPbg84rWmvhgnqj
zDueteQXaWR42VDOXtWkYkZYrM7JgILpaFCy3revqqlvVhQe2Z1gnFszz84B
DSdDzJtMT1hrZk3hkuVK5Y6yFv2n4mX8Qu5CT+ot0Iq4IC+id8W7aKg5ZXn4
5X3JcinVPLhcAYTfQ6A=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 900->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0kKAjEQDB7Eb4g/0AeIX9AXjKAnQdCDePPpLgyDhK6lMx4MjMPY6eqq
SmW+P2+Pk1LKdfb62Xa3zeXS3XfT98ehO62Wp3dx0T+lPNZleP/Dw1ZddzGc
fS72t1/MvwhLcRmDybQgrAyXen9mDpqF9NQ6ar4RF6ZH9SF9yAfGJZtRh7+a
52IwXoqzq115ksmhyh7j7WhVGkv/DPXqO3M2KptUv+l/VIt6mF8tmUBc6hrC
crlEWGqu2u9qRVzUPJW5Fr9d3G8uVs4A9wx29F1jK+7RfuaN8gX1uj5m86x4
MT8VBsNTXLKY0WL9GV9UXloynD1TNyct9wPpjHprbOYH2sPOK6q1cGGzWeYz
nrXkl2lUeGg5Z+9qcjEjLNWXyYCDmdHgZH3sXFfT2Kw4PNCdUJxbM6/Oga1M
hpQ3SE/Ym8yawwXlSnI3shb9p7xAGafcjZnSW6KVcYm4Rx4yrWw2rAsPEbdf
3heUS6vnw+UJn5ZEIA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 901->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKxEAUbFyI1xBvoAcYvMJ4ggi6GhBmFoM7j64jGpLm1a/jwoZMJkm/
elX1qm+f3/avV621083Xz346Px6P0/vT9eXhZTo83B8uH+9+rtY+dm2+/4eL
rf67i+Hsc7GXfjH/KizFZQsm04KwEi79/qQP6oX09Dp6vhUXpkfVIX3IB8Yl
zajDX/VzMRgvxdnVrjxJcjjXCT8qbEer0th26979czIblU2lf7UWfBSXambM
rzgTv74QPMQF+YO4VFgrbUVftj/Ririofipzsd8B7pKLlTPAPcGunntsxb3a
z7xRvqBa18c0z4oX81NhMDzFJcWsFqtPfFF5GclwOlM3JyPnA+msants5gfa
w+ZVfRvhwnqzzCeejeSXaVR4aDmzdzW5mBWWqksy4GAmGpysb+3ratqaFYcH
OhOK82jm1RzYSjKkvEF63F5s5g4XlCvJ3cha9U55gTKutCfvXW97/xysvqb/
z/a752deBBdx+8vzMuOO1Hxz+QTwE0Lf
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 902->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLIQryHeQA8QcoV4ghF0FRCSRcjOo8eghklTv9cDYkMnzHS/
elX1ah5eP7bvq9ba4f7rZzsdN/v9dHq5uzy8Tbvnp93l8PFnt/a5btf//7DV
6s9TjOReij33S/mHsByXJZhKC8OqcOnvV/qwXkxPr6Pni7goPa6O6WM+KC7V
jCb8Xb8UQ/FynFPtzpNKDq91xg+EnWh1Gvvebe25pH6k+5fDzZrxcVzQzJRf
I5lAGtEZw0q5ICzX191PtTIurp/L3IjfKe6cS5Qzwr2CjZ57bMcd3VfeOF9Y
bepjNc+Ol/LTYSg8x6WKiZaqr/ji8jKS4epM05yMfB9MJ6rtsZUf7I6aFzob
4aJ6q8xXPBvJr9Lo8NhKZp9qSjERlqurZCDBrGhIsr60b6ppaVYSHuybcJxH
M+/moFYlQ84bpgfWFrOWcGG5styDrKF3zguWccW9+t55gWbCuCDuyEOlVfVO
z9W96vf1F/ubyxmK0kPh
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 903->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqwzAQFP0ouUbJDdoDhF7BPYELyZeh4HyE/vXorUkTzLLzWBlKBUps
Szs7Mxo9vX8Mp4fW2nn38zOMl9d5Hj/fHpeX4zi9PE/L4v53tvZ1aPf//zDZ
iOsuhrPPxV77xfzLsBSXLZhMC8KqcIn7K31QL6Qn6oh8My5Mj6pD+pAPjEs1
ow5/1c/FYLwUZ1e78qSUw1ud8CPDdrQqjbE36tPjhztvHNaT5Tk+Z2fG/OrJ
BOIS1xCWyyXDUn3Vflcr4qL6qcz1+O3irrlYOQPcK9jZe8RW3LP9zBvlC6p1
fazmWfFifioMhqe4VDGzweorvqi89GS4eqZuTnruB9KZ1UZs5gfaw84rW+vh
wnqzzFc868kv06jw0HDO3tXkYmZYqq6SAQezosHJ+ta+rqatWXF4oDuhOPdm
Xp0DG5UMKW+QnrS2mDWHC8qVy51lLfvm4iF+Ctv5rrzIzgRxYV5kz4532VDr
bF/1fv3FvHL5BjW0Q6I=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 904->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKAjEUDLMQrzF4A+cAMlfQE7SgK2FAF4M7j+6HGWkerz4v7cJAbLuT
V6+qUvnc/qz3H6210/z2sx5+v4/H4byZ3V92w+FrebgvLv5ma5dVez7fYbIR
110MZ5+LPfaL+ZdhKS5TMJkWhFXhEvdX+qBeSE/UEflmXJgeVYf0IR8Yl2pG
Hf6qn4vBeCnOrnblSSWHzzrhR4btaFUaM71Znx4/3PmvPz5RnuN/pAH51ZMJ
xCWuISyXS4al+qr9rlbERfVTmevx28Udc7FyBrhXsLP3iK24Z/uZN8oXVOv6
WM2z4sX8VBgMT3GpYmaD1Vd8UXnpyXD1TN2c9NwPpDOrjdjMD7SHnVe21sOF
9WaZr3jWk1+mUeGh4Zy9q8nFzLBUXSUDDmZFg5P1qX1dTVOz4vBAd0Jx7s28
OofHWI0m0erkGXmD9KS1xaw5XFCuXO4sa9k3Fw/xU9jOd+VFdiYpv4LnFe+y
QddHXFQeXnlf4Lk6ex5crs8iQyA=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 905->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqwzAUFF2UXKPkBu0BQq/gnMCBZGUouIvSXY/ehJRiHm8+T+qiAsWx
pTdvZjR6Or1Nl4fW2vvu+jPNH6/rOn8eH28v53l5eV5ui/uf2drXof0+/8Nk
I667GM4+F3vrF/Mvw1JcRjCZFoRV4RL3V/qgXkhP1BH5ZlyYHlWH9CEfGJdq
Rh3+qp+LwXgpzq525Ukph5vJ/MiwHa1KY6Y369PjhzO3+h3/szWkAfnVkwnE
Ja4hLJdLhqX6qv2uVsRF9VOZ6/Hbxd1ycTQh7hXs7D1iK+7ZfuaN8gXVuj5W
86x4MT8VBsNTXKqY2WD1FV9UXnoyXD1TNyc99wPpzGojNvMD7WHnla31cGG9
WeYrnvXkl2lUeGg4Z+9qcjEzLFVXyYCDWdHgZH20r6tpNCsOD3QnFOfezKtz
YKOSIeUN0uP2YmfucEG5crmzrGXfXDzET2E7311vo38OVqyJ/x3vsuFmSOXh
L+/LyLxz+QbN2EMk
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 906->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktqAkEUbFyEXEO8QTyA5Ap6ghHiShDMIrjz6H4J4+PV5/VkkYbWGbtf
varqanC+Pax3s9ba9/v1Yz38fB6Pw2nzdnv5GvbLj/1tcfGcrZ1X7ff7P0w2
4rqL4exzscd+Mf8yLMVlCibTgrAqXOL+Sh/UC+mJOiLfjAvTo+qQPuQD41LN
qMNf9XMxGC/F2dWuPCnl8DmVHxm2o1VpvA9R1+uHO1+4CP+ztayG+VXNBOMy
5lDJAPOZ+pH0ZfsrWp0zQc9Me9XvCu6Yi6MJca9gZ+8RW3HP9jNvlC+o1vWx
mmfFS90l5R/CU1yqmNlg9RVfVF56Mlw9UzcnPfcD6cxqIzbzA+1h55Wt9XBh
vVnmK5715JdpVHhoOGfvanIxMyxVV8mAg1nR4GR9al9X09SsODzQnVCcezOv
zuE+Vu3lfw/S6uQZeYP0uL3YmTtcUK5c7ixr2W8uHuKnsJ3fXW+jfw5WrInP
jnfZcDOk8vCX92XKfHC5AMn/RWE=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 907->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKwkAQWzyI3xB/oA8Qv1BfUEFPBaEexJtP16JIGWeSzNaDC2ttdyeT
ZLPLw7k5zUopl8Xzp2mvu75vb/v58HJsu826GxZX71nKfVs+z3+YaNh1FUPZ
p2KP/UL+eViMyxRMpCXCynCx+zN9ol6RHqvD8vW4ID2sLtIX+YC4ZDOq8Gf9
VAzEi3FWtTNPMjlEWIy3opVp9PR6fWr8UOeHy2iiPH/VBRoiv2QPBS5jDpkM
IJ8tFuvL9qv5j7iwfixzGQ7eOtuv5g9xz2B77xabcff2I2+YL1Gt6mM2z4wX
8pNhIDzGJYvpDVSf8YXlpSbD2TNVc1JzPyKdXq3FRn5Ee9B5eWs1XFBvlPmM
ZzX5RRoZXjSUs1c1qZgeFqvLZEDBzGhQsj61r6ppalYUHtGdYJxrM8/OAY1M
hpg3kR61FzpzhUuUK5U7ypr3TcWL+DFs5bvqrfVPwbI19r/inTfUDLE8/PK+
TJkvLg8yr0Xh
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 908->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktuwjAUtFggrlFxg/YAEVcIJwhSu4qElC4qdj06EFBF3Tef53SBJUMS
2/Nm5k2kvByO/ceqlPK5ufz0w9dumobTfn29eR/Gt9fxuri9z1K+u/Lz/wyT
jXrdxXD2udiPfjH/IizFZQkm04KwMlzq/Zk6qBbSU+uo+UZcmB51DulDPjAu
2YzO12Y/WN/cemjfPAgXV7vyJJNDhqW8lloNjZHeqE6LH+6suRSRZ3TO9SuT
Y8XlkUMmA8znP36Iumq/q5X2hNRTmUv5Hayr/W7+GPcMdnRfYyvu0X7mjfIF
nXV9zOZZ8WJ+KgyGp7hkMaPBzmd8UXlpyXC2p25OWt4PpDM6W2MzP9Ae1q9o
rYULq80yn/GsJb9Mo8JDw+m9q8nFjLDUuUwGHMyMBifrS+u6mpZmxeGB3gnF
uTXzqg/z6Mqv73ak1ckz8gbpCc8ms+ZwQblyubOsRc9cPMRPYTvPlRdRTxAX
5kV07XgXDTdDKg//+b4smTcuZzwsRt0=
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 909->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbFyI15DcIDmAeAVzggkkqwFBF+LOoycmQYbnq8/rcWFDa890
d72qejXrj/3ua9FaO65+fnbDaXs4DOf35fXhcxjfXsfr5sv/bO2yabf/Z5hs
xH0XwznnYk/9Yv5lWIrLHEymBWFVuMTzlTqoFtITdUS+GRemR91D+pAPjEs1
o79rsx+sb249dO42HpBndr+SQ4alvHa0Ko2Z3qxOjx/ObNM56Q/Lc1wjDcgv
6kfCj3GZcqhkgPkcsVRddd7JC+J75w9YM+0VDtm+Ou/mj3GvYGfPEVtxz84z
b5Qv6K7rYzXPihfzU2EwPMWlipkNdr/ii8pLT4arPXVz0vN9IJ3Z3YjN/EBn
WL+yvR4urDbLfMWznvwyjQoPDaf3riYXM8NS9yoZcDArGpysz63rapqbFYcH
+iYU597Mqz6wUcmQ8gbpcWuxnjtcUK5c7ixr2TsXD/FT2M5719von4MV78S1
41023AypPDzye5kz/7h8A61ARGE=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 910->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcQrxBPMIKuAkJciDuPrglBkuerX48LGzqZmX5d
r6q6+vrpdfNyMcZ4u/r+2SzvD7vd8vF4uX95XrZ3t9v94s1xjvF5P37+/8Nk
o667GE6di33qF/Ovw1Jc1mAyLQgr4VLrkz6oF9JTdVS+HRemR+1D+pAPjEua
0cPzcTq8lZezd+JsBGfl+Mz4Mc6uHx22oxXmHtShPjN+WDobLoPgdlyQBuQX
87DmQnE55ZBkgPl8hmX0rc9df2cdcVH9VOYSDt26qnfzx7gn2N17xVbcu3rm
jfIF7XV9TPOseDE/FQbDU1xSzG6w/YkvKi8zGU7P1M3JzP1AOru9FZv5gWrY
eXVrM1xYb5b5xLOZ/DKNCg8N5+xdTS5mh6X2JRlwMBMNTtbX9nU1rc2KwwPd
CcV5NvPqHNhIMqS8QXrcXuzMHS4oVy53lrXum4uH+Cls57vrbfXvF7/A88S7
bsgMmXn4y/sCz9WpOXD5Ao6sRls=
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 911->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbFyI15DcIB4g5ArmBBPQlRDQRXDn0VWSiPN89Xk9WdjQOjP9
urqqXvXy82u9nbXWDovLz3r4ft/vh+PH/PqyGXar19118eV3tnZ6a7f/Z5hs
xHUXw6lzse/9Yv5lWIrLFEymBWFVuMT6yjnoLKQn6oh8My5Mj9qH9CEfGJdq
Riv9YHXueahuNAq9cnyGGRK6/2qUHym2oXXEI8yHDAC+vX4ozYhLu68xuGQ9
Y34xD7NeII2jfYCLszfT4+rInrPznXXERZ3HNFU5ZOuq3s0f417Bzt4jtuKe
1TNvlC9or+tjNc+Kl3N/mH8IT3GpYmaD7a/4ovLSk+FqT92c9NwPpDPbG7GZ
H6iG9Stb6+HCzmaZr3jWk1+mUeGh4fTe1eRiZlhqXyUDDmZFg5P1qee6mqZm
xeGB7oTi3Jt51Qc2KhlS3iA97lms5w4XlCuXO8ta9s3FQ/wUtvPd9Tb652DF
PfHZ8S4bboZUHv7zvkyZP1zOY0VDnA==
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 912->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktqQkEQbFxIrhG8QXIA8Qp6gickKyGgC3GXo6v4iZlUVVfPy8KBp8/5
VFdV14Cv66/l5yQidi+nj+WwX2y3w2E1Pf/4GDbvb5vz4uz6RHzP4/79DI8a
7bqL4exzsR/9Uv4hrIzLGEylhWFVuLT7K3VYLaan1dHyRVyUnuwc08d8UFyq
Ga30Q+1z67F9lXWHi8tPcXb9QNiOll9zt/nrO+wRyVCPH5ZOwCUELuKCeqb8
Uh6G4irwGBfnLNLj6kDvqL6zzrhk9bL8Vzig9Wy/mz/FvYKNfrfYGXe0X3mT
+cLOuj5W85zxcu6P8o/hZVyqmGio8xVfsrz0ZLjaUzcnPfeD6URnW2zlB9uj
+oXWerio2irzFc968qs0ZnhsOL13NbmYCCs7V8mAg1nR4GR9bF1X09isODzY
ncg492Y+68N9zOPn/yvR6uSZecP0uLVUzx0uLFcud5U1NOfiMX4ZtjPvetv6
94dfwfOKd2i4Gcry8J/3Zcxz4XIEITZGnA==
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 913->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tOwzAQtbpAXANxAzhA1CuUEwQJVpWQygJ1x9FLAUEw7zcOCyy5TTKe
N2/ePF/dP+0eN62158u3n938sj0c5uPdxfnlYd7f3uzPwevP3drr1L7+/8NW
q4+nGMm5FHupl9IPYTkuazBVLwyrwqU/X6nDarF++j56voiL6sflsf6YDopL
1aOVeahzaT12rhJPuKT8FOdUD4Sd9PLj2zKHzWj6jlVnU+2xr/eLW8gFzUzp
pTTs6/VcGR7jwvRhXBCWykXPqH4SZ1xcPef/CgcUd+dT/ynuFWz03mM77ui8
0sbpwnJTHat+dryUng5D4TkuVUy0VH5FF+eXEQ9XZ5r6ZOR+sD5Rbo+t9GBn
1LxQbISLqq08X9FsxL+qR4fHVjL7tKcUE2G5vIoHEsxKD4nX19ZNe1rrlYQH
uxOO86jn3Rze17TYotfEz0wb1g/MLXot4cJ8lXJXXkPfUjzGz2En350WaCaM
i9ICPSfaoZV6yPnhL+/Lmv3B5QQBBEeY
                    "], {{0, 35}, {35, 0}}, {
                    0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 914->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktuAjEUi1hUXANxg/YAqFeAE0yldoWEBAvUHUfnU1Qxj2c/O9NFIwWG
SeJn+zkSi4/d+mvWWjvMLx/r4fi+3w/fm5frj89h+/a6vS4u77O106r9fv+H
yUZcVzGUfSr2o1/Mvwyr4jIFk2lBWA6XuN+pg2ohPVFH5JtxYXqqc0gf8oFx
cTPq9IPtU+uhfc66wkXlxzirfmTYipbRO5C9Ua377OmNq/Gx5khP4FtxyXrG
/GIeRu1MY/TRyQDikmFVdav9Sl4Q3yd/wDPT7nDI1qv9av4Ydwc7+x2xK+7Z
fuZN5Qs6q/ro5rnipdwf5h/Cq7i4mNlg5x1fqrz0ZNjtqZqTnvuBdGZnIzbz
A+1h/crWeriw2izzjmc9+WUaKzw0lN6rmlTMDKs652RAwXQ0KFmfWlfVNDUr
Cg90JyrOvZmv+nAbq/b039XxXfEG6VFrsZ4rXFCuVO4sa9k7FQ/xq7CV96q3
0T8FK56Jz4p32VAzVOXhL+/LlPnD5QxU7kbd
                    "], {{0, 35}, {35, 
                    0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 915->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lKBEEQLDyI3xB/oA8QvzC+oAU9DQjjQbz5dB0cGifJ2Ko9WNCzdGVF
RkRGXT+97l4uxhhvV98fu+X94XBYPh4vj3+el/3d7f64eXN6xvi8H+v3f3jY
qvsuhlPnYv/2i/nXYSkuWzCZFoSVcKn1SR/UC+mpOirfjgvTo84hfcgHxiXN
aDIPVuf2Q3XJvsPF5cc4u3502I6Ws3cge2e9Ts/MbFKN9ey6Cl/FpZsZ84t5
WLUzjdXHJAOIS+uH6KvqnbzYMwG9mfaEQ7ev6t38Me4Jdve/YivuXT3zRvmC
zro+pnlWvJz7w/xDeIpLitktdj7xReVlJsPpTN2czNwPpLM7W7GZH6iGzavb
m+HCerPMJ57N5JdpVHhoObN3NbmYHZY6l2TAwUw0OFnf2tfVtDUrDg90JxTn
2cyrOaxLZJ/57niD9MCzwcwdLihXLneWte6di4f4KWznvfKimwniwrzofjve
dcvNkMrDX96XLc8Ply+xhkYe
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 916->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lKBEEQLDyI3xB/oA8QvzC+oAU9DQjjQbz5dB2URnMytmoPFvQsXZlR
EZFRlw/Pu6ezMcbLxefHbnm9OxyWt/vz45/HZX9zvT9uXn0/Y7zfjvX7Pzxs
1X0Xw6lzsX/6xfzrsBSXLZhMC8JKuNT65Bx0FtJTdVS+HRemR/UhfcgHxiXN
aDIPVueeh+qSfYeLy49xdv3osB0tv96B7HV1M7NJNdbedYk8oz7XL+Zh1c40
Vh+TDCAuJxqNc0/8a8539p2ZoLOZ9oRDt6/q3fwx7gl2979iK+5dPfNG+YJ6
XR/TPCtezv1h/iE8xSXF7BbrT3xReZnJcDpTNycz9wPp7HorNvMD1bB5dXsz
XNjZLPOJZzP5ZRoVHlrO7F1NLmaHpfqSDDiYiQYn61vPdTVtzYrDA90JxXk2
82oO6xLZZ7473iA9sDeYucMF5crlzrLWvXPxED+F7bxXXnQzQVyYF91vx7tu
uRlSefjL+7Ll+eLyAbK+SBw=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 917->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcQrxBPMIKuAkJcSHY5ehKUoI/6vZ6FNkwyM/1e
dVW9mtuX983b1Rjj4+b0s1k+n3a7Zf98fX54XbYP99vz5t33NcbhcVz+/8Ol
Vt1PMZK6FPunX8o/hOW4rMFUWhhWh0ut75zDzmJ6qo7KF3FRelwf08d8UFy6
Ge3MQ9Wl57G6zn7CJeWnOKd+IOxEy693JHuobmY2XY2197IqZ8MFzUz5pTxU
OhSe8tP1Ij11Xurces80uP1kJuxspb3DAe27+jR/insHGz1XbMcd1StvnC+s
N/Wxm2fHK/l+lH8Mz3HpYqKl+ju+uLzMZLg70zQnM98H04l6K7byg9WoeaG9
GS7qbJX5jmcz+VUaHR5byexTTSkmwnJ9nQwkmB0NSdbXnptqWpuVhAf7Jhzn
2cy7OaB7pjXBYN4wPao3nXnCheUq5a6yht6leIyfw07eOy/QTBgX5QW6T7xD
q+Nbmpe/vL64HAFguUfd
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 918->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqw0AQW/JRco3QG7QHCLmCewIX2i9DwP0o+cvRU4dS0snoMWsKXXBi
e3c0kkbevR6H901r7WP79TOMn4d5Hk8vD8vD2zg9P03L5uP31dp5337+/8PF
Vtx3MZxzLvatX8y/DEtxWYPJtCCsCpd4vtIH9UJ6oo7IN+PC9Kg6pA/5wLhU
M1qZBzvn9kPnKvsOF5cf4+z6kWE7Wn69A9nLzvXMpqox1iKNiks2M+YX85Dp
YHhMg6rN9MR5sb7xHmlQ+2wmLeETsRzsHo53z8Qzp3eFq8qgyhDqk51n3ihf
UK3DpSfPipfz/TD/EJ7iUsXMFquv+KLy0pPh6kzdnPR8H0hnVhuxmR/oDJtX
ttfDhfVmma941pNfplHhoeXM3tXkYmZYqq6SAQezosHJ+tq+rqa1WXF4oG9C
ce7NvJrDdRnZZ7473iA9rNaducMF5crlzrKWvXPxED+F7bxXXmQzQVyYF9m9
4122ZIZuLjcvf3k1tX/lcgEkPUac
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 919->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcQrxBPMIKuAkJcSHY5ehIJEh6vfj0INnQyM/26
uqpe9f3b5+bjZozxdXf62SzfL7vdsn+9Pb+8L9unx+158eEyxzg8j9///zDZ
qOsuhlPnYl/7xfzrsBSXNZhMC8JKuNT65Bx0FtJTdVS+HRemR+1D+pAPjEua
0aQfrM49D9Ul6w4Xlx/j7PrRYTtalEbladKbVGPdizQqLl3PmF/Uj8t0NFYf
kwwwrRVLnavqnbyonrDzVOYSDt26qnfzx7gn2N17xVbcu3rmjfIF7XV9TPOs
eDn3h/mH8BSXFLMbbH/ii8rLTIbTnro5mbkfSGe3t2IzP1AN61e3NsOFnc0y
n3g2k1+mUeGh4fTe1eRidlhqX5IBBzPR4GR97bmuprVZcXigO6E4z2Ze9aF7
RlodDOQN0sP2uj13uKBcudxZ1rpvLh7ip7Cd78qLrieIC/Oie3a864bM0NV0
8/KXc6j1Hy5HqlBHng==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 920->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbLIIXiN4Az1A8ArmBCPoSgjoQrLL0ROJiDT16tPjIgOjM9Pv
VVfVq37bfW4PL6218+L3ZztdNqfT9PXxen3ZT8f16nhdXN7u1r7f2/3/P9zs
6tddDKfOxX70i/mHsBSXOZhMS4WVcOnrk32qvSo9vY6eL+LC9Ki+Sl/lA+OS
ZjSZB6tz96vqknWHi8uPcXb9QNiOFqUR4g7OJtXY945yQTNjfik/nJn0eEyD
6kV6XB3oudKg1tlM2H4qcwkHtK7q3fwx7gk2eu+xFXdUz7xRvlS9ro9pnhUv
5/ww/yo8xSXFRBfrT3xReRnJcDpTNycj56PSiXp7bOZHVcPmhdZGuLC9WeYT
z0byyzQqvOpyZu9qcjERlupLMuBgJhqcrM/d19U0NysOj3ufWxfgJufg0d8G
9kt8d7yp9LBed+YOlypXLneWNfTNxav4KWznu/ICzaTiwrxAz4536JIZMvPw
zPMy5/7j8gNiIUge
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 921->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLIQryHeQA8guUI8wQi6CghxIdl59BgMIs/6vZ6FNnQyM92v
uqpe9c3T6+5lM8Z4u/782S3v28NhOT5enV+el/393f68eHuZY3w8jO///zDV
qOspRrIvxf7pl/IPYTkuazCVFobV4VL3d85hZzE9VUfli7goPa6O6WM+KC7d
jHb6ofal57F9nfWES8pPcU79QNiJFqfRedrpTVdjrYUaAy6oZ8ov50fiQ8Vz
fqZcfmEF59ZnpsGtq56o81zmOhzQutuf5k9x72Cj94rtuKP9yhvnC6tNfezm
2fFK7o/yj+E5Ll1MNFR9xxeXl5kMd3ua5mTmfjCdqLZiKz/YHtUvtDbDRZ2t
Mt/xbCa/SqPDYyPpfaopxURYrq6TgQSzoyHJ+tpzU01rs5LwYHfCcZ7NvOsD
emZaEwzmDdOjatOeJ1xYrlLuKmvoW4rH+Dns5LvzAvWEcVFeoOfEOzRshi6z
k5e/nF9cTrZRSV0=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 922->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriG5gTmAeIXkBCOYVUBIFuLOo+dDIqZ59etBsKHn1/2q
q+rVPL19rLcPrbXD4nRZT5+v+/30tXk8v7xPu9Xz7ry4vM7Wvl/az/0/TDb6
dRfD2edi//aL+VdhKS5zMJkWhJVw6fcn56CzkJ5eR8+34sL0qDqkD/nAuKQZ
TfrB9rnnoX3JusPF5cc4u35U2I4WpVF5mvQm1djXlhoNLlXPmF/KD8iTeKz8
dLnc3W+T1FbPSINad3qCzk6ylHJU+938Me4JdvXeYyvu1X7mjfIF1bo+pnlW
vJifCoPhKS4pZjVYfeKLystIhtOeujkZ+T+Qzqq2x2Z+oD2sX9XaCBd2Nst8
4tlIfplGhYeG03tXk4tZYam6JAMOZqLByfrcc11Nc7Pi8ED/hOI8mnnVh8sw
ss98d7xBelit23OHC8qVy51lrfrm4iF+Ctv5rryoeoK4MC+qZ8e7asgMdZl1
8vKXs6n1C5cjCDJJmg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 923->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFxIriHeQA8gXiGeYARdBYRkIe48ugZlCI9Xvx4XNkxmJt2v
XlW9mpvnt/3r1RjjtPv+2S/vj8fj8vF0fX55WQ73d4fz5u3vNcbnw1jv/+Fi
q+67GM45F/vSL+Zfh6W4bMFkWhBWwqWeT/qgXkhP1VH5dlyYHlWH9CEfGJc0
o8k82Dm3HzqX7DtcXH6Ms+tHh+1oURqVp8lsUo21dpZLNzPml/ID9iYeKw0u
l3Wv3Fnf+ow0qP2WS9GNeifzSzmq827+GPcEu3uv2Ip7d555o3xBta6PaZ4V
L+anwmB4ikuK2S1Wn/ii8jKT4XSmbk5mvg+ks6ut2MwPdIbNq9ub4cJ6s8wn
ns3kl2lUeGg5s3c1uZgdlqpLMuBgJhqcrG/t62ramhWHx1rnngtwk+/g0t/R
9Et8d7xBelitO3OHC8qVy51lrfvPxUP8FLbzv/Kimwniwrzonh3vuiUzZObh
L7+XLdcPly/DJEpZ
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 924->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbLIQryHeQA8guUI8wQhmFRDiQrLz6DEoQR71ez0LbZhkZvq9
6qp6NXcvb7v9Zozxfvv1s1s+tsfjcnq+uTy8LofHh8Nl8/7nGuPzaVz//8Ol
Vt1PMZK6FPu3X8o/hOW4rMFUWhhWh0ut75zDzmJ6qo7KF3FRelwf08d8UFy6
Ge3MQ9Wl57G6zn7CJeWnOKd+IOxEi9PoPO3Mpqux9s5yQTNTfjk/krMrntOQ
crnuhTrQPdPg9iEXkauKlWDPcHT1af4U9w42eq7YjjuqV944X1hv6mM3z45X
8v0o/xie49LFREv1d3xxeZnJcHemaU5mvg+mE/VWbOUHq1HzQnszXNTZKvMd
z2byqzQ6PLaS2aeaUkyE5fo6GUgwOxqSrK89N9W0NisJD/ZNOM6zmXdzQPdM
a4LBvGF6VG8684QLy1XKXWUNvUvxGD+Hnbx3XqCZMC7KC3SfeIdWx7c0L395
fXM5A/sSSxw=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 925->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0EKwkAQWzyI3xB/oA8Qv1BfUEFPBaEexJtP1xYpMswkmS2CC9W2s5NN
Mun6dG0ui1LKbfX+adr7oe/bx3E5PJzbbrfthuLmc5Xy3Jfp/x8utGxdxVD2
qdjffiH/PCzGZQ4m0hJhZbjY/ZlzorMiPVaH5etxQXpYX6Qv8gFxyWY0Mw+0
Tz0v2pepK1xUfoiz6oeHrWhhGpmnmdlkNdreWi7ezJBfzI8Mb9uHfFe4TDVR
h3cfaWB1lwvR/I2lYNdwZPvVuSHuGWzv2WIz7t5+5A3zJepVfczmmfFCfjIM
hMe4ZDG9hfozvrC81GQ4O1M1JzXfR6TT67XYyI9oD5qXV6vhgs5Gmc94VpNf
pJHhRUuZvapJxfSwWF8mAwpmRoOS9bnnqprmZkXhEX0TjHNt5tkcxiVkH/mu
eBPpQb3qzBUuUa5U7ihr3jsVL+LHsJX3zAtvJhEX5IV3r3jnLZohk1klL7+8
CquPXF6h7kqa
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 926->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNVktqAkEUbFwEryG5gTmA5ArmBBNIVoKgC8nOoxtJENPU7/W4SMPojN2v
XlW9GnD1vt9+Llprx+X3x3Y6vR4O09fb0/XhY9q9rHfXzeffq7Xzpt2+/8Ol
Vr+fYiTnUux7v5R/CMtxmYOptDCsCpf+fKUP68X09Dp6voiL0uPqmD7mg+JS
zWhlHupc2o+dq+wnXFJ+inPqB8JOtDiNztPKbKoa+9pRLmhmyi/nR4V3X6d8
T7jc9pwOwoH1T/YhF6P5HivBHuHozqdzU9wr2Oi5x3bc0XnljfOF1aY+VvPs
eCk/HYbCc1yqmGip+oovLi8jGa7ONM3JyPvBdKLaHlv5wc6oeaG9ES6qt8p8
xbOR/CqNDo+tZPapphQTYbm6SgYSzIqGJOtz+6aa5mYl4cHeCcd5NPNuDuie
aU0wmDdMj6pNZ55wYblKuausod9SPMbPYSe/Oy/QTBgX5QW6T7xDK8rQpv35
34x6PfJ9mXP9cLkA5iRLGg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 927->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAkEUbFwEryHewBwg5ArmBCMkKyGgi+DOo6tEJDSvfj0gaRidmX6v
uqpezWr3vf1atNaOy+vPdvp5Pxym08fL7eFz2r9u9rfN9f1q7fzWHv//4WKr
33cxnDoX+69fzL8KS3GZg8m0IKyES1+fnIPOQnp6HT3figvTo/qQPuQD45Jm
NJkHq3PPQ3XJvsPF5cc4u35U2I4WpVF5mswm1dj3jnKpZsb8Un4kvPs+5rvD
pcop663ukQa178wTnZ3ML+Wo6t25Me4JdvXcYyvuVT3zRvmCel0f0zwrXiOZ
Qmc62EirwqwW6098UXkZyXA6UzcnI98H0ln19tjMD1TD5lXtjXBhZ7PMJ56N
5JdpVHhoObN3NbmYFZbqSzLgYCYanKzPPdfVNDcrDg/0TSjOo5lXc6jukVYH
A3mD9LBed+YOF5QrlzvLWvXOxUP8FLbzXnlRzQRxYV5U94531XJ8Y3lOvq9n
XL9cLvr4TNs=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 928->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHLIQrxG8gR5AvEI8wRPMKiDEhbjL0WMwiDT163kgDrz8pru6
qrqyfXnb7TdjjPfbr5fd8vF0PC6fzzeXL6/L4eH+cLm8uz5jnB7Hz/t/eNSp
9ylGUpdi//ZL+YewHJc1mEoLw+pwqfWdOWwW01N1VL6Ii9Lj+pg+5oPi0s1o
Zx+qLp3H6jr3CZeUn+Kc+oGwEy1Oo/O0s5uuxto7ywXtTPnl/KCzhcdOQ8oF
5RT2XvlUDmx+cp/sE84zmetwQPeuPs0f4p7mMtklqmdzUL3yxvnCelMfu3l2
vGYyxWYm2Eyrw0RH9Xd8cXmZyXB3p2lOZv4fTCfqrdjKD1aj9oXuZrio2Srz
Hc9m8qs0Ojx2kt2nmlJMhOX6OhlIMDsakqyvnZtqWpuVhAf7TzjOs5l3e1Cn
kyHnDdOTzlI7T7iwXKXcVdbQbyke4+ewk99Tb6t/CZfaUz8n3qGT+KbynOzj
L59vLmcPrExZ
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 929->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPwIuUbwBnqA4BXWE2zAfC0Im4/gX46uQZHYdD16xo8sbDa7
01NdVV2zO7xPx4fW2mn79TPN55d1nT9eN9eXt3l5flqui48/d2uXfft93sPN
rrjuYjh1LvatX8y/DEtxGcFkWhBWhUusr/RBvZCeqCPyzbgwPWof0od8YFyq
Ga3Mg9W5/VBdZd3h4vJjnF0/MmxHi9KoPK3Mpqox7u3lks2M+aX8qPCO+5jv
Dpc/nAzOkQPq76w788z6qcxVOGTrqt6dG+Newc7eI7bintUzb5QvaK/rYzXP
ildPplBPBxtpVZjZxfZXfFF56clwdaZuTnrOB9KZ7Y3YzA9Uw+aVrfVwYb1Z
5iue9eSXaVR46HJm72pyMTMsta+SAQezosHJ+mhfV9NoVhwe6Ewozr2ZV3PI
/iOtDgbyBulxe7GZO1xQrlzuLGvZNxcP8VPYznfX2+gfPQOdGUJcUL3Mo8jD
f56XkfubyycDD0wa
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 930->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU11KAzEYDH0QryHeQA9QeoV6ghX0qSC0D6VvHr1WZVnCN39ZEANpdzfJ
fDPzTR5eP/bvm9ba6f7rZz+dd8fjdHm5u728TYfnp8Nt8fF3tva5bfP/f5hs
9OsuhrPPxV76xfyrsBSXNZhMC8JKuPT7kzqoFtLT6+j5VlyYHnUO6UM+MC5p
RpN+sH1uPbQvWXe4uPwYZ9ePCtvRojQqT5PepBr7s6Ncqp4xv6gfIe8lhyQD
iMu8tl1MwrnnwDxU604/q3rzmpGDEY5qv5s/xj3Brt57bMW92s+8Ub6gs66P
aZ4Vr5FMoZoONtKqMKvBzie+qLyMZDjtqZuTkfuBdFZne2zmB9rD+lWtjXBh
tVnmE89G8ss0Kjw0nN67mlzMCkudSzLgYCYanKyvretqWpsVhwe6E4rzaOZV
H9hIMqS8QXrcWqznDheUK5c7y1r1zcVD/L6fCbbzXXlR9QRyIV5Uz4531bB8
I3lO7tdfzB8uV2MzTFc=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 931->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1sKwkAQW/wQryHeQA9QvIKeoIJ+CYJ+iH8e3SdapjNJZgviQq3tzmST
TDrdHFa7USnlNLn/rNrz8nhsL+vx42Hb7hfz/WNz9r5KuTblc/+HCy27r2Io
dSp21y/kn4fFuAzBRFoirAwXW585Jzor0mN1WL4eF6SH9UX6Ih8Ql2xGM/NA
dep5UV1mX+Gi8kOcVT88bEUL08g8zcwmq9H21nLxZob8Yn487yLvXh/wXeHS
y2nzvfc4N999lgdlX5mn1dytK6BP5eDts3o1f4h7Btt7ttiMu1ePvGG+RL2q
j9k8M141mYrOVLAjrQzTW6g/4wvLS02GszNVc1LzfUQ6vV6LjfyIatC8vL0a
LuhslPmMZzX5RRoZXrSU2auaVEwPi/VlMqBgZjQoWR96rqppaFYUHtE3wTjX
Zp7NAa1Mhpg3kR71LDRzhUuUK5U7ypr3TsWL+LFsK++ZF95MVC62x/5XvPOW
5BvIc+b7+sX14nIDCclK2Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 932->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3oo+UbpD9oHmH7BeYEDzclQcA4ltzw9cRrcMBlpNGMoXdg4
yc5oJY38svvq90+ttcPm8tEP3x/TNBy3z/OPz2F8fxvnw9fbbu3UteX5HzZb
9lzFUOpU7Hu/mH8eVsRlDSbTgrAyXGx95h50F9JjdVi+HhemJ+pD+pAPjEs2
o5l5sDr1PlSXOVe4qPwYZ9UPD1vREmmMPM3MJqvR9la5eDNjfkV+XJ8i74c+
4rvChXF64Nz97igPyrkyT8vrvq4JOahwjOrV/DHuGWw4D6ce3ePVM28iX1Cv
6mM2zxGvSqbQnQo20hpheov1Z3yJ8lLJcHamak4q7wfS6fVabOYHqmHz8s4q
XNjdLPMZzyr5ZRojPLSU2auaVEwPK+rLZEDBzGhQsr72XlXT2qwoPNA7EXGu
Zj6aA1uZDEXeID3qXWzmCheUK5U7y5r3n4qH+C2/kxmqeGv9U7Bsj/2ueOct
xTeWZ2Uef7l/uJwBjrlNlg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 933->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1FKA0EQRAc/JNcQb6AHEK8QT7CCfgWE+CH+eXQNmiCdrurXsyAOTDaz
M11TVV179fiyfb4YY7xuvn62y9v9fr+8P1weFk/L7vZmd9i8/pljfNyN0/M/
TDfiPsUg5yj2b7+cfxlWxWUNptOisDpc4vnOPeoupSfqiHwzLk5PVaf0KR8c
l25GO/1w5+h96lxnn3Ch/Bxn6keGTbRUGitPO73paoy1s1yynjm/Kj86vGOd
851wkT3KOB/XIA9kn/TzjJfQUHnW4Vidp32ruFPsbB2xK+7ZeedN5YuqpT52
81zxmsmUupNgK60VZjZcfceXKi8zGe72lOZk5vtQOrPaiO38UGdcv7K9GS7u
bpf5jmcz+XUaKzw1SO+pJoqZYVV1nQwQzI4GkvW191JNa7NCeKhvouI8m/mq
D6fncRqtJM/KG6WH3uV6TrioXFHuLmvZO4qn+FXY5D31NvpHsGJN/E+8ywbx
zeWZ9OMv5zeXT5TXT5Q=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 934->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqwzAUFF2EXKP0Bs0BQq6QnsCFZhUIJIvQXY/ehpZgxPyeDCUC29h6
bzQzb/z8ftofnlprl/XPbT9dd+fz9Pm2ur18TMfN6/G2+fJ3tfa1bffnI1xq
9fspRlKXYs/9Uv4hLMdlCabSwrAqXPr6yjnsLKan19HzRVyUHtfH9DEfFJdq
RivzUHXpeayusp9wSfkpzqkfCDvR4jQ6TyuzqWrse0e5oJkpv5wfKWfUp3xP
uNAZobNnew30JflOfGa8oYaib8m+q0/n5rin2Oi9x3bcUb3yxvnCelMfHafK
PFm9+o60MA1JZlNMtFR/xReXl5EMV2ea5mTk/2A6UW+PrfxgNWpeaG+Eizpb
Zb7i2Uh+lUaHx1Yy+1RTiomwXF8lAwlmRUOS9aXnppqWZiXhwf4Jx3k0824O
96fJvvI98YbpYfpaYeYJF5arlLvkCr6leIyfy3by3XmBZgL5zfLhPK94h1bi
m8pzMo//vH65fAPYoEzV
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 935->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk11KA0EQhAcfxGuIN9ADiFeIJ1hBnwJCfBDfPLoGf9g03VVfz4I4MEk2
011TVV17+fC8ezobY7xcfH7slte7w2F5uz8/Pjwu+5vr/fHw6nuP8X47fr//
w1YrnlMMUkex134p/zIsx2ULptJSYXW4xPrOPdVdlZ6oI/LNuCg9rq/SV/mg
uHQz2pmHqqP3VXWdc8KF8lOcqR8ZNtHiNDpPO7Ppaoy9s1yymSm/nB+I808v
1EC5EE7Zcnkg52Se2X3RF4fb5ejq6dwcd4qdPUdsxz2rV944X6pe6qPj1Jln
Va/+z7RUGkhmKWa2VH/HF5eXmQx3Z0pzMvN+VDqz3oit/Khq1Lyysxku6m6V
+Y5nM/lVGh1etcjsqSaKmWG5vk4GCGZHA8n61nuppq1ZITyqd8Jxns28m8NY
b6FF+U68qfRELmtOdOaES5WrtD7yN1nL/nNeVBk/+T2RocoX5yXhEmeSeai0
qrvJOckzmcdf7i8uH9kAThA=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 936->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPyQXEO8gR4geIV4ghX0KyAkH+KfR9eoBG3q1bMgDmw2u9Nd
U1Vde/XwvHu6GGMcNx8/u+Xl7nBYXu8vTw+Py/72Zn/avP6+xnjbjvP9P1xq
1f0UI6lLsX/6pfxDWI7LGkylhWF1uNT6zjnsLKan6qh8ERelx/UxfcwHxaWb
0c48VF16Hqvr7CdcUn6Kc+oHwk60OI3O085suhpr7ywXNDPll/Pj8+44b0mf
8D3hAjkVPmi5PCT7yTzRedUXh9vl6OrT/DnuKTZ6rtiOO6pX3jhfWG/qo+PU
mSerV++RFqYhyWyKiZbq7/ji8jKT4e5M05zMfB9MJ+qt2MoPVqPmhfZmuKiz
VeY7ns3kV2l0eGwls081pZgIy/V1MpBgdjQkWV97bqppbVYSHuybcJxnM+/m
cL6b7CvfE2+YHsqlMfOEC8sVrK/8TdbQO+cFy/iv/xMZYr44LxMudSbIQ6VV
nZ3sJ3lO5vGX1xeXd0FuTRI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 937->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA0EUbFyI1xBvoAcIXiGeYARdBYRkEdx5dA2GoI9Xvx4QGzozyftV
1avcPr9tX6/GGIebr4/tcnzc75f3p+vTl5dl93C/OwXvzneMj824PP/DZafG
3R5Ontv7p15Mv66XwrKmJ+OCeiVYan4yB81CfCqPirfDwvioOsQP6cCwpB5N
9sHy3HkoL4k7WFx8DLOrR9fb4aI4Kk2T3aQca+0slm5nTC+lh4V509cx3R0s
zo66o/zgxJ19jvOFHIy+KUaoaeg/pqnypbPL0cQh9oJFaaN0QbUOFgdTsk+U
z37vuCAOjmfdnt1h9Ykuyi/KZwnP1PddTcKP8exqa2+mB8ph++piM1jYbOb5
RLMZ/zKOqh86zu5dTm7PrpeqSzzg9Ew4OF5fO9fltNYrDg70n1CYZz2v9nB5
Cu8z3R1tEB+IJdi5gwX5qs2v+IXXut+UFsjjv94nPIR0UVoqLMpD9b3jymY7
cQeLs4+/vN9YPgEXy08Q
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 938->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lKA0EULVyI1wjeQA8QvEI8QQu6CgTiQtzl6BoU0e9/UzWIBZ10qD+8
KZuHw+7pYozxfPX+sVte7o7H5fX+8vzjcdnf3uzPl9efzxin7fj6/g8PO/Xe
neHUubO/68X062YpLGtmMi5oVoKl1id70C7Ep/KoeDssjI/qQ/yQDgxLmtHE
D1bn7kN1yb2DxcXHMLt6dLMdLoqj0jTxJuVYe2exdJ4xvZQeCe7ax3R3sDge
/TpGHpx7x89uX+p1ihFqGuaPaapy6Xg5mnuIvWBR2ihdUK+DZSbPClecqYYL
4uBk1p3ZHdaf6KLyonKW8Exz3/Uk/BjPrrfOZnqgGuZXdzeDhe1mmU80m8kv
46jmoeN473JyZ3azVF+SAWdmwsHJ+tq9Lqe1WXFwoP+EwjybeeUD4pno7miD
+HRYuhrmuYMF5aqtN7AmfnZaoIz/eJ/IkMKLtFRYVIbqu6NddxzdGBbHj798
PrC8AeNAUJI=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 939->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqQlEQO/RDuo3iDtoFSLegK7hC+yUU7EfpX5deRZEyJJnkXigeuL7O
TCbJxKf9x/b9YYzx+Xh62U5fr8fj9L1bnb+8TYeX58P5cn19xvjZjNv7PTzq
1HsXw6lzsf/6pfxDWB2XJZhKC8NKuNT6ZA6bxfRUHZUv4qL0dH1MH/NBcUkz
muxD1bnzWF1y73Bx+SnOrh8I29HSaew8TXaTaqy9c7mgnSm/Oj9ud4rHBvcp
3x0uakcDcIZ1YL5z7+wT8Uh3nXJk9bXGnZ1mrdah79UXh3vFV950vrBeh4vD
Kdknq1e/Iy3pnpHWDhMd1Z/40uWly1miM8096kn0KZ2ot2IrP1iN2he6m8NF
zVaZTzybk1+lscNjx9m9q8nFRFhdX5IBBzPR4GR96VxX09KsODzYf6LjPDfz
3R6YzsR3xxumB3FBNWrnDheWK1hvcE32ibxgGe+wurqOL/My5VJ76mfHO3Qc
3xSXxMP/eC5cfgHy4k8U
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 940->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FKQ0EQW/yQXkO8gR6geIV6gifYr4JQP8Q/j67FInVIMsk+EBe2r+3O
ZJNM3s3Ty25/NcZ43Xx97Ja3h+NxeX+8Pv14Xg73d4fT4e15j/GxHT/P/7DV
qucuhlPnYl/6pfxDWB2XNZhKC8NKuNT65B52F9NTdVS+iIvS0/UxfcwHxSXN
aDIPVefex+qSc4eLy09xdv1A2I6WTmPnaTKbVGPtneWCZqb86vz4dX7eXR47
DS4XNaMBOMM6cL9z7szz8n+owcBNObL6WuNoql65uUxm6XKv+MqbzhfW63CZ
yXPHK80U0pLOGWntMNFS/YkvaV4U3uxM3ZzMvB9MJ+qt2MoPVqPmhc5muKi7
VeYTz2byqzR2eGw5s3c1uZgIq+tLMuBgJhqcrK+919W0NisOD/ZOdJxnM9/N
gelMfHe8YXoQF1SjZu5wYbmC9QbXZJ7IC5bxDqur6/gyL1Mutad+d7xDy/FN
cUk8/Iv9zeUTVjxPlA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 941->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqwzAQFPkouUboDZoDmF7BPYELzZch4HyE/uXoqdtSyrIzOyNDqUAx
jnZH81gfXs/jaddau+w/fsbp+rws0/vLw/ryNs3Hp3k9fPzerd2G9vP8D5ut
eK5iKHUq9m+/mH8ZVsVlCybTgrAcLrHeuQfdhfREHZFvxoXpqfqQPuQD4+LO
qJMHq1PvQ3XOucJF5cc4q35k2IqWSmPlqZONqzH29nLJMmN+VX4outqQ9zHf
FS4so+z9cwU+kHNxLuluhQYB1+WI6mONoil6qM6lk6XKPeIzbypfUK/CReHk
5Inq2f+ZFjfnTGuFmS3W7/jizgvD681UnZOe7wPpzHojNvMD1bC8srMeLuxu
NvOOZz3zyzRWeGgp2auaVMwMq+pzZkDBdDQos771XlXT1llReKBvouLcO/NV
Dkin47viDdKTcclqWOYKFzRXWb3C1ckz8wLNeIVV1VV8kZcuF+Q508ruVs4V
Lo6Hf7G/uNwBN4FPVQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 942->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3Io+UboD5oHmH7BfYELzckQcA6htzw9dVtKGUYaaQ2lCxvj
7IxW0siH1/N42rXWLvuPn3G6Pi/L9P7ysL68TfPxaV4PH793a7eh/Tz/w2Yr
nqsYSp2K/dsv5l+GVXHZgsm0ICyHS6x37kF3IT1RR+SbcWF6qj6kD/nAuLgZ
debB6tT7UJ1zrnBR+THOqh8ZtqKl0lh56szG1Rh7e7lkM2N+VX4outqQ9zHf
FS5sRtn75xLyoJxLuluhQcB1OaL6WKNoih6quXRmqXKP+MybyhfUq3BRODnz
RPXs/0yLO+dMa4WZLdbv+OLmheH1zlTNSc/3gXRmvRGb+YFq2Lyysx4u7G6W
eceznvwyjRUeWsrsVU0qZoZV9TkZUDAdDUrWt96ratqaFYUH+iYqzr2Zr+aA
dDq+K94gPRmXrIbNXOGCcpXVK1ydeWZeoIxXWFVdxRd56XJBnjOt7G7lXOHi
ePgX+4vLHVbbT9U=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 943->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0FKQ1EQe7gQryHeQA9QvEI9wRd0VRDaRXHn0bUoRaZJJnkfxAe/5ffN
ZJJMevv8tn29GmMcbr4+tsvxcb9f3p+uTy8vy+7hfne6vPt5xvjYjPP3f3jU
qfcuhlPnYv/2S/mHsDouazCVFoaVcKn1yRw2i+mpOipfxEXp6fqYPuaD4pJm
NNmHqnPnsbrk3uHi8lOcXT8QtqOl09h5muwm1Vh7zyfkgnam/Or8uLhHPDa4
T/nucFE7Qu+qzsm343OXy3TXKUdWX2vc2Wnuax16Z1wU94qvvOl8Yb0OF4dT
sk9Wr35HWtI9I60dJjqqP/ElzYvCm92pm5OZ/wfTiXortvKD1ah9obsZLmq2
ynzi2Ux+lcYOjx1n964mFxNhdX1JBhzMRIOT9bVzXU1rs+LwYP+JjvNs5rs9
MJ2J7443TA/igmrUzh0uLFeo3uGa7BN5wTLeYXV1HV/mZcqFea60qtnOvcMl
8fAvnm8unwNGTxY=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 944->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FKA0EUG/yQXkO8gR6geIV6ghXsV0FoP8Q/j65FKeWR5CWzIA5My+68
l0nysncvb7v9zRjjtPn+2S3vT8fj8vF8e354XQ6PD4fz4f3vHuNzOy7//2Gr
Vc9dDKfOxb72S/mHsDouazCVFoaVcKn1yT3sLqan6qh8ERelp+tj+pgPikua
0WQeqs69j9Ul5w4Xl5/i7PqBsB0tncbO02Q2qcbaO8sFzUz51fnh6Bpb3Kd8
d7ioGaHny2ry0OXFnef1excr4YDOWX2tce9Os1br0DPjorhXfOVN5wvrdbg4
nJJ5snr1HmlJ54y0dphoqf7ElzQvCm92pm5OZr4PphP1VmzlB6tR80JnM1zU
3SrziWcz+VUaOzy2nNm7mlxMhNX1JRlwMBMNTtbX3utqWpsVhwf7JjrOs5nv
5sB0Jr473jA9iAuqUTN3uLBcoXqHazJP5AXLeIfV1XV8mZcpF+a50qruds4d
LomHf7F/uHwBDq9Plg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 945->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FKA1EQe/ghXkO8gR5AvEI9wQr6VRDqh/SvR2+LInVIMslbEB+8LtuZ
ySSZ2duX983b1Rjj4+b0s1k+n3a7Zf98fX55XbYP99tz8O77jnF4HD/P/3DV
qXEXw8lzsS/9Uv4hrI7LGkylhWElXGp+0of1YnqqjsoXcVF6ujqmj/mguKQ7
msxD5bn9WF4Sd7i4/BRn1w+E7WjpNHaeJrNJNdZai4tR1/nV+XHZa5SelUut
U747XNSMBuAM80B/J+7M85c/JlbCAcVZfs1xe9u7NjA2emdcFPeKr7zpfGG1
DheHUzJPlq/+R1rSOSOtHSY6qj7xJd0XhTc7U3dPZr4PphPVVmzlB8tR80Kx
GS6qt9r5xLOZ/VUaOzx2nNm7mlxMhNXVJTvgYCYanF1f29fVtHZXHB7sm+g4
z+58NwemM/Hd8YbpQVxQjpq5w4XtFcp3uCbzRF6wHe+wuryOL/My5cI8V1pV
byfucEk8/Iv7xeUIUwdQkg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 946->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FKQ0EQW/yQXkO8gR6geIV6gifoV0GoH+KfR9dqkTokmWQfiAvbsjuz
mSQz7+rhefd0McZ42Xz+7JbXu8Nhebu/PB4el/3tzf4YvD7tMd634+f/P2y1
atzFcPJc7HO/lH8Iq+OyBlNpYVgJl5qf1GG1mJ6qo/JFXJSe7h3Tx3xQXNIZ
Tfqh8tx6LC+JO1xcfoqz6wfCdrR0GjtPk96kGuvbWS6oZ8qvzo9f8dOudxWv
0+ByUT1C569lzIMTd/p5fl+xqk8zHFCc5dcct3Y6azUPnRkXxb3iK286X9hb
h4vDKekny1f3SEvaZ6S1w0RLvU98SedF4c321J2Tme+D6URvK7byg+WofqHY
DBdVW8184tnM/CqNHR5bTu9dTS4mwureJTPgYCYanFlfW9fVtHZWHB7sm+g4
z8581wemM/Hd8YbpQVxQjuq5w4XNFcp3uCb9RF6wGe+wuryOL/My5cI8V1pV
bSfucEk8/Iv9zeUDDglPlA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 947->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0GKAkEQazyI3xB/oA8Qv+C+YIT1JAh6EG8+XWVFlqKSSnpAHGhl6KpU
ksrMd8ftftJaO88eP9vhsjmdhuvP9PnyOxxWy8PzcvE6rd3W7f3/DYc98V7F
UOpU7P9+Mf8yrIrLGEymBWE5XGK9MwfNQnqijsg348L0VH1IH/KBcXEz6uyD
1anzUJ1zr3BR+THOqh8ZtqKl0lh56uzG1Rh7e7lkO2N+VX44vGMf813hwnaU
vSu61Xtln9k8d9cuR8VTVVP0UM2ls0uVe8Rn3lS+oF6FS0+eK15upjIt7p4z
rRVm9rB+xxc3Lwyvd6dqTnq+D6Qz643YzA9Uw/aV3fVwYbNZ5h3PevLLNFZ4
6FF2r2pSMTOsqs/JgILpaFCyPnauqmlsVhQe6JuoOPdmvtoD0un4rniD9GRc
shq2c4ULylVWr3B19pl5gTJeYVV1FV/kpcsFec60stnKvcLF8fAT54/LHVra
UhQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 948->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0lKBEEQLDyI3xB/oA8QvzC+oAU9DQjjQbz5dB0V6UkytmoQG2oWKjMy
luzLh+fd09kY4+Xi82O3vN4dDsvb/fnxz+Oyv7neHy+vfs4Y77fj9/s/HPbU
exfDqXOx134x/zosxWULJtOCsBIutT6Zg2YhPVVH5dtxYXpUH9KHfGBc0h1N
8mB17jxUl9w7XFx+jLPrR4ftaFEaladJNqnG2jvLpcuM+aX8SHjXPua7w4Vl
1P13dLv3Tp7dvK/fq+N4lnBE9bXm5M7IS/mwrk2ydLlXfOaN8gX1Olxm9lnx
Sneq0+LkrLQqzO5h/Ykv6b4wvNlM3T2ZeT+Qzq63YjM/UA3Lq7ub4cJms51P
PJvZX6ZR4aHHyd7V5GJ2WKov2QEHM9Hg7PrWua6mrbvi8EDvhOI8u/MqB6Qz
8d3xBunpuHQ1LHOHC9qrrt7hmuTZeYF2XGGpOsUXeZlyQZ4zrWy2c+9wSTz8
i/PN5QMrgVAU
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 949->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0GKAkEQazwsfkP8gT5A/IL7gllYT4KgB/Hm01VWlrWspJIekB1oZeiq
VJLKzL72m+2ktXac3n42w2l9OAznz4/7y/ewWy5298v547R2WbXf//9w2BPv
VQylTsX+6xfzL8OquIzBZFoQlsMl1jtz0CykJ+qIfDMuTE/Vh/QhHxgXN6PO
PlidOg/VOfcKF5Uf46z6kWErWiqNlafOblyNsbeXS7Yz5lflh8M79jHfFS5s
R9m7olu9V/aZzXt6Fz1zOKL6WPN0t3rlknmo5tLZpco94jNvKl9Qr8KlJ88V
LzdTmRZlz5XWCjN7WL/ji5sXhte7UzUnPd8H0pn1RmzmB6ph+8rueriw2Szz
jmc9+WUaKzz0KLtXNamYGVbV52RAwXQ0KFkfO1fVNDYrCg/0TVScezNf7QHp
dHxXvEF6Mi5ZDdu5wgXlKqtXuDr7zLxAGa+wqrqKL/LS5YI8Z1rZbOVe4eJ4
+I7zw+UKks1P1Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 950->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPyQXEO8gR4geIV4ghXMV0CIH+KfR9dgCNp0vWZBHNgsobtr
qqprb55edvurMcbr5utnt7w9HI/L++P16c/zcri/O5yKt+dnjI/tuLz/w8NO
rbsYTp+L/dMv5l+HpbiswWRaEFbCpfYn96C7kJ6qo/LtuDA9ag7pQz4wLmlG
k32wPvc+1JfUHS4uP8bZ9aPDdrQojcrTZDepxjo7y6XbGfNL+fGrLrjUOea7
w4XtaJz51OPkwak7+7xwQr4buClH1F976t4ql85TN5fJLl3uFZ95o3xBsw6X
mTwrXmmmOi3OnpVWhdkdNp/4kuaF4c3u1M3JzPeBdHazFZv5gXrYvrraDBd2
N8t84tlMfplGhYeOs3tXk4vZYam5JAMOZqLByfrae11Na7Pi8EDfhOI8m3m1
B6Qz8d3xBunpuHQ9bOcOF5Srrt/hmuyz8wJlXGGpPsUXeZlyQZ4zrexup+5w
STz8i+ebyycW006U
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 951->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tqAkEQHPwIuYZ4g3iAkCuYE2wgfgmCfgT/PLpKJISx6zULIQujLNNd
XVVdu/zYb7aL1trx+fqzmb7eDofp9P50e/mcduuX3e1ydT+tnV/bz/9/OOzp
710Mp87F/u0X86/CUlzmYDItCCvh0tcnc9AspKfX0fOtuDA9qg/pQz4wLmlG
k32wOnceqkvuHS4uP8bZ9aPCdrQojcrTZDepxr53lEu1M+aX8iPh3fcx3x0u
bEfVu6PbvXf2Wc1TmUs4MF1JLqueykM3l8kuH7iH2UFamS+o1+EykmfFK81U
pcXZs8qmwqwe1p/4kuaF4Smdqh7pmPN9IJ1Vb4/N/EA1bF/V3QgXNptlPvFs
JL9Mo8JDj7N7V5OLWWGpviQDDmaiwcn63LmuprlZcXigb0JxHs282gPSmfju
eIP0VFyqGrZzhwvKVVXvcE32WXmBMq6wVJ3ii7xMuSDPmVY227l3uCQe/sX5
5nIBSrVPlg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 952->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQfLiQXEO8gR4geIV4ghHMKiAkC3Hn0TUYQtJ0/WZEHHgJyeuu
rqquuXt522xvxhiH1ffHZnp/2u+nj+fb44/Xaff4sDte3p/OGJ/rcf7+D4c9
9d7FcOpc7Eu/mH8dluKyBJNpQVgJl1qfzEGzkJ6qo/LtuDA9qg/pQz4wLmlG
k32wOnceqkvuHS4uP8bZ9aPDdrQojcrTZDepxto7l0u3M+aX8iPhXfuY7w4X
tqOxPp1x/Z+TB+fe2eeZE/Hd8SzhiOprjbvrNGsdDpvlcq/4zBvlC+q9qv/F
PCteKlMstwxPcUkxu4f1I7wl2bzEZPtJ8qVy3/Uk+pjOrrdiMz9QDdtXdzeH
C5vNMp94Nie/TKPCQ4+ze1eTi9lhqb4kAw5mosHJ+tK5rqalWXF4oHdCcZ6b
ebUHpDPx3fEG6em4dDVs5w4XlKuu3uGa7LPzAmVcYak6xRd5mXJBnjOtbLZz
73BJPPyL88PlC2nFTxQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 953->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0sKwkAUG1yI1xBvoAcQr6AnqKCrgqALcefRtShFxpe8pAWxUEXmvUx+
zven7XFSSrnMnh/b5ro5n5vbbtr9ODTtatl2h4v3W8p9Xfrvf3jZU5+rGMqc
iv3pF/Mvwsq4jMFkWhCWw6Wed+5BdyE9tY6ab8SF6cn2kD7kA+PidtTJg82p
96E551zhovJjnFU/ImxFS6Yx89TJxtVY7w7lEmXG/Mr8cHjXe8x3hQvLqCQ9
RrrVcyXPiEfWOYcD0+X0siSeq1xRdizLL+5md5BW5gva7c+FbjNOTp5onnoU
aFFyZvgKZvSwfYRndZNwYfkwnU6uaMfRx3RGuzU28wPNsLyisyFc2N2s845n
Q/rLNGZ46FGyVzWpmBFWtud0QMF0NChdH3uvqmlsVxQe6D+RcR7a+SwHpNPx
XfEG6Ym4RDMsc4UL6lU0r3B18oy8QB3PsLK5jC/y0uWCPGda2d3KucLF8fAX
74vLAwaTTtU=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 954->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0Fqw1AQQz9ZlFwj9AbtAUqv4JzAgXZlKDiLkl2O3po0xR5GGsmGUoMT
7D9f/0kzPpw+uvdda+28//7p+s/Xcewvx4fp4a0fnp+GafHx527t+tJ+///D
za64rmoodar2PC+WX6ZVsWzRZF6QlsMS651z0FnIT/QReTMW5qfah/yhHBiL
O6NOP1ideh6qc9YVFpWPMat5ZNqKl8pjlanTG9dj3LuWJesZy6vKw+GO+1ju
CovSo8UlzoOyrvQz41g8i5k5jEqmWZbsnZLDvNbpJeNSZgd5ZbmgvQrLmnmu
uKTZARpMr2JBXEjzzoHqq2eVRZkXplf5dPqK9jj+mM9sb9RmeaCayJ/lGN+7
LOxsNvNOZmvml3ms9NCl9F71pGpmWtU+ZwYUTceDMutbz1U9bZ0VhQN9ExXz
2pmv+oB8Orkr2SA/GUtWw3qusKC5yuoVVqefWRZoxiutqq7iRVm6LChz5pWd
rawrLE6Gf3HfWL4AFp5Q0w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 955->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQfLgIXkNyA3MA8QrxBCMkq0AgLsSdR9dgkNB2/WZAMvASJq+7
uqq68vB63O7vxhhv998f2+n9+XSaPl5W55fddNg8Hs6X68sZ4/Np/H7fwmFP
vXcxnDoX+9ov5l+HpbgswWRaEFbCpdYnc9AspKfqqHw7LkyP6kP6kA+MS5rR
ZB+szp2H6pJ7h4vLj3F2/eiwHS1Ko/I02U2qsfbO5dLtjPml/Eh41z7mu8MF
7sjIMdLt3jv77OapzCUcmC43l0PsOs1ah8N2+Yd7mB2klfmCehGvpXlWvKzs
AAyGp7ggXggT+ee+u1ycvDA8pTPZK+pJ9DGdXW/FZn6gmsq/87H+nnJhs1nm
E8/m5JdpVHjocXbvanIxOyzVl2TAwUw0OFlfOtfVtDQrDg/0n1Cc52Ze7QHp
THx3vEF6Oi5dDdu5wwXlqqt3uCb77LxAGVdYqk7xRV6mXJDnTCub7dw7XBIP
/+P8cPkC0WVQFA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 956->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhZssJNcI3iA5QMgV9AQjmJUQMIuQXY6eiCJS1PubgeBAK2NX
v/7eq/Jp97F5fxhjfD7+fWymr7fjcfrerk4v++nw8nw4ba4va4yf13H9vofF
nrrvajh1rvZtXiy/TkuxLNFkXpBWwlLrk3vQXchP9VF5OxbmR51D/lAOjCWd
0aQfrM69D9Ul+w6Ly8eY3Tw6bceL8qgyTXqTeqxn57J0PWN5qTyuewZ3Pcdy
d1hgj4w5Rr7dfaeftyzofiezhBHV15raN5RbOmu1rnuHLMIn63uSCzrrsMyZ
Z8VF8xTsTE+xIK5Oc9RZMZiQnjubzB/TUz6TvqIziT/msztbtVkeqKbydznW
31MWdjeb+SSzOfPLPCo99Di9dz25mp2WOpfMgKOZeHBmfem9rqels+JwoP+E
Yp4786oPyGeSu5MN8tOxdDWs5w4Lmquu3mFN+tllgWZcaak6xYuyTFlQ5swr
u9vZd1iSDP9jnVl+ARk5TtM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 957->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN4gHCLlCPMEIugoEkkVw59GToIgU9f5mIDjQ+evq
6u+9enl6O+w+HsYYp9X1ZTedt8fj9Pn6ePvyPu1f1vvb5vPPGuNrM37f/8Ni
T913ezh1bu+/fjH/ul6KZUlPpgX1SlhqfXIPugvpqToqb8fC9KhzSB/ygbGk
GU3mwerc+1Bdsu+wuHyM2fWj6+1oURqVp8lsUo317FyWbmbML+VHwl3PMd8d
FieH9XHy4Ow78xyG745nCSOqH4K38xexq1wms0Sf3ewgLcwXdNZhmZNnxaUy
xdhZP8WCuFBPxeAyKhYnL6yf46M7V3Qm0cd0dmdrb+YHqqn8nY/195SF3c0y
n3g2J79Mo+qHHmf2ria3Z9dLnUsy4PRMNDhZX3qvq2lpVhwO9J9QzHMzr+aA
dCa+O94gPR1LV8Nm7rCgXHX1Dmsyz84LlHHVS9UpXuRlyoI8Z1rZ3c6+w5J4
eI/1zXIBy9xR0w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 958->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0tKBEEQRBMX4jXEG+gBxCuMJ2jBWQ0I40LceXQd/CBJxq8bxIaaX2Vl
vYiMuXx42u3Pqur54uNlt7zcHY/L6/356cvjcri5Ppw2r75W1dtt/bz/h8We
vu/2cOrc3r/9Yv5NvRTLlp5MC+qVsPT65B50F9LTdXTeiYXpUeeQPuQDY0kz
msyD1bn3obpk32Fx+Riz68fU29GiNCpPk9mkGvvZtSzTzJhfyo+Eu59jvjss
Tg774+TB2Xfm2TVP9zueJYyoHvrzvcpnV7lMZjl9riA7SCvzBZ1FXFvzrLio
n4Kd9VMsiAv1rMajmFA/N5uUhfRTOpO5ojOJPpr14WzvzfxANZ1/8rH/nrKw
u1nmE8/W5JdpVP3Q48ze1eT2nHqpc0kGnJ6JBifrW+91NW3NisOB/hOKeW3m
1RyQzsR3xxukZ2KZatjMHRaUq6neYU3mOXmBMq56qTrFi7xMWZDnTCu729l3
WBIP/2J9srwDiQJPFA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 959->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAlEQfGQRco3gDZIDSK6gJxjBrISAWYTscvQoikjT9ZuBkIHn73VX
V1WXz7uPzfvDGOPz6fSymb7ejsfpe/t4/rKfDq8vh/Pl6nrG+FmP2/t/OOyp
9y6GU+di3/vF/OuwFJclmEwLwkq41PpkDpqF9FQdlW/HhelRfUgf8oFxSTOa
7IPVufNQXXLvcHH5Mc6uHx22o0VpVJ4mu0k11t65XLqdMb+UHwnv2sd8d7g4
OayPkwfn3tln1dzNdzxLOKJ65k/KXeUy2WX3eQTZQVqZL6jX8WVOnhUv6qfg
zvAUF8SrwxzruwPqXY5uNpk+hqd0JntFPYk+mvWmt2IzP1BN5d/5WH9PubDZ
LPOJZ3PyyzQqPPQ4u3c1uZgdlupLMuBgJhqcrC+d62pamhWHB/pPKM5zM6/2
gHQmvjveID0dl66G7dzhgnLV1Ttck312XqCMKyxVp/giL1MuyHOmlc127h0u
iYd/cS5cfgEuc0+U
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 960->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0tKQ0EQRRsHwW1IdqALELeQrOAFdBQQ4kCcuXQN+SBF3d97IHnQ+XX1
7XNvVR5275u3uzHGx/3vy2b6fDkcpq/t6vjlddo/Pe6Pm+vzGuP7eVzfb2Gx
p+67Gk6dq/03L5Zfp6VYlmgyL0grYan1yT3oLuSn+qi8HQvzo84hfygHxpLO
aNIPVufeh+qSfYfF5WPMbh6dtuNFeVSZJr1JPdazc1m6nrG8VB7XPYO7nmO5
OyxsDkfD7Ph2951+Vs+IUWWWMKL6WlM5KgtjV3OZ9LL7rFhUNioXdBZxLZ1n
xUXzFOxMT7Egrk7zMiOD1LuM7mwyf0xP+Uz6is4k/uisN2erNssD1VT+Lsf6
e8rC7mYzn2Q2Z36ZR6WHHqf3ridXs9NS55IZcDQTD86sL73X9bR0VhwO9J9Q
zHNnXvUB+Uxyd7JBfjqWrob13GFBc9XVO6xJP7ss0IwrLVWneFGWKQvKnHll
dzv7DkuS4X+sE8sPQMNN0w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 961->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPwQryHeQA8QvEI8wQr6FRDih/jn0TUqozRdr10QBybZzXTX
VFVXLu+f9o9nY4zni4+P/fJyezwur3fnp5eH5XBzfTgdXn3vMd52Y37/h81W
PXcxnDoX+7dfzL8OS3HZgsm0IKyES61P7kF3IT1VR+XbcWF6VB/Sh3xgXNKM
JvNgde59qC45d7i4/Bhn148O29GiNCpPk9mkGmvvWi7dzJhfyo95ZvCufcx3
h4uTw7qcPDjnzjyr5vkczC/liOo7fyaP3c9W3J1cJrNEvNzsIK3MF9SLeG3N
s+KlMvW5AAbDU1wQL4Q5l/BT4TnZVHlheEpnMlfUk+ijWW96KzbzA9VU/p2P
9feUC7ubZT7xbE1+mUaFh5Yze1eTi9lhqb4kAw5mosHJ+tZ7XU1bs+LwQP8J
xXlt5tUckM7Ed8cbpKfj0tWwmTtcUK66eodrMs/OC5RxhaXqFF/kZcoFec60
srudc4dL4uFf7C8u7+xtTZQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 962->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPIhuUbwBnoA8QrxBCvoV0BIPiR/OboGZQlN12sXxIFJNpnu
mqrq2t3rx/59M8Y4bb8/9tPn8/E4nV/urj/epsPjw+F6eP+7x7g8jfn7P2y2
6rmL4dS52Ld+Mf86LMVlDSbTgrASLrU+uQfdhfRUHZVvx4XpUX1IH/KBcUkz
msyD1bn3obrk3OHi8mOcXT86bEeL0qg8TWaTaqy9S7l0M2N+KT/mM4N37WO+
O1ycHNbl5ME5d+ZZNc/PwfxSjqi+82fmITx3uaLZsVmiZzc7SCvzBfU6XJbk
WfFSmRoEg+EpLinmuN3ET4XnZFPlheEpnclcUU+ij+nseis28wPVVP6dj/X/
lAu7m2U+8WxJfplGhYeWM3tXk4vZYam+JAMOZqLByfrae11Na7Pi8EDvhOK8
NPNqDkhn4rvjDdLTcelq2MwdLihXXb3DNZln5wXKuMJSdYov8jLlgjxnWtnd
zrnDJfHwL/YPly+er0+S
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 963->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqAlEQfGQRco3gDeIBQq5gTjCCrgTBLEJ2OXoiikjT9ZuBkIGnDq+7
uqq6fN4eN/uHMcbH0+/HZvp8O52mr/fH88tuOqxfDufL1fWM8f06bt//4bCn
3rsYTp2Lfe8X86/DUlyWYDItCCvhUuuTOWgW0lN1VL4dF6ZH9SF9yAfGJc1o
sg9W585Ddcm9w8Xlxzi7fnTYjhalUXma7CbVWHvncul2xvxSftzuDN61j/nu
cGE5HA1nR7d77+yzau7mO54lHFF9rUE7cbirXCa7RL/d7CCtzBfU63CZk2fF
S2Wq04FmuhqWYKJ69e5ycfLC8JTOZK+oJ9HHdHa9FZv5gWq6XXVeKB2MC5vN
Mp94Nie/TKPCQ4+ze1eTi9lhqb4kAw5mosHJ+tK5rqalWXF4oP+E4jw382oP
SGfiu+MN0tNx6WrYzh0uKFddvcM12WfnBcq4wlJ1ii/yMuWCPGda2Wzn3uGS
ePgX58LlB+FvT5Y=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 964->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1tKA0EQHPIhuUbwBnoA8QrxBCvoV0BIPiR/OboGRaTpeu2AuDAJy3RX
V1XX7p7f9q+bMcZp+/mzX94fj8fl/HRzfXlZDvd3h+vl7fcZ4/Iwfv7/w2FP
vXcxnDoX+7dfzL8OS3GZwWRaEFbCpdYnc9AspKfqqHw7LkyP6kP6kA+MS5rR
ZB+szp2H6pJ7h4vLj3F2/eiwHS1Ko/I02U2qsfau5dLtjPml/Eh41z7mu8OF
5XCIHCPd7r2zz6q5m+94lnBE9bUG7cThrnKZ7LLlFWQHaWW+oF7EazbPipfK
VKcDzXQ1zGCievXucnHywvCUzmSvqCfRR7Pe9FZs5geq6XbVeaF0MC5sNst8
4tma/DKNCg89zu5dTS5mh6X6kgw4mIkGJ+uzc11Ns1lxeKBvQnFem3m1B6Qz
8d3xBunpuHQ1bOcOF5Srrt7hmuyz8wJlXGGpOsUXeZlyQZ4zrWy2c+9wSTz8
i/PF5QMHjU+W
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 965->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0uKQkEQa1yI15C5gR5AvIJzgjegK0HQhbjz6I6MyFhUUkk/EBueH7oq
laTy5j+HzW7SWjvNfj82w3l9PA6X7+n9z3bYLxf7++XX42ntumrP70942In3
KoZSp2L/94v5l2FVXMZgMi0Iy+ES6505aBbSE3VEvhkXpqfqQ/qQD4yLm1Fn
H6xOnYfqnHuFi8qPcVb9yLAVLZXGylNnN67G2NvLJdsZ86vyw+Ed+5jvChcl
h/EoeVDulX1Gzdl8xTOHI6rP/HnhZ3CvcunsEv1Ws4O0Ml9Qr8KlJ88VrypT
mQ40U9XQg5kd1o/wVK0VF7YfptPZK+px9DGdWW/EZn6gGrav7K6HC5vNMu94
1pNfprHCQ0fZvapJxcywqj4nAwqmo0HJ+ti5qqaxWVF4oHei4tyb+WoPSKfj
u+IN0pNxyWrYzhUuKFdZvcLV2WfmBcp4hVXVVXyRly4X5DnTymYr9woXx8N3
PH9cbofSUBY=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 966->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHFxIriHeQA8QvEI8wRPMKiDEhbjz6BoNIk3Xb56IA5MQpru6
qrpy9fC021+MMZ43Hx+75eXueFxe7y9PPx6Xw+3N4fR4fb5jvG3H9/d/uOzU
dxfDqXOxf/rF/OuwFJc1mEwLwkq41PpkDpqF9FQdlW/HhelRfUgf8oFxSTOa
7IPVufNQXfLucHH5Mc6uHx22o0VpVJ4mu0k11t5ZLt3OmF/Kj4R37WO+O1xg
Ds+X5Rjpdt+dfVbNn0dkLuHAdFlZKD4q7m4uk112XJLsIK3MF9Tb8fqNPCte
KlOdDjTT1TCD2R3Wj/BcrYoL2w/TmewV9ST6mM6ut2IzP1AN21f3NsOFzWaZ
TzybyS/TqPDQcXbvanIxOyzVl2TAwUw0OFlfO9fVtDYrDg/0n1CcZzOv9oB0
Jr473iA9HZeuhu3c4YJy1dU7XJN9dl6gjCssVaf4Ii9TLshzppXNdt4dLomH
f3G/uLwDMddO1Q==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 967->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsX4jWCN9ADBK8QTzCCrgKBuBB3OboGf5Cy3l8PiAMTMV1V
/b1XL5uHw+7pYozxfPX+sVte7o7H5fX+8vzP47K/vdmfD68/3zFO2/H99z+8
7Knn7gynzp390y/mXzdLsayZybSgWQlLrU/uQXchPVVH5e1YmB7Vh/QhHxhL
mtFkH6zOvQ/VJecOi8vHmF0/utmOFqVReZrsJtVYe2dZup0xv5QfCXftY747
LC3T13cix0i3e+7ss2ru7nc8SxhRfa35xRewq1wmu2y5guwgrcwX1Iu41uZZ
calMdTrQna6GmZndw/rRPFerYmH7YTqTvaKeRB/NetNbZzM/UA3bV3c2w8Lu
ZplPPJvJL9Oo5qHH2b2ryZ3ZzVJ9SQacmYkGJ+tr73U1rc2Kw4F+E4p5NvNq
D0hn4rvjDdLTsXQ1bOcOC8pVV++wJvvsvEAZV7NUneJFXqYsyHOmld3tnDss
iYd/8X6wvAHZxE6W
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 968->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA1EQhB9ZSK4h3kAPEHKFeIIRzCogxIVk59FjUAZpuv5mQByYiHnd
/b6qrty/vB2OmzHG+/br4zB97M/n6fJ8d/vndTo9PZ5uhw8/7xifuzH//Q8v
e+q5O8Opc2f/9ov5181SLGtmMi1oVsJS65N70F1IT9VReTsWpkf1IX3IB8aS
ZjTZB6tz70N1ybnD4vIxZtePbrajRWlUnia7STXW3qUs3c6YX8qP+czgrn3M
d4fF2VF9nDw4584+O65BNKUMTFeahdrTsbu5THbZcgXZQVqZL6gXca3Ns+JS
mep0oDtdDUtmzo/wU81ztSoWth+mM9kr6kn00aw3vXU28wPVVP7Ox/p9ysLu
ZplPPFuSX6ZRzUOPs3tXkzuzm6X6kgw4MxMNTtbX3utqWpsVhwP9JhTz0syr
PSCdie+ON0hPx9LVsJ07LChXXb3Dmuyz8wJlXM1SdYoXeZmyIM+ZVna3c+6w
JB7+xfvNcgUbik3X
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 969->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tqQkEQHLKQXCPkBnqAkCvoCV4groSAWQR3Ht1P5CFN16dnQBx4fpju
6qrqem9fP+vtS2vt9/X8sZ7+Pvf76bBZXP58T7vVcne5fL89rR0/2vz9DA87
8d7FcOpc7Hu/mH8ZluIygsm0IKwKl1hfmYNmIT1RR+SbcWF6VB/Sh3xgXKoZ
reyD1bnzUF3l3uHi8mOcXT8ybEeL0qg8reymqjH29nLJdsb8Un7Mdwbv2Md8
d7g4OYzHyYNz7+zzeiKeyFyFA9OlstBuO7v3ke3L4Ypw2C7nvvDbzQ7SynxB
vYjXaJ4VL5WpTAea6WD3YmaH9SM8V6viwvLIdKp6pGPk/YD5SnojNvMD1bB9
ZXc9XNhslvmKZz35ZRoVHjrO7l1NLmaGpfoqGXAwKxqcrI/OdTWNZsXhgd4J
xbk382oPSGfFd8cbpCfjktWwnTtcUK6yeodrZZ+ZFyjjCkvVKb7IyyoX5DnT
ymY79w6XioePeP65nADRZE1V
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 970->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU11Kw2AQ/OiD9BrFG+gBxCvUE0TQp4LQPkjfenQtSinbnb8ExEAa0m93
dmZ2snn92L6vxhiH9ffPdvp83u+n48vd+eVt2j0+7M6H97/3GKencXn+h5td
9dzFcOpc7Gu/mH8dluKyBJNpQVgJl1qfzEGzkJ6qo/LtuDA9qg/pQz4wLmlG
k32wOnceqkvOHS4uP8bZ9aPDdrQojcrTZDepxto7l0u3M+aX8uNyZvCufcx3
h4uTw3o5eXDOnX1Wzd18x7OEI6q/qQE7cbirXCa7hLzM7CCtzBfU2/FCuWac
kn2ieupRo0X1yTwYmOPKj65evbtcnLwwPKVT1SMdS74PmK+mt2IzP1BN5d/5
WP9PubDZLPOJZ3PyyzQqPHQ5u3c1uZgdlupLMuBgJhqcrC+d62pamhWHB/om
FOe5mVd7QDoT3x1vkJ6OS1fDdu5wQbnq6h2uyT47L1DGFZaqU3yRlykX5DnT
ymY75w6XxMO/uH+4fAFHQE3V
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 971->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN9ADBK8QTzCCWQWEZCHuPLpGZQhFvb8ZERs6Yrr6
9fdeVW6eXnb7qzHGafP5sZteH47H6e3x+vzP83S4vzucD29/9hjv2zH//Q+b
rXruajh1rvZlXiy/TkuxrNFkXpBWwlLrk3fQW8hP9VF5OxbmR91D/lAOjCWd
0aQfrM59D9Ul5w6Ly8eY3Tw6bceL8qgyTXqTeqx3l7J0PWN5qTzmM4O73mO5
OyzOHNblzINz7vSzeu7edzJLGFF9l0/lc9nVXCa9nO8JjXrGslG5oLsd12/M
s+KieQp2pqdYEBfS/Frbiy2YklzieSF6ymfSV3Qn8cd8dnerNssD1VT+Lsf6
fcrC3mYzn2S2ZH6ZR6WHltN715Or2Wmpe8kMOJqJB2fW177relo7Kw4H+k0o
5qUzr/qAfCa5O9kgPx1LV8N67rCguerqHdakn10WaMaVlqpTvCjLlAVlzryy
t51zhyXJ8C/2N8sHzYZNlg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 972->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1Fqw0AQQ5d8lF4j9AbtAUyv4JzAgfbLUHA+Sv5y9NZpKGYy0kg2lBo2
JtnZ2SeNsj9+9O+71trp8fujHz5fp2k4Hx7mL2/D+PI8zptPt9XapWu/7/+w
2BP31R5Kndp76RfzL+tVsWzpybSgXg5LrHfuQXchPVFH5M1YmJ7qHNKHfGAs
bkadebA69T5U5+wrLCofY1b9yHorWiqN18dkUf1wtbZuHUs2M+ZX5YeqKTvH
fFdYlBzGR8mDsq/MM2rO7lc8cxhRfeZP5FPZaS6TPmyWiEvNDtLKfEFnEdfW
PFdc1M+CnfWrWBBX1rMt33GB844vbl7u6gydzlzRGUdflXWmufID1UT+zMf4
u8vC7maZdzxbk1+mseqHHmX2qia1Z9arOudkQOnpaFCyvvVeVdPWrCgc6D9R
Ma/NfDUHpNPxXfEG6clYsho2c4UF5SqrV1ideWZeoIxXvaq6ihd56bIgz5lW
dreyr7A4Hv7F+mH5AglpTVM=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 973->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU1FKA1EQe/ghXkN6Az2AeIX2BFuoXwWhfoh/Hl1Ly1KGJJN0i7jwurRv
JpNk0sft+/rtbozx8fD7sZ4+Xw+H6Wtzf/yym/bPT/vj5ep8xvh+GfP7Pxz1
1HsXw6lzsS/9Uv4hrI7LEkylhWElXGp9MofNYnqqjsoXcVF6uj6mj/mguKQZ
Tfah6tx5rC65d7i4/BRn1w+E7WjpNHaeJrtJNdbeYeAgLmhnyq/OD1cT6lO+
O1ycHNbHyYNz7+yzakbzHc8Sjqwe+VP5udxlLgGO2uXcV3mZ2WFalS+sF/G6
RZ47Xl2mFHeF13FhvBjm/Eb7Cjg62WzzIvAcH929sp5En9KJeiu28oPVVP7I
x/p7ykXNVplPPLsmv0pjh8ceZ/euJhcTYXV9SQYczESDk/Wlc11NS7Pi8GD/
iY7ztZnv9sB0Jr473jA9iAuqUTt3uLBcoXqHa7JP5AXLeIfV1XV8mZcpF+a5
0qpmO/cOl8TDvzgnLj/uMk4W
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 974->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0Fqw0AQW3Io+UboD9IHlH7BeYEL7clQcA4ltzy9NWlDM4w00hpCFzbG
2VmNpJF3rx/D+6a1dtx+/wzj58s8j6fDw/LyNk5P+2k5fPzZrZ2f2/X5HzZb
8VzFUOpU7L9+Mf8yrIrLGkymBWE5XGK90wf1Qnqijsg348L0VPeQPuQD4+Jm
1JkHq1P7oTrnXOGi8mOcVT8ybEVLpbHy1JmNqzHFN31BOWN+VX6omrJ7zHeF
i5LDuJQ8KOfKPKPmrL/imcMR1Wf+RH4qd+ZBhsNm2cOl8qbyBd29qRdmjjg5
80T1iCt6Z3OuMqtiXp+/u5Ojkk0lL2w+TKczV3TH0cd0ZncjNvMD1UT+mY/x
f5cL680y73jWk1+mscJDS5m9qknFzLCqe04GFExHg5L1tX1VTWuzovBA30TF
uTfz1RyQTsd3xRukJ+OS1bCZK1xQrrJ6haszz8wLlPEKq6qr+CIvXS7Ic6aV
9VbOFS6Oh/fYFy5fAWVOlg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 975->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKQ0EQHFyI1xBvoAcQrxBP8ARdBYS4kOxy9CSoQZr69TwQH0xCMt3V
VdX1bl/eN29XY4yPm9PHZvl82u2W/fP1+cfrsn24354v777PGIfHcfn+D0c9
9T7FSOpS7N9+Kf8QluOyBlNpYVgdLrW+M4fNYnqqjsoXcVF6XB/Tx3xQXLoZ
7exD1aXzWF3nPuGS8lOcUz8QdqLFaXSednbT1Vh7R4CDuKCdKb+cH6km1Kd8
T7gkOaxPkofkPtln1YzmJ551OLJ65E/ll3KXuQQ4apczXJw3zhfW6zTO5tnx
cn4q7grPcWG8GObl++dMckyymeQl3ZN7N1zuUU9Hn9KJeiu28oPVVP7Ix/p/
l4uarTLf8Wwmv0qjw2NPsvtUU4qJsFxfJwMJZkdDkvW1c1NNa7OS8GDvhOM8
m3m3B6az43viDdODuKAatfOEC8sVqk+4dvaJvGAZd1iuzvFlXna5MM+VVjU7
uU+4dDz8i/PF5QgBT05X
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 976->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA1EQhB9ZSK4RvIEeQLxCPMEIugoIyUKyy9E1qME0XX8zIA5MxLzu
fl9VVzbPb9vX1RjjsP782E7vj/v9dHy6Of/zMu3u73bnw9vvd4zTw7j8/Q8v
e+q5O8Opc2f/9ov5181SLEtmMi1oVsJS65N70F1IT9VReTsWpkf1IX3IB8aS
ZjTZB6tz70N1ybnD4vIxZtePbrajRWlUnia7STXW3rks3c6YX8oPV1PXx3x3
WJwc1sfJg3Pu7LNq7u53PEsYUX3nT+Vz2VUuk11e+n7ODBbljfIF9SqNc/Os
uJSfjJ3NUyyIC828Ol/A6GRT5oXMUzqTvaKeRB/T2fXW2cwPVFP5Ox/r9ykL
u5tlPvFsTn6ZRjUPPc7uXU3uzG6W6ksy4MxMNDhZX3qvq2lpVhwO9JtQzHMz
r/aAdCa+O94gPR1LV8N27rCgXHX1Dmuyz84LlHE1S9UpXuRlyoI8Z1rZ3c65
w5J4+BfvF8sHyFVNmA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 977->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhZssJNcI3kAPELxCPMEIugoIyUKyy9E1UUSLen8zIDZMQtLV
1d979Wbz9Lp7WY0xjuuPj9309nA4TKfHm8uP52l/f7e/bN5+PWOct+P7+z88
bNV9t4dT5/b+6Rfzr+ulWJb0ZFpQr4Sl1if3oLuQnqqj8nYsTI86h/QhHxhL
mtFkHqzOvQ/VJfsOi8vHmF0/ut6OFqXxukIW149U69jOY+lmxvxSfriaunPM
d4fFyWFdTh6cfWeeVXN3v+NZwojqO3+uy/DcZUV92CwryzBYlDfKF3RWaZyb
Z8Wl/GTsrJ9iQVyo56/9BYxONp28uHNS74bKfXcm0cd0dmdrb+YHqqn8nY/1
/5SF3c0yn3g2J79Mo+qHljN7V5Pbs+ulziUZcHomGpysL73X1bQ0Kw4HeicU
89zMqzkgnYnvjjdIT8fS1bCZOywoV129w5rMs/MCZVz1UnWKF3mZsiDPmVZ2
t7PvsCQe/sXzyfIOm/xOlA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 978->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQfGQhuUbwBnoA8QrxBCPoKiDEhbjL0WM0iHS6fjMiPpiE5HVX
V1XXbB5fts+rMcbr+uNjO73d7/fT+8PV6cfTtLu92Z0ur8/PGIe78f39Hx52
6r2L4dS52D/9Yv51WIrLEkymBWElXGp9MgfNQnqqjsq348L0qD6kD/nAuKQZ
TfbB6tx5qC65d7i4/Bhn148O29GiNCpPk92kGmvvmOELyhnzS/nhaur6mO8O
FyeH9Th5cO6dfVbN3XzHs4Qjqu/8+TznLNUexp3mssFhu5zDRXmjfEG9F79/
Kc+Kl/KTcWd4igvihTBTTgjPyaaTF5ZHplPVIx1L3g+ks+ut2MwPVFP5dz7W
/1MubDbLfOLZnPwyjQoPHWf3riYXs8NSfUkGHMxEg5P1pXNdTUuz4vBA74Ti
PDfzag9IZ+K74w3S03HpatjOHS4oV129wzXZZ+cFyrjCUnWKL/Iy5YI8Z1rZ
bOfe4ZJ4+BfPF5cjDO9Nlg==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 979->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNU0tKA1EQfGQhuUbwBnoA8QrxBCPoKiAkC8kuR9eMItJ0/WZAfDAJyeuu
rqqu2T2/7V83Y4zT9vNjP70/Ho/T+enm+uNlOtzfHa6Xt9/PGJeH8fP9Hx52
6r2L4dS52L/9Yv51WIrLGkymBWElXGp9MgfNQnqqjsq348L0qD6kD/nAuKQZ
TfbB6tx5qC65d7i4/Bhn148O29GiNCpPk92kGmvvfEJfUM6YX8qP+dvQ1PYR
3x0uTg7rcfLg3Dv7rJq7+Y5nCUdU3/kzH8NzlyvCYbusXLosVS7KG+UL6lUa
l+ZZ8VJ+Mu4MT3FBvBBmygnhOdl08uLuSb0bKvddT6KP6ex6KzbzA9VU/p2P
9f+UC5vNMp94tiS/TKPCQ8fZvavJxeywVF+SAQcz0eBkfe1cV9ParDg80Duh
OC/NvNoD0pn47niD9HRcuhq2c4cLylVX73BN9tl5gTKusFSd4ou8TLkgz5lW
Ntu5d7gkHv7F88XlAyvOTVc=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 980->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA1EQhB8ugtcQbxAPIF4hnmCEuAoIcSHuPLrGxCBN198MhAyMoq9f
91fVNXcvb5vXmzHG++3Pj8308bTfT5/Pq8Mf22n3sN4dDu9P7xhfj+P8+xpe
9tRzt4dT5/b+7xfzr+ulWJb0ZFpQr4Sl1idz0Cykp+qovB0L06PuIX3IB8aS
ZjTZB6tz56G65Nxhcfna/wV7RMyOFqXx9xE8c/1w38qS+IJyxvxSfvztR2lq
7xHfHRYnh/Vx8uCcO/usmrv5jmcJI6rv/Kl8LrvKZbLLOqOb1XEyb5QvbI7a
9Zw8Ky7lJ2Nn/RQL4kI9UybUz8mmkxd3T+rbULnv7iT6mM7ubu3N/EA13TfV
eaF0MBY2m2U+8WxOfplG1Q89zu5dTW7Prpe6l2TA6ZlocLK+dK6raWlWHA70
TSjmuZlXe0A6E98db5CejqWrYTt3WFCuunqHNdln5wXKuOql6hQv8jJlQZ4z
rWy2c+6wJB5e4j2yfANZp0vZ
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 981->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhZssxGsEb6AHEK8QTzCCrgJCXEh2ObpGo8Sy3t8MiAOdkHR1
9fdevVk/PG+eVmOMl8v3j830erfbTfv7i+OPx2l7c709bl6d1hiH2/H9/R8W
e+q+28Opc3uf+8X863opliU9mRbUK2Gp9ck96C6kp+qovB0L06POIX3IB8aS
ZjSZB6tz70N1yb7D4vIxZtePrrejRWlUniazSTXWs3NZupkxv5QfH9+npVh+
nSO+OyxODuvj5MHZd+ZZNXf3O54ljKi+86fyuewql8ksf9zxlSXBorxRvqCz
SuPcPCsu5SdjZ/0UC+JCPVMm1M/JppMXd07q3VC5784k+pjO7mztzfxANZW/
87H+n7Kwu1nmE8/m5JdpVP3Q48ze1eT27Hqpc0kGnJ6JBifrS+91NS3NisOB
3gnFPDfzag5IZ+K74w3S07F0NWzmDgvKVVfvsCbz7LxAGVe9VJ3iRV6mLMhz
ppXd7ew7LImHf7E+Wd4ASB5NGA==
                    "], {{0, 35}, {35, 0}}, {0., 
                    1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 982->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA1EQhB8uJNcQb6AHkFwhnmACugoIySJk59E1GIJ0uv5mQByYiHnd
9b6q7jxsPzbvd2OMw+r7YzMd1/v9dHq9P//zNu2en3bnw8fLO8bny7j+/Q8v
e+q5q+HUudq/82L5dVqKZYkm84K0EpZan9yD7kJ+qo/K27EwP6oP+UM5MJZ0
R5N5sDr3PlSXnDssLh9jdvPotB0vyqPKNJlN6rH2DkOnY+lmxvJSeVzPDO7a
x3J3WJw9rI+zD865M8/qubvfySxhRPVdPpXPZad72eiwWd6wGywqG5UL6lUe
5+6z4lJ5Mnamp1gQF9JMmZCes5tqX5ie8pnMFfUk/pjPrrdqszxQTeXvcqzf
pyzsbrbzSWZz9pd5VHrocWbvenI1Oy3Vl+yAo5l4cHZ96b2up6W74nCg34Ri
nrvzag7IZ5K7kw3y07F0NWzmDgvaq67eYU3m2WWBdlxpqTrFi7JMWVDmzCu7
2zl3WJIM/+L9YfkCZsJOVw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 983->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA1EQhB8ugteQ3EAPIF4hOcEEdBUQ4kLceXQN+UGarr8ZkAxMxLzu
el9Vdx5275u3uzHGx/3vx2b6fDkcpq/t6vjP67R/etwfD9fnd4zv53H9ewsv
e+q5q+HUudp/82L5dVqKZYkm84K0EpZan9yD7kJ+qo/K27EwP6oP+UM5MJZ0
R5N5sDr3PlSXnDssLh9jdvPotB0vyqPKNJlN6jHRZ7XdzFheKo+Epfax3B0W
Zw/r4+yDc+7Ms3ru7ncySxhRfZdP5XPZWQadDpvlte9yZrCobFQuqFd5nLvP
ikvlydiZnmJBXEgzZUJ6zm7KfSF6ymcyV9ST+GM+u96qzfJANZW/y7F+n7Kw
u9nOJ5nN2V/mUemhx5m968nV7LRUX7IDjmbiwdn1pfe6npbuisOBfhOKee7O
qzkgn0nuTjbIT8fS1bCZOyxor7p6hzWZZ5cF2nGlpeoUL8oyZUGZM6/sbufc
YUky/I/3xPIDoU1OGA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 984->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA1EQhB8uxGtIbhAPIF4hOcEE4iogxIW48+gaEkJouv5mIDgwEfP6
VX9V3XnefWzeH8YYn09/H5vp6+14nL63j6d/9tPhZX04Ha4u7xg/r+P69z+8
7KnnroZT52rf5sXy67QUyxJN5gVpJSy1PumDeiE/1Ufl7ViYH3UP+UM5MJZ0
R5N5sDq3H6pLzh0Wl48xu3l02o4X5XFc3oTFzSP1OpelmxnLi+Zxq2Ow1Hss
d4fFmVF9nH1wzp15Vs9dfyezhBHV1xo0E4ed7mWjw2bZsSsWlY3KhfVRs56z
z4pL5cnYmZ5iQVxIM2VCes5uqn1hespnMld0J/HHfHZ3qzbLA9VU/i7H+n3K
wnqznU8ym7O/zKPSQ48ze9eTq9lpqXvJDjiaiQdn15f2dT0t3RWHA/0mFPPc
nVdzQD6T3J1skJ+OpathM3dY0F519Q5rMs8uC7TjSkvVKV6UZcqCMmdeWW/n
3GFJMrzHe2b5BdiHTpQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 985->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN9ADiFeIJxhBVwEhWYg7j65BCUNR768HxIHOX1e/
/t6rys3z2/71aoxx2n2/7Jf3x+Nx+Xi6Pn95WQ73d4fz5u3vGuPzYVze/8Ni
T913NZw6V3udF8uv01IsWzSZF6SVsNT65B50F/JTfVTejoX5UeeQP5QDY0ln
NOkHq3PvQ3XJvsPi8jFmN49O2/GiPI4JFjePGa8zLF3PWF40j7WOwVLPsdwd
FmcO6+PMg7Pv9KR6vnwm3hMG5suahfUaHrvKoNNhvezYFYvKRuXC7lG9npln
xaXyZOxMT7EgLqSZMiE9ZzbVvDA95TPpKzqT+GM+u7NVm+WBaip/l2P9PWVh
d7OZTzKbmV/mUemhx+m968nV7LTUuWQGHM3EgzPrW+91PW2dFYcD/ScU8+zM
qz4gn0nuTjbIT8fS1bCeOyxorrp6hzXpZ5cFmnGlpeoUL8oyZUGZM6/sbmff
YUky/Iv1w/IFhcxP0w==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 986->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KQ0EQhAcXkmuIN9ADBK8QT/AEswoIcSHuPLoGJYSm628eig8mf9NT
81V15+bpZbe/GmO8br5edsvbw/G4vD9en748L4f7u8Np8/ZnjfGxHef3/7DY
U/ddDafO1b7Mi+XXaSmWNZrMC9JKWGp9cg+6C/mpPipvx8L8qHPIH8qBsaQz
mvSD1bn3obpk32Fx+Rizm0en7XhRHscEi5vHjNcZlq5nLC+aR8hSz7HcHRZn
DuvjzIOz7/Skej5/Jt4TBubLmoXLNTx2lUGnw3rZsSsWlY3Khd3zG/OsuFSe
jJ3pKRbEhTRTJqTnzKaaF6anfCZ9RWcSf8xnd7ZqszxQTeXvcqy/pyzsbjbz
SWYz88s8Kj30OL13PbmanZY6l8yAo5l4cGZ97b2up7Wz4nCg/4Rinp151Qfk
M8ndyQb56Vi6GtZzhwXNVVfvsCb97LJAM660VJ3iRVmmLChz5pXd7ew7LEmG
f7G+WT4B+yZQUw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 987->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhZssxGuE3MAcQHIFc4IJmJUg6EKyy9ETSRBp6/31gDgwDmNX
v/7eq5rnj/3m86m1dlz+/mym09vhMH29L84v22n3utqdF1/+79a+1+3yfISb
Xf26q+HUudrXebH8Ki3FMkeTeUFaCUtfn5yDzkJ+eh89b8XC/Kh9yB/KgbGk
M5r0g9W556G6ZN1hcfkYs5tHpe14GenbaG9Sj6X+AEvVM5YXy+PyNFlu9pHc
HZaSicyD43uk90qD5e5kljCi+r6mytFlZxlUOqyXFbtiUdmoXNg5qtcj86y4
VJ6MnekpFsSFNFMmpOfOpsPi9El9G2ruqz2JP+az2ttrszxQTc9f5dj/n7Kw
s9nMJ5mNzC/zqPTQ5fTe9eRqVlpqXzIDjmbiwZn1uee6nubOisOBvgnFPDrz
qg/IZ5K7kw3yU7FUNaznDguaq6reYU36WWWBZlxpqTrFi7JMWVDmzCs721l3
WJIM73H/sfwAddtQFA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 988->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsXkmuIN9ADBK8QTzCCrgJCXIg7j67BEEJZ768HxIHOkHT1
6++9qtw8ve5ersYYb5vvj93y/nA4LB+P18cvz8v+/m5/3Lw9rTE+t+P8/g+L
PXXf1XDqXO3LvFh+nZZiWaPJvCCthKXWJ/egu5Cf6qPydizMjzqH/KEcGEs6
o0k/WJ17H6pL9h0Wl48xu3l02o6Xmb7N9ib1OHO2Y+l6xvJieZzfp6VYfp0j
uTssLROZB8f3TO+hxkUu1b+jPcOI6kfDW/lYvxxWpNMygxnt7qosKhuVC7tH
9XpmnhWXypOxMz3FgriQZsqE9BQLypnNWeIz6Ss6k/hjPruzVZvlgWoqf5dj
/T1lYXezmU8ym5lf5lHpocfpvevJ1ey01LlkBhzNxIMz62vvdT2tnRWHA/0n
FPPszKs+IJ9J7k42yE/H0tWwnjssaK66eoc16WeXBZpxpaXqFC/KMmVBmTOv
7G5n32FJMvyL9cPyBdAaT9E=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 989->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk0FqQkEQRAcXwWtIbpAcIOQK5gQ/kKyEgC6CO4+eSETMWFVdNV9ChPGr
01PzqrpdvX6s3xettd3y+209fT5vt9P+5e745W3aPD5sjpv3p9Xa4amdn/9h
qVe/72o4da72ZV4qP6RVsczRVF6YVsLS1yf3sLuYn95Hz4tYlJ/qHPPHclAs
6Ywm/VB17n2sLtl3WFw+xezmgbQdLyN9G+1N6nHkLGJBPVN5qTzOz9OqWK7O
idwdFsh0g3lIe680oH/AOcKA9p1Mf302MndyuKxNetmzoLt6liqbKhd2FuVy
i3muuKo8FbvSq1gYF9NMmZieO5sOS7WQz6Sv7EziT/lEZ3ttlQer6flRjv3v
KYu6W818ktnI/CqPlR57Ob13PbmaSKs6l8yAo5l4cGZ97r2up7mz4nCw/0TF
PDrzVR+YzyR3JxvmB7GgGtVzh4XNFap3WJN+oizYjFdaVV3Fy7JMWVjmyqu6
29l3WJIM/2L9sHwBgcBRzw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 990->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk1EKAjEQQ4sf4jXEG+gBxCvoCVbQrwVBP8Q/j66iLFImmaQLolB17TR9
yYzz/Wl7nJRSLrPn27a7bs7n7rabvh4OXb9a9q/NxWeVcl+X4fMfFnvV+6qG
Uqdqf+fF8ou0MpYxmswL0nJY6nrnHnQX8lP7qHkjFuYnO4f8oRwYizujTj9Y
nXofqnP2FRaVjzGreUTaipeWvrX2xvXYcjZiiXrG8mJ5KF4jPcSCtBALYnL8
Ie5sX+lJxOFotzCi+rrGyVxlRTqsl8M5cRaVDLNc2D3Dd6HniMnpJ6pHrOhZ
7TObzUzTZUJ6zmxmLNmKfDp9RWccf8xndLbWZnmgmpo/yrH+3WVhd7OZdzJr
mV/mMdNDL6X3qidVM9LKzjkzoGg6HpRZH3uv6mnsrCgc6D+RMbfOfNYH5NPJ
XckG+YlYohrWc4UFzVVUr7A6/YyyQDOeaWV1GS/K0mVBmTOv7G5lX2FxMvzF
erM8AJ5tURQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 991->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhZssxGtIbmAOILmCOcEEdCUEdCHZefREEkJs6v31gDgwjtrV
r7/3qmb1/rHdP7XWTsvvj+10fj0ep8+3xfXHbjq8rA/Xxeffu7XLpv09H+Fm
V7/uajh1rvb/vFh+lZZimaPJvCCthKWvT85BZyE/vY+et2JhftQ+5A/lwFjS
GU36werc81Bdsu6wuHyM2c2j0na8jPRttDepx5G9FUvVM5YXy6PSUfPGWJBH
xIKYEn+IWa07PUH5uNojjKi+r0kyd1mRDuvlzXcxd6zvSS5or/I4Os+KS+XJ
2JmeYkFcSDNlQnrJbCoWp0/q3VBzX+1J/DGf1d5em+WBanr+Ksf+/5SFnc1m
PslsZH6ZR6WHLqf3ridXs9JS+5IZcDQTD86szz3X9TR3VhwO9E4o5tGZV31A
PpPcnWyQn4qlqmE9d1jQXFX1DmvSzyoLNONKS9UpXpRlyoIyZ17Z2c66w5Jk
eI/7h+UL/9pRlA==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 992->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhRsX4jXEG+gBxCvEE4ygq4AQF5Jdjp4ENUhR768HxIFOmHT1
6++9qty+vG/ersYYHzenj83y+bTbLfvn6/PL67J9uN+eN+++1xiHx3H5/g+L
PXXf1XDqXO3febH8Oi3FskaTeUFaCUutT+5BdyE/1Ufl7ViYH3UO+UM5MJZ0
RpN+sDr3PlSX7DssLh9jdvPotB0vM32b7U3qEc5syNL1jOXF8mh1xLwxFugR
sCAm9u72Vu07/ezySbRnGFF9ranzg/JhmqgfSS8v535Wc1dlUdmoXNDZLhfV
G2eeFZfKk7EzPcWCuJBmyoT03Nl0WNTqfCZ9RWcSf8xnd7ZqszxQTeXvcqy/
pyzsbjbzSWYz88s8Kj30OL13PbmanZY6l8yAo5l4cGZ97b2up7Wz4nCg/4Ri
np151QfkM8ndyQb56Vi6GtZzhwXNVVfvsCb97LJAM660VJ3iRVmmLChz5pXd
7ew7LEmGf7G+WI6huU5V
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 993->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhZssJNcIuYEeQHIFc4IJxJUgmEXILkdXMQRp6/31gDjQinb1
6++9qnn52G+2T621r+fTx2b6fjscpp/3xfnH57RbLXfnzde/1drvuv1/P8Ji
T7/vajh1rvZ1Xiy/SkuxzNFkXpBWwtLXJ/egu5Cf3kfPW7EwP+oc8odyYCzp
jCb9YHXufagu2XdYXD7G7OZRaTteRvo22pvUI5vZhKXqGcuL5XGjs74sNY+I
hXlEvm+YrtboPKS9ZxrIv6M9wuhkqvYRr5NBpcN6WbErFpWNyoXdo3o9Ms+K
S+XJ2JmeYkFcSDNlQnrJbCoWp0/q3VBzX51J/DGf1dlem+WBanr+Ksf+/5SF
3c1mPslsZH6ZR6WHHqf3ridXs9JS55IZcDQTD86sz73X9TR3VhwO9E4o5tGZ
V31APpPcnWyQn4qlqmE9d1jQXFX1DmvSzyoLNONKS9UpXpRlyoIyZ17Z3c6+
w5JkeI91YTkC/Z1QUw==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 994->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KQ0EQhAcX4jXEG+gBgleIJ3iCrgJCsgjuPLqGqISm628eiIFJSF5P
9VfVndvnt+3r1RjjcPP1tl2Oj/v98v50ffrysuwe7nenh3ffZ4yPzfj9/A+H
vepzV8Opc7Uv82L5dVqKZY0m84K0EpZan/RBvZCf6qPydizMj7qH/KEcGEu6
o8k8WJ3bD9Ulzx0Wl48xu3l02o6XmbnNzib1CL1uzsdl6WbG8mJ5pCz1Hsvd
YWmZCoPy1/VPZ081fpiKf0d7hpFlOhreSyY2L4cV6bBZduyKRWWjcmF91Kxn
9llxqTwZO9NTLIgLaaZMSE+xOPvC9JTPZK7oTuKP+ezuVm2WB6qp/F2O9feU
hfVmO59kNrO/zKPSQy9n9q4nV7PTUveSHXA0Ew/Orq/t63pauysOB/pPKObZ
nVdzQD6T3J1skJ+OpathM3dY0F519Q5rMs8uC7TjSkvVKV6UZcqCMmdeWW/n
ucOSZPgX58zyCeijTZQ=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 995->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KA0EQhZssxGuIN9ADhFwhnmAEXQWEZBGy8+gxRGTs1PvrATHQ+evq
1997VfPw+rF9X7XWDvdfb9vpuNnvp9PL3eXH27R7ftpdNh+/V2uf6/bz+R8W
e/X7roZT52rP82L5VVqKZYkm84K0Epa+PrkH3YX89D563oqF+VHnkD+UA2NJ
ZzTpB6tz70N1yb7D4vIxZjePStvxMtK30d6kHhN9Vlv1jOXF8rjRWV+XmkfE
gnwhlpIJzUPYW7Xv9HN+7w2j2b+U0cn013cjcyeHeW3Sy4pdsahsVC7sHtXr
kXlWXCpPxs70FAviQpopE9JzZ9Nhcfqkng0199WZxB/zWZ3ttVkeqKbnr3Ls
/09Z2N1s5pPMRuaXeVR66OX03vXkalZa6lwyA45m4sGZ9aX3up6WzorDgZ4J
xTw686oPyGeSu5MN8lOxVDWs5w4Lmquq3mFN+lllgWZcaak6xYuyTFlQ5swr
u9vZd1iSDP9iXVnOZs5QUQ==
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 996->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01KQ0EQhAcXkmuIN9ADBK8QT/AEswoIcSHuPLoGg2jb9TcPxMDkb3pq
vqrud/XwtNtfjDGeNx9vu+Xl7nhcXu8vTz8el8PtzeG0eX1eY7xtx9fnf1js
VfddDafO1f6eF8uv01IsazSZF6SVsNT65B50F/JTfVTejoX5UeeQP5QDY0ln
NOkHq3PvQ3XJvsPi8jFmN49O2/Ey07fZ3qQeW/3zSli6nrG8WB6/dARLPcdy
d1haJsBV2ZDvmd5TjaoXaM8wOpl23+uZH5marEiH9bJjVywqG5ULu0f1emae
FZfKk7EzPcWCuJBmyoT03Nl0WJw+qWdDzX13JvHHfHZnqzbLA9VU/i7H+n/K
wu5mM59kNjO/zKPSQy+n964nV7PTUueSGXA0Ew/OrK+91/W0dlYcDvRMKObZ
mVd9QD6T3J1skJ+OpathPXdY0Fx19Q5r0s8uCzTjSkvVKV6UZcqCMmde2d3O
vsOSZPgX65PlHQz7T5I=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 997->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qQkEQhAcXIdeQ3CAeIHgFc4IXiCtB0IW48+hGIiJD/fU8CBGeotNT
/VV1u/zab7aL1trx9edtM53Wh8N0/ny5ffmedqv33e3w7f60dvloj8//8KhX
f55qJHWp9nNeKj+k5VjmaCovTKvC0tdX+rBezE/vo+dFLMqPu8f8sRwUS3VH
K/NQdWk/Vlc5T1hSPsWc5oG0Ey8jcxudTdXjyF3Egmam8lJ5IB23b4qFeWQs
jAn6K87WnSczee6LGJ32CCOr72tQjmpeCSvTUbNE7I7FZeNyUX3crEf22XG5
PBW70nMsjItpVpmYXrqbCUsyJ/ffcHuP7lT8KZ/obq+t8mA1PT/Ksf+9yqJ6
q52vZDayv8qj02OvZPapp1QTabl7lR1INCsekl2f2zf1NHdXEg72n3DMozvv
5sB8VnJPsmF+EAuqUTNPWNheofqEtTJPlAXbcafl6hwvy7LKwjJXXlXv5Dxh
qWT4F88vyxUjZFBV
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 998->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qQkEQhAcXkmuE3CAeIHgFPcEL6EoImEVwl6OrRIJM6q/nQVAY/2am
+qvqfs/vH5v9orX2+XR520xf6+NxOm2X1x+76bB6PVw3X26rte+39vv5CEu9
+v1UIzmXat/npfJDWo5ljqbywrQqLP35Sh1Wi/npffS8iEX5cfeYP5aDYqnO
aKUf6lxaj52r7CcsKZ9iTvNA2omXkb6N9qbqkc7sbaUsqGcqL5UH1CFM6J7K
PWFhTH+4SDasfrX3SoP5T7RHGJNM0ff+jspUeUU6qpeI3bG4bFwuqo7r9cg8
Oy6Xp2JXeo6FcTHNKhPTS2czYUn65J4NN/foTsWf8onu9toqD3am50c59v9X
WVRtNfOVzEbmV3l0euyV9D71lGoiLXevMgOJZsVDMutz66ae5s5KwsGeCcc8
OvOuD8xnJfckG+YHsaAzqucJC5srdD5hrfQTZcFm3Gm5c46XZVllYZkrr6p2
sp+wVDL8j/XDcgZ6SU8U
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 999->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhRsXwWuINzAHCLmCOcEIyUoI6CK48+gqEQlNvb8ekAyMo3b1
6++9qlntvrdfi9bacXn92E4/74fDdPp4uf34nPavm/1tcX2/Wzu/tcfzP9zs
6tddDafO1f6bF8uv0lIsczSZF6SVsPT1yTnoLOSn99HzVizMj9qH/KEcGEs6
o0k/WJ17HqpL1h0Wl48xu3lU2o6Xkb6N9ib1qGbWZal6xvJieSAdlTFiSTz2
Gsyfmv+RdaefVT6J9gijk2n1vcoXZcq8VjqslxW7YlHZqFzYOarXI/OsuFSe
jJ3pKRbEhTRTJqTnzqbD4vRJvRtq7qs9iT/ms9rba7M8UE3PX+XY/5+ysLPZ
zCeZjcwv86j00OX03vXkalZaal8yA45m4sGZ9bnnup7mzorDgd4JxTw686oP
yGeSu5MN8lOxVDWs5w4Lmquq3mFN+lllgWZcaak6xYuyTFlQ5swrO9tZd1iS
DJ9x/7JcABvlTxg=
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False], 1000->
                FrameBox[
                 GraphicsBox[
                  TagBox[RasterBox[CompressedData["
1:eJzNk01qAkEQhRsXwWuINzAHCLmCOcEIyUoI6CK48+gqEQnN+6sekAjjX9e8
+t6rmtXue/u1aK0dl9e37fTzfjhMp4+X24/Paf+62d8O1/ertfNbe3z+h0u9
+vNUI6lLtf/mpfJDWo5ljqbywrQqLH19pQ/rxfz0PnpexKL8uPuYP5aDYqnu
aGUeqi7tx+oq5wlLyqeY0zyQduJlZG6js6l6THY2YUEzU3mpXkgnmTdjcR5R
DWJCvquzdefJPFU+ifYIY5Ip+o7yZZkqr0hHzRKxO5Zk71Uuqo+b9cg+Oy6X
p2JXeo6FcTHNKhPTS3czYUnm5J4Nt/fonoo/5RPd22urPFhNz49y7P+vsqje
aucrmY3sr/Lo9NgrmX3qKdVEWu6+yg4kmhUPya7P7Zt6mrsrCQd7Jhzz6M67
OTCfldyTbJgfxIJq1MwTFrZXqD5hrcwTZcF23Gm5OsfLsqyysMyVV9U7OU9Y
Khk+4/pluQC2Xk8Y
                    "], {{0, 35}, {35, 0}}, {0., 1.},
                    ColorFunction->GrayLevel],
                   BoxForm`ImageTag[
                   "Real32", ColorSpace -> Automatic, Interleaving -> None],
                   Selectable->False],
                  DefaultBaseStyle->"ImageGraphics",
                  ImageSize->Small,
                  ImageSizeRaw->{35, 35},
                  PlotRange->{{0, 35}, {0, 35}}],
                 StripOnInput->False]}, Dynamic[$CellContext`i30$$],
                Alignment->Automatic,
                BaseStyle->"ListAnimateCore",
                ImageSize->All,
                TransitionDirection->Horizontal,
                TransitionDuration->0.5,
                TransitionEffect->Automatic],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
        GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}}], If[
        And[
         CurrentValue["NotebookSelected"], 
         CurrentValue["SelectionOver"]], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i30$$, \
$CellContext`i30$46967524$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 1000, 1}, 1000, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{309., {122.884033203125, 128.615966796875}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.773609388138578*^9},
 CellLabel->
  "Out[321]=",ExpressionUUID->"ed0fd453-bb30-411c-b8cf-3646a2c72632"]
}, Open  ]],

Cell["\<\
From these movies, it\[CloseCurlyQuote]s easy to see that if a stable \
solution were to be perturbed by \[OpenCurlyDoubleQuote]damaging\
\[CloseCurlyDoubleQuote] some pixels (i.e. flipping their values), the \
WalkSATCRN would immediately get to work re-establishing connectivity.  It \
would be extraordinary unlikely for the original solution to be \
re-established, but a new solution will be found that might not change \
unaffected areas by much.  This is reminiscent of a self-healing activity, \
and it is intrinsic to patterns established by satisfiability constraints.\
\>", "Text",
 CellChangeTimes->{{3.683224502613168*^9, 3.683224542566287*^9}, {
   3.683224585063489*^9, 3.683224600759535*^9}, {3.6832246471913033`*^9, 
   3.683224704354827*^9}, {3.683224754384179*^9, 3.683224766384227*^9}, {
   3.683225703380989*^9, 3.68322570424437*^9}, {3.683225939963592*^9, 
   3.683225948099937*^9}, {3.683227667006626*^9, 3.68322767610086*^9}, {
   3.68322884914076*^9, 3.683228851796751*^9}, 3.683230612502606*^9, {
   3.773607579983191*^9, 3.7736076317337008`*^9}, {3.773607670465179*^9, 
   3.77360773654235*^9}, {3.773607773858426*^9, 3.773607875131447*^9}, {
   3.773607951899206*^9, 3.773607972609044*^9}, {3.773609142389237*^9, 
   3.773609305323983*^9}},
 Background->RGBColor[
  1, 0.9, 0.8],ExpressionUUID->"e82d1541-0338-4869-a8c9-7cc5dda47e59"]
}, Open  ]]
},
WindowSize->{1046, 947},
WindowMargins->{{Automatic, 38}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1199, 18, 120, "Text",ExpressionUUID->"07a9c1e2-ad94-4f25-ab88-8408d0d895bb"],
Cell[CellGroupData[{
Cell[1782, 42, 338, 5, 67, "Section",ExpressionUUID->"4a485d40-6bec-460b-a8fe-c11fd994f9c1"],
Cell[2123, 49, 2476, 37, 396, "Text",ExpressionUUID->"ae684848-15bf-40b4-bb80-08c2ccece031"],
Cell[4602, 88, 2877, 68, 173, "Input",ExpressionUUID->"b07be64a-a142-4f4e-a769-58c20b03ad13",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[7504, 160, 618, 10, 30, "Input",ExpressionUUID->"8d653884-393b-45fe-9fce-bb385e0d927b"],
Cell[8125, 172, 1049, 33, 56, "Output",ExpressionUUID->"f1f420bf-e89d-4b57-a13a-8ba2efd8c83d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9211, 210, 263, 4, 30, "Input",ExpressionUUID->"900e5f6f-9b54-4998-8e2b-efdf2d4ad3d6"],
Cell[9477, 216, 339, 5, 34, "Output",ExpressionUUID->"fed2eef6-25b6-4c45-901a-be33dfa2ff34"]
}, Open  ]],
Cell[9831, 224, 295, 6, 51, "Text",ExpressionUUID->"51de36eb-1ea3-4699-acdf-d3b090672476"],
Cell[10129, 232, 900, 24, 68, "Input",ExpressionUUID->"47fa993e-aa3d-4ae7-8c00-358f926f08b9",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[11054, 260, 221, 3, 30, "Input",ExpressionUUID->"31330635-9988-45f4-9628-f11378ea9095"],
Cell[11278, 265, 519, 10, 34, "Output",ExpressionUUID->"990d5dd9-de01-465c-b122-9490ef746297"]
}, Open  ]],
Cell[11812, 278, 1232, 29, 73, "Input",ExpressionUUID->"5c67d52e-6f10-498f-b591-978745ebec09"],
Cell[CellGroupData[{
Cell[13069, 311, 438, 7, 30, "Input",ExpressionUUID->"3f0e9785-b05e-427d-86ca-d2944ce22bcb"],
Cell[CellGroupData[{
Cell[13532, 322, 286, 7, 24, "Print",ExpressionUUID->"644df2e6-d6f3-4308-b11b-392a136d8e86"],
Cell[13821, 331, 287, 7, 24, "Print",ExpressionUUID->"95d4c9e6-9c0a-4577-b3c7-8f1ea6143104"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14169, 345, 227, 4, 67, "Section",ExpressionUUID->"97e060b4-fa6f-4252-817c-614ae7f5d133"],
Cell[14399, 351, 1978, 30, 281, "Text",ExpressionUUID->"0c500a1b-c2f1-41b2-bb15-6e5aa100191b"],
Cell[16380, 383, 2903, 59, 89, "Input",ExpressionUUID->"01a2480c-8721-427b-8bb8-16ce2be3462d",
 InitializationCell->True],
Cell[19286, 444, 4936, 120, 320, "Input",ExpressionUUID->"1648ca59-5466-45f4-9161-3aec6bb30216",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[24247, 568, 2287, 69, 157, "Input",ExpressionUUID->"3ff80e14-b438-461d-a18d-2f302615376f"],
Cell[26537, 639, 2182, 61, 49, "Output",ExpressionUUID->"46d558ee-7733-4434-aa19-281b5f4af3fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28756, 705, 382, 8, 30, "Input",ExpressionUUID->"b5302d73-a853-4e09-bd70-e656e061d147"],
Cell[29141, 715, 9829, 303, 707, "Output",ExpressionUUID->"fad495e7-67fd-4bb1-966b-5746cdf0c269"]
}, Closed]],
Cell[CellGroupData[{
Cell[39007, 1023, 219, 4, 26, "Input",ExpressionUUID->"c94a3878-3ada-4f51-a65d-e08e71cda07b"],
Cell[39229, 1029, 207, 4, 34, "Output",ExpressionUUID->"8d7eb4e2-993b-46b8-b946-414bd58ecc81"]
}, Open  ]],
Cell[39451, 1036, 464, 8, 74, "Text",ExpressionUUID->"7e2749be-e465-49e1-abc7-6e0a6ba08d6d"],
Cell[CellGroupData[{
Cell[39940, 1048, 226, 4, 30, "Input",ExpressionUUID->"baddc9f9-dd53-4dfd-bb73-f0f86b0b2395"],
Cell[40169, 1054, 256, 5, 34, "Output",ExpressionUUID->"02e3fc16-7700-4ae8-8bd7-12ab15425e6d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40462, 1064, 243, 5, 30, "Input",ExpressionUUID->"47a0a090-a485-485a-980b-814461003014"],
Cell[40708, 1071, 710, 16, 56, "Output",ExpressionUUID->"5cfb52cb-5902-4a0e-a07c-158383e40898"]
}, Open  ]],
Cell[41433, 1090, 4971, 111, 299, "Input",ExpressionUUID->"6a0c4008-e604-4e6b-9110-ad3c1ee50698",
 InitializationCell->True],
Cell[46407, 1203, 155, 3, 30, "Input",ExpressionUUID->"f5599664-c7ab-4f58-86c2-080953d8b0fc"],
Cell[CellGroupData[{
Cell[46587, 1210, 268, 5, 30, "Input",ExpressionUUID->"86c870f9-2009-48ea-8a28-a852b5c4adc5"],
Cell[46858, 1217, 707, 20, 129, "Output",ExpressionUUID->"e968db83-9280-4b27-9179-bc264b859458"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47602, 1242, 361, 8, 30, "Input",ExpressionUUID->"edddfbfd-a65f-4daa-b341-b229a00ec883"],
Cell[47966, 1252, 1086, 27, 77, "Output",ExpressionUUID->"b8e8197e-9f35-474c-afbb-32515fd4a570"]
}, Open  ]],
Cell[49067, 1282, 382, 7, 51, "Text",ExpressionUUID->"06c2b59a-9512-4211-98da-eec8708e0160"],
Cell[49452, 1291, 971, 24, 68, "Input",ExpressionUUID->"3bbf5390-a180-45b5-8808-06dd2e704ce1",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[50448, 1319, 298, 6, 30, "Input",ExpressionUUID->"2a25765c-33d8-4e9c-9fa9-d57647ab9115"],
Cell[50749, 1327, 2627, 82, 129, "Output",ExpressionUUID->"3a954e1b-c6af-4874-a5f2-4d194085f417"]
}, Open  ]],
Cell[53391, 1412, 288, 4, 51, "Text",ExpressionUUID->"88983f03-a27a-4ab4-ba5d-d19d29824552"],
Cell[CellGroupData[{
Cell[53704, 1420, 2739, 78, 178, "Input",ExpressionUUID->"ed1f1403-78f5-480a-82cc-b899f9ea306c"],
Cell[56446, 1500, 50761, 873, 64, "Output",ExpressionUUID->"4f7ca0b7-6701-4fbe-b552-1682b6566be9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[107244, 2378, 3582, 108, 178, "Input",ExpressionUUID->"82dde36e-6e2a-4dbd-a008-3135d0d37213"],
Cell[110829, 2488, 3624, 101, 432, "Output",ExpressionUUID->"44d76937-7802-4626-81fa-94259027c597"]
}, Open  ]],
Cell[114468, 2592, 404, 10, 30, "Input",ExpressionUUID->"7207e662-6e6d-416b-b69a-654e9b391112"],
Cell[114875, 2604, 602, 12, 30, "Input",ExpressionUUID->"6cf1fbe4-47ea-4935-9f05-9b43e5ba077a"],
Cell[CellGroupData[{
Cell[115502, 2620, 342, 8, 30, "Input",ExpressionUUID->"83be6c81-6a06-486e-9634-7cf1cc3d2856"],
Cell[115847, 2630, 175, 3, 34, "Output",ExpressionUUID->"dde3ccc8-3dcc-4cf4-90e2-469702b90d22"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116059, 2638, 267, 5, 30, "Input",ExpressionUUID->"f1cef060-00cc-4028-b373-611e8f722c95"],
Cell[116329, 2645, 246, 4, 34, "Output",ExpressionUUID->"afe01d04-8c86-4a7d-87c9-7a42bf977d69"]
}, Open  ]],
Cell[116590, 2652, 354, 7, 51, "Text",ExpressionUUID->"413fc386-2e9c-4e11-b644-67c4cf900a53"],
Cell[CellGroupData[{
Cell[116969, 2663, 373, 6, 30, "Input",ExpressionUUID->"578928a8-ad06-448f-bb44-a9efe86086a6"],
Cell[117345, 2671, 230, 4, 34, "Output",ExpressionUUID->"809c5c27-f35d-4532-9eca-12aa673d5a75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117612, 2680, 447, 8, 30, "Input",ExpressionUUID->"c09d2bf0-3179-4cab-a446-ecbade163063"],
Cell[118062, 2690, 211, 4, 34, "Output",ExpressionUUID->"21f0e612-af21-478e-ba36-aeae41ffecc3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118310, 2699, 642, 14, 30, "Input",ExpressionUUID->"b1e26919-9068-416b-af36-9dbac759f535"],
Cell[118955, 2715, 11737, 327, 405, "Output",ExpressionUUID->"d0adfe25-9c7a-4211-84a0-0d5fac4473ba"]
}, Open  ]],
Cell[130707, 3045, 892, 14, 97, "Text",ExpressionUUID->"70a4529b-39a7-4c8c-9809-343bb89031f8"],
Cell[CellGroupData[{
Cell[131624, 3063, 471, 12, 30, "Input",ExpressionUUID->"f0b49837-be5d-4f57-a7a4-1ee06b826288"],
Cell[132098, 3077, 602, 11, 34, "Output",ExpressionUUID->"4b50a2f9-bef6-492c-a6c8-caa111c4ec06"]
}, Open  ]],
Cell[132715, 3091, 1284, 21, 212, "Text",ExpressionUUID->"f88412fc-bed1-4e08-9200-04a50c6c9c73"],
Cell[134002, 3114, 664, 18, 46, "Input",ExpressionUUID->"3c4411fd-8029-4b93-8a6f-96d7f0316322",
 InitializationCell->True],
Cell[134669, 3134, 6750, 149, 404, "Input",ExpressionUUID->"6a419f7c-acf9-41fe-8f90-1c116e19e80d",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[141444, 3287, 319, 7, 30, "Input",ExpressionUUID->"43acb53e-a427-465e-b281-11a39b9e3a9f"],
Cell[141766, 3296, 834738, 18002, 203, "Output",ExpressionUUID->"30a8cd2c-377e-4355-9c82-8bd1d5f1efd7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[976541, 21303, 460, 12, 30, "Input",ExpressionUUID->"d61886b3-b88a-4a57-9ede-6fb752ceb58a"],
Cell[977004, 21317, 551, 14, 117, "Output",ExpressionUUID->"7ad8f294-58ef-4e51-a1d3-94bca1dd5a56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[977592, 21336, 1229, 25, 115, "Input",ExpressionUUID->"512aa3c8-1a45-42ee-8273-d8df241fd9e5"],
Cell[978824, 21363, 918151, 19300, 203, "Output",ExpressionUUID->"cc96ea53-dfdd-4312-8911-d8aed4ff72d2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1897012, 40668, 2067, 40, 220, "Input",ExpressionUUID->"d3aff378-15a6-4ee3-814a-42317477d0d5"],
Cell[1899082, 40710, 1001228, 20715, 203, "Output",ExpressionUUID->"d6f32b8c-f03b-473d-bd6d-d956f6e66682"]
}, Open  ]],
Cell[2900325, 61428, 937, 17, 143, "Text",ExpressionUUID->"ed0eec3d-4abb-49d7-b2da-1728d0115feb"],
Cell[2901265, 61447, 1226, 36, 89, "Input",ExpressionUUID->"a605416d-ae15-4f57-b23a-da11e923bee3",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[2902516, 61487, 252, 5, 30, "Input",ExpressionUUID->"c9129179-4d33-4cc9-a339-6462da5b3948"],
Cell[2902771, 61494, 660, 15, 34, "Output",ExpressionUUID->"4bbfa6fa-01fb-4fac-a726-9226e1f19b8c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2903468, 61514, 805, 17, 52, "Input",ExpressionUUID->"2bf74d38-c063-4f70-9106-74fe4dd702cf"],
Cell[2904276, 61533, 868100, 18616, 203, "Output",ExpressionUUID->"7efeed36-cab7-4705-85a3-a128f64c9e6b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3772425, 80155, 262, 4, 67, "Section",ExpressionUUID->"2dd66fc1-dd27-43b9-8a4f-8e36ee97a6b4"],
Cell[3772690, 80161, 1835, 27, 189, "Text",ExpressionUUID->"01ec5b9b-42b6-4115-8819-6bac339afe89"],
Cell[3774528, 80190, 6991, 178, 383, "Input",ExpressionUUID->"91ad4aa3-f839-4517-93d1-a79b4f9cd7be",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[3781544, 80372, 534, 10, 30, "Input",ExpressionUUID->"8c598de3-b3c0-4e8e-ba22-341c0c4dd13b"],
Cell[3782081, 80384, 17654, 528, 1085, "Output",ExpressionUUID->"2f322b1d-4d08-4bdd-8427-91a6e4e453b4"]
}, Closed]],
Cell[CellGroupData[{
Cell[3799772, 80917, 522, 10, 26, "Input",ExpressionUUID->"85463176-d96d-4dda-8514-fb0bb8e8ed81"],
Cell[3800297, 80929, 8520, 229, 267, "Output",ExpressionUUID->"61435ffb-639a-4581-a8b2-f09c53a01ccf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3808854, 81163, 502, 10, 30, "Input",ExpressionUUID->"d0229289-220e-4315-8530-21b788c3183c"],
Cell[3809359, 81175, 367, 6, 34, "Output",ExpressionUUID->"fb410bb9-bf40-4152-b0ad-5e25ded48b79"]
}, Open  ]],
Cell[3809741, 81184, 606, 12, 30, "Input",ExpressionUUID->"fc7aed5c-643c-497f-b387-d5070c6c1738"],
Cell[CellGroupData[{
Cell[3810372, 81200, 502, 10, 30, "Input",ExpressionUUID->"617d67ae-24ba-46c8-afde-06185424c335"],
Cell[3810877, 81212, 155, 3, 34, "Output",ExpressionUUID->"d70f3433-771e-49af-b542-3e879e627163"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3811069, 81220, 221, 4, 30, "Input",ExpressionUUID->"504cf3f4-27df-4f9d-9d1a-a200487b925f"],
Cell[3811293, 81226, 725, 20, 129, "Output",ExpressionUUID->"8f0daf41-6396-4a2e-8dc6-f6ba8c1af1b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3812055, 81251, 573, 12, 30, "Input",ExpressionUUID->"9db32e0c-2e23-46de-abe4-563faafd6d9b"],
Cell[3812631, 81265, 6503, 179, 267, "Output",ExpressionUUID->"44c4759f-7d44-4791-b050-ca33450db3a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3819171, 81449, 268, 6, 30, "Input",ExpressionUUID->"0cbaae70-1efa-4b18-a33b-b96e849cbccf"],
Cell[3819442, 81457, 822612, 17861, 203, "Output",ExpressionUUID->"329ae6ae-909f-49c7-90a9-607b7bd0f3b6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4642091, 99323, 394, 10, 30, "Input",ExpressionUUID->"f2a005ea-d507-4765-ab72-0285222c9a4c"],
Cell[4642488, 99335, 1167014, 23480, 283, "Output",ExpressionUUID->"ed0fd453-bb30-411c-b8cf-3646a2c72632"]
}, Open  ]],
Cell[5809517, 122818, 1372, 21, 120, "Text",ExpressionUUID->"e82d1541-0338-4869-a8c9-7cc5dda47e59"]
}, Open  ]]
}
]
*)

